-
- All Known Subinterfaces:
BooleanArrayAccessor.BooleanArrayProperty
public interface BooleanArrayAccessorProvides an accessor for a boolean array property.
-
-
Nested Class Summary
Nested Classes Modifier and Type Interface Description static interfaceBooleanArrayAccessor.BooleanArrayBuilder<B extends BooleanArrayAccessor.BooleanArrayBuilder<B>>Provides a builder method for a boolean array property returning the builder for applying multiple build operations.static interfaceBooleanArrayAccessor.BooleanArrayMutatorProvides a mutator for a boolean array property.static interfaceBooleanArrayAccessor.BooleanArrayPropertyProvides a boolean array property.
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description boolean[]getBooleans()Retrieves the boolean array from the boolean array property.
-