Module org.refcodes.struct
Package org.refcodes.struct
Interface BooleanArrayAccessor.BooleanArrayMutator
-
- All Known Subinterfaces:
BooleanArrayAccessor.BooleanArrayProperty
- Enclosing interface:
- BooleanArrayAccessor
public static interface BooleanArrayAccessor.BooleanArrayMutatorProvides a mutator for a boolean array property.
-
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description voidsetBooleans(boolean[] aBooleans)Sets the boolean array for the boolean array property.
-