-
- All Known Subinterfaces:
ByteArrayAccessor.ByteArrayProperty
public interface ByteArrayAccessorProvides an accessor for a byte array property.
-
-
Nested Class Summary
Nested Classes Modifier and Type Interface Description static interfaceByteArrayAccessor.ByteArrayBuilder<B extends ByteArrayAccessor.ByteArrayBuilder<B>>Provides a builder method for a byte array property returning the builder for applying multiple build operations.static interfaceByteArrayAccessor.ByteArrayMutatorProvides a mutator for a byte array property.static interfaceByteArrayAccessor.ByteArrayPropertyProvides a byte array property.
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description byte[]getBytes()Retrieves the byte array from the byte array property.
-