-
- All Known Subinterfaces:
ByteArrayAccessor.ByteArrayProperty
- Enclosing interface:
- ByteArrayAccessor
public static interface ByteArrayAccessor.ByteArrayMutatorProvides a mutator for a byte array property.
-
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description voidsetBytes(byte[] aBytes)Sets the byte array for the byte array property.
-