-
- All Superinterfaces:
org.refcodes.mixin.AnnotatorAccessor,CanonicalMap,org.refcodes.mixin.Clearable,Containable,org.refcodes.mixin.DelimiterAccessor,Dictionary<String,String>,Dictionary.MutableDictionary<String,String>,org.refcodes.mixin.Dumpable,org.refcodes.mixin.EmptyAccessor,InterOperableMap<String>,InterOperableMap.MutableInterOperableMap<String>,Keys<String,String>,Keys.MutableKeys<String,String>,Keys.MutableValues<String,String>,Map<String,String>,PathMap<String>,PathMap.MutablePathMap<String>,org.refcodes.mixin.TypeAccessor<String>
- All Known Subinterfaces:
CanonicalMap.CanonicalMapBuilder
- All Known Implementing Classes:
CanonicalMapBuilderImpl
- Enclosing interface:
- CanonicalMap
public static interface CanonicalMap.MutableCanonicalMap extends CanonicalMap, InterOperableMap.MutableInterOperableMap<String>, Map<String,String>
The Interface MutableCanonicalMap.
-
-
Nested Class Summary
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.AnnotatorAccessor
org.refcodes.mixin.AnnotatorAccessor.AnnotatorBuilder<B extends org.refcodes.mixin.AnnotatorAccessor.AnnotatorBuilder<B>>, org.refcodes.mixin.AnnotatorAccessor.AnnotatorMutator, org.refcodes.mixin.AnnotatorAccessor.AnnotatorProperty
-
Nested classes/interfaces inherited from interface org.refcodes.struct.CanonicalMap
CanonicalMap.CanonicalMapBuilder, CanonicalMap.MutableCanonicalMap
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.DelimiterAccessor
org.refcodes.mixin.DelimiterAccessor.DelimiterBuilder<B extends org.refcodes.mixin.DelimiterAccessor.DelimiterBuilder<B>>, org.refcodes.mixin.DelimiterAccessor.DelimiterMutator, org.refcodes.mixin.DelimiterAccessor.DelimiterProperty
-
Nested classes/interfaces inherited from interface org.refcodes.struct.Dictionary
Dictionary.MutableDictionary<K,V>
-
Nested classes/interfaces inherited from interface org.refcodes.struct.Dictionary.MutableDictionary
Dictionary.MutableDictionary.DictionaryBuilder<K,V,B extends Dictionary.MutableDictionary.DictionaryBuilder<K,V,B>>
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.EmptyAccessor
org.refcodes.mixin.EmptyAccessor.EmptyMutator, org.refcodes.mixin.EmptyAccessor.EmptyProperty
-
Nested classes/interfaces inherited from interface org.refcodes.struct.InterOperableMap
InterOperableMap.InterOperableMapBuilder<T>, InterOperableMap.MutableInterOperableMap<T>
-
Nested classes/interfaces inherited from interface org.refcodes.struct.Keys
Keys.MutableKeys<K,V>, Keys.MutableValues<K,V>
-
Nested classes/interfaces inherited from interface java.util.Map
Map.Entry<K extends Object,V extends Object>
-
Nested classes/interfaces inherited from interface org.refcodes.struct.PathMap
PathMap.MutablePathMap<T>, PathMap.PathMapBuilder<T>
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.TypeAccessor
org.refcodes.mixin.TypeAccessor.TypeBuilder<T extends Object,B extends org.refcodes.mixin.TypeAccessor.TypeBuilder<T,B>>, org.refcodes.mixin.TypeAccessor.TypeMutator<T extends Object>, org.refcodes.mixin.TypeAccessor.TypeProperty<T extends Object>
-
-
Method Summary
All Methods Instance Methods Default Methods Modifier and Type Method Description default booleancontainsValue(Object value)This method is defined for the sake ofMapconformity.default voidinsert(CanonicalMap aFrom)Method to semantically emphasize that we support our own types.default voidinsertBetween(String aToPath, CanonicalMap aFrom, String aFromPath)Method to semantically emphasize that we support our own types.default voidinsertFrom(CanonicalMap aFrom, String aFromPath)Method to semantically emphasize that we support our own types.default voidinsertTo(String aToPath, CanonicalMap aFrom)Method to semantically emphasize that we support our own types.default Stringput(Object[] aPathElements, String aValue)Puts the given value into the child's path, relative to the given parent's path.default Stringput(Object aKey, String aValue)Adds the given element related to the given key.default Stringput(String[] aPathElements, String aValue)Puts the given value into the child's path, relative to the given parent's path.default Stringput(Property aProperty)Puts the key/value-pair from the providedProperty.default Stringput(Relation<String,String> aRelation)Adds the given element related to the given key.default voidputAll(Map<? extends String,? extends String> aProperties)default voidputAll(Properties aProperties)This method inserts all elements (key/value-pairs) found in the providedPropertiesinstances of interoperability reasons.default voidputAll(CanonicalMap aProperties)This method inserts all elements (key/value-pairs) found in the providedCanonicalMapinstances of interoperability reasons.default CanonicalMapputDirAt(int aIndex, Object aDir)An indexed directory represents all elements which begin with a path which's last path element represents an index.default CanonicalMapputDirAt(int aIndex, PathMap<String> aDir)An indexed directory represents all elements which begin with a path which's last path element represents an index.default CanonicalMapputDirAt(Object[] aPathElements, int aIndex, Object aDir)An indexed directory represents all elements which begin with a path which's last path element represents an index.default CanonicalMapputDirAt(Object[] aPathElements, int aIndex, PathMap<String> aDir)An indexed directory represents all elements which begin with a path which's last path element represents an index.default CanonicalMapputDirAt(Object aPath, int aIndex, Object aDir)An indexed directory represents all elements which begin with a path which's last path element represents an index.default CanonicalMapputDirAt(Object aPath, int aIndex, PathMap<String> aDir)An indexed directory represents all elements which begin with a path which's last path element represents an index.default CanonicalMapputDirAt(String[] aPathElements, int aIndex, Object aDir)An indexed directory represents all elements which begin with a path which's last path element represents an index.default CanonicalMapputDirAt(String[] aPathElements, int aIndex, PathMap<String> aDir)An indexed directory represents all elements which begin with a path which's last path element represents an index.default CanonicalMapputDirAt(String aPath, int aIndex, Object aDir)An indexed directory represents all elements which begin with a path which's last path element represents an index.default CanonicalMapputDirAt(String aPath, int aIndex, PathMap<String> aDir)An indexed directory represents all elements which begin with a path which's last path element represents an index.default CanonicalMapputDirAt(Collection<?> aPathElements, int aIndex, Object aDir)An indexed directory represents all elements which begin with a path which's last path element represents an index.default CanonicalMapputDirAt(Collection<?> aPathElements, int aIndex, PathMap<String> aDir)An indexed directory represents all elements which begin with a path which's last path element represents an index.default CanonicalMapremoveAll(Object aPathQuery)Removes all elements which's keys match the provided path query.default CanonicalMapremoveAll(Object... aPathQueryElements)Removes all elements which's keys match the provided path query.default CanonicalMapremoveAll(String aPathQuery)Removes all elements which's keys match the provided path query.default CanonicalMapremoveAll(String... aPathQueryElements)Removes all elements which's keys match the provided path query.default CanonicalMapremoveAll(Collection<?> aPathQueryElements)Removes all elements which's keys match the provided path query.default CanonicalMapremoveAll(Pattern aRegExp)Removes all elements which's keys match the provided regular expression: Queries the keys of the instance using the providedPatterndefault CanonicalMapremoveDirAt(int aIndex)An indexed directory represents all elements which begin with a path which's last path element represents an index.default CanonicalMapremoveDirAt(Object[] aPathElements, int aIndex)An indexed directory represents all elements which begin with a path which's last path element represents an index.default CanonicalMapremoveDirAt(Object aPath, int aIndex)An indexed directory represents all elements which begin with a path which's last path element represents an index.default CanonicalMapremoveDirAt(String[] aPathElements, int aIndex)An indexed directory represents all elements which begin with a path which's last path element represents an index.default CanonicalMapremoveDirAt(String aPath, int aIndex)An indexed directory represents all elements which begin with a path which's last path element represents an index.default CanonicalMapremoveFrom(Object aPath)Removes all properties below the provided path and returns thePathMapwith the removed elements, by which the paths exclude the parent's path.default CanonicalMapremoveFrom(Object... aPathElements)Removes all properties below the provided path and returns thePathMapwith the removed elements, by which the paths exclude the parent's path.default CanonicalMapremoveFrom(String aPath)Removes all properties below the provided path and returns thePathMapwith the removed elements, by which the paths exclude the parent's path.default CanonicalMapremoveFrom(String... aPathElements)Removes all properties below the provided path and returns thePathMapwith the removed elements, by which the paths exclude the parent's path.default CanonicalMapremoveFrom(Collection<?> aPathElements)Removes all properties below the provided path and returns thePathMapwith the removed elements, by which the paths exclude the parent's path.default CanonicalMapremovePaths(String... aPaths)Removes the paths contained in the provided collection.default CanonicalMapremovePaths(Collection<?> aPaths)Removes the paths contained in the provided collection.default Map<String,String>toDump(Map<String,String> aDump)-
Methods inherited from interface org.refcodes.struct.CanonicalMap
asArray, asArray, asArray, asArray, asBooleanArray, asBooleanArray, asBooleanArray, asBooleanArray, asByteArray, asByteArray, asByteArray, asByteArray, asCharArray, asCharArray, asCharArray, asCharArray, asDoubleArray, asDoubleArray, asDoubleArray, asDoubleArray, asFloatArray, asFloatArray, asFloatArray, asFloatArray, asIntArray, asIntArray, asIntArray, asIntArray, asLongArray, asLongArray, asLongArray, asLongArray, asShortArray, asShortArray, asShortArray, asShortArray, getDir, getDir, getDir, getDir, getDir, getDirAt, getDirAt, getDirAt, getDirAt, getDirAt, getDirAt, query, query, query, query, query, queryBetween, queryBetween, queryBetween, queryBetween, queryBetween, queryBetween, queryFrom, queryFrom, queryFrom, queryFrom, queryFrom, queryFrom, queryTo, queryTo, queryTo, queryTo, queryTo, queryTo, retrieveBetween, retrieveBetween, retrieveBetween, retrieveBetween, retrieveBetween, retrieveFrom, retrieveFrom, retrieveFrom, retrieveFrom, retrieveFrom, retrieveTo, retrieveTo, retrieveTo, retrieveTo, retrieveTo, toMap, toProperties
-
Methods inherited from interface org.refcodes.struct.Containable
size
-
Methods inherited from interface org.refcodes.struct.InterOperableMap
getBoolean, getBoolean, getBoolean, getBoolean, getBoolean, getBooleanOr, getBooleanOr, getBooleanOr, getBooleanOr, getBooleanOr, getByte, getByte, getByte, getByte, getByte, getByteOr, getByteOr, getByteOr, getByteOr, getByteOr, getChar, getChar, getChar, getChar, getChar, getCharOr, getCharOr, getCharOr, getCharOr, getCharOr, getClass, getClass, getClass, getClass, getClass, getClassOr, getClassOr, getClassOr, getClassOr, getClassOr, getDouble, getDouble, getDouble, getDouble, getDouble, getDoubleOr, getDoubleOr, getDoubleOr, getDoubleOr, getDoubleOr, getEnum, getEnum, getEnum, getEnum, getEnum, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getFloat, getFloat, getFloat, getFloat, getFloat, getFloatOr, getFloatOr, getFloatOr, getFloatOr, getFloatOr, getInt, getInt, getInt, getInt, getInt, getIntOr, getIntOr, getIntOr, getIntOr, getIntOr, getLong, getLong, getLong, getLong, getLong, getLongOr, getLongOr, getLongOr, getLongOr, getLongOr, getShort, getShort, getShort, getShort, getShort, getShortOr, getShortOr, getShortOr, getShortOr, getShortOr, getString, getString, getString, getString, getString, getStringOr, getStringOr, getStringOr, getStringOr, getStringOr
-
Methods inherited from interface org.refcodes.struct.InterOperableMap.MutableInterOperableMap
insert, insertBetween, insertFrom, insertTo, putBoolean, putBoolean, putBoolean, putBoolean, putBoolean, putByte, putByte, putByte, putByte, putByte, putChar, putChar, putChar, putChar, putChar, putClass, putClass, putClass, putClass, putClass, putDouble, putDouble, putDouble, putDouble, putDouble, putEnum, putEnum, putEnum, putEnum, putEnum, putFloat, putFloat, putFloat, putFloat, putFloat, putInt, putInt, putInt, putInt, putInt, putLong, putLong, putLong, putLong, putLong, putShort, putShort, putShort, putShort, putShort, putString, putString, putString, putString, putString
-
Methods inherited from interface org.refcodes.struct.Keys
containsKey, get, getOr, keySet, use, values
-
Methods inherited from interface org.refcodes.struct.Keys.MutableValues
put
-
Methods inherited from interface java.util.Map
clear, compute, computeIfAbsent, computeIfPresent, containsKey, entrySet, equals, forEach, get, getOrDefault, hashCode, isEmpty, keySet, merge, put, putIfAbsent, remove, remove, replace, replace, replaceAll, size, values
-
Methods inherited from interface org.refcodes.struct.PathMap
children, children, children, children, children, children, containsKey, containsKey, containsKey, dirs, dirs, dirs, dirs, dirs, dirs, findPaths, fromExternalPath, get, get, get, getArray, getArray, getArray, getArray, getArray, getArrayIndexes, getArrayIndexes, getArrayIndexes, getArrayIndexes, getArrayIndexes, getDirIndexes, getDirIndexes, getDirIndexes, getDirIndexes, getDirIndexes, getRootPath, getValueAt, getValueAt, getValueAt, getValueAt, getValueAt, getValueAt, hasChildren, hasChildren, hasChildren, hasChildren, hasChildren, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasParentPath, hasPath, hasPath, hasPath, hasPath, hasSubDirs, hasSubDirs, hasSubDirs, hasSubDirs, hasValue, hasValue, hasValue, hasValue, hasValue, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, isArray, isArray, isArray, isArray, isArray, isArray, isChild, isChild, isChild, isChild, isDir, isDir, isDir, isDir, isDir, isEqualTo, isIndexDir, isIndexDir, isIndexDir, isIndexDir, isIndexDir, isLeaf, isLeaf, isLeaf, isLeaf, isLeaf, isRootPath, keySet, keySet, keySet, keySet, keySet, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastDirIndex, lastDirIndex, lastDirIndex, lastDirIndex, lastDirIndex, lastDirIndex, leaves, leaves, leaves, leaves, leaves, leaves, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextDirIndex, nextDirIndex, nextDirIndex, nextDirIndex, nextDirIndex, nextDirIndex, paths, paths, paths, paths, paths, paths, queryPaths, queryPaths, queryPaths, queryPaths, queryPaths, queryPaths, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, toDataStructure, toDataStructure, toExternalPath, toInstance, toInstance, toLeaf, toMap, toNormalizedPath, toParentPath, toPath, toPath, toPath, toPath, toPathElements, toPathList, toPathStack, toPropertyPath, toType, toType, toType, toType, toType, toType, toType, toType
-
Methods inherited from interface org.refcodes.struct.PathMap.MutablePathMap
add, add, add, add, add, add, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendValueTo, appendValueTo, appendValueTo, appendValueTo, appendValueTo, appendValueTo, delete, delete, delete, delete, delete, insert, insert, insertBetween, insertBetween, insertBetween, insertBetween, insertBetween, insertBetween, insertBetween, insertBetween, insertBetween, insertBetween, insertFrom, insertFrom, insertFrom, insertFrom, insertFrom, insertFrom, insertFrom, insertFrom, insertFrom, insertFrom, insertTo, insertTo, insertTo, insertTo, insertTo, insertTo, insertTo, insertTo, insertTo, insertTo, merge, merge, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeTo, mergeTo, mergeTo, mergeTo, mergeTo, mergeTo, mergeTo, mergeTo, mergeTo, mergeTo, put, putArray, putArray, putArray, putArray, putArray, putArray, putArray, putArray, putArray, putArray, putArray, putArray, putValueAt, putValueAt, putValueAt, putValueAt, putValueAt, putValueAt, remove, remove, remove, removeValueAt, removeValueAt, removeValueAt, removeValueAt, removeValueAt, toSourceCode, toSourceCode
-
-
-
-
Method Detail
-
containsValue
default boolean containsValue(Object value)
This method is defined for the sake ofMapconformity. Tests whether the provided value has a key assigned.- Specified by:
containsValuein interfaceCanonicalMap- Specified by:
containsValuein interfaceInterOperableMap.MutableInterOperableMap<String>- Specified by:
containsValuein interfaceKeys<String,String>- Specified by:
containsValuein interfaceMap<String,String>- Parameters:
value- The value to test if a key references this value.- Returns:
- True in case the given value is referenced by a key.
-
insert
default void insert(CanonicalMap aFrom)
Method to semantically emphasize that we support our own types. Actually delegates toPathMap.MutablePathMap.insert(Object).- Parameters:
aFrom- TheCanonicalMapwhich is to be inspected with the therein contained values being added with their according determined paths.
-
insertBetween
default void insertBetween(String aToPath, CanonicalMap aFrom, String aFromPath)
Method to semantically emphasize that we support our own types. Actually delegates toPathMap.MutablePathMap.insertBetween(String, Object, String).- Parameters:
aToPath- The sub-path where to insert the object's introspected values to.aFrom- TheCanonicalMapwhich is to be inspected with the therein contained values being added with their according determined paths.aFromPath- The path from where to start adding elements of the provided object.
-
insertFrom
default void insertFrom(CanonicalMap aFrom, String aFromPath)
Method to semantically emphasize that we support our own types. Actually delegates toPathMap.MutablePathMap.insertFrom(Object, String).- Parameters:
aFrom- TheCanonicalMapwhich is to be inspected with the therein contained values being added with their according determined paths.aFromPath- The path from where to start adding elements of the provided object.
-
insertTo
default void insertTo(String aToPath, CanonicalMap aFrom)
Method to semantically emphasize that we support our own types. Actually delegates toPathMap.MutablePathMap.insertTo(String, Object).- Parameters:
aToPath- The sub-path where to insert the object's introspected values to.aFrom- TheCanonicalMapwhich is to be inspected with the therein contained values being added with their according determined paths.
-
put
default String put(Object aKey, String aValue)
Adds the given element related to the given key. As the key passed is an enumeration, theEnum.toString()method is used on the enumeration to resolve the enumeration to a {link String} key.- Parameters:
aKey- The key for which to add the element.aValue- The value to be related with the given key.- Returns:
- The value being replaced by the provided value or null if none value has been replaced.
-
put
default String put(Object[] aPathElements, String aValue)
Puts the given value into the child's path, relative to the given parent's path.- Specified by:
putin interfacePathMap.MutablePathMap<String>- Parameters:
aPathElements- The path elements of the path relative to which to put the value.aValue- The value to be added.- Returns:
- The replaced value in case a value has already been set for the resulting path, or null.
-
put
default String put(Property aProperty)
Puts the key/value-pair from the providedProperty.- Parameters:
aProperty- The property's key/value to be inserted.- Returns:
- The property value overwritten by the provided property.
-
put
default String put(Relation<String,String> aRelation)
Adds the given element related to the given key.- Specified by:
putin interfaceDictionary.MutableDictionary<String,String>- Specified by:
putin interfacePathMap.MutablePathMap<String>- Parameters:
aRelation- the relation- Returns:
- The value being replaced by the provided value or null if none value has been replaced.
-
put
default String put(String[] aPathElements, String aValue)
Puts the given value into the child's path, relative to the given parent's path.- Specified by:
putin interfacePathMap.MutablePathMap<String>- Parameters:
aPathElements- The path elements of the path relative to which to put the value.aValue- The value to be added.- Returns:
- The replaced value in case a value has already been set for the resulting path, or null.
-
putAll
default void putAll(CanonicalMap aProperties)
This method inserts all elements (key/value-pairs) found in the providedCanonicalMapinstances of interoperability reasons.- Parameters:
aProperties- ACanonicalMapcontaining the key/value pairs to be inserted.
-
putAll
default void putAll(Properties aProperties)
This method inserts all elements (key/value-pairs) found in the providedPropertiesinstances of interoperability reasons.- Parameters:
aProperties- APropertiescontaining the key/value-pairs to be inserted.
-
putDirAt
default CanonicalMap putDirAt(Collection<?> aPathElements, int aIndex, Object aDir) throws IllegalArgumentException
An indexed directory represents all elements which begin with a path which's last path element represents an index. There may by many sub-paths for the same indexed path which are all are included by the according directory. Puts the given values below the path at the given index.- Specified by:
putDirAtin interfacePathMap.MutablePathMap<String>- Parameters:
aPathElements- The path elements of the path where to put the indexed element.aIndex- The index of the indexed element.aDir- The values to be put at the index.- Returns:
- The directory which has been replaced by the given directory.
- Throws:
IllegalArgumentException- in case the path does not represent indexed elements as ofPathMap.isIndexDir(String).
-
putDirAt
default CanonicalMap putDirAt(Collection<?> aPathElements, int aIndex, PathMap<String> aDir) throws IllegalArgumentException
An indexed directory represents all elements which begin with a path which's last path element represents an index. There may by many sub-paths for the same indexed path which are all are included by the according directory. Puts the given values below the path at the given index.- Specified by:
putDirAtin interfacePathMap.MutablePathMap<String>- Parameters:
aPathElements- The path elements of the path where to put the indexed element.aIndex- The index of the indexed element.aDir- The values to be put at the index.- Returns:
- The directory which has been replaced by the given directory.
- Throws:
IllegalArgumentException- in case the path does not represent indexed elements as ofPathMap.isIndexDir(String).
-
putDirAt
default CanonicalMap putDirAt(int aIndex, Object aDir) throws IllegalArgumentException
An indexed directory represents all elements which begin with a path which's last path element represents an index. There may by many sub-paths for the same indexed path which are all are included by the according directory. Puts the given values below the root path at the given index.- Specified by:
putDirAtin interfacePathMap.MutablePathMap<String>- Parameters:
aIndex- The index of the indexed element.aDir- The values to be put at the index.- Returns:
- The directory which has been replaced by the given directory.
- Throws:
IllegalArgumentException- in case the path does not represent indexed elements as ofPathMap.isIndexDir(String).
-
putDirAt
default CanonicalMap putDirAt(int aIndex, PathMap<String> aDir) throws IllegalArgumentException
An indexed directory represents all elements which begin with a path which's last path element represents an index. There may by many sub-paths for the same indexed path which are all are included by the according directory. Puts the given values below the root path at the given index.- Specified by:
putDirAtin interfacePathMap.MutablePathMap<String>- Parameters:
aIndex- The index of the indexed element.aDir- The values to be put at the index.- Returns:
- The directory which has been replaced by the given directory.
- Throws:
IllegalArgumentException- in case the path does not represent indexed elements as ofPathMap.isIndexDir(String).
-
putDirAt
default CanonicalMap putDirAt(Object aPath, int aIndex, Object aDir) throws IllegalArgumentException
An indexed directory represents all elements which begin with a path which's last path element represents an index. There may by many sub-paths for the same indexed path which are all are included by the according directory. Puts the given values below the path at the given index.- Specified by:
putDirAtin interfacePathMap.MutablePathMap<String>- Parameters:
aPath- The path where to put the indexed element.aIndex- The index of the indexed element.aDir- The values to be put at the index.- Returns:
- The directory which has been replaced by the given directory.
- Throws:
IllegalArgumentException- in case the path does not represent indexed elements as ofPathMap.isIndexDir(String).
-
putDirAt
default CanonicalMap putDirAt(Object aPath, int aIndex, PathMap<String> aDir) throws IllegalArgumentException
An indexed directory represents all elements which begin with a path which's last path element represents an index. There may by many sub-paths for the same indexed path which are all are included by the according directory. Puts the given values below the path at the given index.- Specified by:
putDirAtin interfacePathMap.MutablePathMap<String>- Parameters:
aPath- The path where to put the indexed element.aIndex- The index of the indexed element.aDir- The values to be put at the index.- Returns:
- The directory which has been replaced by the given directory.
- Throws:
IllegalArgumentException- in case the path does not represent indexed elements as ofPathMap.isIndexDir(String).
-
putDirAt
default CanonicalMap putDirAt(Object[] aPathElements, int aIndex, Object aDir) throws IllegalArgumentException
An indexed directory represents all elements which begin with a path which's last path element represents an index. There may by many sub-paths for the same indexed path which are all are included by the according directory. Puts the given values below the path at the given index.- Specified by:
putDirAtin interfacePathMap.MutablePathMap<String>- Parameters:
aPathElements- The path elements of the path where to put the indexed element.aIndex- The index of the indexed element.aDir- The values to be put at the index.- Returns:
- The directory which has been replaced by the given directory.
- Throws:
IllegalArgumentException- in case the path does not represent indexed elements as ofPathMap.isIndexDir(String).
-
putDirAt
default CanonicalMap putDirAt(Object[] aPathElements, int aIndex, PathMap<String> aDir) throws IllegalArgumentException
An indexed directory represents all elements which begin with a path which's last path element represents an index. There may by many sub-paths for the same indexed path which are all are included by the according directory. Puts the given values below the path at the given index.- Specified by:
putDirAtin interfacePathMap.MutablePathMap<String>- Parameters:
aPathElements- The path elements of the path where to put the indexed element.aIndex- The index of the indexed element.aDir- The values to be put at the index.- Returns:
- The directory which has been replaced by the given directory.
- Throws:
IllegalArgumentException- in case the path does not represent indexed elements as ofPathMap.isIndexDir(String).
-
putDirAt
default CanonicalMap putDirAt(String aPath, int aIndex, Object aDir) throws IllegalArgumentException
An indexed directory represents all elements which begin with a path which's last path element represents an index. There may by many sub-paths for the same indexed path which are all are included by the according directory. Puts the given values below the path at the given index.- Specified by:
putDirAtin interfacePathMap.MutablePathMap<String>- Parameters:
aPath- The path where to put the indexed element.aIndex- The index of the indexed element.aDir- The values to be put at the index.- Returns:
- The directory which has been replaced by the given directory.
- Throws:
IllegalArgumentException- in case the path does not represent indexed elements as ofPathMap.isIndexDir(String).
-
putDirAt
default CanonicalMap putDirAt(String aPath, int aIndex, PathMap<String> aDir) throws IllegalArgumentException
An indexed directory represents all elements which begin with a path which's last path element represents an index. There may by many sub-paths for the same indexed path which are all are included by the according directory. Puts the given values below the path at the given index.- Specified by:
putDirAtin interfacePathMap.MutablePathMap<String>- Parameters:
aPath- The path where to put the indexed element.aIndex- The index of the indexed element.aDir- The values to be put at the index.- Returns:
- The directory which has been replaced by the given directory.
- Throws:
IllegalArgumentException- in case the path does not represent indexed elements as ofPathMap.isIndexDir(String).
-
putDirAt
default CanonicalMap putDirAt(String[] aPathElements, int aIndex, Object aDir) throws IllegalArgumentException
An indexed directory represents all elements which begin with a path which's last path element represents an index. There may by many sub-paths for the same indexed path which are all are included by the according directory. Puts the given values below the path at the given index.- Specified by:
putDirAtin interfacePathMap.MutablePathMap<String>- Parameters:
aPathElements- The path elements of the path where to put the indexed element.aIndex- The index of the indexed element.aDir- The values to be put at the index.- Returns:
- The directory which has been replaced by the given directory.
- Throws:
IllegalArgumentException- in case the path does not represent indexed elements as ofPathMap.isIndexDir(String).
-
putDirAt
default CanonicalMap putDirAt(String[] aPathElements, int aIndex, PathMap<String> aDir) throws IllegalArgumentException
An indexed directory represents all elements which begin with a path which's last path element represents an index. There may by many sub-paths for the same indexed path which are all are included by the according directory. Puts the given values below the path at the given index.- Specified by:
putDirAtin interfacePathMap.MutablePathMap<String>- Parameters:
aPathElements- The path elements of the path where to put the indexed element.aIndex- The index of the indexed element.aDir- The values to be put at the index.- Returns:
- The directory which has been replaced by the given directory.
- Throws:
IllegalArgumentException- in case the path does not represent indexed elements as ofPathMap.isIndexDir(String).
-
removeAll
default CanonicalMap removeAll(Collection<?> aPathQueryElements)
Removes all elements which's keys match the provided path query. Queries the keys of the instance using thePathMatcher' matching patterns, similar to the wildcards '*', '?' and '**' known when querying folders of a filesystem: ThePathMatcherapplies the following rules from the ANT path pattern to the query provided: A single asterisk ("*" as ofWildcard.FILE) matches zero or more characters within a path name. A double asterisk ("**" as ofWildcard.PATH) matches zero or more characters across directory levels. A question mark ("?" as ofWildcard.CHAR) matches exactly one character within a path name. The single asterisk ("*" as ofWildcard.FILE), the double asterisk ("**" as ofWildcard.PATH) and the question mark ("?" as ofWildcard.CHAR) we refer to as wildcards.- Specified by:
removeAllin interfacePathMap.MutablePathMap<String>- Parameters:
aPathQueryElements- The elements representing your path query including your wildcards.- Returns:
- The removed properties.
-
removeAll
default CanonicalMap removeAll(Object... aPathQueryElements)
Removes all elements which's keys match the provided path query. Queries the keys of the instance using thePathMatcher' matching patterns, similar to the wildcards '*', '?' and '**' known when querying folders of a filesystem: ThePathMatcherapplies the following rules from the ANT path pattern to the query provided: A single asterisk ("*" as ofWildcard.FILE) matches zero or more characters within a path name. A double asterisk ("**" as ofWildcard.PATH) matches zero or more characters across directory levels. A question mark ("?" as ofWildcard.CHAR) matches exactly one character within a path name. The single asterisk ("*" as ofWildcard.FILE), the double asterisk ("**" as ofWildcard.PATH) and the question mark ("?" as ofWildcard.CHAR) we refer to as wildcards.- Specified by:
removeAllin interfacePathMap.MutablePathMap<String>- Parameters:
aPathQueryElements- The elements representing your path query including your wildcards.- Returns:
- The removed properties.
-
removeAll
default CanonicalMap removeAll(Object aPathQuery)
Removes all elements which's keys match the provided path query. Queries the keys of the instance using thePathMatcher' matching patterns, similar to the wildcards '*', '?' and '**' known when querying folders of a filesystem: ThePathMatcherapplies the following rules from the ANT path pattern to the query provided: A single asterisk ("*" as ofWildcard.FILE) matches zero or more characters within a path name. A double asterisk ("**" as ofWildcard.PATH) matches zero or more characters across directory levels. A question mark ("?" as ofWildcard.CHAR) matches exactly one character within a path name. The single asterisk ("*" as ofWildcard.FILE), the double asterisk ("**" as ofWildcard.PATH) and the question mark ("?" as ofWildcard.CHAR) we refer to as wildcards.- Specified by:
removeAllin interfacePathMap.MutablePathMap<String>- Parameters:
aPathQuery- The path query including your wildcards.- Returns:
- The removed properties.
-
removeAll
default CanonicalMap removeAll(Pattern aRegExp)
Removes all elements which's keys match the provided regular expression: Queries the keys of the instance using the providedPattern- Specified by:
removeAllin interfacePathMap.MutablePathMap<String>- Parameters:
aRegExp- The regular expression to be used for the query.- Returns:
- The removed properties.
-
removeAll
default CanonicalMap removeAll(String... aPathQueryElements)
Removes all elements which's keys match the provided path query. Queries the keys of the instance using thePathMatcher' matching patterns, similar to the wildcards '*', '?' and '**' known when querying folders of a filesystem: ThePathMatcherapplies the following rules from the ANT path pattern to the query provided: A single asterisk ("*" as ofWildcard.FILE) matches zero or more characters within a path name. A double asterisk ("**" as ofWildcard.PATH) matches zero or more characters across directory levels. A question mark ("?" as ofWildcard.CHAR) matches exactly one character within a path name. The single asterisk ("*" as ofWildcard.FILE), the double asterisk ("**" as ofWildcard.PATH) and the question mark ("?" as ofWildcard.CHAR) we refer to as wildcards.- Specified by:
removeAllin interfacePathMap.MutablePathMap<String>- Parameters:
aPathQueryElements- The elements representing your path query including your wildcards.- Returns:
- The removed properties.
-
removeAll
default CanonicalMap removeAll(String aPathQuery)
Removes all elements which's keys match the provided path query. Queries the keys of the instance using thePathMatcher' matching patterns, similar to the wildcards '*', '?' and '**' known when querying folders of a filesystem: ThePathMatcherapplies the following rules from the ANT path pattern to the query provided: A single asterisk ("*" as ofWildcard.FILE) matches zero or more characters within a path name. A double asterisk ("**" as ofWildcard.PATH) matches zero or more characters across directory levels. A question mark ("?" as ofWildcard.CHAR) matches exactly one character within a path name. The single asterisk ("*" as ofWildcard.FILE), the double asterisk ("**" as ofWildcard.PATH) and the question mark ("?" as ofWildcard.CHAR) we refer to as wildcards.- Specified by:
removeAllin interfacePathMap.MutablePathMap<String>- Parameters:
aPathQuery- The path query including your wildcards.- Returns:
- The removed properties.
-
removeDirAt
default CanonicalMap removeDirAt(int aIndex)
An indexed directory represents all elements which begin with a path which's last path element represents an index. There may by many sub-paths for the same indexed path which are all are included by the according directory. Removes the elements of the given index below the root path. Given the following paths and index = 1:/0/0aaa /0/0bbb /0/0bbb /1/1aaa /1/1bbb /1/1bbbYou will get a result containing all the elements which's keys begin with "/1/". The keys of the result will exclude the path "prefix" "/1".- Specified by:
removeDirAtin interfacePathMap.MutablePathMap<String>- Parameters:
aIndex- The index which to use.- Returns:
- The indexed elements without the indexed path "prefixes".
-
removeDirAt
default CanonicalMap removeDirAt(Object aPath, int aIndex)
An indexed directory represents all elements which begin with a path which's last path element represents an index. There may by many sub-paths for the same indexed path which are all are included by the according directory. Removes the elements of the given index below the given path. Given the following paths and index = 1 with a queried path "/root/child":/root/child/0/0aaa /root/child/0/0bbb /root/child/0/0bbb /root/child/1/1aaa /root/child/1/1bbb /root/child/1/1bbbYou will get a result containing all the elements which's keys begin with "/root/child/1/". The keys of the result will exclude the path "prefix" "/root/child/1".- Specified by:
removeDirAtin interfacePathMap.MutablePathMap<String>- Parameters:
aPath- The path from which to remove the indexed elements.aIndex- The index which to use.- Returns:
- The indexed elements without the indexed path "prefixes".
-
removeDirAt
default CanonicalMap removeDirAt(Object[] aPathElements, int aIndex)
An indexed directory represents all elements which begin with a path which's last path element represents an index. There may by many sub-paths for the same indexed path which are all are included by the according directory. Removes the elements of the given index below the given path. Given the following paths and index = 1 with a queried path "/root/child":/root/child/0/0aaa /root/child/0/0bbb /root/child/0/0bbb /root/child/1/1aaa /root/child/1/1bbb /root/child/1/1bbbYou will get a result containing all the elements which's keys begin with "/root/child/1/".The keys of the result will exclude the path "prefix" "/root/child/1".- Specified by:
removeDirAtin interfacePathMap.MutablePathMap<String>- Parameters:
aPathElements- The elements of the path from which to remove the indexed elements.aIndex- The index which to use.- Returns:
- The indexed elements without the indexed path "prefixes".
-
removeDirAt
default CanonicalMap removeDirAt(String aPath, int aIndex)
An indexed directory represents all elements which begin with a path which's last path element represents an index. There may by many sub-paths for the same indexed path which are all are included by the according directory. Removes the elements of the given index below the given path. Given the following paths and index = 1 with a queried path "/root/child":/root/child/0/0aaa /root/child/0/0bbb /root/child/0/0bbb /root/child/1/1aaa /root/child/1/1bbb /root/child/1/1bbbYou will get a result containing all the elements which's keys begin with "/root/child/1/".The keys of the result will exclude the path "prefix" "/root/child/1".- Specified by:
removeDirAtin interfacePathMap.MutablePathMap<String>- Parameters:
aPath- The path from which to remove the indexed elements.aIndex- The index which to use.- Returns:
- The indexed elements without the indexed path "prefixes".
-
removeDirAt
default CanonicalMap removeDirAt(String[] aPathElements, int aIndex)
An indexed directory represents all elements which begin with a path which's last path element represents an index. There may by many sub-paths for the same indexed path which are all are included by the according directory. Removes the elements of the given index below the given path. Given the following paths and index = 1 with a queried path "/root/child":/root/child/0/0aaa /root/child/0/0bbb /root/child/0/0bbb /root/child/1/1aaa /root/child/1/1bbb /root/child/1/1bbbYou will get a result containing all the elements which's keys begin with "/root/child/1/".The keys of the result will exclude the path "prefix" "/root/child/1".- Specified by:
removeDirAtin interfacePathMap.MutablePathMap<String>- Parameters:
aPathElements- The elements of the path from which to remove the indexed elements.aIndex- The index which to use.- Returns:
- The indexed elements without the indexed path "prefixes".
-
removeFrom
default CanonicalMap removeFrom(Collection<?> aPathElements)
Removes all properties below the provided path and returns thePathMapwith the removed elements, by which the paths exclude the parent's path.- Specified by:
removeFromin interfacePathMap.MutablePathMap<String>- Parameters:
aPathElements- The path elements for the path from where to remove all properties.- Returns:
- The removed properties.
-
removeFrom
default CanonicalMap removeFrom(Object... aPathElements)
Removes all properties below the provided path and returns thePathMapwith the removed elements, by which the paths exclude the parent's path.- Specified by:
removeFromin interfacePathMap.MutablePathMap<String>- Parameters:
aPathElements- The path elements for the path from where to remove all properties.- Returns:
- The removed properties.
-
removeFrom
default CanonicalMap removeFrom(Object aPath)
Removes all properties below the provided path and returns thePathMapwith the removed elements, by which the paths exclude the parent's path.- Specified by:
removeFromin interfacePathMap.MutablePathMap<String>- Parameters:
aPath- The path from where to remove all properties.- Returns:
- The removed properties.
-
removeFrom
default CanonicalMap removeFrom(String aPath)
Removes all properties below the provided path and returns thePathMapwith the removed elements, by which the paths exclude the parent's path.- Specified by:
removeFromin interfacePathMap.MutablePathMap<String>- Parameters:
aPath- The path from where to remove all properties.- Returns:
- The removed properties.
-
removeFrom
default CanonicalMap removeFrom(String... aPathElements)
Removes all properties below the provided path and returns thePathMapwith the removed elements, by which the paths exclude the parent's path.- Specified by:
removeFromin interfacePathMap.MutablePathMap<String>- Parameters:
aPathElements- The path elements for the path from where to remove all properties.- Returns:
- The removed properties.
-
removePaths
default CanonicalMap removePaths(Collection<?> aPaths)
Removes the paths contained in the provided collection.- Specified by:
removePathsin interfacePathMap.MutablePathMap<String>- Parameters:
aPaths- The paths to be removed.- Returns:
- The removed properties.
-
removePaths
default CanonicalMap removePaths(String... aPaths)
Removes the paths contained in the provided collection.- Specified by:
removePathsin interfacePathMap.MutablePathMap<String>- Parameters:
aPaths- The paths to be removed.- Returns:
- The removed properties.
-
-