Class CanonicalMapBuilderImpl
- All Implemented Interfaces:
Serializable, Map<String,String>, org.refcodes.mixin.AnnotatorAccessor, org.refcodes.mixin.Clearable, org.refcodes.mixin.DelimiterAccessor, org.refcodes.mixin.EmptyAccessor, org.refcodes.mixin.TypeAccessor<String>, CanonicalMap, CanonicalMap.CanonicalMapBuilder, CanonicalMap.MutableCanonicalMap, Containable, InterOperableMap<String>, InterOperableMap.InterOperableMapBuilder<String>, InterOperableMap.MutableInterOperableMap<String>, Keys<String, String>, Keys.MutableKeys<String, String>, Keys.MutableValues<String, String>, PathMap<String>, PathMap.MutablePathMap<String>, PathMap.PathMapBuilder<String>, Table<String, String>, Table.TableDictionary<String, String>, Table.TableDictionary.TableBuilder<String, String, PathMap.PathMapBuilder<String>>
public class CanonicalMapBuilderImpl
extends PathMapBuilderImpl<String>
implements CanonicalMap.CanonicalMapBuilder
The Class CanonicalMapBuilderImpl.
- See Also:
-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.mixin.AnnotatorAccessor
org.refcodes.mixin.AnnotatorAccessor.AnnotatorBuilder<B>, org.refcodes.mixin.AnnotatorAccessor.AnnotatorMutator, org.refcodes.mixin.AnnotatorAccessor.AnnotatorPropertyNested classes/interfaces inherited from interface CanonicalMap
CanonicalMap.CanonicalMapBuilder, CanonicalMap.MutableCanonicalMapNested classes/interfaces inherited from interface org.refcodes.mixin.DelimiterAccessor
org.refcodes.mixin.DelimiterAccessor.DelimiterBuilder<B>, org.refcodes.mixin.DelimiterAccessor.DelimiterMutator, org.refcodes.mixin.DelimiterAccessor.DelimiterPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.EmptyAccessor
org.refcodes.mixin.EmptyAccessor.EmptyBuilder<B>, org.refcodes.mixin.EmptyAccessor.EmptyMutator, org.refcodes.mixin.EmptyAccessor.EmptyPropertyNested classes/interfaces inherited from interface InterOperableMap
InterOperableMap.InterOperableMapBuilder<T>, InterOperableMap.MutableInterOperableMap<T>Nested classes/interfaces inherited from interface Keys
Keys.MutableKeys<K,V>, Keys.MutableValues<K, V> Nested classes/interfaces inherited from interface PathMap
PathMap.MutablePathMap<T>, PathMap.PathMapBuilder<T>Nested classes/interfaces inherited from interface Table
Table.TableDictionary<K,V> Nested classes/interfaces inherited from interface Table.TableDictionary
Table.TableDictionary.TableBuilder<K,V, B> Nested classes/interfaces inherited from interface org.refcodes.mixin.TypeAccessor
org.refcodes.mixin.TypeAccessor.TypeBuilder<T,B>, org.refcodes.mixin.TypeAccessor.TypeMutator<T>, org.refcodes.mixin.TypeAccessor.TypeProperty<T> -
Field Summary
-
Constructor Summary
ConstructorsConstructorDescriptionCreate an emptyCanonicalMap.CanonicalMapBuilderinstance using the default path delimiter "/" (Delimiter.PATH) for the path declarations.CanonicalMapBuilderImpl(char aDelimiter) Create aCanonicalMap.CanonicalMapBuilderinstance using the provided path delimiter for the path declarations.Create aCanonicalMap.CanonicalMapBuilderinstance containing the elements as ofPathMap.MutablePathMap.insert(Object)using the default path delimiter "/" (Delimiter.PATH) for the path declarations.CanonicalMapBuilderImpl(Object aObj, char aDelimiter) Creates aCanonicalMap.CanonicalMapBuilderinstance containing the elements as ofPathMap.MutablePathMap.insert(Object).CanonicalMapBuilderImpl(Object aObj, String aFromPath) Creates aCanonicalMap.CanonicalMapBuilderinstance containing the elements as ofPathMap.MutablePathMap.insert(Object)using the default path delimiter "/" (Delimiter.PATH) for the path declarations.CanonicalMapBuilderImpl(Object aObj, String aFromPath, char aDelimiter) Creates aCanonicalMap.CanonicalMapBuilderinstance containing the elements as ofPathMap.MutablePathMap.insert(Object).CanonicalMapBuilderImpl(String aToPath, Object aObj) Create aCanonicalMap.CanonicalMapBuilderinstance containing the elements as ofPathMap.MutablePathMap.insert(Object)using the default path delimiter "/" (Delimiter.PATH) for the path declarations.CanonicalMapBuilderImpl(String aToPath, Object aObj, char aDelimiter) Creates aCanonicalMap.CanonicalMapBuilderinstance containing the elements as ofPathMap.MutablePathMap.insert(Object).CanonicalMapBuilderImpl(String aToPath, Object aObj, String aFromPath) Creates aCanonicalMap.CanonicalMapBuilderinstance containing the elements as ofPathMap.MutablePathMap.insert(Object)using the default path delimiter "/" (Delimiter.PATHfor the path declarations.CanonicalMapBuilderImpl(String aToPath, Object aObj, String aFromPath, char aDelimiter) Create aCanonicalMap.CanonicalMapBuilderinstance containing the elements as ofPathMap.MutablePathMap.insert(Object). -
Method Summary
Modifier and TypeMethodDescriptionprotected StringfromInstance(Object aValue) Hook method when introspecting an object to help conversion of that object to the target types.fromObject(Object aFrom) retrieveFrom(String aFromPath) retrieveTo(String aToPath) protected <TYPE> TYPEtoInstance(String aValue, Class<TYPE> aType) Hook method when reconstructing an object, opposite ofPathMapBuilderImpl.fromInstance(Object), tries to convert the given value to the desired type.Builder method forKeys.MutableValues.put(Object, Object).Methods inherited from class PathMapBuilderImpl
clear, compute, computeIfAbsent, computeIfPresent, containsKey, containsValue, createBackingMap, entrySet, equals, forEach, fromValue, fromValue, get, getAnnotator, getDelimiter, getOrDefault, getType, hashCode, insert, insertBetween, insertFrom, insertTo, isEmpty, keySet, merge, merge, mergeBetween, mergeFrom, mergeTo, put, putAll, putIfAbsent, remove, remove, replace, replace, replaceAll, size, toDataStructure, toType, valuesMethods inherited from class Object
clone, finalize, getClass, notify, notifyAll, toString, wait, wait, waitMethods inherited from interface org.refcodes.mixin.AnnotatorAccessor
getAnnotatorMethods inherited from interface CanonicalMap
asArray, asArray, asArray, asArray, asBooleanArray, asBooleanArray, asBooleanArray, asBooleanArray, asByteArray, asByteArray, asByteArray, asByteArray, asCharArray, asCharArray, asCharArray, asCharArray, asDoubleArray, asDoubleArray, asDoubleArray, asDoubleArray, asFloatArray, asFloatArray, asFloatArray, asFloatArray, asIntArray, asIntArray, asIntArray, asIntArray, asLongArray, asLongArray, asLongArray, asLongArray, asShortArray, asShortArray, asShortArray, asShortArray, getDir, getDir, getDir, getDir, getDir, getDirAt, getDirAt, getDirAt, getDirAt, getDirAt, getDirAt, getDirs, getDirs, getDirs, getDirs, getDirs, query, query, query, query, query, queryBetween, queryBetween, queryBetween, queryBetween, queryBetween, queryBetween, queryFrom, queryFrom, queryFrom, queryFrom, queryFrom, queryFrom, queryTo, queryTo, queryTo, queryTo, queryTo, queryTo, retrieveBetween, retrieveBetween, retrieveBetween, retrieveBetween, retrieveBetween, retrieveFrom, retrieveFrom, retrieveFrom, retrieveFrom, retrieveTo, retrieveTo, retrieveTo, retrieveTo, toMap, toPropertiesMethods inherited from interface CanonicalMap.CanonicalMapBuilder
withInsert, withInsert, withInsertBetween, withInsertBetween, withInsertBetween, withInsertBetween, withInsertBetween, withInsertBetween, withInsertBetween, withInsertBetween, withInsertBetween, withInsertBetween, withInsertFrom, withInsertFrom, withInsertFrom, withInsertFrom, withInsertFrom, withInsertFrom, withInsertFrom, withInsertFrom, withInsertFrom, withInsertFrom, withInsertTo, withInsertTo, withInsertTo, withInsertTo, withInsertTo, withInsertTo, withInsertTo, withInsertTo, withInsertTo, withInsertTo, withMerge, withMerge, withMergeBetween, withMergeBetween, withMergeBetween, withMergeBetween, withMergeBetween, withMergeBetween, withMergeBetween, withMergeBetween, withMergeBetween, withMergeBetween, withMergeFrom, withMergeFrom, withMergeFrom, withMergeFrom, withMergeFrom, withMergeFrom, withMergeFrom, withMergeFrom, withMergeFrom, withMergeFrom, withMergeTo, withMergeTo, withMergeTo, withMergeTo, withMergeTo, withMergeTo, withMergeTo, withMergeTo, withMergeTo, withMergeTo, withPut, withPut, withPut, withPut, withPut, withPutBoolean, withPutBoolean, withPutBoolean, withPutBoolean, withPutBoolean, withPutByte, withPutByte, withPutByte, withPutByte, withPutByte, withPutChar, withPutChar, withPutChar, withPutChar, withPutChar, withPutClass, withPutClass, withPutClass, withPutClass, withPutClass, withPutDirAt, withPutDirAt, withPutDirAt, withPutDirAt, withPutDirAt, withPutDirAt, withPutDirAt, withPutDirAt, withPutDirAt, withPutDirAt, withPutDirAt, withPutDirAt, withPutDouble, withPutDouble, withPutDouble, withPutDouble, withPutDouble, withPutEnum, withPutEnum, withPutEnum, withPutEnum, withPutEnum, withPutFloat, withPutFloat, withPutFloat, withPutFloat, withPutFloat, withPutInt, withPutInt, withPutInt, withPutInt, withPutInt, withPutLong, withPutLong, withPutLong, withPutLong, withPutLong, withPutShort, withPutShort, withPutShort, withPutShort, withPutShort, withPutString, withPutString, withPutString, withPutString, withPutString, withRemoveFrom, withRemoveFrom, withRemoveFrom, withRemoveFrom, withRemoveFrom, withRemovePathsMethods inherited from interface CanonicalMap.MutableCanonicalMap
containsValue, insert, insertBetween, insertFrom, insertTo, put, put, put, put, put, putAll, putAll, putAll, putDirAt, putDirAt, putDirAt, putDirAt, putDirAt, putDirAt, putDirAt, putDirAt, putDirAt, putDirAt, putDirAt, putDirAt, removeAll, removeAll, removeAll, removeAll, removeAll, removeAll, removeDirAt, removeDirAt, removeDirAt, removeDirAt, removeDirAt, removeFrom, removeFrom, removeFrom, removeFrom, removeFrom, removePaths, removePathsMethods inherited from interface org.refcodes.mixin.Clearable
clearMethods inherited from interface Containable
sizeMethods inherited from interface org.refcodes.mixin.DelimiterAccessor
getDelimiterMethods inherited from interface org.refcodes.mixin.EmptyAccessor
isEmptyMethods inherited from interface InterOperableMap
getBoolean, getBoolean, getBoolean, getBoolean, getBoolean, getBooleanOr, getBooleanOr, getBooleanOr, getBooleanOr, getBooleanOr, getByte, getByte, getByte, getByte, getByte, getByteOr, getByteOr, getByteOr, getByteOr, getByteOr, getChar, getChar, getChar, getChar, getChar, getCharOr, getCharOr, getCharOr, getCharOr, getCharOr, getClass, getClass, getClass, getClass, getClass, getClassOr, getClassOr, getClassOr, getClassOr, getClassOr, getDouble, getDouble, getDouble, getDouble, getDouble, getDoubleOr, getDoubleOr, getDoubleOr, getDoubleOr, getDoubleOr, getEnum, getEnum, getEnum, getEnum, getEnum, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getFloat, getFloat, getFloat, getFloat, getFloat, getFloatOr, getFloatOr, getFloatOr, getFloatOr, getFloatOr, getInt, getInt, getInt, getInt, getInt, getIntOr, getIntOr, getIntOr, getIntOr, getIntOr, getLong, getLong, getLong, getLong, getLong, getLongOr, getLongOr, getLongOr, getLongOr, getLongOr, getShort, getShort, getShort, getShort, getShort, getShortOr, getShortOr, getShortOr, getShortOr, getShortOr, getString, getString, getString, getString, getString, getStringOr, getStringOr, getStringOr, getStringOr, getStringOrMethods inherited from interface InterOperableMap.MutableInterOperableMap
containsValue, insert, insertBetween, insertFrom, insertTo, putBoolean, putBoolean, putBoolean, putBoolean, putBoolean, putByte, putByte, putByte, putByte, putByte, putChar, putChar, putChar, putChar, putChar, putClass, putClass, putClass, putClass, putClass, putDouble, putDouble, putDouble, putDouble, putDouble, putEnum, putEnum, putEnum, putEnum, putEnum, putFloat, putFloat, putFloat, putFloat, putFloat, putInt, putInt, putInt, putInt, putInt, putLong, putLong, putLong, putLong, putLong, putShort, putShort, putShort, putShort, putShort, putString, putString, putString, putString, putStringMethods inherited from interface Keys.MutableValues
putMethods inherited from interface Map
clear, compute, computeIfAbsent, computeIfPresent, containsKey, containsValue, entrySet, equals, forEach, get, getOrDefault, hashCode, isEmpty, keySet, merge, put, putIfAbsent, remove, remove, replace, replace, replaceAll, size, valuesMethods inherited from interface PathMap
children, children, children, children, children, children, containsKey, containsKey, containsKey, dirs, dirs, dirs, dirs, dirs, dirs, findPaths, fromExternalPath, get, get, get, getArray, getArray, getArray, getArray, getArray, getArray, getArrayIndexes, getArrayIndexes, getArrayIndexes, getArrayIndexes, getArrayIndexes, getArrayOr, getArrayOr, getArrayOr, getArrayOr, getArrayOr, getArrayOr, getDirIndexes, getDirIndexes, getDirIndexes, getDirIndexes, getDirIndexes, getDirIndexes, getRootPath, getValueAt, getValueAt, getValueAt, getValueAt, getValueAt, getValueAt, hasChildren, hasChildren, hasChildren, hasChildren, hasChildren, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasParentPath, hasPath, hasPath, hasPath, hasPath, hasPath, hasSubDirs, hasSubDirs, hasSubDirs, hasSubDirs, hasValue, hasValue, hasValue, hasValue, hasValue, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, isArray, isArray, isArray, isArray, isArray, isArray, isChild, isChild, isChild, isChild, isDir, isDir, isDir, isDir, isDir, isEqualTo, isIndexDir, isIndexDir, isIndexDir, isIndexDir, isIndexDir, isLeaf, isLeaf, isLeaf, isLeaf, isLeaf, isRootPath, keySet, keySet, keySet, keySet, keySet, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastDirIndex, lastDirIndex, lastDirIndex, lastDirIndex, lastDirIndex, lastDirIndex, leaves, leaves, leaves, leaves, leaves, leaves, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextDirIndex, nextDirIndex, nextDirIndex, nextDirIndex, nextDirIndex, nextDirIndex, paths, paths, paths, paths, paths, paths, queryPaths, queryPaths, queryPaths, queryPaths, queryPaths, queryPaths, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, toDataStructure, toDataStructure, toExternalPath, toInstance, toInstance, toLeaf, toMap, toNormalizedPath, toParentPath, toPath, toPath, toPath, toPath, toPathElements, toPathList, toPathStack, toPrintable, toPropertyPath, toType, toType, toType, toType, toType, toType, toType, toTypeMethods inherited from interface PathMap.MutablePathMap
add, add, add, add, add, add, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendValueTo, appendValueTo, appendValueTo, appendValueTo, appendValueTo, appendValueTo, delete, delete, delete, delete, delete, fromType, fromType, fromType, fromType, fromType, fromType, fromType, fromType, insert, insert, insertBetween, insertBetween, insertBetween, insertBetween, insertBetween, insertBetween, insertBetween, insertBetween, insertBetween, insertBetween, insertFrom, insertFrom, insertFrom, insertFrom, insertFrom, insertFrom, insertFrom, insertFrom, insertFrom, insertFrom, insertTo, insertTo, insertTo, insertTo, insertTo, insertTo, insertTo, insertTo, insertTo, insertTo, merge, merge, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeTo, mergeTo, mergeTo, mergeTo, mergeTo, mergeTo, mergeTo, mergeTo, mergeTo, mergeTo, put, putArray, putArray, putArray, putArray, putArray, putArray, putArray, putArray, putArray, putArray, putArray, putArray, putValueAt, putValueAt, putValueAt, putValueAt, putValueAt, putValueAt, remove, remove, remove, removeValueAt, removeValueAt, removeValueAt, removeValueAt, removeValueAt, toSourceCode, toSourceCodeMethods inherited from interface org.refcodes.mixin.TypeAccessor
getType
-
Constructor Details
-
CanonicalMapBuilderImpl
public CanonicalMapBuilderImpl()Create an emptyCanonicalMap.CanonicalMapBuilderinstance using the default path delimiter "/" (Delimiter.PATH) for the path declarations. -
CanonicalMapBuilderImpl
public CanonicalMapBuilderImpl(char aDelimiter) Create aCanonicalMap.CanonicalMapBuilderinstance using the provided path delimiter for the path declarations.- Parameters:
aDelimiter- The path delimiter to be used for the path declarations.
-
CanonicalMapBuilderImpl
Create aCanonicalMap.CanonicalMapBuilderinstance containing the elements as ofPathMap.MutablePathMap.insert(Object)using the default path delimiter "/" (Delimiter.PATH) for the path declarations.- Parameters:
aObj- The object from which the elements are to be added.
-
CanonicalMapBuilderImpl
Create aCanonicalMap.CanonicalMapBuilderinstance containing the elements as ofPathMap.MutablePathMap.insert(Object)using the default path delimiter "/" (Delimiter.PATH) for the path declarations.- Parameters:
aToPath- The sub-path where to insert the object's introspected values to.aObj- The object from which the elements are to be added.
-
CanonicalMapBuilderImpl
Creates aCanonicalMap.CanonicalMapBuilderinstance containing the elements as ofPathMap.MutablePathMap.insert(Object)using the default path delimiter "/" (Delimiter.PATH) for the path declarations.- Parameters:
aObj- The object from which the elements are to be added.aFromPath- The path from where to start adding elements of the provided object.
-
CanonicalMapBuilderImpl
Creates aCanonicalMap.CanonicalMapBuilderinstance containing the elements as ofPathMap.MutablePathMap.insert(Object)using the default path delimiter "/" (Delimiter.PATHfor the path declarations.- Parameters:
aToPath- The sub-path where to insert the object's introspected values to.aObj- The object from which the elements are to be added.aFromPath- The path from where to start adding elements of the provided object.
-
CanonicalMapBuilderImpl
Creates aCanonicalMap.CanonicalMapBuilderinstance containing the elements as ofPathMap.MutablePathMap.insert(Object).- Parameters:
aObj- The object from which the elements are to be added.aDelimiter- The path delimiter to be used for the path declarations.
-
CanonicalMapBuilderImpl
Creates aCanonicalMap.CanonicalMapBuilderinstance containing the elements as ofPathMap.MutablePathMap.insert(Object).- Parameters:
aToPath- The sub-path where to insert the object's introspected values to.aObj- The object from which the elements are to be added.aDelimiter- The path delimiter to be used for the path declarations.
-
CanonicalMapBuilderImpl
Creates aCanonicalMap.CanonicalMapBuilderinstance containing the elements as ofPathMap.MutablePathMap.insert(Object).- Parameters:
aObj- The object from which the elements are to be added.aFromPath- The path from where to start adding elements of the provided object.aDelimiter- The path delimiter to be used for the path declarations.
-
CanonicalMapBuilderImpl
Create aCanonicalMap.CanonicalMapBuilderinstance containing the elements as ofPathMap.MutablePathMap.insert(Object).- Parameters:
aToPath- The sub-path where to insert the object's introspected values to.aObj- The object from which the elements are to be added.aFromPath- The path from where to start adding elements of the provided object.aDelimiter- The path delimiter to be used for the path declarations.
-
-
Method Details
-
retrieveFrom
Extracts a newPathMapfrom the elements of thisPathMapfound below the "from-path". The sub-paths will be the root paths for the newPathMap. Given we have a value for path "/dog/cat" in thePathMapand we callPathMap.retrieveFrom(String)with "/dog", then the resultingPathMapwill contain the path "/cat" for that value.- Specified by:
retrieveFromin interfaceCanonicalMap- Specified by:
retrieveFromin interfacePathMap<String>- Overrides:
retrieveFromin classPathMapBuilderImpl<String>- Parameters:
aFromPath- The path from where to start extracting the paths.- Returns:
- The
PathMapwith the elements below the provided path which are root elements in the newPathMap.
-
retrieveTo
Extracts a newPathMapfrom thisPathMap's elements with the paths relocated to the provided "to-path". Given we have a value for path "/dog/cat" in thePathMapand we callPathMap.retrieveTo(String)with "/animals", then the resultingPathMapwill contain the path "/animals/dog/cat" for that value.- Specified by:
retrieveToin interfaceCanonicalMap- Specified by:
retrieveToin interfacePathMap<String>- Overrides:
retrieveToin classPathMapBuilderImpl<String>- Parameters:
aToPath- The path where to relocate the paths of thisPathMapto.- Returns:
- The
PathMapwith the elements from the providedPathMapwith accordingly relocated paths.
-
withPut
Builder method forKeys.MutableValues.put(Object, Object).- Specified by:
withPutin interfaceInterOperableMap.InterOperableMapBuilder<String>- Specified by:
withPutin interfaceTable.TableDictionary.TableBuilder<String, String, PathMap.PathMapBuilder<String>>- Overrides:
withPutin classPathMapBuilderImpl<String>- Parameters:
aKey- the key for the property to be put.aValue- the value for the property to be put.- Returns:
- The implementing instance as of the builder pattern.
-
fromObject
Hook method when internally creatingPathMapsub-types in the accordingPathMapsub-type implementations.- Overrides:
fromObjectin classPathMapBuilderImpl<String>- Parameters:
aFrom- TheObjectfrom which to create aPathMap(sub-type) instance.- Returns:
- The according
PathMap(sub-type) instance.
-
fromInstance
Hook method when introspecting an object to help conversion of that object to the target types. By default this methods just tests for assignment conformity as ofClass.isAssignableFrom(Class)with the type retrieved byPathMapBuilderImpl.getType().- Overrides:
fromInstancein classPathMapBuilderImpl<String>- Parameters:
aValue- The value which is to be transformed to the expected type as ofPathMapBuilderImpl.getType().- Returns:
- The converted type or null if conversion is not possible.
-
toInstance
Hook method when reconstructing an object, opposite ofPathMapBuilderImpl.fromInstance(Object), tries to convert the given value to the desired type.- Overrides:
toInstancein classPathMapBuilderImpl<String>- Type Parameters:
TYPE- The type to which to convert to.- Parameters:
aValue- The value to by converted from this instance's type as ofPathMapBuilderImpl.getType()to the desired type.aType- The type to which to convert to.- Returns:
- The converted type or null if conversion is not possible.
-