Interface Containable

All Superinterfaces:
EmptyAccessor
All Known Subinterfaces:
CanonicalTable, ClassStructTable, Container<E>, Container.ClearableContainer<E>, Container.MutableContainer<E>, ImmutableCanonicalTable, ImmutableCanonicalTable.MutableCanonicalTable, ImmutableClassStructTable, ImmutableClassStructTable.MutableClassStructTable, ImmutableInterOperableTable<T>, ImmutableInterOperableTable.MutableInterOperableTable<T>, ImmutablePathTable<T>, ImmutablePathTable.MutablePathTable<T>, ImmutableSimpleTypeTable, ImmutableSimpleTypeTable.MutableSimpleTypeTable, ImmutableTable<K,V>, ImmutableTable.MutableTable<K,V>, InterOperableTable<T>, PathTable<T>, SimpleTypeTable, Table<K,V,B>
All Known Implementing Classes:
MapCanonicalTable, MapClassStructTable, MapPathTable, MapSimpleTypeTable, UnmodifiableCanonicalTableDecorator, UnmodifiableClassStructTableDecorator, UnmodifiablePathTableDecorator, UnmodifiableSimpleTypeTableDecorator

public interface Containable extends EmptyAccessor
A Containable is the base functionality provided container (collection). The Containableit just informs about the metrics of a container.
  • Method Details

    • size

      int size()
      Returns the number of data elements contained in the collection.
      Returns:
      An integer representing the number of items stored in the accumulation.