-
- Type Parameters:
K- The type of the key.V- The type of the value which relates to a key.
- All Superinterfaces:
Containable,org.refcodes.mixin.EmptyAccessor,Keys<K,V>
- All Known Subinterfaces:
CanonicalMap,CanonicalMap.CanonicalMapBuilder,CanonicalMap.MutableCanonicalMap,ClassStructMap,ClassStructMap.ClassStructMapBuilder,ClassStructMap.MutableClassStructMap,Dictionary.MutableDictionary<K,V>,Dictionary.MutableDictionary.DictionaryBuilder<K,V,B>,InterOperableMap<T>,InterOperableMap.InterOperableMapBuilder<T>,InterOperableMap.MutableInterOperableMap<T>,PathMap<T>,PathMap.MutablePathMap<T>,PathMap.PathMapBuilder<T>,SimpleTypeMap,SimpleTypeMap.MutableSimpleTypeMap,SimpleTypeMap.SimpleTypeMapBuilder
- All Known Implementing Classes:
CanonicalMapBuilderImpl,CanonicalMapImpl,ClassStructMapBuilderImpl,ClassStructMapImpl,PathMapBuilderImpl,PathMapImpl,SimpleTypeMapBuilderImpl,SimpleTypeMapImpl
public interface Dictionary<K,V> extends Keys<K,V>, Containable
Basic functionality being provided by anyDictionary(map) style class.
-
-
Nested Class Summary
Nested Classes Modifier and Type Interface Description static interfaceDictionary.MutableDictionary<K,V>Extends theDictionarywith mutable (writable) functionality, especially by providingKeys.MutableValues.put(Object, Object)andKeys.MutableKeys.delete(String)methods.-
Nested classes/interfaces inherited from interface org.refcodes.mixin.EmptyAccessor
org.refcodes.mixin.EmptyAccessor.EmptyMutator, org.refcodes.mixin.EmptyAccessor.EmptyProperty
-
Nested classes/interfaces inherited from interface org.refcodes.struct.Keys
Keys.MutableKeys<K,V>, Keys.MutableValues<K,V>
-
-
Method Summary
-
Methods inherited from interface org.refcodes.struct.Containable
size
-
Methods inherited from interface org.refcodes.struct.Keys
containsKey, containsValue, get, getOr, keySet, use, values
-
-