Module org.refcodes.struct
Package org.refcodes.struct
Interface Dictionary.MutableDictionary.DictionaryBuilder<K,V,B extends Dictionary.MutableDictionary.DictionaryBuilder<K,V,B>>
- Type Parameters:
K- the key typeV- The type of the value which relates to a key.B- The builder to return in order to be able to apply multiple build operations.
- All Superinterfaces:
org.refcodes.mixin.Clearable,Containable,Dictionary<K,,V> Dictionary.MutableDictionary<K,,V> org.refcodes.mixin.EmptyAccessor,Keys<K,,V> Keys.MutableKeys<K,,V> Keys.MutableValues<K,V>
- All Known Subinterfaces:
CanonicalMap.CanonicalMapBuilder,ClassStructMap.ClassStructMapBuilder,InterOperableMap.InterOperableMapBuilder<T>,PathMap.PathMapBuilder<T>,SimpleTypeMap.SimpleTypeMapBuilder
- All Known Implementing Classes:
CanonicalMapBuilderImpl,ClassStructMapBuilderImpl,PathMapBuilderImpl,SimpleTypeMapBuilderImpl
- Enclosing interface:
- Dictionary.MutableDictionary<K,
V>
public static interface Dictionary.MutableDictionary.DictionaryBuilder<K,V,B extends Dictionary.MutableDictionary.DictionaryBuilder<K,V,B>>
extends Dictionary.MutableDictionary<K,V>
Provides a builder method for a
Relation property returning
the builder for applying multiple build operations.-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.struct.Dictionary
Dictionary.MutableDictionary<K,V> Nested classes/interfaces inherited from interface org.refcodes.struct.Dictionary.MutableDictionary
Dictionary.MutableDictionary.DictionaryBuilder<K,V, B extends Dictionary.MutableDictionary.DictionaryBuilder<K, V, B>> Nested classes/interfaces inherited from interface org.refcodes.mixin.EmptyAccessor
org.refcodes.mixin.EmptyAccessor.EmptyMutator, org.refcodes.mixin.EmptyAccessor.EmptyPropertyNested classes/interfaces inherited from interface org.refcodes.struct.Keys
Keys.MutableKeys<K,V>, Keys.MutableValues<K, V> -
Method Summary
Methods inherited from interface org.refcodes.mixin.Clearable
clearMethods inherited from interface org.refcodes.struct.Containable
sizeMethods inherited from interface org.refcodes.struct.Dictionary.MutableDictionary
putMethods inherited from interface org.refcodes.mixin.EmptyAccessor
isEmptyMethods inherited from interface org.refcodes.struct.Keys
containsKey, containsValue, get, getOr, keySet, use, valuesMethods inherited from interface org.refcodes.struct.Keys.MutableKeys
deleteMethods inherited from interface org.refcodes.struct.Keys.MutableValues
put
-
Method Details
-
withPut
Builder method forKeys.MutableValues.put(Object, Object).- Parameters:
aKey- the key for the property to be put.aValue- the value for the property to be put.- Returns:
- The implementing instance as of the builder pattern.
-
withPut
Builder method forDictionary.MutableDictionary.put(Relation).- Parameters:
aRelation- the property to be put.- Returns:
- The implementing instance as of the builder pattern.
-