-
- Type Parameters:
E- The type of the elements being stored in theElements.MutableElements.
- All Known Subinterfaces:
Container<E>,Container.ClearableContainer<E>,Container.MutableContainer<E>,Elements.ClearableElements<E>,Elements.MutableElements<E>
public interface Elements<E>Basic functionality being provided by anyElements(collection) style class.
-
-
Nested Class Summary
Nested Classes Modifier and Type Interface Description static interfaceElements.ClearableElements<E>static interfaceElements.MutableElements<E>Extends theElementswith mutable (writable) functionality, especially by enabling theIterator.remove()method in theIteratorprovided viaElements.MutableElements.iterator()and by providing theElements.MutableElements.add(Object)and theElements.MutableElements.remove(Object)methods.
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description booleancontains(Object aElement)Tests whether the specified object is an element of theElements(collection).Iterator<E>iterator()Returns anIteratorinstance of all the data elements contained in theElements(collection). ------------------------------------------------------------------------- ATTENTION: TheIterator.remove()method may be disabled in the returnedIteratorinstance as theElementsis supposed to be read-only.
-
-
-
Method Detail
-
iterator
Iterator<E> iterator()
Returns anIteratorinstance of all the data elements contained in theElements(collection). ------------------------------------------------------------------------- ATTENTION: TheIterator.remove()method may be disabled in the returnedIteratorinstance as theElementsis supposed to be read-only.
-
contains
boolean contains(Object aElement)
-
-