-
- Type Parameters:
E- The type of the elements being stored in theElements.ClearableElements.
- All Superinterfaces:
org.refcodes.mixin.Clearable,Elements<E>
- All Known Subinterfaces:
Container.ClearableContainer<E>,Container.MutableContainer<E>,Elements.MutableElements<E>
public static interface Elements.ClearableElements<E> extends Elements<E>, org.refcodes.mixin.Clearable
Extends theElementsinterface withClearablefunctionality (as ofClearable.clear()). The case of having a plainElementswithout dedicatedElements.MutableElements.add(Object)orElements.MutableElements.remove(Object)methods but with a dedicatedClearable.clear()method seems to be quite common, therefore this interface has been provided.
-
-
Nested Class Summary
-
Nested classes/interfaces inherited from interface org.refcodes.struct.Elements
Elements.ClearableElements<E>, Elements.MutableElements<E>
-
-