Interface Elements.MutableElements<E>
- Type Parameters:
E- The type of the elements being stored in theElements.MutableElements.
- All Superinterfaces:
Clearable, Elements<E>, Elements.ClearableElements<E>
- All Known Subinterfaces:
Container.MutableContainer<E>
Extends the
Elements with mutable (writable) functionality,
ehttps://www.metacodes.proly by enabling the Iterator.remove()
method in the Iterator provided via iterator() and by
providing the add(Object) and the remove(Object)
methods.-
Nested Class Summary
Nested classes/interfaces inherited from interface Elements
Elements.ClearableElements<E>, Elements.MutableElements<E> -
Method Summary
Modifier and TypeMethodDescriptionbooleanSame asCollection.add(Object).iterator()Returns anIteratorinstance of all the data elements contained in the container (collection). --------------------------------------------------------------------- ATTENTION: TheIterator.remove()method is enabled in the returnedIteratorinstance as theElements.MutableElementsis possibly readable and writable.booleanSame asCollection.remove(Object).
-
Method Details
-
add
Same asCollection.add(Object).- Parameters:
aElement- the element whose presence in this collection is to be ensured- Returns:
- True if this collection changed as a result of the call
- See Also:
-
remove
Same asCollection.remove(Object).- Parameters:
aElement- The element to be removed from this collection, if present- Returns:
- True if an element was removed as a result of this call.
- See Also:
-
iterator
Returns anIteratorinstance of all the data elements contained in the container (collection). --------------------------------------------------------------------- ATTENTION: TheIterator.remove()method is enabled in the returnedIteratorinstance as theElements.MutableElementsis possibly readable and writable.
-