-
- All Known Subinterfaces:
FloatArrayAccessor.FloatArrayProperty
public interface FloatArrayAccessorProvides an accessor for a float array property.
-
-
Nested Class Summary
Nested Classes Modifier and Type Interface Description static interfaceFloatArrayAccessor.FloatArrayBuilder<B extends FloatArrayAccessor.FloatArrayBuilder<B>>Provides a builder method for a float array property returning the builder for applying multiple build operations.static interfaceFloatArrayAccessor.FloatArrayMutatorProvides a mutator for a float array property.static interfaceFloatArrayAccessor.FloatArrayPropertyProvides a float array property.
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description float[]getFloats()Retrieves the float array from the float array property.
-