Module org.refcodes.struct
Package org.refcodes.struct
Interface FloatArrayAccessor.FloatArrayMutator
-
- All Known Subinterfaces:
FloatArrayAccessor.FloatArrayProperty
- Enclosing interface:
- FloatArrayAccessor
public static interface FloatArrayAccessor.FloatArrayMutatorProvides a mutator for a float array property.
-
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description voidsetFloats(float[] aFloats)Sets the float array for the float array property.
-