Interface ImmutableTable.MutableTable<K,V>

Type Parameters:
K - The type of the keys.
V - The type of a value relating to a key.
All Superinterfaces:
Clearable, Containable, EmptyAccessor, ImmutableTable<K,V>, Keys<K,V>, Keys.MutableKeys<K,V>, Keys.MutableValues<K,V>, Map<K,V>
All Known Subinterfaces:
CanonicalTable, ClassStructTable, ImmutableCanonicalTable.MutableCanonicalTable, ImmutableClassStructTable.MutableClassStructTable, ImmutableInterOperableTable.MutableInterOperableTable<T>, ImmutablePathTable.MutablePathTable<T>, ImmutableSimpleTypeTable.MutableSimpleTypeTable, InterOperableTable<T>, PathTable<T>, SimpleTypeTable, Table<K,V,B>
All Known Implementing Classes:
MapCanonicalTable, MapClassStructTable, MapPathTable, MapSimpleTypeTable
Enclosing interface:
ImmutableTable<K,V>

public static interface ImmutableTable.MutableTable<K,V> extends ImmutableTable<K,V>, Keys.MutableValues<K,V>, Map<K,V>
The ImmutableTable.MutableTable type extends the ImmutableTable type with mutable (writable) functionality and provides mutator methods such as Keys.MutableValues.put(Object, Object) and delete(String) methods.
  • Method Details

    • put

      default V put(Relation<K,V> aRelation)
      Adds the given element related to the given key.
      Parameters:
      aRelation - the relation
      Returns:
      The value being replaced by the provided value or null if none value has been replaced.
    • delete

      default V delete(Object aKey)
      Removes an element identified by the given key.
      Specified by:
      delete in interface Keys.MutableKeys<K,V>
      Parameters:
      aKey - The key which's element is to be removed.
      Returns:
      The value being removed.