Module org.refcodes.struct
Package org.refcodes.struct
Interface InterOperableMap.MutableInterOperableMap<T>
-
- All Superinterfaces:
org.refcodes.mixin.AnnotatorAccessor,org.refcodes.mixin.Clearable,Containable,org.refcodes.mixin.DelimiterAccessor,Dictionary<String,T>,Dictionary.MutableDictionary<String,T>,org.refcodes.mixin.Dumpable,org.refcodes.mixin.EmptyAccessor,Keys<String,T>,Keys.MutableKeys<String,T>,Keys.MutableValues<String,T>,Map<String,T>,PathMap<T>,PathMap.MutablePathMap<T>,org.refcodes.mixin.TypeAccessor<T>
- All Known Subinterfaces:
CanonicalMap.CanonicalMapBuilder,CanonicalMap.MutableCanonicalMap,InterOperableMap.InterOperableMapBuilder<T>,SimpleTypeMap.MutableSimpleTypeMap,SimpleTypeMap.SimpleTypeMapBuilder
- All Known Implementing Classes:
CanonicalMapBuilderImpl,SimpleTypeMapBuilderImpl
- Enclosing interface:
- InterOperableMap<T>
public static interface InterOperableMap.MutableInterOperableMap<T> extends PathMap.MutablePathMap<T>
TheInterOperableMap.InterOperableMapBuilderprovides convenience accessor default methods for supporting primitive data types.
-
-
Nested Class Summary
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.AnnotatorAccessor
org.refcodes.mixin.AnnotatorAccessor.AnnotatorBuilder<B extends org.refcodes.mixin.AnnotatorAccessor.AnnotatorBuilder<B>>, org.refcodes.mixin.AnnotatorAccessor.AnnotatorMutator, org.refcodes.mixin.AnnotatorAccessor.AnnotatorProperty
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.DelimiterAccessor
org.refcodes.mixin.DelimiterAccessor.DelimiterBuilder<B extends org.refcodes.mixin.DelimiterAccessor.DelimiterBuilder<B>>, org.refcodes.mixin.DelimiterAccessor.DelimiterMutator, org.refcodes.mixin.DelimiterAccessor.DelimiterProperty
-
Nested classes/interfaces inherited from interface org.refcodes.struct.Dictionary
Dictionary.MutableDictionary<K,V>
-
Nested classes/interfaces inherited from interface org.refcodes.struct.Dictionary.MutableDictionary
Dictionary.MutableDictionary.DictionaryBuilder<K,V,B extends Dictionary.MutableDictionary.DictionaryBuilder<K,V,B>>
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.EmptyAccessor
org.refcodes.mixin.EmptyAccessor.EmptyMutator, org.refcodes.mixin.EmptyAccessor.EmptyProperty
-
Nested classes/interfaces inherited from interface org.refcodes.struct.Keys
Keys.MutableKeys<K,V>, Keys.MutableValues<K,V>
-
Nested classes/interfaces inherited from interface java.util.Map
Map.Entry<K extends Object,V extends Object>
-
Nested classes/interfaces inherited from interface org.refcodes.struct.PathMap
PathMap.MutablePathMap<T>, PathMap.PathMapBuilder<T>
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.TypeAccessor
org.refcodes.mixin.TypeAccessor.TypeBuilder<T extends Object,B extends org.refcodes.mixin.TypeAccessor.TypeBuilder<T,B>>, org.refcodes.mixin.TypeAccessor.TypeMutator<T extends Object>, org.refcodes.mixin.TypeAccessor.TypeProperty<T extends Object>
-
-
Method Summary
All Methods Instance Methods Default Methods Modifier and Type Method Description default booleancontainsValue(Object value)This method is defined for the sake ofMapconformity.default voidinsert(InterOperableMap.InterOperableMapBuilder<T> aFrom)Method to semantically emphasize that we support our own types.default voidinsertBetween(String aToPath, InterOperableMap.InterOperableMapBuilder<T> aFrom, String aFromPath)Method to semantically emphasize that we support our own types.default voidinsertFrom(InterOperableMap.InterOperableMapBuilder<T> aFrom, String aFromPath)Method to semantically emphasize that we support our own types.default voidinsertTo(String aToPath, InterOperableMap.InterOperableMapBuilder<T> aFrom)Method to semantically emphasize that we support our own types.default TputBoolean(Object[] aPathElements, Boolean aValue)Sets theBooleanvalue for the property referred to by the path elements representing the addressed path.default TputBoolean(Object aKey, Boolean aValue)Sets theBooleanvalue for the property referred to by the key.default TputBoolean(String[] aPathElements, Boolean aValue)Sets theBooleanvalue for the property referred to by the path elements representing the addressed path.default TputBoolean(String aKey, Boolean aValue)Sets theBooleanvalue for the property referred to by the key.default TputBoolean(Collection<?> aPathElements, Boolean aValue)Sets theBooleanvalue for the property referred to by the path elements representing the addressed path.default TputByte(Object[] aPathElements, Byte aValue)Sets theBytevalue for the property referred to by the path elements representing the addressed path.default TputByte(Object aKey, Byte aValue)Sets theBytevalue for the property referred to by the key.default TputByte(String[] aPathElements, Byte aValue)Sets theBytevalue for the property referred to by the path elements representing the addressed path.default TputByte(String aKey, Byte aValue)Sets theBytevalue for the property referred to by the key.default TputByte(Collection<?> aPathElements, Byte aValue)Sets theBytevalue for the property referred to by the path elements representing the addressed path.default TputChar(Object[] aPathElements, Character aValue)Sets theCharactervalue for the property referred to by the path elements representing the addressed path.default TputChar(Object aKey, Character aValue)Sets theCharactervalue for the property referred to by the key.default TputChar(String[] aPathElements, Character aValue)Sets theCharactervalue for the property referred to by the path elements representing the addressed path.default TputChar(String aKey, Character aValue)Sets theCharactervalue for the property referred to by the key.default TputChar(Collection<?> aPathElements, Character aValue)Sets theCharactervalue for the property referred to by the path elements representing the addressed path.default <C> TputClass(Object[] aPathElements, Class<C> aValue)Sets theClassvalue for the property referred to by the path elements representing the addressed path.default <C> TputClass(Object aKey, Class<C> aValue)Sets theClassvalue for the property referred to by the key.default <C> TputClass(String[] aPathElements, Class<C> aValue)Sets theClassvalue for the property referred to by the path elements representing the addressed path.default <C> TputClass(String aKey, Class<C> aValue)Sets theClassvalue for the property referred to by the key.default <C> TputClass(Collection<?> aPathElements, Class<C> aValue)Sets theClassvalue for the property referred to by the path elements representing the addressed path.default TputDouble(Object[] aPathElements, Double aValue)Sets theDoublevalue for the property referred to by the path elements representing the addressed path.default TputDouble(Object aKey, Double aValue)Sets theDoublevalue for the property referred to by the key.default TputDouble(String[] aPathElements, Double aValue)Sets theDoublevalue for the property referred to by the path elements representing the addressed path.default TputDouble(String aKey, Double aValue)Sets theDoublevalue for the property referred to by the key.default TputDouble(Collection<?> aPathElements, Double aValue)Sets theDoublevalue for the property referred to by the path elements representing the addressed path.default <E extends Enum<E>>
TputEnum(Object[] aPathElements, E aValue)Sets theEnumvalue for the property referred to by the path elements representing the addressed path.default <E extends Enum<E>>
TputEnum(Object aKey, E aValue)Sets theEnumvalue for the property referred to by the key.default <E extends Enum<E>>
TputEnum(String[] aPathElements, E aValue)Sets theEnumvalue for the property referred to by the path elements representing the addressed path.default <E extends Enum<E>>
TputEnum(String aKey, E aValue)Sets theEnumvalue for the property referred to by the key.default <E extends Enum<E>>
TputEnum(Collection<?> aPathElements, E aValue)Sets theEnumvalue for the property referred to by the path elements representing the addressed path.default TputFloat(Object[] aPathElements, Float aValue)Sets theFloatvalue for the property referred to by the path elements representing the addressed path.default TputFloat(Object aKey, Float aValue)Sets theFloatvalue for the property referred to by the key.default TputFloat(String[] aPathElements, Float aValue)Sets theFloatvalue for the property referred to by the path elements representing the addressed path.default TputFloat(String aKey, Float aValue)Sets theFloatvalue for the property referred to by the key.default TputFloat(Collection<?> aPathElements, Float aValue)Sets theFloatvalue for the property referred to by the path elements representing the addressed path.default TputInt(Object[] aPathElements, Integer aValue)Sets theIntegervalue for the property referred to by the path elements representing the addressed path.default TputInt(Object aKey, Integer aValue)Sets theIntegervalue for the property referred to by the key.default TputInt(String[] aPathElements, Integer aValue)Sets theIntegervalue for the property referred to by the path elements representing the addressed path.default TputInt(String aKey, Integer aValue)Sets theIntegervalue for the property referred to by the key.default TputInt(Collection<?> aPathElements, Integer aValue)Sets theIntegervalue for the property referred to by the path elements representing the addressed path.default TputLong(Object[] aPathElements, Long aValue)Sets theLongvalue for the property referred to by the path elements representing the addressed path.default TputLong(Object aKey, Long aValue)Sets theLongvalue for the property referred to by the key.default TputLong(String[] aPathElements, Long aValue)Sets theLongvalue for the property referred to by the path elements representing the addressed path.default TputLong(String aKey, Long aValue)Sets theLongvalue for the property referred to by the key.default TputLong(Collection<?> aPathElements, Long aValue)Sets theLongvalue for the property referred to by the path elements representing the addressed path.default TputShort(Object[] aPathElements, Short aValue)Sets theShortvalue for the property referred to by the path elements representing the addressed path.default TputShort(Object aKey, Short aValue)Sets theShortvalue for the property referred to by the key.default TputShort(String[] aPathElements, Short aValue)Sets theShortvalue for the property referred to by the path elements representing the addressed path.default TputShort(String aKey, Short aValue)Sets theShortvalue for the property referred to by the key.default TputShort(Collection<?> aPathElements, Short aValue)Sets theShortvalue for the property referred to by the path elements representing the addressed path.default TputString(Object[] aPathElements, String aValue)Sets theStringvalue for the property referred to by the path elements representing the addressed path.default TputString(Object aKey, String aValue)Sets theStringvalue for the property referred to by the key.default TputString(String[] aPathElements, String aValue)Sets theStringvalue for the property referred to by the path elements representing the addressed path.default TputString(String aKey, String aValue)Sets theStringvalue for the property referred to by the key.default TputString(Collection<?> aPathElements, String aValue)Sets theStringvalue for the property referred to by the path elements representing the addressed path.-
Methods inherited from interface org.refcodes.struct.Containable
size
-
Methods inherited from interface org.refcodes.struct.Keys
containsKey, get, getOr, keySet, use, values
-
Methods inherited from interface org.refcodes.struct.Keys.MutableValues
put
-
Methods inherited from interface java.util.Map
clear, compute, computeIfAbsent, computeIfPresent, containsKey, entrySet, equals, forEach, get, getOrDefault, hashCode, isEmpty, keySet, merge, put, putAll, putIfAbsent, remove, remove, replace, replace, replaceAll, size, values
-
Methods inherited from interface org.refcodes.struct.PathMap
children, children, children, children, children, children, containsKey, containsKey, containsKey, dirs, dirs, dirs, dirs, dirs, dirs, findPaths, fromExternalPath, get, get, get, getArray, getArray, getArray, getArray, getArray, getArrayIndexes, getArrayIndexes, getArrayIndexes, getArrayIndexes, getArrayIndexes, getArrayOr, getArrayOr, getArrayOr, getArrayOr, getArrayOr, getDir, getDir, getDir, getDir, getDir, getDirAt, getDirAt, getDirAt, getDirAt, getDirAt, getDirAt, getDirIndexes, getDirIndexes, getDirIndexes, getDirIndexes, getDirIndexes, getDirs, getDirs, getDirs, getDirs, getDirs, getRootPath, getValueAt, getValueAt, getValueAt, getValueAt, getValueAt, getValueAt, hasChildren, hasChildren, hasChildren, hasChildren, hasChildren, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasParentPath, hasPath, hasPath, hasPath, hasPath, hasSubDirs, hasSubDirs, hasSubDirs, hasSubDirs, hasValue, hasValue, hasValue, hasValue, hasValue, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, isArray, isArray, isArray, isArray, isArray, isArray, isChild, isChild, isChild, isChild, isDir, isDir, isDir, isDir, isDir, isEqualTo, isIndexDir, isIndexDir, isIndexDir, isIndexDir, isIndexDir, isLeaf, isLeaf, isLeaf, isLeaf, isLeaf, isRootPath, keySet, keySet, keySet, keySet, keySet, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastDirIndex, lastDirIndex, lastDirIndex, lastDirIndex, lastDirIndex, lastDirIndex, leaves, leaves, leaves, leaves, leaves, leaves, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextDirIndex, nextDirIndex, nextDirIndex, nextDirIndex, nextDirIndex, nextDirIndex, paths, paths, paths, paths, paths, paths, query, query, query, query, query, queryBetween, queryBetween, queryBetween, queryBetween, queryBetween, queryBetween, queryFrom, queryFrom, queryFrom, queryFrom, queryFrom, queryFrom, queryPaths, queryPaths, queryPaths, queryPaths, queryPaths, queryPaths, queryTo, queryTo, queryTo, queryTo, queryTo, queryTo, retrieveBetween, retrieveBetween, retrieveBetween, retrieveBetween, retrieveBetween, retrieveFrom, retrieveFrom, retrieveFrom, retrieveFrom, retrieveFrom, retrieveTo, retrieveTo, retrieveTo, retrieveTo, retrieveTo, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, toDataStructure, toDataStructure, toExternalPath, toInstance, toInstance, toLeaf, toMap, toMap, toNormalizedPath, toParentPath, toPath, toPath, toPath, toPath, toPathElements, toPathList, toPathStack, toPropertyPath, toType, toType, toType, toType, toType, toType, toType, toType
-
Methods inherited from interface org.refcodes.struct.PathMap.MutablePathMap
add, add, add, add, add, add, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendValueTo, appendValueTo, appendValueTo, appendValueTo, appendValueTo, appendValueTo, delete, delete, delete, delete, delete, insert, insert, insertBetween, insertBetween, insertBetween, insertBetween, insertBetween, insertBetween, insertBetween, insertBetween, insertBetween, insertBetween, insertFrom, insertFrom, insertFrom, insertFrom, insertFrom, insertFrom, insertFrom, insertFrom, insertFrom, insertFrom, insertTo, insertTo, insertTo, insertTo, insertTo, insertTo, insertTo, insertTo, insertTo, insertTo, merge, merge, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeTo, mergeTo, mergeTo, mergeTo, mergeTo, mergeTo, mergeTo, mergeTo, mergeTo, mergeTo, put, put, put, put, putArray, putArray, putArray, putArray, putArray, putArray, putArray, putArray, putArray, putArray, putArray, putArray, putDirAt, putDirAt, putDirAt, putDirAt, putDirAt, putDirAt, putDirAt, putDirAt, putDirAt, putDirAt, putDirAt, putDirAt, putValueAt, putValueAt, putValueAt, putValueAt, putValueAt, putValueAt, remove, remove, remove, removeAll, removeAll, removeAll, removeAll, removeAll, removeAll, removeDirAt, removeDirAt, removeDirAt, removeDirAt, removeDirAt, removeFrom, removeFrom, removeFrom, removeFrom, removeFrom, removePaths, removePaths, removeValueAt, removeValueAt, removeValueAt, removeValueAt, removeValueAt, toSourceCode, toSourceCode
-
-
-
-
Method Detail
-
containsValue
default boolean containsValue(Object value)
This method is defined for the sake ofMapconformity. Tests whether the provided value has a key assigned.- Specified by:
containsValuein interfaceKeys<String,T>- Specified by:
containsValuein interfaceMap<String,T>- Parameters:
value- The value to test if a key references this value.- Returns:
- True in case the given value is referenced by a key.
-
insert
default void insert(InterOperableMap.InterOperableMapBuilder<T> aFrom)
Method to semantically emphasize that we support our own types. Actually delegates toPathMap.MutablePathMap.insert(Object).- Parameters:
aFrom- TheInterOperableMap.InterOperableMapBuilderwhich is to be inspected with the therein contained values being added with their according determined paths.
-
insertBetween
default void insertBetween(String aToPath, InterOperableMap.InterOperableMapBuilder<T> aFrom, String aFromPath)
Method to semantically emphasize that we support our own types. Actually delegates toPathMap.MutablePathMap.insertBetween(String, Object, String).- Parameters:
aToPath- The sub-path where to insert the object's introspected values to.aFrom- TheInterOperableMap.InterOperableMapBuilderwhich is to be inspected with the therein contained values being added with their according determined paths.aFromPath- The path from where to start adding elements of the provided object.
-
insertFrom
default void insertFrom(InterOperableMap.InterOperableMapBuilder<T> aFrom, String aFromPath)
Method to semantically emphasize that we support our own types. Actually delegates toPathMap.MutablePathMap.insertFrom(Object, String).- Parameters:
aFrom- TheInterOperableMap.InterOperableMapBuilderwhich is to be inspected with the therein contained values being added with their according determined paths.aFromPath- The path from where to start adding elements of the provided object.
-
insertTo
default void insertTo(String aToPath, InterOperableMap.InterOperableMapBuilder<T> aFrom)
Method to semantically emphasize that we support our own types. Actually delegates toPathMap.MutablePathMap.insertTo(String, Object).- Parameters:
aToPath- The sub-path where to insert the object's introspected values to.aFrom- TheInterOperableMap.InterOperableMapBuilderwhich is to be inspected with the therein contained values being added with their according determined paths.
-
putBoolean
default T putBoolean(Object aKey, Boolean aValue)
Sets theBooleanvalue for the property referred to by the key. As property keys and values are of typeString, theBooleanvalue is converted accordingly.- Parameters:
aKey- The key for which to retrieve the value.aValue- TheBooleanrepresentation for theStringvalue.- Returns:
- The previous value associated with path, or null if there was no mapping for the path. (A null return can also indicate that the map previously associated null with the path, if the implementation supports null values.)
-
putBoolean
default T putBoolean(Object[] aPathElements, Boolean aValue)
Sets theBooleanvalue for the property referred to by the path elements representing the addressed path. As property keys and values are of typeString, theBooleanvalue is converted accordingly.- Parameters:
aPathElements- The path elements of the path addressing the value.aValue- The valueBooleanto be associated with the path.- Returns:
- The previous value associated with path, or null if there was no mapping for the path. (A null return can also indicate that the map previously associated null with the path, if the implementation supports null values.)
-
putBoolean
default T putBoolean(Collection<?> aPathElements, Boolean aValue)
Sets theBooleanvalue for the property referred to by the path elements representing the addressed path. As property keys and values are of typeString, theBooleanvalue is converted accordingly.- Parameters:
aPathElements- The path elements of the path addressing the value.aValue- The valueBooleanto be associated with the path.- Returns:
- The previous value associated with path, or null if there was no mapping for the path. (A null return can also indicate that the map previously associated null with the path, if the implementation supports null values.)
-
putBoolean
default T putBoolean(String aKey, Boolean aValue)
Sets theBooleanvalue for the property referred to by the key. As property keys and values are of typeString, theBooleanvalue is converted accordingly.- Parameters:
aKey- The key for which to retrieve the value.aValue- TheBooleanrepresentation for theStringvalue.- Returns:
- The previous value associated with path, or null if there was no mapping for the path. (A null return can also indicate that the map previously associated null with the path, if the implementation supports null values.)
-
putBoolean
default T putBoolean(String[] aPathElements, Boolean aValue)
Sets theBooleanvalue for the property referred to by the path elements representing the addressed path. As property keys and values are of typeString, theBooleanvalue is converted accordingly.- Parameters:
aPathElements- The path elements of the path addressing the value.aValue- TheBooleanvalue to be associated with the path.- Returns:
- The previous value associated with path, or null if there was no mapping for the path. (A null return can also indicate that the map previously associated null with the path, if the implementation supports null values.)
-
putByte
default T putByte(Object aKey, Byte aValue)
Sets theBytevalue for the property referred to by the key. As property keys and values are of typeString, theBooleanvalue is converted accordingly.- Parameters:
aKey- The key for which to retrieve the value.aValue- TheByterepresentation for theStringvalue.- Returns:
- The previous value associated with path, or null if there was no mapping for the path. (A null return can also indicate that the map previously associated null with the path, if the implementation supports null values.)
-
putByte
default T putByte(Object[] aPathElements, Byte aValue)
Sets theBytevalue for the property referred to by the path elements representing the addressed path. As property keys and values are of typeString, theBytevalue is converted accordingly.- Parameters:
aPathElements- The path elements of the path addressing the value.aValue- The valueByteto be associated with the path.- Returns:
- The previous value associated with path, or null if there was no mapping for the path. (A null return can also indicate that the map previously associated null with the path, if the implementation supports null values.)
-
putByte
default T putByte(Collection<?> aPathElements, Byte aValue)
Sets theBytevalue for the property referred to by the path elements representing the addressed path. As property keys and values are of typeString, theBytevalue is converted accordingly.- Parameters:
aPathElements- The path elements of the path addressing the value.aValue- The valueByteto be associated with the path.- Returns:
- The previous value associated with path, or null if there was no mapping for the path. (A null return can also indicate that the map previously associated null with the path, if the implementation supports null values.)
-
putByte
default T putByte(String aKey, Byte aValue)
Sets theBytevalue for the property referred to by the key. As property keys and values are of typeString, theBytevalue is converted accordingly.- Parameters:
aKey- The key for which to retrieve the value.aValue- TheByterepresentation for theStringvalue.- Returns:
- The previous value associated with path, or null if there was no mapping for the path. (A null return can also indicate that the map previously associated null with the path, if the implementation supports null values.)
-
putByte
default T putByte(String[] aPathElements, Byte aValue)
Sets theBytevalue for the property referred to by the path elements representing the addressed path. As property keys and values are of typeString, theBytevalue is converted accordingly.- Parameters:
aPathElements- The path elements of the path addressing the value.aValue- TheBytevalue to be associated with the path.- Returns:
- The previous value associated with path, or null if there was no mapping for the path. (A null return can also indicate that the map previously associated null with the path, if the implementation supports null values.)
-
putChar
default T putChar(Object aKey, Character aValue)
Sets theCharactervalue for the property referred to by the key. As property keys and values are of typeString, theBooleanvalue is converted accordingly.- Parameters:
aKey- The key for which to retrieve the value.aValue- TheCharacterrepresentation for theStringvalue.- Returns:
- The previous value associated with path, or null if there was no mapping for the path. (A null return can also indicate that the map previously associated null with the path, if the implementation supports null values.)
-
putChar
default T putChar(Object[] aPathElements, Character aValue)
Sets theCharactervalue for the property referred to by the path elements representing the addressed path. As property keys and values are of typeString, theCharactervalue is converted accordingly.- Parameters:
aPathElements- The path elements of the path addressing the value.aValue- The valueCharacterto be associated with the path.- Returns:
- The previous value associated with path, or null if there was no mapping for the path. (A null return can also indicate that the map previously associated null with the path, if the implementation supports null values.)
-
putChar
default T putChar(Collection<?> aPathElements, Character aValue)
Sets theCharactervalue for the property referred to by the path elements representing the addressed path. As property keys and values are of typeString, theCharactervalue is converted accordingly.- Parameters:
aPathElements- The path elements of the path addressing the value.aValue- The valueCharacterto be associated with the path.- Returns:
- The previous value associated with path, or null if there was no mapping for the path. (A null return can also indicate that the map previously associated null with the path, if the implementation supports null values.)
-
putChar
default T putChar(String aKey, Character aValue)
Sets theCharactervalue for the property referred to by the key. As property keys and values are of typeString, theCharactervalue is converted accordingly.- Parameters:
aKey- The key for which to retrieve the value.aValue- TheCharacterrepresentation for theStringvalue.- Returns:
- The previous value associated with path, or null if there was no mapping for the path. (A null return can also indicate that the map previously associated null with the path, if the implementation supports null values.)
-
putChar
default T putChar(String[] aPathElements, Character aValue)
Sets theCharactervalue for the property referred to by the path elements representing the addressed path. As property keys and values are of typeString, theCharactervalue is converted accordingly.- Parameters:
aPathElements- The path elements of the path addressing the value.aValue- TheCharactervalue to be associated with the path.- Returns:
- The previous value associated with path, or null if there was no mapping for the path. (A null return can also indicate that the map previously associated null with the path, if the implementation supports null values.)
-
putClass
default <C> T putClass(Object aKey, Class<C> aValue)
Sets theClassvalue for the property referred to by the key. As property keys and values are of typeString, theBooleanvalue is converted accordingly.- Type Parameters:
C- The type of the class in question.- Parameters:
aKey- The key for which to retrieve the value.aValue- TheClassrepresentation for theStringvalue.- Returns:
- The previous value associated with path, or null if there was no mapping for the path. (A null return can also indicate that the map previously associated null with the path, if the implementation supports null values.)
-
putClass
default <C> T putClass(Object[] aPathElements, Class<C> aValue)
Sets theClassvalue for the property referred to by the path elements representing the addressed path. As property keys and values are of typeString, theClassvalue is converted accordingly.- Type Parameters:
C- The type of the class in question.- Parameters:
aPathElements- The path elements of the path addressing the value.aValue- The valueClassto be associated with the path.- Returns:
- The previous value associated with path, or null if there was no mapping for the path. (A null return can also indicate that the map previously associated null with the path, if the implementation supports null values.)
-
putClass
default <C> T putClass(Collection<?> aPathElements, Class<C> aValue)
Sets theClassvalue for the property referred to by the path elements representing the addressed path. As property keys and values are of typeString, theClassvalue is converted accordingly.- Type Parameters:
C- The type of the class in question.- Parameters:
aPathElements- The path elements of the path addressing the value.aValue- The valueClassto be associated with the path.- Returns:
- The previous value associated with path, or null if there was no mapping for the path. (A null return can also indicate that the map previously associated null with the path, if the implementation supports null values.)
-
putClass
default <C> T putClass(String aKey, Class<C> aValue)
Sets theClassvalue for the property referred to by the key. As property keys and values are of typeString, theClassvalue is converted accordingly.- Type Parameters:
C- The type of the class in question.- Parameters:
aKey- The key for which to retrieve the value.aValue- TheClassrepresentation for theStringvalue.- Returns:
- The previous value associated with path, or null if there was no mapping for the path. (A null return can also indicate that the map previously associated null with the path, if the implementation supports null values.)
-
putClass
default <C> T putClass(String[] aPathElements, Class<C> aValue)
Sets theClassvalue for the property referred to by the path elements representing the addressed path. As property keys and values are of typeString, theClassvalue is converted accordingly.- Type Parameters:
C- The type of the class in question.- Parameters:
aPathElements- The path elements of the path addressing the value.aValue- TheClassvalue to be associated with the path.- Returns:
- The previous value associated with path, or null if there was no mapping for the path. (A null return can also indicate that the map previously associated null with the path, if the implementation supports null values.)
-
putDouble
default T putDouble(Object aKey, Double aValue)
Sets theDoublevalue for the property referred to by the key. As property keys and values are of typeString, theBooleanvalue is converted accordingly.- Parameters:
aKey- The key for which to retrieve the value.aValue- TheDoublerepresentation for theStringvalue.- Returns:
- The previous value associated with path, or null if there was no mapping for the path. (A null return can also indicate that the map previously associated null with the path, if the implementation supports null values.)
-
putDouble
default T putDouble(Object[] aPathElements, Double aValue)
Sets theDoublevalue for the property referred to by the path elements representing the addressed path. As property keys and values are of typeString, theDoublevalue is converted accordingly.- Parameters:
aPathElements- The path elements of the path addressing the value.aValue- The valueDoubleto be associated with the path.- Returns:
- The previous value associated with path, or null if there was no mapping for the path. (A null return can also indicate that the map previously associated null with the path, if the implementation supports null values.)
-
putDouble
default T putDouble(Collection<?> aPathElements, Double aValue)
Sets theDoublevalue for the property referred to by the path elements representing the addressed path. As property keys and values are of typeString, theDoublevalue is converted accordingly.- Parameters:
aPathElements- The path elements of the path addressing the value.aValue- The valueDoubleto be associated with the path.- Returns:
- The previous value associated with path, or null if there was no mapping for the path. (A null return can also indicate that the map previously associated null with the path, if the implementation supports null values.)
-
putDouble
default T putDouble(String aKey, Double aValue)
Sets theDoublevalue for the property referred to by the key. As property keys and values are of typeString, theDoublevalue is converted accordingly.- Parameters:
aKey- The key for which to retrieve the value.aValue- TheDoublerepresentation for theStringvalue.- Returns:
- The previous value associated with path, or null if there was no mapping for the path. (A null return can also indicate that the map previously associated null with the path, if the implementation supports null values.)
-
putDouble
default T putDouble(String[] aPathElements, Double aValue)
Sets theDoublevalue for the property referred to by the path elements representing the addressed path. As property keys and values are of typeString, theDoublevalue is converted accordingly.- Parameters:
aPathElements- The path elements of the path addressing the value.aValue- TheDoublevalue to be associated with the path.- Returns:
- The previous value associated with path, or null if there was no mapping for the path. (A null return can also indicate that the map previously associated null with the path, if the implementation supports null values.)
-
putEnum
default <E extends Enum<E>> T putEnum(Object aKey, E aValue)
Sets theEnumvalue for the property referred to by the key. As property keys and values are of typeString, theBooleanvalue is converted accordingly.- Type Parameters:
E- The type of the enumeration in question.- Parameters:
aKey- The key for which to retrieve the value.aValue- TheEnumrepresentation for theStringvalue.- Returns:
- The previous value associated with path, or null if there was no mapping for the path. (A null return can also indicate that the map previously associated null with the path, if the implementation supports null values.)
-
putEnum
default <E extends Enum<E>> T putEnum(Object[] aPathElements, E aValue)
Sets theEnumvalue for the property referred to by the path elements representing the addressed path. As property keys and values are of typeString, theEnumvalue is converted accordingly.- Type Parameters:
E- The type of the enumeration in question.- Parameters:
aPathElements- The path elements of the path addressing the value.aValue- The valueEnumto be associated with the path.- Returns:
- The previous value associated with path, or null if there was no mapping for the path. (A null return can also indicate that the map previously associated null with the path, if the implementation supports null values.)
-
putEnum
default <E extends Enum<E>> T putEnum(Collection<?> aPathElements, E aValue)
Sets theEnumvalue for the property referred to by the path elements representing the addressed path. As property keys and values are of typeString, theEnumvalue is converted accordingly.- Type Parameters:
E- The type of the enumeration in question.- Parameters:
aPathElements- The path elements of the path addressing the value.aValue- The valueEnumto be associated with the path.- Returns:
- The previous value associated with path, or null if there was no mapping for the path. (A null return can also indicate that the map previously associated null with the path, if the implementation supports null values.)
-
putEnum
default <E extends Enum<E>> T putEnum(String aKey, E aValue)
Sets theEnumvalue for the property referred to by the key. As property keys and values are of typeString, theEnumvalue is converted accordingly.- Type Parameters:
E- The type of the enumeration in question.- Parameters:
aKey- The key for which to retrieve the value.aValue- TheEnumrepresentation for theStringvalue.- Returns:
- The previous value associated with path, or null if there was no mapping for the path. (A null return can also indicate that the map previously associated null with the path, if the implementation supports null values.)
-
putEnum
default <E extends Enum<E>> T putEnum(String[] aPathElements, E aValue)
Sets theEnumvalue for the property referred to by the path elements representing the addressed path. As property keys and values are of typeString, theEnumvalue is converted accordingly.- Type Parameters:
E- The type of the enumeration in question.- Parameters:
aPathElements- The path elements of the path addressing the value.aValue- TheEnumvalue to be associated with the path.- Returns:
- The previous value associated with path, or null if there was no mapping for the path. (A null return can also indicate that the map previously associated null with the path, if the implementation supports null values.)
-
putFloat
default T putFloat(Object aKey, Float aValue)
Sets theFloatvalue for the property referred to by the key. As property keys and values are of typeString, theBooleanvalue is converted accordingly.- Parameters:
aKey- The key for which to retrieve the value.aValue- TheFloatrepresentation for theStringvalue.- Returns:
- The previous value associated with path, or null if there was no mapping for the path. (A null return can also indicate that the map previously associated null with the path, if the implementation supports null values.)
-
putFloat
default T putFloat(Object[] aPathElements, Float aValue)
Sets theFloatvalue for the property referred to by the path elements representing the addressed path. As property keys and values are of typeString, theFloatvalue is converted accordingly.- Parameters:
aPathElements- The path elements of the path addressing the value.aValue- The valueFloatto be associated with the path.- Returns:
- The previous value associated with path, or null if there was no mapping for the path. (A null return can also indicate that the map previously associated null with the path, if the implementation supports null values.)
-
putFloat
default T putFloat(Collection<?> aPathElements, Float aValue)
Sets theFloatvalue for the property referred to by the path elements representing the addressed path. As property keys and values are of typeString, theFloatvalue is converted accordingly.- Parameters:
aPathElements- The path elements of the path addressing the value.aValue- The valueFloatto be associated with the path.- Returns:
- The previous value associated with path, or null if there was no mapping for the path. (A null return can also indicate that the map previously associated null with the path, if the implementation supports null values.)
-
putFloat
default T putFloat(String aKey, Float aValue)
Sets theFloatvalue for the property referred to by the key. As property keys and values are of typeString, theFloatvalue is converted accordingly.- Parameters:
aKey- The key for which to retrieve the value.aValue- TheFloatrepresentation for theStringvalue.- Returns:
- The previous value associated with path, or null if there was no mapping for the path. (A null return can also indicate that the map previously associated null with the path, if the implementation supports null values.)
-
putFloat
default T putFloat(String[] aPathElements, Float aValue)
Sets theFloatvalue for the property referred to by the path elements representing the addressed path. As property keys and values are of typeString, theFloatvalue is converted accordingly.- Parameters:
aPathElements- The path elements of the path addressing the value.aValue- TheFloatvalue to be associated with the path.- Returns:
- The previous value associated with path, or null if there was no mapping for the path. (A null return can also indicate that the map previously associated null with the path, if the implementation supports null values.)
-
putInt
default T putInt(Object aKey, Integer aValue)
Sets theIntegervalue for the property referred to by the key. As property keys and values are of typeString, theBooleanvalue is converted accordingly.- Parameters:
aKey- The key for which to retrieve the value.aValue- TheIntegerrepresentation for theStringvalue.- Returns:
- The previous value associated with path, or null if there was no mapping for the path. (A null return can also indicate that the map previously associated null with the path, if the implementation supports null values.)
-
putInt
default T putInt(Object[] aPathElements, Integer aValue)
Sets theIntegervalue for the property referred to by the path elements representing the addressed path. As property keys and values are of typeString, theIntegervalue is converted accordingly.- Parameters:
aPathElements- The path elements of the path addressing the value.aValue- The valueIntegerto be associated with the path.- Returns:
- The previous value associated with path, or null if there was no mapping for the path. (A null return can also indicate that the map previously associated null with the path, if the implementation supports null values.)
-
putInt
default T putInt(Collection<?> aPathElements, Integer aValue)
Sets theIntegervalue for the property referred to by the path elements representing the addressed path. As property keys and values are of typeString, theIntegervalue is converted accordingly.- Parameters:
aPathElements- The path elements of the path addressing the value.aValue- The valueIntegerto be associated with the path.- Returns:
- The previous value associated with path, or null if there was no mapping for the path. (A null return can also indicate that the map previously associated null with the path, if the implementation supports null values.)
-
putInt
default T putInt(String aKey, Integer aValue)
Sets theIntegervalue for the property referred to by the key. As property keys and values are of typeString, theIntegervalue is converted accordingly.- Parameters:
aKey- The key for which to retrieve the value.aValue- TheIntegerrepresentation for theStringvalue.- Returns:
- The previous value associated with path, or null if there was no mapping for the path. (A null return can also indicate that the map previously associated null with the path, if the implementation supports null values.)
-
putInt
default T putInt(String[] aPathElements, Integer aValue)
Sets theIntegervalue for the property referred to by the path elements representing the addressed path. As property keys and values are of typeString, theIntegervalue is converted accordingly.- Parameters:
aPathElements- The path elements of the path addressing the value.aValue- TheIntegervalue to be associated with the path.- Returns:
- The previous value associated with path, or null if there was no mapping for the path. (A null return can also indicate that the map previously associated null with the path, if the implementation supports null values.)
-
putLong
default T putLong(Object aKey, Long aValue)
Sets theLongvalue for the property referred to by the key. As property keys and values are of typeString, theBooleanvalue is converted accordingly.- Parameters:
aKey- The key for which to retrieve the value.aValue- TheLongrepresentation for theStringvalue.- Returns:
- The previous value associated with path, or null if there was no mapping for the path. (A null return can also indicate that the map previously associated null with the path, if the implementation supports null values.)
-
putLong
default T putLong(Object[] aPathElements, Long aValue)
Sets theLongvalue for the property referred to by the path elements representing the addressed path. As property keys and values are of typeString, theLongvalue is converted accordingly.- Parameters:
aPathElements- The path elements of the path addressing the value.aValue- The valueLongto be associated with the path.- Returns:
- The previous value associated with path, or null if there was no mapping for the path. (A null return can also indicate that the map previously associated null with the path, if the implementation supports null values.)
-
putLong
default T putLong(Collection<?> aPathElements, Long aValue)
Sets theLongvalue for the property referred to by the path elements representing the addressed path. As property keys and values are of typeString, theLongvalue is converted accordingly.- Parameters:
aPathElements- The path elements of the path addressing the value.aValue- The valueLongto be associated with the path.- Returns:
- The previous value associated with path, or null if there was no mapping for the path. (A null return can also indicate that the map previously associated null with the path, if the implementation supports null values.)
-
putLong
default T putLong(String aKey, Long aValue)
Sets theLongvalue for the property referred to by the key. As property keys and values are of typeString, theLongvalue is converted accordingly.- Parameters:
aKey- The key for which to retrieve the value.aValue- TheLongrepresentation for theStringvalue.- Returns:
- The previous value associated with path, or null if there was no mapping for the path. (A null return can also indicate that the map previously associated null with the path, if the implementation supports null values.)
-
putLong
default T putLong(String[] aPathElements, Long aValue)
Sets theLongvalue for the property referred to by the path elements representing the addressed path. As property keys and values are of typeString, theLongvalue is converted accordingly.- Parameters:
aPathElements- The path elements of the path addressing the value.aValue- TheLongvalue to be associated with the path.- Returns:
- The previous value associated with path, or null if there was no mapping for the path. (A null return can also indicate that the map previously associated null with the path, if the implementation supports null values.)
-
putShort
default T putShort(Object aKey, Short aValue)
Sets theShortvalue for the property referred to by the key. As property keys and values are of typeString, theBooleanvalue is converted accordingly.- Parameters:
aKey- The key for which to retrieve the value.aValue- TheShortrepresentation for theStringvalue.- Returns:
- The previous value associated with path, or null if there was no mapping for the path. (A null return can also indicate that the map previously associated null with the path, if the implementation supports null values.)
-
putShort
default T putShort(Object[] aPathElements, Short aValue)
Sets theShortvalue for the property referred to by the path elements representing the addressed path. As property keys and values are of typeString, theShortvalue is converted accordingly.- Parameters:
aPathElements- The path elements of the path addressing the value.aValue- The valueShortto be associated with the path.- Returns:
- The previous value associated with path, or null if there was no mapping for the path. (A null return can also indicate that the map previously associated null with the path, if the implementation supports null values.)
-
putShort
default T putShort(Collection<?> aPathElements, Short aValue)
Sets theShortvalue for the property referred to by the path elements representing the addressed path. As property keys and values are of typeString, theShortvalue is converted accordingly.- Parameters:
aPathElements- The path elements of the path addressing the value.aValue- The valueShortto be associated with the path.- Returns:
- The previous value associated with path, or null if there was no mapping for the path. (A null return can also indicate that the map previously associated null with the path, if the implementation supports null values.)
-
putShort
default T putShort(String aKey, Short aValue)
Sets theShortvalue for the property referred to by the key. As property keys and values are of typeString, theShortvalue is converted accordingly.- Parameters:
aKey- The key for which to retrieve the value.aValue- TheShortrepresentation for theStringvalue.- Returns:
- The previous value associated with path, or null if there was no mapping for the path. (A null return can also indicate that the map previously associated null with the path, if the implementation supports null values.)
-
putShort
default T putShort(String[] aPathElements, Short aValue)
Sets theShortvalue for the property referred to by the path elements representing the addressed path. As property keys and values are of typeString, theShortvalue is converted accordingly.- Parameters:
aPathElements- The path elements of the path addressing the value.aValue- TheShortvalue to be associated with the path.- Returns:
- The previous value associated with path, or null if there was no mapping for the path. (A null return can also indicate that the map previously associated null with the path, if the implementation supports null values.)
-
putString
default T putString(Object aKey, String aValue)
Sets theStringvalue for the property referred to by the key. As property keys and values are of typeString, theBooleanvalue is converted accordingly.- Parameters:
aKey- The key for which to retrieve the value.aValue- TheStringrepresentation for theStringvalue.- Returns:
- The previous value associated with path, or null if there was no mapping for the path. (A null return can also indicate that the map previously associated null with the path, if the implementation supports null values.)
-
putString
default T putString(Object[] aPathElements, String aValue)
Sets theStringvalue for the property referred to by the path elements representing the addressed path. As property keys and values are of typeString, theStringvalue is converted accordingly.- Parameters:
aPathElements- The path elements of the path addressing the value.aValue- The valueStringto be associated with the path.- Returns:
- The previous value associated with path, or null if there was no mapping for the path. (A null return can also indicate that the map previously associated null with the path, if the implementation supports null values.)
-
putString
default T putString(Collection<?> aPathElements, String aValue)
Sets theStringvalue for the property referred to by the path elements representing the addressed path. As property keys and values are of typeString, theStringvalue is converted accordingly.- Parameters:
aPathElements- The path elements of the path addressing the value.aValue- The valueStringto be associated with the path.- Returns:
- The previous value associated with path, or null if there was no mapping for the path. (A null return can also indicate that the map previously associated null with the path, if the implementation supports null values.)
-
putString
default T putString(String aKey, String aValue)
Sets theStringvalue for the property referred to by the key. As property keys and values are of typeString, theStringvalue is converted accordingly.- Parameters:
aKey- The key for which to retrieve the value.aValue- TheStringrepresentation for theStringvalue.- Returns:
- The previous value associated with path, or null if there was no mapping for the path. (A null return can also indicate that the map previously associated null with the path, if the implementation supports null values.)
-
putString
default T putString(String[] aPathElements, String aValue)
Sets theStringvalue for the property referred to by the path elements representing the addressed path. As property keys and values are of typeString, theStringvalue is converted accordingly.- Parameters:
aPathElements- The path elements of the path addressing the value.aValue- TheStringvalue to be associated with the path.- Returns:
- The previous value associated with path, or null if there was no mapping for the path. (A null return can also indicate that the map previously associated null with the path, if the implementation supports null values.)
-
-