Interface InterOperableTable<T>

Type Parameters:
T - The type of the values being supported by this InterOperableTable.
All Superinterfaces:
org.refcodes.mixin.AnnotatorAccessor, org.refcodes.mixin.Clearable, Containable, org.refcodes.mixin.DelimiterAccessor, org.refcodes.mixin.EmptyAccessor, ImmutableInterOperableTable<T>, ImmutableInterOperableTable.MutableInterOperableTable<T>, ImmutablePathTable<T>, ImmutablePathTable.MutablePathTable<T>, ImmutableTable<String,T>, ImmutableTable.MutableTable<String,T>, Keys<String,T>, Keys.MutableKeys<String,T>, Keys.MutableValues<String,T>, Map<String,T>, PathTable<T>, Table<String,T,PathTable<T>>, org.refcodes.mixin.TypeAccessor<T>
All Known Subinterfaces:
CanonicalTable, SimpleTypeTable
All Known Implementing Classes:
MapCanonicalTable, MapSimpleTypeTable

public interface InterOperableTable<T> extends ImmutableInterOperableTable.MutableInterOperableTable<T>, PathTable<T>
The InterOperableTable type extends the ImmutableInterOperableTable.MutableInterOperableTable and provides mutator as well as builder methods for manipulating the entries supporting primitive data types.