- java.lang.Object
-
- java.lang.Throwable
-
- java.lang.Exception
-
- org.refcodes.exception.AbstractException
-
- org.refcodes.struct.StructureException
-
- org.refcodes.struct.KeyNotFoundException
-
- All Implemented Interfaces:
Serializable,org.refcodes.exception.ErrorCodeAccessor,org.refcodes.exception.Trap,org.refcodes.mixin.KeyAccessor<String>
public class KeyNotFoundException extends StructureException implements org.refcodes.mixin.KeyAccessor<String>
Thrown in case this instance does not contain the requested element (no such key found in the collection).- See Also:
- Serialized Form
-
-
Nested Class Summary
-
Nested classes/interfaces inherited from interface org.refcodes.exception.ErrorCodeAccessor
org.refcodes.exception.ErrorCodeAccessor.ErrorCodeBuilder<B extends org.refcodes.exception.ErrorCodeAccessor.ErrorCodeBuilder<B>>, org.refcodes.exception.ErrorCodeAccessor.ErrorCodeMutator, org.refcodes.exception.ErrorCodeAccessor.ErrorCodeProperty
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.KeyAccessor
org.refcodes.mixin.KeyAccessor.KeyBuilder<K extends Object,B extends org.refcodes.mixin.KeyAccessor.KeyBuilder<K,B>>, org.refcodes.mixin.KeyAccessor.KeyMutator<K extends Object>, org.refcodes.mixin.KeyAccessor.KeyProperty<K extends Object>
-
-
Constructor Summary
Constructors Constructor Description KeyNotFoundException(String aKey, String message)Instantiates a new net runtime exception.KeyNotFoundException(String aKey, String aMessage, String aErrorCode)Instantiates a new net runtime exception.KeyNotFoundException(String aKey, String message, Throwable cause)Instantiates a new net runtime exception.KeyNotFoundException(String aKey, String aMessage, Throwable aCause, String aErrorCode)Instantiates a new net runtime exception.KeyNotFoundException(String aKey, Throwable cause)Instantiates a new net runtime exception.KeyNotFoundException(String aKey, Throwable aCause, String aErrorCode)Instantiates a new net runtime exception.
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description StringgetKey()-
Methods inherited from class java.lang.Throwable
addSuppressed, fillInStackTrace, getCause, getLocalizedMessage, getMessage, getStackTrace, getSuppressed, initCause, printStackTrace, printStackTrace, printStackTrace, setStackTrace, toString
-
-
-
-
Constructor Detail
-
KeyNotFoundException
public KeyNotFoundException(String aKey, String aMessage, String aErrorCode)
Instantiates a new net runtime exception.- Parameters:
aKey- The key which has not been found.aMessage- the messageaErrorCode- the error code
-
KeyNotFoundException
public KeyNotFoundException(String aKey, String aMessage, Throwable aCause, String aErrorCode)
Instantiates a new net runtime exception.- Parameters:
aKey- The key which has not been found.aMessage- the messageaCause- the causeaErrorCode- the error code
-
KeyNotFoundException
public KeyNotFoundException(String aKey, String message, Throwable cause)
Instantiates a new net runtime exception.- Parameters:
aKey- The key which has not been found.message- the messagecause- the cause
-
KeyNotFoundException
public KeyNotFoundException(String aKey, String message)
Instantiates a new net runtime exception.- Parameters:
aKey- The key which has not been found.message- the message
-
KeyNotFoundException
public KeyNotFoundException(String aKey, Throwable aCause, String aErrorCode)
Instantiates a new net runtime exception.- Parameters:
aKey- The key which has not been found.aCause- the causeaErrorCode- the error code
-
-