-
- Type Parameters:
K- The type of the key.V- The type of the value which relates to a key.
- All Superinterfaces:
org.refcodes.mixin.Clearable,Keys<K,V>,Keys.MutableKeys<K,V>
- All Known Subinterfaces:
CanonicalMap.CanonicalMapBuilder,CanonicalMap.MutableCanonicalMap,ClassStructMap.ClassStructMapBuilder,ClassStructMap.MutableClassStructMap,Dictionary.MutableDictionary<K,V>,Dictionary.MutableDictionary.DictionaryBuilder<K,V,B>,InterOperableMap.InterOperableMapBuilder<T>,InterOperableMap.MutableInterOperableMap<T>,PathMap.MutablePathMap<T>,PathMap.PathMapBuilder<T>,SimpleTypeMap.MutableSimpleTypeMap,SimpleTypeMap.SimpleTypeMapBuilder
- All Known Implementing Classes:
CanonicalMapBuilderImpl,ClassStructMapBuilderImpl,PathMapBuilderImpl,SimpleTypeMapBuilderImpl
public static interface Keys.MutableValues<K,V> extends Keys.MutableKeys<K,V>
Mixin for mutable functionality accompanying theKeysinterface.
-
-
Nested Class Summary
-
Nested classes/interfaces inherited from interface org.refcodes.struct.Keys
Keys.MutableKeys<K,V>, Keys.MutableValues<K,V>
-
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description Vput(K aKey, V aValue)Puts an element identified by the given key.-
Methods inherited from interface org.refcodes.struct.Keys
containsKey, containsValue, get, getOr, keySet, use, values
-
Methods inherited from interface org.refcodes.struct.Keys.MutableKeys
delete
-
-