Class MapCanonicalTable

java.lang.Object
org.refcodes.struct.MapPathTable<String>
org.refcodes.struct.MapCanonicalTable
All Implemented Interfaces:
Serializable, Map<String,String>, org.refcodes.mixin.AnnotatorAccessor, org.refcodes.mixin.Clearable, org.refcodes.mixin.DelimiterAccessor, org.refcodes.mixin.EmptyAccessor, org.refcodes.mixin.TypeAccessor<String>, CanonicalTable, Containable, ImmutableCanonicalTable, ImmutableCanonicalTable.MutableCanonicalTable, ImmutableInterOperableTable<String>, ImmutableInterOperableTable.MutableInterOperableTable<String>, ImmutablePathTable<String>, ImmutablePathTable.MutablePathTable<String>, ImmutableTable<String,String>, ImmutableTable.MutableTable<String,String>, InterOperableTable<String>, Keys<String,String>, Keys.MutableKeys<String,String>, Keys.MutableValues<String,String>, PathTable<String>, Table<String,String,PathTable<String>>

public class MapCanonicalTable extends MapPathTable<String> implements CanonicalTable
The MapCanonicalTable class implements the CanonicalTable using a backing Map instance.
See Also:
  • Constructor Details

    • MapCanonicalTable

      public MapCanonicalTable()
      Create an empty CanonicalTable instance using the default path delimiter "/" (Delimiter.PATH) for the path declarations.
    • MapCanonicalTable

      public MapCanonicalTable(char aDelimiter)
      Create a CanonicalTable instance using the provided path delimiter for the path declarations.
      Parameters:
      aDelimiter - The path delimiter to be used for the path declarations.
    • MapCanonicalTable

      public MapCanonicalTable(Object aObj)
      Create a CanonicalTable instance containing the elements as of ImmutablePathTable.MutablePathTable.insert(Object) using the default path delimiter "/" (Delimiter.PATH) for the path declarations.
      Parameters:
      aObj - The object from which the elements are to be added.
    • MapCanonicalTable

      public MapCanonicalTable(String aToPath, Object aObj)
      Create a CanonicalTable instance containing the elements as of ImmutablePathTable.MutablePathTable.insert(Object) using the default path delimiter "/" (Delimiter.PATH) for the path declarations.
      Parameters:
      aToPath - The sub-path where to insert the object's introspected values to.
      aObj - The object from which the elements are to be added.
    • MapCanonicalTable

      public MapCanonicalTable(Object aObj, String aFromPath)
      Creates a CanonicalTable instance containing the elements as of ImmutablePathTable.MutablePathTable.insert(Object) using the default path delimiter "/" (Delimiter.PATH) for the path declarations.
      Parameters:
      aObj - The object from which the elements are to be added.
      aFromPath - The path from where to start adding elements of the provided object.
    • MapCanonicalTable

      public MapCanonicalTable(String aToPath, Object aObj, String aFromPath)
      Creates a CanonicalTable instance containing the elements as of ImmutablePathTable.MutablePathTable.insert(Object) using the default path delimiter "/" (Delimiter.PATH for the path declarations.
      Parameters:
      aToPath - The sub-path where to insert the object's introspected values to.
      aObj - The object from which the elements are to be added.
      aFromPath - The path from where to start adding elements of the provided object.
    • MapCanonicalTable

      public MapCanonicalTable(Object aObj, char aDelimiter)
      Creates a CanonicalTable instance containing the elements as of ImmutablePathTable.MutablePathTable.insert(Object).
      Parameters:
      aObj - The object from which the elements are to be added.
      aDelimiter - The path delimiter to be used for the path declarations.
    • MapCanonicalTable

      public MapCanonicalTable(String aToPath, Object aObj, char aDelimiter)
      Creates a CanonicalTable instance containing the elements as of ImmutablePathTable.MutablePathTable.insert(Object).
      Parameters:
      aToPath - The sub-path where to insert the object's introspected values to.
      aObj - The object from which the elements are to be added.
      aDelimiter - The path delimiter to be used for the path declarations.
    • MapCanonicalTable

      public MapCanonicalTable(Object aObj, String aFromPath, char aDelimiter)
      Creates a CanonicalTable instance containing the elements as of ImmutablePathTable.MutablePathTable.insert(Object).
      Parameters:
      aObj - The object from which the elements are to be added.
      aFromPath - The path from where to start adding elements of the provided object.
      aDelimiter - The path delimiter to be used for the path declarations.
    • MapCanonicalTable

      public MapCanonicalTable(String aToPath, Object aObj, String aFromPath, char aDelimiter)
      Create a CanonicalTable instance containing the elements as of ImmutablePathTable.MutablePathTable.insert(Object).
      Parameters:
      aToPath - The sub-path where to insert the object's introspected values to.
      aObj - The object from which the elements are to be added.
      aFromPath - The path from where to start adding elements of the provided object.
      aDelimiter - The path delimiter to be used for the path declarations.
    • MapCanonicalTable

      public MapCanonicalTable(Map<String,String> aBackingMap)
      Create an empty CanonicalTable instance using the default path delimiter "/" (Delimiter.PATH) for the path declarations.
      Parameters:
      aBackingMap - The backing map used as underlying Map instance.
    • MapCanonicalTable

      public MapCanonicalTable(char aDelimiter, Map<String,String> aBackingMap)
      Create a CanonicalTable instance using the provided path delimiter for the path declarations.
      Parameters:
      aDelimiter - The path delimiter to be used for the path declarations.
      aBackingMap - The backing map used as underlying Map instance.
    • MapCanonicalTable

      public MapCanonicalTable(Object aObj, Map<String,String> aBackingMap)
      Create a CanonicalTable instance containing the elements as of ImmutablePathTable.MutablePathTable.insert(Object) using the default path delimiter "/" (Delimiter.PATH) for the path declarations.
      Parameters:
      aObj - The object from which the elements are to be added.
      aBackingMap - The backing map used as underlying Map instance.
    • MapCanonicalTable

      public MapCanonicalTable(String aToPath, Object aObj, Map<String,String> aBackingMap)
      Create a CanonicalTable instance containing the elements as of ImmutablePathTable.MutablePathTable.insert(Object) using the default path delimiter "/" (Delimiter.PATH) for the path declarations.
      Parameters:
      aToPath - The sub-path where to insert the object's introspected values to.
      aObj - The object from which the elements are to be added.
      aBackingMap - The backing map used as underlying Map instance.
    • MapCanonicalTable

      public MapCanonicalTable(Object aObj, String aFromPath, Map<String,String> aBackingMap)
      Creates a CanonicalTable instance containing the elements as of ImmutablePathTable.MutablePathTable.insert(Object) using the default path delimiter "/" (Delimiter.PATH) for the path declarations.
      Parameters:
      aObj - The object from which the elements are to be added.
      aFromPath - The path from where to start adding elements of the provided object.
      aBackingMap - The backing map used as underlying Map instance.
    • MapCanonicalTable

      public MapCanonicalTable(String aToPath, Object aObj, String aFromPath, Map<String,String> aBackingMap)
      Creates a CanonicalTable instance containing the elements as of ImmutablePathTable.MutablePathTable.insert(Object) using the default path delimiter "/" (Delimiter.PATH for the path declarations.
      Parameters:
      aToPath - The sub-path where to insert the object's introspected values to.
      aObj - The object from which the elements are to be added.
      aFromPath - The path from where to start adding elements of the provided object.
      aBackingMap - The backing map used as underlying Map instance.
    • MapCanonicalTable

      public MapCanonicalTable(Object aObj, char aDelimiter, Map<String,String> aBackingMap)
      Creates a CanonicalTable instance containing the elements as of ImmutablePathTable.MutablePathTable.insert(Object).
      Parameters:
      aObj - The object from which the elements are to be added.
      aDelimiter - The path delimiter to be used for the path declarations.
      aBackingMap - The backing map used as underlying Map instance.
    • MapCanonicalTable

      public MapCanonicalTable(String aToPath, Object aObj, char aDelimiter, Map<String,String> aBackingMap)
      Creates a CanonicalTable instance containing the elements as of ImmutablePathTable.MutablePathTable.insert(Object).
      Parameters:
      aToPath - The sub-path where to insert the object's introspected values to.
      aObj - The object from which the elements are to be added.
      aDelimiter - The path delimiter to be used for the path declarations.
      aBackingMap - The backing map used as underlying Map instance.
    • MapCanonicalTable

      public MapCanonicalTable(Object aObj, String aFromPath, char aDelimiter, Map<String,String> aBackingMap)
      Creates a CanonicalTable instance containing the elements as of ImmutablePathTable.MutablePathTable.insert(Object).
      Parameters:
      aObj - The object from which the elements are to be added.
      aFromPath - The path from where to start adding elements of the provided object.
      aDelimiter - The path delimiter to be used for the path declarations.
      aBackingMap - The backing map used as underlying Map instance.
    • MapCanonicalTable

      public MapCanonicalTable(String aToPath, Object aObj, String aFromPath, char aDelimiter, Map<String,String> aBackingMap)
      Create a CanonicalTable instance containing the elements as of ImmutablePathTable.MutablePathTable.insert(Object).
      Parameters:
      aToPath - The sub-path where to insert the object's introspected values to.
      aObj - The object from which the elements are to be added.
      aFromPath - The path from where to start adding elements of the provided object.
      aDelimiter - The path delimiter to be used for the path declarations.
      aBackingMap - The backing map used as underlying Map instance.
  • Method Details