Class MapClassStructTable

java.lang.Object
org.refcodes.struct.MapPathTable<Class<?>>
org.refcodes.struct.MapClassStructTable
All Implemented Interfaces:
Serializable, Map<String,Class<?>>, AnnotatorAccessor, Clearable, DelimiterAccessor, EmptyAccessor, TypeAccessor<Class<?>>, ClassStructTable, Containable, ImmutableClassStructTable, ImmutableClassStructTable.MutableClassStructTable, ImmutablePathTable<Class<?>>, ImmutablePathTable.MutablePathTable<Class<?>>, ImmutableTable<String,Class<?>>, ImmutableTable.MutableTable<String,Class<?>>, Keys<String,Class<?>>, Keys.MutableKeys<String,Class<?>>, Keys.MutableValues<String,Class<?>>, PathTable<Class<?>>, Table<String, Class<?>, PathTable<Class<?>>>, TypeModeAccessor

public class MapClassStructTable extends MapPathTable<Class<?>> implements ClassStructTable
The MapClassStructTable class implements the ClassStructTable using a backing Map instance.
See Also:
  • Constructor Details

    • MapClassStructTable

      public MapClassStructTable()
      Create an empty ClassStructTable instance using the default path delimiter "/" (Delimiter.PATH) for the path declarations.
    • MapClassStructTable

      public MapClassStructTable(char aDelimiter)
      Create a ClassStructTable instance using the provided path delimiter for the path declarations.
      Parameters:
      aDelimiter - The path delimiter to be used for the path declarations.
    • MapClassStructTable

      public MapClassStructTable(Object aObj)
      Create a ClassStructTable instance containing the elements as of ImmutablePathTable.MutablePathTable.insert(Object) using the default path delimiter "/" (Delimiter.PATH) for the path declarations.
      Parameters:
      aObj - The object from which the elements are to be added.
    • MapClassStructTable

      public MapClassStructTable(String aToPath, Object aObj)
      Create a ClassStructTable instance containing the elements as of ImmutablePathTable.MutablePathTable.insert(Object) using the default path delimiter "/" (Delimiter.PATH) for the path declarations.
      Parameters:
      aToPath - The sub-path where to insert the object's introspected values to.
      aObj - The object from which the elements are to be added.
    • MapClassStructTable

      public MapClassStructTable(Object aObj, String aFromPath)
      Creates a ClassStructTable instance containing the elements as of ImmutablePathTable.MutablePathTable.insert(Object) using the default path delimiter "/" (Delimiter.PATH) for the path declarations.
      Parameters:
      aObj - The object from which the elements are to be added.
      aFromPath - The path from where to start adding elements of the provided object.
    • MapClassStructTable

      public MapClassStructTable(String aToPath, Object aObj, String aFromPath)
      Creates a ClassStructTable instance containing the elements as of ImmutablePathTable.MutablePathTable.insert(Object) using the default path delimiter "/" (Delimiter.PATH for the path declarations.
      Parameters:
      aToPath - The sub-path where to insert the object's introspected values to.
      aObj - The object from which the elements are to be added.
      aFromPath - The path from where to start adding elements of the provided object.
    • MapClassStructTable

      public MapClassStructTable(Object aObj, char aDelimiter)
      Creates a ClassStructTable instance containing the elements as of ImmutablePathTable.MutablePathTable.insert(Object).
      Parameters:
      aObj - The object from which the elements are to be added.
      aDelimiter - The path delimiter to be used for the path declarations.
    • MapClassStructTable

      public MapClassStructTable(String aToPath, Object aObj, char aDelimiter)
      Creates a ClassStructTable instance containing the elements as of ImmutablePathTable.MutablePathTable.insert(Object).
      Parameters:
      aToPath - The sub-path where to insert the object's introspected values to.
      aObj - The object from which the elements are to be added.
      aDelimiter - The path delimiter to be used for the path declarations.
    • MapClassStructTable

      public MapClassStructTable(Object aObj, String aFromPath, char aDelimiter)
      Creates a ClassStructTable instance containing the elements as of ImmutablePathTable.MutablePathTable.insert(Object).
      Parameters:
      aObj - The object from which the elements are to be added.
      aFromPath - The path from where to start adding elements of the provided object.
      aDelimiter - The path delimiter to be used for the path declarations.
    • MapClassStructTable

      public MapClassStructTable(String aToPath, Object aObj, String aFromPath, char aDelimiter)
      Create a ClassStructTable instance containing the elements as of ImmutablePathTable.MutablePathTable.insert(Object).
      Parameters:
      aToPath - The sub-path where to insert the object's introspected values to.
      aObj - The object from which the elements are to be added.
      aFromPath - The path from where to start adding elements of the provided object.
      aDelimiter - The path delimiter to be used for the path declarations.
    • MapClassStructTable

      public MapClassStructTable(SimpleType aTypeMode)
      Create an empty ClassStructTable instance using the default path delimiter "/" (Delimiter.PATH) for the path declarations.
      Parameters:
      aTypeMode - The SimpleType to use when processing primitive types, wrapper types or complex types.
    • MapClassStructTable

      public MapClassStructTable(char aDelimiter, SimpleType aTypeMode)
      Create a ClassStructTable instance using the provided path delimiter for the path declarations.
      Parameters:
      aDelimiter - The path delimiter to be used for the path declarations.
      aTypeMode - The SimpleType to use when processing primitive types, wrapper types or complex types.
    • MapClassStructTable

      public MapClassStructTable(Object aObj, SimpleType aTypeMode)
      Create a ClassStructTable instance containing the elements as of ImmutablePathTable.MutablePathTable.insert(Object) using the default path delimiter "/" (Delimiter.PATH) for the path declarations.
      Parameters:
      aObj - The object from which the elements are to be added.
      aTypeMode - The SimpleType to use when processing primitive types, wrapper types or complex types.
    • MapClassStructTable

      public MapClassStructTable(String aToPath, Object aObj, SimpleType aTypeMode)
      Create a ClassStructTable instance containing the elements as of ImmutablePathTable.MutablePathTable.insert(Object) using the default path delimiter "/" (Delimiter.PATH) for the path declarations.
      Parameters:
      aToPath - The sub-path where to insert the object's introspected values to.
      aObj - The object from which the elements are to be added.
      aTypeMode - The SimpleType to use when processing primitive types, wrapper types or complex types.
    • MapClassStructTable

      public MapClassStructTable(Object aObj, String aFromPath, SimpleType aTypeMode)
      Creates a ClassStructTable instance containing the elements as of ImmutablePathTable.MutablePathTable.insert(Object) using the default path delimiter "/" (Delimiter.PATH) for the path declarations.
      Parameters:
      aObj - The object from which the elements are to be added.
      aFromPath - The path from where to start adding elements of the provided object.
      aTypeMode - The SimpleType to use when processing primitive types, wrapper types or complex types.
    • MapClassStructTable

      public MapClassStructTable(String aToPath, Object aObj, String aFromPath, SimpleType aTypeMode)
      Creates a ClassStructTable instance containing the elements as of ImmutablePathTable.MutablePathTable.insert(Object) using the default path delimiter "/" (Delimiter.PATH for the path declarations.
      Parameters:
      aToPath - The sub-path where to insert the object's introspected values to.
      aObj - The object from which the elements are to be added.
      aFromPath - The path from where to start adding elements of the provided object.
      aTypeMode - The SimpleType to use when processing primitive types, wrapper types or complex types.
    • MapClassStructTable

      public MapClassStructTable(Object aObj, char aDelimiter, SimpleType aTypeMode)
      Creates a ClassStructTable instance containing the elements as of ImmutablePathTable.MutablePathTable.insert(Object).
      Parameters:
      aObj - The object from which the elements are to be added.
      aDelimiter - The path delimiter to be used for the path declarations.
      aTypeMode - The SimpleType to use when processing primitive types, wrapper types or complex types.
    • MapClassStructTable

      public MapClassStructTable(String aToPath, Object aObj, char aDelimiter, SimpleType aTypeMode)
      Creates a ClassStructTable instance containing the elements as of ImmutablePathTable.MutablePathTable.insert(Object).
      Parameters:
      aToPath - The sub-path where to insert the object's introspected values to.
      aObj - The object from which the elements are to be added.
      aDelimiter - The path delimiter to be used for the path declarations.
      aTypeMode - The SimpleType to use when processing primitive types, wrapper types or complex types.
    • MapClassStructTable

      public MapClassStructTable(Object aObj, String aFromPath, char aDelimiter, SimpleType aTypeMode)
      Creates a ClassStructTable instance containing the elements as of ImmutablePathTable.MutablePathTable.insert(Object).
      Parameters:
      aObj - The object from which the elements are to be added.
      aFromPath - The path from where to start adding elements of the provided object.
      aDelimiter - The path delimiter to be used for the path declarations.
      aTypeMode - The SimpleType to use when processing primitive types, wrapper types or complex types.
    • MapClassStructTable

      public MapClassStructTable(String aToPath, Object aObj, String aFromPath, char aDelimiter, SimpleType aTypeMode)
      Create a ClassStructTable instance containing the elements as of ImmutablePathTable.MutablePathTable.insert(Object).
      Parameters:
      aToPath - The sub-path where to insert the object's introspected values to.
      aObj - The object from which the elements are to be added.
      aFromPath - The path from where to start adding elements of the provided object.
      aDelimiter - The path delimiter to be used for the path declarations.
      aTypeMode - The SimpleType to use when processing primitive types, wrapper types or complex types.
    • MapClassStructTable

      public MapClassStructTable(Map<String,Class<?>> aBackingMap)
      Create an empty ClassStructTable instance using the default path delimiter "/" (Delimiter.PATH) for the path declarations.
      Parameters:
      aBackingMap - The backing map used as underlying Map instance.
    • MapClassStructTable

      public MapClassStructTable(char aDelimiter, Map<String,Class<?>> aBackingMap)
      Create a ClassStructTable instance using the provided path delimiter for the path declarations.
      Parameters:
      aDelimiter - The path delimiter to be used for the path declarations.
      aBackingMap - The backing map used as underlying Map instance.
    • MapClassStructTable

      public MapClassStructTable(Object aObj, Map<String,Class<?>> aBackingMap)
      Create a ClassStructTable instance containing the elements as of ImmutablePathTable.MutablePathTable.insert(Object) using the default path delimiter "/" (Delimiter.PATH) for the path declarations.
      Parameters:
      aObj - The object from which the elements are to be added.
      aBackingMap - The backing map used as underlying Map instance.
    • MapClassStructTable

      public MapClassStructTable(String aToPath, Object aObj, Map<String,Class<?>> aBackingMap)
      Create a ClassStructTable instance containing the elements as of ImmutablePathTable.MutablePathTable.insert(Object) using the default path delimiter "/" (Delimiter.PATH) for the path declarations.
      Parameters:
      aToPath - The sub-path where to insert the object's introspected values to.
      aObj - The object from which the elements are to be added.
      aBackingMap - The backing map used as underlying Map instance.
    • MapClassStructTable

      public MapClassStructTable(Object aObj, String aFromPath, Map<String,Class<?>> aBackingMap)
      Creates a ClassStructTable instance containing the elements as of ImmutablePathTable.MutablePathTable.insert(Object) using the default path delimiter "/" (Delimiter.PATH) for the path declarations.
      Parameters:
      aObj - The object from which the elements are to be added.
      aFromPath - The path from where to start adding elements of the provided object.
      aBackingMap - The backing map used as underlying Map instance.
    • MapClassStructTable

      public MapClassStructTable(String aToPath, Object aObj, String aFromPath, Map<String,Class<?>> aBackingMap)
      Creates a ClassStructTable instance containing the elements as of ImmutablePathTable.MutablePathTable.insert(Object) using the default path delimiter "/" (Delimiter.PATH for the path declarations.
      Parameters:
      aToPath - The sub-path where to insert the object's introspected values to.
      aObj - The object from which the elements are to be added.
      aFromPath - The path from where to start adding elements of the provided object.
      aBackingMap - The backing map used as underlying Map instance.
    • MapClassStructTable

      public MapClassStructTable(Object aObj, char aDelimiter, Map<String,Class<?>> aBackingMap)
      Creates a ClassStructTable instance containing the elements as of ImmutablePathTable.MutablePathTable.insert(Object).
      Parameters:
      aObj - The object from which the elements are to be added.
      aDelimiter - The path delimiter to be used for the path declarations.
      aBackingMap - The backing map used as underlying Map instance.
    • MapClassStructTable

      public MapClassStructTable(String aToPath, Object aObj, char aDelimiter, Map<String,Class<?>> aBackingMap)
      Creates a ClassStructTable instance containing the elements as of ImmutablePathTable.MutablePathTable.insert(Object).
      Parameters:
      aToPath - The sub-path where to insert the object's introspected values to.
      aObj - The object from which the elements are to be added.
      aDelimiter - The path delimiter to be used for the path declarations.
      aBackingMap - The backing map used as underlying Map instance.
    • MapClassStructTable

      public MapClassStructTable(Object aObj, String aFromPath, char aDelimiter, Map<String,Class<?>> aBackingMap)
      Creates a ClassStructTable instance containing the elements as of ImmutablePathTable.MutablePathTable.insert(Object).
      Parameters:
      aObj - The object from which the elements are to be added.
      aFromPath - The path from where to start adding elements of the provided object.
      aDelimiter - The path delimiter to be used for the path declarations.
      aBackingMap - The backing map used as underlying Map instance.
    • MapClassStructTable

      public MapClassStructTable(String aToPath, Object aObj, String aFromPath, char aDelimiter, Map<String,Class<?>> aBackingMap)
      Create a ClassStructTable instance containing the elements as of ImmutablePathTable.MutablePathTable.insert(Object).
      Parameters:
      aToPath - The sub-path where to insert the object's introspected values to.
      aObj - The object from which the elements are to be added.
      aFromPath - The path from where to start adding elements of the provided object.
      aDelimiter - The path delimiter to be used for the path declarations.
      aBackingMap - The backing map used as underlying Map instance.
    • MapClassStructTable

      public MapClassStructTable(SimpleType aTypeMode, Map<String,Class<?>> aBackingMap)
      Create an empty ClassStructTable instance using the default path delimiter "/" (Delimiter.PATH) for the path declarations.
      Parameters:
      aTypeMode - The SimpleType to use when processing primitive types, wrapper types or complex types.
      aBackingMap - The backing map used as underlying Map instance.
    • MapClassStructTable

      public MapClassStructTable(char aDelimiter, SimpleType aTypeMode, Map<String,Class<?>> aBackingMap)
      Create a ClassStructTable instance using the provided path delimiter for the path declarations.
      Parameters:
      aDelimiter - The path delimiter to be used for the path declarations.
      aTypeMode - The SimpleType to use when processing primitive types, wrapper types or complex types.
      aBackingMap - The backing map used as underlying Map instance.
    • MapClassStructTable

      public MapClassStructTable(Object aObj, SimpleType aTypeMode, Map<String,Class<?>> aBackingMap)
      Create a ClassStructTable instance containing the elements as of ImmutablePathTable.MutablePathTable.insert(Object) using the default path delimiter "/" (Delimiter.PATH) for the path declarations.
      Parameters:
      aObj - The object from which the elements are to be added.
      aTypeMode - The SimpleType to use when processing primitive types, wrapper types or complex types.
      aBackingMap - The backing map used as underlying Map instance.
    • MapClassStructTable

      public MapClassStructTable(String aToPath, Object aObj, SimpleType aTypeMode, Map<String,Class<?>> aBackingMap)
      Create a ClassStructTable instance containing the elements as of ImmutablePathTable.MutablePathTable.insert(Object) using the default path delimiter "/" (Delimiter.PATH) for the path declarations.
      Parameters:
      aToPath - The sub-path where to insert the object's introspected values to.
      aObj - The object from which the elements are to be added.
      aTypeMode - The SimpleType to use when processing primitive types, wrapper types or complex types.
      aBackingMap - The backing map used as underlying Map instance.
    • MapClassStructTable

      public MapClassStructTable(Object aObj, String aFromPath, SimpleType aTypeMode, Map<String,Class<?>> aBackingMap)
      Creates a ClassStructTable instance containing the elements as of ImmutablePathTable.MutablePathTable.insert(Object) using the default path delimiter "/" (Delimiter.PATH) for the path declarations.
      Parameters:
      aObj - The object from which the elements are to be added.
      aFromPath - The path from where to start adding elements of the provided object.
      aTypeMode - The SimpleType to use when processing primitive types, wrapper types or complex types.
      aBackingMap - The backing map used as underlying Map instance.
    • MapClassStructTable

      public MapClassStructTable(String aToPath, Object aObj, String aFromPath, SimpleType aTypeMode, Map<String,Class<?>> aBackingMap)
      Creates a ClassStructTable instance containing the elements as of ImmutablePathTable.MutablePathTable.insert(Object) using the default path delimiter "/" (Delimiter.PATH for the path declarations.
      Parameters:
      aToPath - The sub-path where to insert the object's introspected values to.
      aObj - The object from which the elements are to be added.
      aFromPath - The path from where to start adding elements of the provided object.
      aTypeMode - The SimpleType to use when processing primitive types, wrapper types or complex types.
      aBackingMap - The backing map used as underlying Map instance.
    • MapClassStructTable

      public MapClassStructTable(Object aObj, char aDelimiter, SimpleType aTypeMode, Map<String,Class<?>> aBackingMap)
      Creates a ClassStructTable instance containing the elements as of ImmutablePathTable.MutablePathTable.insert(Object).
      Parameters:
      aObj - The object from which the elements are to be added.
      aDelimiter - The path delimiter to be used for the path declarations.
      aTypeMode - The SimpleType to use when processing primitive types, wrapper types or complex types.
      aBackingMap - The backing map used as underlying Map instance.
    • MapClassStructTable

      public MapClassStructTable(String aToPath, Object aObj, char aDelimiter, SimpleType aTypeMode, Map<String,Class<?>> aBackingMap)
      Creates a ClassStructTable instance containing the elements as of ImmutablePathTable.MutablePathTable.insert(Object).
      Parameters:
      aToPath - The sub-path where to insert the object's introspected values to.
      aObj - The object from which the elements are to be added.
      aDelimiter - The path delimiter to be used for the path declarations.
      aTypeMode - The SimpleType to use when processing primitive types, wrapper types or complex types.
      aBackingMap - The backing map used as underlying Map instance.
    • MapClassStructTable

      public MapClassStructTable(Object aObj, String aFromPath, char aDelimiter, SimpleType aTypeMode, Map<String,Class<?>> aBackingMap)
      Creates a ClassStructTable instance containing the elements as of ImmutablePathTable.MutablePathTable.insert(Object).
      Parameters:
      aObj - The object from which the elements are to be added.
      aFromPath - The path from where to start adding elements of the provided object.
      aDelimiter - The path delimiter to be used for the path declarations.
      aTypeMode - The SimpleType to use when processing primitive types, wrapper types or complex types.
      aBackingMap - The backing map used as underlying Map instance.
    • MapClassStructTable

      public MapClassStructTable(String aToPath, Object aObj, String aFromPath, char aDelimiter, SimpleType aTypeMode, Map<String,Class<?>> aBackingMap)
      Create a ClassStructTable instance containing the elements as of ImmutablePathTable.MutablePathTable.insert(Object).
      Parameters:
      aToPath - The sub-path where to insert the object's introspected values to.
      aObj - The object from which the elements are to be added.
      aFromPath - The path from where to start adding elements of the provided object.
      aDelimiter - The path delimiter to be used for the path declarations.
      aTypeMode - The SimpleType to use when processing primitive types, wrapper types or complex types.
      aBackingMap - The backing map used as underlying Map instance.
  • Method Details