Class PropertyImpl
- All Implemented Interfaces:
KeyAccessor<String>, ValueAccessor<String>, Property, Relation<String,String>
- Direct Known Subclasses:
PropertyImpl.PropertyBuilderImpl
Implementation of the
Property interface.-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic classImplementation of theProperty.PropertyBuilderinterface.Nested classes/interfaces inherited from class RelationImpl
RelationImpl.RelationBuilderImpl<K,V> Nested classes/interfaces inherited from interface KeyAccessor
KeyAccessor.KeyBuilder<K,B>, KeyAccessor.KeyMutator<K>, KeyAccessor.KeyProperty<K> Nested classes/interfaces inherited from interface Property
Property.PropertyBuilderNested classes/interfaces inherited from interface Relation
Relation.RelationBuilder<K,V> Nested classes/interfaces inherited from interface ValueAccessor
ValueAccessor.ValueBuilder<V,B>, ValueAccessor.ValueMutator<V>, ValueAccessor.ValueProperty<V> -
Field Summary
Fields inherited from class RelationImpl
_key, _value -
Constructor Summary
ConstructorsModifierConstructorDescriptionprotectedInstantiates a new property impl.PropertyImpl(String aTupel) Initializes thePropertyImplwith the given values.PropertyImpl(String aTupel, char aTupelDelimeter) Initializes thePropertyImplwith the given values.PropertyImpl(String aKey, String aValue) Initializes thePropertyImplwith the given values. -
Method Summary
Methods inherited from class RelationImpl
getKey, getValue, toStringMethods inherited from class Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface KeyAccessor
getKeyMethods inherited from interface Property
toPropertyMethods inherited from interface ValueAccessor
getValue, getValueOr, hasValue
-
Constructor Details
-
PropertyImpl
protected PropertyImpl()Instantiates a new property impl. -
PropertyImpl
Initializes thePropertyImplwith the given values.- Parameters:
aKey- The according key to set.aValue- The according value to set.
-
PropertyImpl
Initializes thePropertyImplwith the given values.- Parameters:
aTupel- A tupel is a key and a value with the assignment operator "=" inbetween, e.g. "a=5" (the key would be a, the value would be 5).
-
PropertyImpl
Initializes thePropertyImplwith the given values.- Parameters:
aTupel- A tupel is a key and a value with the assignment operator "=" inbetween, e.g. "a=5" (the key would be a, the value would be 5).aTupelDelimeter- The delimiter to be used for dividing the key/value-pair.
-