Class PropertyImpl.PropertyBuilderImpl

All Implemented Interfaces:
KeyAccessor<String>, KeyAccessor.KeyBuilder<String, Relation.RelationBuilder<String,String>>, KeyAccessor.KeyMutator<String>, KeyAccessor.KeyProperty<String>, ValueAccessor<String>, ValueAccessor.ValueBuilder<String, Relation.RelationBuilder<String,String>>, ValueAccessor.ValueMutator<String>, ValueAccessor.ValueProperty<String>, Property, Property.PropertyBuilder, Relation<String,String>, Relation.RelationBuilder<String,String>
Enclosing class:
PropertyImpl

public static class PropertyImpl.PropertyBuilderImpl extends PropertyImpl implements Property.PropertyBuilder
Implementation of the Property.PropertyBuilder interface.
  • Constructor Details

    • PropertyBuilderImpl

      public PropertyBuilderImpl()
      Use the builder methods or the bean attributes to set the key and the value.
    • PropertyBuilderImpl

      public PropertyBuilderImpl(String aTupel, char aTupelDelimeter)
      Initializes the PropertyImpl.PropertyBuilderImpl with the given values.
      Parameters:
      aTupel - A tupel is a key and a value with the assignment operator "=" inbetween, e.g. "a=5" (the key would be a, the value would be 5).
      aTupelDelimeter - The delimiter to be used for dividing the key/value-pair.
    • PropertyBuilderImpl

      public PropertyBuilderImpl(String aKey, String aValue)
      Initializes the PropertyImpl.PropertyBuilderImpl with the given values.
      Parameters:
      aKey - The according key to set.
      aValue - The according value to set.
    • PropertyBuilderImpl

      public PropertyBuilderImpl(String aTupel)
      Initializes the PropertyImpl.PropertyBuilderImpl with the given values.
      Parameters:
      aTupel - A tupel is a key and a value with the assignment operator "=" inbetween, e.g. "a=5" (the key would be a, the value would be 5).
  • Method Details