-
- All Known Subinterfaces:
ShortArrayAccessor.ShortArrayProperty
public interface ShortArrayAccessorProvides an accessor for a short array property.
-
-
Nested Class Summary
Nested Classes Modifier and Type Interface Description static interfaceShortArrayAccessor.ShortArrayBuilder<B extends ShortArrayAccessor.ShortArrayBuilder<B>>Provides a builder method for a short array property returning the builder for applying multiple build operations.static interfaceShortArrayAccessor.ShortArrayMutatorProvides a mutator for a short array property.static interfaceShortArrayAccessor.ShortArrayPropertyProvides a short array property.
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description short[]getShorts()Retrieves the short array from the short array property.
-