Interface Table<K, V, B extends Table<K,V,B>>
- Type Parameters:
K- the key typeV- The type of the value which relates to a key.B- The builder to return in order to be able to apply multiple build operations.
- All Superinterfaces:
Clearable, Containable, EmptyAccessor, ImmutableTable<K,V>, ImmutableTable.MutableTable<K, V>, Keys<K, V>, Keys.MutableKeys<K, V>, Keys.MutableValues<K, V>, Map<K, V>
- All Known Subinterfaces:
CanonicalTable, ClassStructTable, InterOperableTable<T>, PathTable<T>, SimpleTypeTable
- All Known Implementing Classes:
MapCanonicalTable, MapClassStructTable, MapPathTable, MapSimpleTypeTable
The
Table type extends the ImmutableTable.MutableTable type and provides
mutator as well as builder methods for manipulating the entries.-
Nested Class Summary
Nested classes/interfaces inherited from interface EmptyAccessor
EmptyAccessor.EmptyBuilder<B>, EmptyAccessor.EmptyMutator, EmptyAccessor.EmptyPropertyNested classes/interfaces inherited from interface ImmutableTable
ImmutableTable.MutableTable<K,V> Nested classes/interfaces inherited from interface Keys
Keys.MutableKeys<K,V>, Keys.MutableValues<K, V> -
Method Summary
Methods inherited from interface Containable
sizeMethods inherited from interface EmptyAccessor
isEmptyMethods inherited from interface ImmutableTable.MutableTable
delete, putMethods inherited from interface Keys
containsKey, containsValue, get, getOr, keySet, valuesMethods inherited from interface Keys.MutableValues
putMethods inherited from interface Map
clear, compute, computeIfAbsent, computeIfPresent, containsKey, containsValue, entrySet, equals, forEach, get, getOrDefault, hashCode, isEmpty, keySet, merge, put, putAll, putIfAbsent, remove, remove, replace, replace, replaceAll, size, values
-
Method Details
-
withPut
Builder method forKeys.MutableValues.put(Object, Object).- Parameters:
aKey- the key for the property to be put.aValue- the value for the property to be put.- Returns:
- The implementing instance as of the builder pattern.
-
withPut
Builder method forImmutableTable.MutableTable.put(Relation).- Parameters:
aRelation- the property to be put.- Returns:
- The implementing instance as of the builder pattern.
-