Interface Table.TableDictionary<K,V>
- Type Parameters:
K- The type of the key.V- The type of the value which relates to a key.
- All Superinterfaces:
org.refcodes.mixin.Clearable, Containable, org.refcodes.mixin.EmptyAccessor, Keys<K,V>, Keys.MutableKeys<K, V>, Keys.MutableValues<K, V>, Table<K, V>
- All Known Subinterfaces:
CanonicalMap.CanonicalMapBuilder, CanonicalMap.MutableCanonicalMap, ClassStructMap.ClassStructMapBuilder, ClassStructMap.MutableClassStructMap, InterOperableMap.InterOperableMapBuilder<T>, InterOperableMap.MutableInterOperableMap<T>, PathMap.MutablePathMap<T>, PathMap.PathMapBuilder<T>, SimpleTypeMap.MutableSimpleTypeMap, SimpleTypeMap.SimpleTypeMapBuilder, Table.TableDictionary.TableBuilder<K,V, B>
- All Known Implementing Classes:
CanonicalMapBuilderImpl, ClassStructMapBuilderImpl, PathMapBuilderImpl, SimpleTypeMapBuilderImpl
Extends the
Table with mutable (writable) functionality,
ehttps://www.metacodes.proly by providing Keys.MutableValues.put(Object, Object)
and Keys.MutableKeys.delete(String) methods.-
Nested Class Summary
Nested ClassesModifier and TypeInterfaceDescriptionstatic interfaceTable.TableDictionary.TableBuilder<K, V, B extends Table.TableDictionary.TableBuilder<K,V, B>> Provides a builder method for aRelationproperty returning the builder for applying multiple build operations.Nested classes/interfaces inherited from interface org.refcodes.mixin.EmptyAccessor
org.refcodes.mixin.EmptyAccessor.EmptyBuilder<B>, org.refcodes.mixin.EmptyAccessor.EmptyMutator, org.refcodes.mixin.EmptyAccessor.EmptyPropertyNested classes/interfaces inherited from interface Keys
Keys.MutableKeys<K,V>, Keys.MutableValues<K, V> Nested classes/interfaces inherited from interface Table
Table.TableDictionary<K,V> -
Method Summary
Methods inherited from interface org.refcodes.mixin.Clearable
clearMethods inherited from interface Containable
sizeMethods inherited from interface org.refcodes.mixin.EmptyAccessor
isEmptyMethods inherited from interface Keys
containsKey, containsValue, get, getOr, keySet, use, valuesMethods inherited from interface Keys.MutableKeys
deleteMethods inherited from interface Keys.MutableValues
put
-
Method Details
-
put
-