Interface Table.TableDictionary.TableBuilder<K, V, B extends Table.TableDictionary.TableBuilder<K,V,B>>
- Type Parameters:
K- the key typeV- The type of the value which relates to a key.B- The builder to return in order to be able to apply multiple build operations.
- All Superinterfaces:
org.refcodes.mixin.Clearable, Containable, org.refcodes.mixin.EmptyAccessor, Keys<K,V>, Keys.MutableKeys<K, V>, Keys.MutableValues<K, V>, Table<K, V>, Table.TableDictionary<K, V>
- All Known Subinterfaces:
CanonicalMap.CanonicalMapBuilder, ClassStructMap.ClassStructMapBuilder, InterOperableMap.InterOperableMapBuilder<T>, PathMap.PathMapBuilder<T>, SimpleTypeMap.SimpleTypeMapBuilder
- All Known Implementing Classes:
CanonicalMapBuilderImpl, ClassStructMapBuilderImpl, PathMapBuilderImpl, SimpleTypeMapBuilderImpl
- Enclosing interface:
Table.TableDictionary<K,V>
public static interface Table.TableDictionary.TableBuilder<K, V, B extends Table.TableDictionary.TableBuilder<K,V,B>>
extends Table.TableDictionary<K,V>
Provides a builder method for a
Relation property returning
the builder for applying multiple build operations.-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.mixin.EmptyAccessor
org.refcodes.mixin.EmptyAccessor.EmptyBuilder<B>, org.refcodes.mixin.EmptyAccessor.EmptyMutator, org.refcodes.mixin.EmptyAccessor.EmptyPropertyNested classes/interfaces inherited from interface Keys
Keys.MutableKeys<K,V>, Keys.MutableValues<K, V> Nested classes/interfaces inherited from interface Table
Table.TableDictionary<K,V> Nested classes/interfaces inherited from interface Table.TableDictionary
Table.TableDictionary.TableBuilder<K,V, B> -
Method Summary
Methods inherited from interface org.refcodes.mixin.Clearable
clearMethods inherited from interface Containable
sizeMethods inherited from interface org.refcodes.mixin.EmptyAccessor
isEmptyMethods inherited from interface Keys
containsKey, containsValue, get, getOr, keySet, use, valuesMethods inherited from interface Keys.MutableKeys
deleteMethods inherited from interface Keys.MutableValues
putMethods inherited from interface Table.TableDictionary
put
-
Method Details
-
withPut
Builder method forKeys.MutableValues.put(Object, Object).- Parameters:
aKey- the key for the property to be put.aValue- the value for the property to be put.- Returns:
- The implementing instance as of the builder pattern.
-
withPut
Builder method forTable.TableDictionary.put(Relation).- Parameters:
aRelation- the property to be put.- Returns:
- The implementing instance as of the builder pattern.
-