Uses of Interface
org.refcodes.struct.CanonicalMap

  • Uses of CanonicalMap in org.refcodes.struct

    Subinterfaces of CanonicalMap in org.refcodes.struct
    Modifier and Type
    Interface
    Description
    static interface 
    The Interface CanonicalMapBuilder.
    static interface 
    The Interface MutableCanonicalMap.
    Classes in org.refcodes.struct that implement CanonicalMap
    Modifier and Type
    Class
    Description
    class 
    The Class CanonicalMapBuilderImpl.
    class 
    The Class CanonicalMapImpl.
    Methods in org.refcodes.struct that return CanonicalMap
    Modifier and Type
    Method
    Description
    default CanonicalMap
    CanonicalMap.getDir(Object aPath)
    Gets the children elements of the provided parent's path, excluding the parent's path.
    default CanonicalMap
    CanonicalMap.getDir(Object... aPathElements)
    Gets the children elements of the provided parent's path elements, excluding the parent's path.
    default CanonicalMap
    CanonicalMap.getDir(String aPath)
    Gets the children elements of the provided parent's path elements, excluding the parent's path.
    default CanonicalMap
    CanonicalMap.getDir(String... aPathElements)
    Gets the children elements of the provided parent's path elements, excluding the parent's path.
    default CanonicalMap
    CanonicalMap.getDir(Collection<?> aPathElements)
    Gets the children elements of the provided parent's path elements, excluding the parent's path.
    default CanonicalMap
    CanonicalMap.getDirAt(int aIndex)
    An indexed directory represents all elements which begin with a path which's last path element represents an index.
    default CanonicalMap
    CanonicalMap.getDirAt(Object[] aPathElements, int aIndex)
    An indexed directory represents all elements which begin with a path which's last path element represents an index.
    default CanonicalMap
    CanonicalMap.getDirAt(Object aPath, int aIndex)
    An indexed directory represents all elements which begin with a path which's last path element represents an index.
    default CanonicalMap
    CanonicalMap.getDirAt(String[] aPathElements, int aIndex)
    An indexed directory represents all elements which begin with a path which's last path element represents an index.
    default CanonicalMap
    CanonicalMap.getDirAt(String aPath, int aIndex)
    An indexed directory represents all elements which begin with a path which's last path element represents an index.
    default CanonicalMap
    CanonicalMap.getDirAt(Collection<?> aPathElements, int aIndex)
    An indexed directory represents all elements which begin with a path which's last path element represents an index.
    default CanonicalMap[]
    CanonicalMap.getDirs(Object aPath)
    Gets the children elements of the provided parent's path, excluding the parent's path.
    default CanonicalMap[]
    CanonicalMap.getDirs(Object... aPathElements)
    Gets the children elements of the provided parent's path elements, excluding the parent's path.
    default CanonicalMap[]
    CanonicalMap.getDirs(String aPath)
    Gets the children elements of the provided parent's path elements, excluding the parent's path.
    default CanonicalMap[]
    CanonicalMap.getDirs(String... aPathElements)
    Gets the children elements of the provided parent's path elements, excluding the parent's path.
    default CanonicalMap[]
    CanonicalMap.getDirs(Collection<?> aPathElements)
    Gets the children elements of the provided parent's path, excluding the parent's path.
    default CanonicalMap
    CanonicalMap.MutableCanonicalMap.putDirAt(int aIndex, Object aDir)
    An indexed directory represents all elements which begin with a path which's last path element represents an index.
    default CanonicalMap
    CanonicalMap.MutableCanonicalMap.putDirAt(int aIndex, PathMap<String> aDir)
    An indexed directory represents all elements which begin with a path which's last path element represents an index.
    default CanonicalMap
    CanonicalMap.MutableCanonicalMap.putDirAt(Object[] aPathElements, int aIndex, Object aDir)
    An indexed directory represents all elements which begin with a path which's last path element represents an index.
    default CanonicalMap
    CanonicalMap.MutableCanonicalMap.putDirAt(Object[] aPathElements, int aIndex, PathMap<String> aDir)
    An indexed directory represents all elements which begin with a path which's last path element represents an index.
    default CanonicalMap
    CanonicalMap.MutableCanonicalMap.putDirAt(Object aPath, int aIndex, Object aDir)
    An indexed directory represents all elements which begin with a path which's last path element represents an index.
    default CanonicalMap
    CanonicalMap.MutableCanonicalMap.putDirAt(Object aPath, int aIndex, PathMap<String> aDir)
    An indexed directory represents all elements which begin with a path which's last path element represents an index.
    default CanonicalMap
    CanonicalMap.MutableCanonicalMap.putDirAt(String[] aPathElements, int aIndex, Object aDir)
    An indexed directory represents all elements which begin with a path which's last path element represents an index.
    default CanonicalMap
    CanonicalMap.MutableCanonicalMap.putDirAt(String[] aPathElements, int aIndex, PathMap<String> aDir)
    An indexed directory represents all elements which begin with a path which's last path element represents an index.
    default CanonicalMap
    CanonicalMap.MutableCanonicalMap.putDirAt(String aPath, int aIndex, Object aDir)
    An indexed directory represents all elements which begin with a path which's last path element represents an index.
    default CanonicalMap
    CanonicalMap.MutableCanonicalMap.putDirAt(String aPath, int aIndex, PathMap<String> aDir)
    An indexed directory represents all elements which begin with a path which's last path element represents an index.
    default CanonicalMap
    CanonicalMap.MutableCanonicalMap.putDirAt(Collection<?> aPathElements, int aIndex, Object aDir)
    An indexed directory represents all elements which begin with a path which's last path element represents an index.
    default CanonicalMap
    CanonicalMap.MutableCanonicalMap.putDirAt(Collection<?> aPathElements, int aIndex, PathMap<String> aDir)
    An indexed directory represents all elements which begin with a path which's last path element represents an index.
    default CanonicalMap
    CanonicalMap.query(Object... aQueryElements)
    Queries the keys of the instance using the PathMatcher' matching patterns, similar to the wildcards '*', '?'
    default CanonicalMap
    CanonicalMap.query(String aPathQuery)
    Queries the keys of the instance using the PathMatcher' matching patterns, similar to the wildcards '*', '?'
    default CanonicalMap
    CanonicalMap.query(String... aQueryElements)
    Queries the keys of the instance using the PathMatcher' matching patterns, similar to the wildcards '*', '?'
    default CanonicalMap
    CanonicalMap.query(Collection<?> aQueryElements)
    Queries the keys of the instance using the PathMatcher' matching patterns, similar to the wildcards '*', '?'
    default CanonicalMap
    CanonicalMap.query(Pattern aRegExp)
    Queries the keys of the instance using a regular expression as of the provided Pattern instance.
    default CanonicalMap
    CanonicalMap.queryBetween(Object[] aFromPath, Object[] aPathQuery, Object[] aToPath)
    Queries the keys of the instance using the PathMatcher' matching patterns, similar to the wildcards '*', '?'
    default CanonicalMap
    CanonicalMap.queryBetween(Object aFromPath, Object aPathQuery, Object aToPath)
    Queries the keys of the instance using the PathMatcher' matching patterns, similar to the wildcards '*', '?'
    default CanonicalMap
    CanonicalMap.queryBetween(String[] aFromPath, String[] aPathQuery, String[] aToPath)
    Queries the keys of the instance using the PathMatcher' matching patterns, similar to the wildcards '*', '?'
    default CanonicalMap
    CanonicalMap.queryBetween(String aFromPath, String aPathQuery, String aToPath)
    Queries the keys of the instance using the PathMatcher' matching patterns, similar to the wildcards '*', '?'
    default CanonicalMap
    CanonicalMap.queryBetween(String aFromPath, Pattern aRegExp, String aToPath)
    Queries the keys of the instance using a regular expression as of the provided Pattern.
    default CanonicalMap
    CanonicalMap.queryBetween(Collection<?> aFromPath, Collection<?> aPathQuery, Collection<?> aToPath)
    Queries the keys of the instance using the PathMatcher' matching patterns, similar to the wildcards '*', '?'
    default CanonicalMap
    CanonicalMap.queryFrom(Object[] aPathQuery, Object[] aFromPath)
    Queries the keys of the instance using the PathMatcher' matching patterns, similar to the wildcards '*', '?'
    default CanonicalMap
    CanonicalMap.queryFrom(Object aPathQuery, Object aFromPath)
    Queries the keys of the instance using the PathMatcher' matching patterns, similar to the wildcards '*', '?'
    default CanonicalMap
    CanonicalMap.queryFrom(String[] aPathQuery, String[] aFromPath)
    Queries the keys of the instance using the PathMatcher' matching patterns, similar to the wildcards '*', '?'
    default CanonicalMap
    CanonicalMap.queryFrom(String aPathQuery, String aFromPath)
    Queries the keys of the instance using the PathMatcher' matching patterns, similar to the wildcards '*', '?'
    default CanonicalMap
    CanonicalMap.queryFrom(Collection<?> aPathQuery, Collection<?> aFromPath)
    Queries the keys of the instance using the PathMatcher' matching patterns, similar to the wildcards '*', '?'
    default CanonicalMap
    CanonicalMap.queryFrom(Pattern aRegExp, String aFromPath)
    Queries the keys of the instance using a regular expression as of the provided Pattern.
    default CanonicalMap
    CanonicalMap.queryTo(Object[] aPathQuery, String aToPath)
    Queries the keys of the instance using the PathMatcher' matching patterns, similar to the wildcards '*', '?'
    default CanonicalMap
    CanonicalMap.queryTo(Object aPathQuery, String aToPath)
    Queries the keys of the instance using the PathMatcher' matching patterns, similar to the wildcards '*', '?'
    default CanonicalMap
    CanonicalMap.queryTo(String[] aPathQuery, String aToPath)
    Queries the keys of the instance using the PathMatcher' matching patterns, similar to the wildcards '*', '?'
    default CanonicalMap
    CanonicalMap.queryTo(String aPathQuery, String aToPath)
    Queries the keys of the instance using the PathMatcher' matching patterns, similar to the wildcards '*', '?'
    default CanonicalMap
    CanonicalMap.queryTo(Collection<?> aPathQuery, String aToPath)
    Queries the keys of the instance using the PathMatcher' matching patterns, similar to the wildcards '*', '?'
    default CanonicalMap
    CanonicalMap.queryTo(Pattern aRegExp, String aToPath)
    Queries the keys of the instance using a regular expression as of the provided Pattern.
    default CanonicalMap
    CanonicalMap.MutableCanonicalMap.removeAll(Object aPathQuery)
    Removes all elements which's keys match the provided path query.
    default CanonicalMap
    CanonicalMap.MutableCanonicalMap.removeAll(Object... aPathQueryElements)
    Removes all elements which's keys match the provided path query.
    default CanonicalMap
    CanonicalMap.MutableCanonicalMap.removeAll(String aPathQuery)
    Removes all elements which's keys match the provided path query.
    default CanonicalMap
    CanonicalMap.MutableCanonicalMap.removeAll(String... aPathQueryElements)
    Removes all elements which's keys match the provided path query.
    default CanonicalMap
    CanonicalMap.MutableCanonicalMap.removeAll(Collection<?> aPathQueryElements)
    Removes all elements which's keys match the provided path query.
    default CanonicalMap
    CanonicalMap.MutableCanonicalMap.removeAll(Pattern aRegExp)
    Removes all elements which's keys match the provided regular expression: Queries the keys of the instance using the provided Pattern.
    default CanonicalMap
    CanonicalMap.MutableCanonicalMap.removeDirAt(int aIndex)
    An indexed directory represents all elements which begin with a path which's last path element represents an index.
    default CanonicalMap
    CanonicalMap.MutableCanonicalMap.removeDirAt(Object[] aPathElements, int aIndex)
    An indexed directory represents all elements which begin with a path which's last path element represents an index.
    default CanonicalMap
    CanonicalMap.MutableCanonicalMap.removeDirAt(Object aPath, int aIndex)
    An indexed directory represents all elements which begin with a path which's last path element represents an index.
    default CanonicalMap
    CanonicalMap.MutableCanonicalMap.removeDirAt(String[] aPathElements, int aIndex)
    An indexed directory represents all elements which begin with a path which's last path element represents an index.
    default CanonicalMap
    CanonicalMap.MutableCanonicalMap.removeDirAt(String aPath, int aIndex)
    An indexed directory represents all elements which begin with a path which's last path element represents an index.
    default CanonicalMap
    CanonicalMap.MutableCanonicalMap.removeFrom(Object aPath)
    Removes all properties below the provided path and returns the PathMap with the removed elements, by which the paths exclude the parent's path.
    default CanonicalMap
    CanonicalMap.MutableCanonicalMap.removeFrom(Object... aPathElements)
    Removes all properties below the provided path and returns the PathMap with the removed elements, by which the paths exclude the parent's path.
    default CanonicalMap
    CanonicalMap.MutableCanonicalMap.removeFrom(String aPath)
    Removes all properties below the provided path and returns the PathMap with the removed elements, by which the paths exclude the parent's path.
    default CanonicalMap
    CanonicalMap.MutableCanonicalMap.removeFrom(String... aPathElements)
    Removes all properties below the provided path and returns the PathMap with the removed elements, by which the paths exclude the parent's path.
    default CanonicalMap
    CanonicalMap.MutableCanonicalMap.removeFrom(Collection<?> aPathElements)
    Removes all properties below the provided path and returns the PathMap with the removed elements, by which the paths exclude the parent's path.
    default CanonicalMap
    CanonicalMap.MutableCanonicalMap.removePaths(String... aPaths)
    Removes the paths contained in the provided collection.
    default CanonicalMap
    CanonicalMap.MutableCanonicalMap.removePaths(Collection<?> aPaths)
    Removes the paths contained in the provided collection.
    default CanonicalMap
    CanonicalMap.retrieveBetween(Object[] aFromPath, Object[] aToPath)
    Extracts a new PathMap from the elements of this PathMap found below the "from-path".
    default CanonicalMap
    CanonicalMap.retrieveBetween(Object aFromPath, Object aToPath)
    Extracts a new PathMap from the elements of this PathMap found below the "from-path".
    default CanonicalMap
    CanonicalMap.retrieveBetween(String[] aFromPath, String[] aToPath)
    Extracts a new PathMap from the elements of this PathMap found below the "from-path".
    default CanonicalMap
    CanonicalMap.retrieveBetween(String aFromPath, String aToPath)
    Extracts a new PathMap from the elements of this PathMap found below the "from-path".
    default CanonicalMap
    CanonicalMap.retrieveBetween(Collection<?> aFromPath, Collection<?> aToPath)
    Extracts a new PathMap from the elements of this PathMap found below the "from-path".
    default CanonicalMap
    CanonicalMap.retrieveFrom(Object aParentPath)
    Gets the children elements of the provided parent's path, excluding the parent's path.
    default CanonicalMap
    CanonicalMap.retrieveFrom(Object... aPathElements)
    Gets the children elements of the provided parent's path elements, excluding the parent's path.
    CanonicalMap.retrieveFrom(String aFromPath)
    Extracts a new PathMap from the elements of this PathMap found below the "from-path".
    default CanonicalMap
    CanonicalMap.retrieveFrom(String... aPathElements)
    Gets the children elements of the provided parent's path elements, excluding the parent's path.
    default CanonicalMap
    CanonicalMap.retrieveFrom(Collection<?> aPathElements)
    Gets the children elements of the provided parent's path elements, excluding the parent's path.
    CanonicalMapImpl.retrieveFrom(String aFromPath)
    Extracts a new PathMap from the elements of this PathMap found below the "from-path".
    default CanonicalMap
    CanonicalMap.retrieveTo(Object aToPath)
    Extracts a new PathMap from this PathMap's elements with the paths relocated to the provided "to-path".
    default CanonicalMap
    CanonicalMap.retrieveTo(Object... aToPathElements)
    Extracts a new PathMap from this PathMap's elements with the paths relocated to the provided "to-path".
    CanonicalMap.retrieveTo(String aToPath)
    Extracts a new PathMap from this PathMap's elements with the paths relocated to the provided "to-path".
    default CanonicalMap
    CanonicalMap.retrieveTo(String... aToPathElements)
    Extracts a new PathMap from this PathMap's elements with the paths relocated to the provided "to-path".
    default CanonicalMap
    CanonicalMap.retrieveTo(Collection<?> aToPathElements)
    Extracts a new PathMap from this PathMap's elements with the paths relocated to the provided "to-path".
    CanonicalMapImpl.retrieveTo(String aToPath)
    Extracts a new PathMap from this PathMap's elements with the paths relocated to the provided "to-path".
    Methods in org.refcodes.struct with parameters of type CanonicalMap
    Modifier and Type
    Method
    Description
    default void
    CanonicalMap.MutableCanonicalMap.insert(CanonicalMap aFrom)
    Method to semantically emphasize that we support our own types.
    default void
    CanonicalMap.MutableCanonicalMap.insertBetween(String aToPath, CanonicalMap aFrom, String aFromPath)
    Method to semantically emphasize that we support our own types.
    default void
    CanonicalMap.MutableCanonicalMap.insertFrom(CanonicalMap aFrom, String aFromPath)
    Method to semantically emphasize that we support our own types.
    default void
    CanonicalMap.MutableCanonicalMap.insertTo(String aToPath, CanonicalMap aFrom)
    Method to semantically emphasize that we support our own types.
    default void
    CanonicalMap.MutableCanonicalMap.putAll(CanonicalMap aProperties)
    This method inserts all elements (key/value-pairs) found in the provided CanonicalMap instances of interoperability reasons.