Uses of Interface
org.refcodes.struct.CanonicalMap.CanonicalMapBuilder
-
Uses of CanonicalMap.CanonicalMapBuilder in org.refcodes.struct
Classes in org.refcodes.struct that implement CanonicalMap.CanonicalMapBuilderModifier and TypeClassDescriptionclassThe Class CanonicalMapBuilderImpl.Fields in org.refcodes.struct declared as CanonicalMap.CanonicalMapBuilderModifier and TypeFieldDescriptionprotected CanonicalMap.CanonicalMapBuilderCanonicalMapImpl._canonicalMapMethods in org.refcodes.struct that return CanonicalMap.CanonicalMapBuilderModifier and TypeMethodDescriptionCanonicalMapBuilderImpl.retrieveFrom(String aFromPath) CanonicalMapBuilderImpl.retrieveTo(String aToPath) default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withInsert(Object aObj) Convenience method for providing builder functionality to thePathMap.MutablePathMap.insert(Object)method.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withInsert(PathMap<String> aFrom) Method to semantically emphasize that we support our own types.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withInsertBetween(Object[] aToPathElements, Object aFrom, Object[] aFromPathElements) Convenience method for providing builder functionality to thePathMap.MutablePathMap.insertBetween(String, Object, String)method.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withInsertBetween(Object[] aToPathElements, PathMap<String> aFrom, Object[] aFromPathElements) Method to semantically emphasize that we support our own types.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withInsertBetween(Object aToPath, Object aFrom, Object aFromPath) Convenience method for providing builder functionality to thePathMap.MutablePathMap.insertBetween(String, Object, String)method.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withInsertBetween(Object aToPath, PathMap<String> aFrom, Object aFromPath) Method to semantically emphasize that we support our own types.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withInsertBetween(String[] aToPathElements, Object aFrom, String[] aFromPathElements) Convenience method for providing builder functionality to thePathMap.MutablePathMap.insertBetween(String, Object, String)method.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withInsertBetween(String[] aToPathElements, PathMap<String> aFrom, String[] aFromPathElements) Method to semantically emphasize that we support our own types.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withInsertBetween(String aToPath, Object aFrom, String aFromPath) Convenience method for providing builder functionality to thePathMap.MutablePathMap.insertBetween(String, Object, String)method.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withInsertBetween(String aToPath, PathMap<String> aFrom, String aFromPath) Method to semantically emphasize that we support our own types.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withInsertBetween(Collection<?> aToPathElements, Object aFrom, Collection<?> aFromPathElements) Convenience method for providing builder functionality to thePathMap.MutablePathMap.insertBetween(String, Object, String)method.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withInsertBetween(Collection<?> aToPathElements, PathMap<String> aFrom, Collection<?> aFromPathElements) Method to semantically emphasize that we support our own types.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withInsertFrom(Object aFrom, Object aFromPath) Convenience method for providing builder functionality to thePathMap.MutablePathMap.insertFrom(Object, String)method.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withInsertFrom(Object aFrom, Object... aFromPathElements) Convenience method for providing builder functionality to thePathMap.MutablePathMap.insertFrom(Object, String)method.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withInsertFrom(Object aFrom, String aFromPath) Convenience method for providing builder functionality to thePathMap.MutablePathMap.insertFrom(Object, String)method.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withInsertFrom(Object aFrom, String... aFromPathElements) Convenience method for providing builder functionality to thePathMap.MutablePathMap.insertFrom(Object, String)method.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withInsertFrom(Object aFrom, Collection<?> aFromPathElements) Convenience method for providing builder functionality to thePathMap.MutablePathMap.insertFrom(Object, String)method.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withInsertFrom(PathMap<String> aFrom, Object aFromPath) Method to semantically emphasize that we support our own types.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withInsertFrom(PathMap<String> aFrom, Object... aFromPathElements) Method to semantically emphasize that we support our own types.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withInsertFrom(PathMap<String> aFrom, String aFromPath) Method to semantically emphasize that we support our own types.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withInsertFrom(PathMap<String> aFrom, String... aFromPathElements) Method to semantically emphasize that we support our own types.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withInsertFrom(PathMap<String> aFrom, Collection<?> aFromPathElements) Method to semantically emphasize that we support our own types.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withInsertTo(Object[] aToPathElements, Object aFrom) Convenience method for providing builder functionality to thePathMap.MutablePathMap.insertTo(String, Object)method.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withInsertTo(Object[] aToPathElements, PathMap<String> aFrom) Method to semantically emphasize that we support our own types.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withInsertTo(Object aToPath, Object aFrom) Convenience method for providing builder functionality to thePathMap.MutablePathMap.insertTo(String, Object)method.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withInsertTo(Object aToPath, PathMap<String> aFrom) Method to semantically emphasize that we support our own types.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withInsertTo(String[] aToPathElements, Object aFrom) Convenience method for providing builder functionality to thePathMap.MutablePathMap.insertTo(String, Object)method.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withInsertTo(String[] aToPathElements, PathMap<String> aFrom) Method to semantically emphasize that we support our own types.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withInsertTo(String aToPath, Object aFrom) Convenience method for providing builder functionality to thePathMap.MutablePathMap.insertTo(String, Object)method.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withInsertTo(String aToPath, PathMap<String> aFrom) Method to semantically emphasize that we support our own types.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withInsertTo(Collection<?> aToPathElements, Object aFrom) Convenience method for providing builder functionality to thePathMap.MutablePathMap.insertTo(String, Object)method.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withInsertTo(Collection<?> aToPathElements, PathMap<String> aFrom) Method to semantically emphasize that we support our own types.default CanonicalMap.CanonicalMapBuilderConvenience method for providing builder functionality to thePathMap.MutablePathMap.merge(Object)method.default CanonicalMap.CanonicalMapBuilderMethod to semantically emphasize that we support our own types.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withMergeBetween(Object[] aToPathElements, Object aFrom, Object[] aFromPathElements) Convenience method for providing builder functionality to thePathMap.MutablePathMap.mergeBetween(String, Object, String)method.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withMergeBetween(Object[] aToPathElements, PathMap<String> aFrom, Object[] aFromPathElements) Method to semantically emphasize that we support our own types.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withMergeBetween(Object aToPath, Object aFrom, Object aFromPath) Convenience method for providing builder functionality to thePathMap.MutablePathMap.mergeBetween(String, Object, String)method.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withMergeBetween(Object aToPath, PathMap<String> aFrom, Object aFromPath) Method to semantically emphasize that we support our own types.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withMergeBetween(String[] aToPathElements, Object aFrom, String[] aFromPathElements) Convenience method for providing builder functionality to thePathMap.MutablePathMap.mergeBetween(String, Object, String)method.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withMergeBetween(String[] aToPathElements, PathMap<String> aFrom, String[] aFromPathElements) Method to semantically emphasize that we support our own types.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withMergeBetween(String aToPath, Object aFrom, String aFromPath) Convenience method for providing builder functionality to thePathMap.MutablePathMap.mergeBetween(String, Object, String)method.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withMergeBetween(String aToPath, PathMap<String> aFrom, String aFromPath) Method to semantically emphasize that we support our own types.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withMergeBetween(Collection<?> aToPathElements, Object aFrom, Collection<?> aFromPathElements) Convenience method for providing builder functionality to thePathMap.MutablePathMap.mergeBetween(String, Object, String)method.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withMergeBetween(Collection<?> aToPathElements, PathMap<String> aFrom, Collection<?> aFromPathElements) Method to semantically emphasize that we support our own types.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withMergeFrom(Object aFrom, Object aFromPath) Convenience method for providing builder functionality to thePathMap.MutablePathMap.mergeFrom(Object, String)method.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withMergeFrom(Object aFrom, Object... aFromPathElements) Convenience method for providing builder functionality to thePathMap.MutablePathMap.mergeFrom(Object, String)method.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withMergeFrom(Object aFrom, String aFromPath) Convenience method for providing builder functionality to thePathMap.MutablePathMap.mergeFrom(Object, String)method.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withMergeFrom(Object aFrom, String... aFromPathElements) Convenience method for providing builder functionality to thePathMap.MutablePathMap.mergeFrom(Object, String)method.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withMergeFrom(Object aFrom, Collection<?> aFromPathElements) Convenience method for providing builder functionality to thePathMap.MutablePathMap.mergeFrom(Object, String)method.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withMergeFrom(PathMap<String> aFrom, Object aFromPath) Method to semantically emphasize that we support our own types.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withMergeFrom(PathMap<String> aFrom, Object... aFromPathElements) Method to semantically emphasize that we support our own types.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withMergeFrom(PathMap<String> aFrom, String aFromPath) Method to semantically emphasize that we support our own types.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withMergeFrom(PathMap<String> aFrom, String... aFromPathElements) Method to semantically emphasize that we support our own types.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withMergeFrom(PathMap<String> aFrom, Collection<?> aFromPathElements) Method to semantically emphasize that we support our own types.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withMergeTo(Object[] aToPathElements, Object aFrom) Convenience method for providing builder functionality to thePathMap.MutablePathMap.mergeTo(String, Object)method.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withMergeTo(Object[] aToPathElements, PathMap<String> aFrom) Method to semantically emphasize that we support our own types.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withMergeTo(Object aToPath, Object aFrom) Convenience method for providing builder functionality to thePathMap.MutablePathMap.mergeTo(String, Object)method.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withMergeTo(Object aToPath, PathMap<String> aFrom) Method to semantically emphasize that we support our own types.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withMergeTo(String[] aToPathElements, Object aFrom) Convenience method for providing builder functionality to thePathMap.MutablePathMap.mergeTo(String, Object)method.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withMergeTo(String[] aToPathElements, PathMap<String> aFrom) Method to semantically emphasize that we support our own types.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withMergeTo(String aToPath, Object aFrom) Convenience method for providing builder functionality to thePathMap.MutablePathMap.mergeTo(String, Object)method.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withMergeTo(String aToPath, PathMap<String> aFrom) Method to semantically emphasize that we support our own types.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withMergeTo(Collection<?> aToPathElements, Object aFrom) Convenience method for providing builder functionality to thePathMap.MutablePathMap.mergeTo(String, Object)method.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withMergeTo(Collection<?> aToPathElements, PathMap<String> aFrom) Method to semantically emphasize that we support our own types.default CanonicalMap.CanonicalMapBuilderBuilder method forKeys.MutableValues.put(Object, Object).default CanonicalMap.CanonicalMapBuilderBuilder method forKeys.MutableValues.put(Object, Object).default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withPut(Collection<?> aPathElements, String aValue) Builder method forKeys.MutableValues.put(Object, Object).default CanonicalMap.CanonicalMapBuilderBuilder method forCanonicalMap.MutableCanonicalMap.put(Property).default CanonicalMap.CanonicalMapBuilderBuilder method forTable.TableDictionary.put(Relation).Builder method forKeys.MutableValues.put(Object, Object).default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withPutBoolean(Object[] aPathElements, Boolean aValue) Sets theBooleanvalue for the property referred to by the path elements representing the addressed path.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withPutBoolean(Object aKey, Boolean aValue) Sets theBooleanvalue for the property referred to by the key.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withPutBoolean(String[] aPathElements, Boolean aValue) Sets theBooleanvalue for the property referred to by the path elements representing the addressed path.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withPutBoolean(String aKey, Boolean aValue) Sets theBooleanvalue for the property referred to by the key.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withPutBoolean(Collection<?> aPathElements, Boolean aValue) Sets theBooleanvalue for the property referred to by the path elements representing the addressed path.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withPutByte(Object[] aPathElements, Byte aValue) Sets theBytevalue for the property referred to by the path elements representing the addressed path.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withPutByte(Object aKey, Byte aValue) Sets theBytevalue for the property referred to by the key.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withPutByte(String[] aPathElements, Byte aValue) Sets theBytevalue for the property referred to by the path elements representing the addressed path.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withPutByte(String aKey, Byte aValue) Sets theBytevalue for the property referred to by the key.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withPutByte(Collection<?> aPathElements, Byte aValue) Sets theBytevalue for the property referred to by the path elements representing the addressed path.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withPutChar(Object[] aPathElements, Character aValue) Sets theCharactervalue for the property referred to by the path elements representing the addressed path.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withPutChar(Object aKey, Character aValue) Sets theCharactervalue for the property referred to by the key.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withPutChar(String[] aPathElements, Character aValue) Sets theCharactervalue for the property referred to by the path elements representing the addressed path.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withPutChar(String aKey, Character aValue) Sets theCharactervalue for the property referred to by the key.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withPutChar(Collection<?> aPathElements, Character aValue) Sets theCharactervalue for the property referred to by the path elements representing the addressed path.default <C> CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withPutClass(Object[] aPathElements, Class<C> aValue) Sets theClassvalue for the property referred to by the path elements representing the addressed path.default <C> CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withPutClass(Object aKey, Class<C> aValue) Sets theClassvalue for the property referred to by the key.default <C> CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withPutClass(String[] aPathElements, Class<C> aValue) Sets theClassvalue for the property referred to by the path elements representing the addressed path.default <C> CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withPutClass(String aKey, Class<C> aValue) Sets theClassvalue for the property referred to by the key.default <C> CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withPutClass(Collection<?> aPathElements, Class<C> aValue) Sets theClassvalue for the property referred to by the path elements representing the addressed path.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withPutDirAt(int aIndex, Object aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withPutDirAt(int aIndex, PathMap<String> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withPutDirAt(Object[] aPathElements, int aIndex, Object aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withPutDirAt(Object[] aPathElements, int aIndex, PathMap<String> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withPutDirAt(Object aPath, int aIndex, Object aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withPutDirAt(Object aPath, int aIndex, PathMap<String> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withPutDirAt(String[] aPathElements, int aIndex, Object aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withPutDirAt(String[] aPathElements, int aIndex, PathMap<String> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withPutDirAt(String aPath, int aIndex, Object aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withPutDirAt(String aPath, int aIndex, PathMap<String> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withPutDirAt(Collection<?> aPathElements, int aIndex, Object aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withPutDirAt(Collection<?> aPathElements, int aIndex, PathMap<String> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withPutDouble(Object[] aPathElements, Double aValue) Sets theDoublevalue for the property referred to by the path elements representing the addressed path.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withPutDouble(Object aKey, Double aValue) Sets theDoublevalue for the property referred to by the key.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withPutDouble(String[] aPathElements, Double aValue) Sets theDoublevalue for the property referred to by the path elements representing the addressed path.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withPutDouble(String aKey, Double aValue) Sets theDoublevalue for the property referred to by the key.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withPutDouble(Collection<?> aPathElements, Double aValue) Sets theDoublevalue for the property referred to by the path elements representing the addressed path.default <E extends Enum<E>>
CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withPutEnum(Object[] aPathElements, E aValue) Sets theEnumvalue for the property referred to by the path elements representing the addressed path.default <E extends Enum<E>>
CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withPutEnum(Object aKey, E aValue) Sets theEnumvalue for the property referred to by the key.default <E extends Enum<E>>
CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withPutEnum(String[] aPathElements, E aValue) Sets theEnumvalue for the property referred to by the path elements representing the addressed path.default <E extends Enum<E>>
CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withPutEnum(String aKey, E aValue) Sets theEnumvalue for the property referred to by the key.default <E extends Enum<E>>
CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withPutEnum(Collection<?> aPathElements, E aValue) Sets theEnumvalue for the property referred to by the path elements representing the addressed path.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withPutFloat(Object[] aPathElements, Float aValue) Sets theFloatvalue for the property referred to by the path elements representing the addressed path.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withPutFloat(Object aKey, Float aValue) Sets theFloatvalue for the property referred to by the key.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withPutFloat(String[] aPathElements, Float aValue) Sets theFloatvalue for the property referred to by the path elements representing the addressed path.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withPutFloat(String aKey, Float aValue) Sets theFloatvalue for the property referred to by the key.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withPutFloat(Collection<?> aPathElements, Float aValue) Sets theFloatvalue for the property referred to by the path elements representing the addressed path.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withPutInt(Object[] aPathElements, Integer aValue) Sets theIntegervalue for the property referred to by the path elements representing the addressed path.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withPutInt(Object aKey, Integer aValue) Sets theIntegervalue for the property referred to by the key.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withPutInt(String[] aPathElements, Integer aValue) Sets theIntegervalue for the property referred to by the path elements representing the addressed path.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withPutInt(String aKey, Integer aValue) Sets theIntegervalue for the property referred to by the key.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withPutInt(Collection<?> aPathElements, Integer aValue) Sets theIntegervalue for the property referred to by the path elements representing the addressed path.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withPutLong(Object[] aPathElements, Long aValue) Sets theLongvalue for the property referred to by the path elements representing the addressed path.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withPutLong(Object aKey, Long aValue) Sets theLongvalue for the property referred to by the key.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withPutLong(String[] aPathElements, Long aValue) Sets theLongvalue for the property referred to by the path elements representing the addressed path.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withPutLong(String aKey, Long aValue) Sets theLongvalue for the property referred to by the key.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withPutLong(Collection<?> aPathElements, Long aValue) Sets theLongvalue for the property referred to by the path elements representing the addressed path.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withPutShort(Object[] aPathElements, Short aValue) Sets theShortvalue for the property referred to by the path elements representing the addressed path.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withPutShort(Object aKey, Short aValue) Sets theShortvalue for the property referred to by the key.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withPutShort(String[] aPathElements, Short aValue) Sets theShortvalue for the property referred to by the path elements representing the addressed path.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withPutShort(String aKey, Short aValue) Sets theShortvalue for the property referred to by the key.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withPutShort(Collection<?> aPathElements, Short aValue) Sets theShortvalue for the property referred to by the path elements representing the addressed path.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withPutString(Object[] aPathElements, String aValue) Sets theStringvalue for the property referred to by the path elements representing the addressed path.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withPutString(Object aKey, String aValue) Sets theStringvalue for the property referred to by the key.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withPutString(String[] aPathElements, String aValue) Sets theStringvalue for the property referred to by the path elements representing the addressed path.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withPutString(String aKey, String aValue) Sets theStringvalue for the property referred to by the key.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withPutString(Collection<?> aPathElements, String aValue) Sets theStringvalue for the property referred to by the path elements representing the addressed path.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withRemoveFrom(Object aPath) Convenience method for providing builder functionality to thePathMap.MutablePathMap.removeFrom(String)method.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withRemoveFrom(Object... aPathElements) Convenience method for providing builder functionality to thePathMap.MutablePathMap.removeFrom(String)method.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withRemoveFrom(String aPath) Convenience method for providing builder functionality to thePathMap.MutablePathMap.removeFrom(String)method.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withRemoveFrom(String... aPathElements) Convenience method for providing builder functionality to thePathMap.MutablePathMap.removeFrom(String)method.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withRemoveFrom(Collection<?> aPathElements) Convenience method for providing builder functionality to thePathMap.MutablePathMap.removeFrom(String)method.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder.withRemovePaths(String... aPathElements) Convenience method for providing builder functionality to thePathMap.MutablePathMap.removeFrom(String)method.