Uses of Interface
org.refcodes.struct.CanonicalTable
-
Uses of CanonicalTable in org.refcodes.struct
Classes in org.refcodes.struct that implement CanonicalTableModifier and TypeClassDescriptionclassFields in org.refcodes.struct declared as CanonicalTableModifier and TypeFieldDescriptionprotected CanonicalTableUnmodifiableCanonicalTableDecorator._canonicalTableMethods in org.refcodes.struct that return CanonicalTableModifier and TypeMethodDescriptiondefault CanonicalTableGets the children elements of the provided parent's path, excluding the parent's path.default CanonicalTableGets the children elements of the provided parent's path elements, excluding the parent's path.default CanonicalTableGets the children elements of the provided parent's path elements, excluding the parent's path.default CanonicalTableGets the children elements of the provided parent's path elements, excluding the parent's path.default CanonicalTableImmutableCanonicalTable.getDir(Collection<?> aPathElements) Gets the children elements of the provided parent's path elements, excluding the parent's path.default CanonicalTableImmutableCanonicalTable.getDirAt(int aIndex) An indexed directory represents all elements which begin with a path which's last path element represents an index.default CanonicalTableAn indexed directory represents all elements which begin with a path which's last path element represents an index.default CanonicalTableAn indexed directory represents all elements which begin with a path which's last path element represents an index.default CanonicalTableAn indexed directory represents all elements which begin with a path which's last path element represents an index.default CanonicalTableAn indexed directory represents all elements which begin with a path which's last path element represents an index.default CanonicalTableImmutableCanonicalTable.getDirAt(Collection<?> aPathElements, int aIndex) An indexed directory represents all elements which begin with a path which's last path element represents an index.default CanonicalTable[]Gets the children elements of the provided parent's path, excluding the parent's path.default CanonicalTable[]Gets the children elements of the provided parent's path elements, excluding the parent's path.default CanonicalTable[]Gets the children elements of the provided parent's path elements, excluding the parent's path.default CanonicalTable[]Gets the children elements of the provided parent's path elements, excluding the parent's path.default CanonicalTable[]ImmutableCanonicalTable.getDirs(Collection<?> aPathElements) Gets the children elements of the provided parent's path, excluding the parent's path.default CanonicalTableAn indexed directory represents all elements which begin with a path which's last path element represents an index.default CanonicalTableImmutableCanonicalTable.MutableCanonicalTable.putDirAt(int aIndex, ImmutablePathTable<String> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default CanonicalTableImmutableCanonicalTable.MutableCanonicalTable.putDirAt(Object[] aPathElements, int aIndex, Object aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default CanonicalTableImmutableCanonicalTable.MutableCanonicalTable.putDirAt(Object[] aPathElements, int aIndex, ImmutablePathTable<String> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default CanonicalTableAn indexed directory represents all elements which begin with a path which's last path element represents an index.default CanonicalTableImmutableCanonicalTable.MutableCanonicalTable.putDirAt(Object aPath, int aIndex, ImmutablePathTable<String> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default CanonicalTableImmutableCanonicalTable.MutableCanonicalTable.putDirAt(String[] aPathElements, int aIndex, Object aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default CanonicalTableImmutableCanonicalTable.MutableCanonicalTable.putDirAt(String[] aPathElements, int aIndex, ImmutablePathTable<String> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default CanonicalTableAn indexed directory represents all elements which begin with a path which's last path element represents an index.default CanonicalTableImmutableCanonicalTable.MutableCanonicalTable.putDirAt(String aPath, int aIndex, ImmutablePathTable<String> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default CanonicalTableImmutableCanonicalTable.MutableCanonicalTable.putDirAt(Collection<?> aPathElements, int aIndex, Object aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default CanonicalTableImmutableCanonicalTable.MutableCanonicalTable.putDirAt(Collection<?> aPathElements, int aIndex, ImmutablePathTable<String> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default CanonicalTableQueries the keys of the instance matching patterns with the wildcards '*', '?'default CanonicalTableQueries the keys of the instance matching patterns with the wildcards '*', '?'default CanonicalTableQueries the keys of the instance matching patterns with the wildcards '*', '?'default CanonicalTableImmutableCanonicalTable.query(Collection<?> aQueryElements) Queries the keys of the instance matching patterns with the wildcards '*', '?'default CanonicalTableQueries the keys of the instance using a regular expression as of the providedPatterninstance.default CanonicalTableImmutableCanonicalTable.queryBetween(Object[] aFromPath, Object[] aPathQuery, Object[] aToPath) Queries the keys of the instance matching patterns with the wildcards '*', '?'default CanonicalTableImmutableCanonicalTable.queryBetween(Object aFromPath, Object aPathQuery, Object aToPath) Queries the keys of the instance matching patterns with the wildcards '*', '?'default CanonicalTableImmutableCanonicalTable.queryBetween(String[] aFromPath, String[] aPathQuery, String[] aToPath) Queries the keys of the instance matching patterns with the wildcards '*', '?'default CanonicalTableImmutableCanonicalTable.queryBetween(String aFromPath, String aPathQuery, String aToPath) Queries the keys of the instance matching patterns with the wildcards '*', '?'default CanonicalTableImmutableCanonicalTable.queryBetween(String aFromPath, Pattern aRegExp, String aToPath) Queries the keys of the instance using a regular expression as of the providedPattern.default CanonicalTableImmutableCanonicalTable.queryBetween(Collection<?> aFromPath, Collection<?> aPathQuery, Collection<?> aToPath) Queries the keys of the instance matching patterns with the wildcards '*', '?'default CanonicalTableQueries the keys of the instance matching patterns with the wildcards '*', '?'default CanonicalTableQueries the keys of the instance matching patterns with the wildcards '*', '?'default CanonicalTableQueries the keys of the instance matching patterns with the wildcards '*', '?'default CanonicalTableQueries the keys of the instance matching patterns with the wildcards '*', '?'default CanonicalTableImmutableCanonicalTable.queryFrom(Collection<?> aPathQuery, Collection<?> aFromPath) Queries the keys of the instance matching patterns with the wildcards '*', '?'default CanonicalTableQueries the keys of the instance using a regular expression as of the providedPattern.default CanonicalTableQueries the keys of the instance matching patterns with the wildcards '*', '?'default CanonicalTableQueries the keys of the instance matching patterns with the wildcards '*', '?'default CanonicalTableQueries the keys of the instance matching patterns with the wildcards '*', '?'default CanonicalTableQueries the keys of the instance matching patterns with the wildcards '*', '?'default CanonicalTableImmutableCanonicalTable.queryTo(Collection<?> aPathQuery, String aToPath) Queries the keys of the instance matching patterns with the wildcards '*', '?'default CanonicalTableQueries the keys of the instance using a regular expression as of the providedPattern.default CanonicalTableRemoves all elements which's keys match the provided path query.default CanonicalTableRemoves all elements which's keys match the provided path query.default CanonicalTableRemoves all elements which's keys match the provided path query.default CanonicalTableRemoves all elements which's keys match the provided path query.default CanonicalTableImmutableCanonicalTable.MutableCanonicalTable.removeAll(Collection<?> aPathQueryElements) Removes all elements which's keys match the provided path query.default CanonicalTableRemoves all elements which's keys match the provided regular expression: Queries the keys of the instance using the providedPattern.default CanonicalTableImmutableCanonicalTable.MutableCanonicalTable.removeDirAt(int aIndex) An indexed directory represents all elements which begin with a path which's last path element represents an index.default CanonicalTableImmutableCanonicalTable.MutableCanonicalTable.removeDirAt(Object[] aPathElements, int aIndex) An indexed directory represents all elements which begin with a path which's last path element represents an index.default CanonicalTableImmutableCanonicalTable.MutableCanonicalTable.removeDirAt(Object aPath, int aIndex) An indexed directory represents all elements which begin with a path which's last path element represents an index.default CanonicalTableImmutableCanonicalTable.MutableCanonicalTable.removeDirAt(String[] aPathElements, int aIndex) An indexed directory represents all elements which begin with a path which's last path element represents an index.default CanonicalTableImmutableCanonicalTable.MutableCanonicalTable.removeDirAt(String aPath, int aIndex) An indexed directory represents all elements which begin with a path which's last path element represents an index.default CanonicalTableImmutableCanonicalTable.MutableCanonicalTable.removeFrom(Object aPath) Removes all properties below the provided path and returns thePathTablewith the removed elements, by which the paths exclude the parent's path.default CanonicalTableImmutableCanonicalTable.MutableCanonicalTable.removeFrom(Object... aPathElements) Removes all properties below the provided path and returns thePathTablewith the removed elements, by which the paths exclude the parent's path.default CanonicalTableImmutableCanonicalTable.MutableCanonicalTable.removeFrom(String aPath) Removes all properties below the provided path and returns thePathTablewith the removed elements, by which the paths exclude the parent's path.default CanonicalTableImmutableCanonicalTable.MutableCanonicalTable.removeFrom(String... aPathElements) Removes all properties below the provided path and returns thePathTablewith the removed elements, by which the paths exclude the parent's path.default CanonicalTableImmutableCanonicalTable.MutableCanonicalTable.removeFrom(Collection<?> aPathElements) Removes all properties below the provided path and returns thePathTablewith the removed elements, by which the paths exclude the parent's path.default CanonicalTableImmutableCanonicalTable.MutableCanonicalTable.removePaths(String... aPaths) Removes the paths contained in the provided collection.default CanonicalTableImmutableCanonicalTable.MutableCanonicalTable.removePaths(Collection<?> aPaths) Removes the paths contained in the provided collection.default CanonicalTableImmutableCanonicalTable.retrieveBetween(Object[] aFromPath, Object[] aToPath) Extracts a newPathTablefrom the elements of this instance found below the "from-path".default CanonicalTableImmutableCanonicalTable.retrieveBetween(Object aFromPath, Object aToPath) Extracts a newPathTablefrom the elements of this instance found below the "from-path".default CanonicalTableImmutableCanonicalTable.retrieveBetween(String[] aFromPath, String[] aToPath) Extracts a newPathTablefrom the elements of this instance found below the "from-path".default CanonicalTableImmutableCanonicalTable.retrieveBetween(String aFromPath, String aToPath) Extracts a newPathTablefrom the elements of this instance found below the "from-path".default CanonicalTableImmutableCanonicalTable.retrieveBetween(Collection<?> aFromPath, Collection<?> aToPath) Extracts a newPathTablefrom the elements of this instance found below the "from-path".default CanonicalTableImmutableCanonicalTable.retrieveFrom(Object aParentPath) Gets the children elements of the provided parent's path, excluding the parent's path.default CanonicalTableImmutableCanonicalTable.retrieveFrom(Object... aPathElements) Gets the children elements of the provided parent's path elements, excluding the parent's path.ImmutableCanonicalTable.retrieveFrom(String aFromPath) Extracts a newPathTablefrom the elements of this instance found below the "from-path".default CanonicalTableImmutableCanonicalTable.retrieveFrom(String... aPathElements) Gets the children elements of the provided parent's path elements, excluding the parent's path.default CanonicalTableImmutableCanonicalTable.retrieveFrom(Collection<?> aPathElements) Gets the children elements of the provided parent's path elements, excluding the parent's path.MapCanonicalTable.retrieveFrom(String aFromPath) Extracts a newPathTablefrom the elements of this instance found below the "from-path".UnmodifiableCanonicalTableDecorator.retrieveFrom(String aFromPath) Extracts a newPathTablefrom the elements of this instance found below the "from-path".default CanonicalTableImmutableCanonicalTable.retrieveTo(Object aToPath) Extracts a newPathTablefrom this instance's elements with the paths relocated to the provided "to-path".default CanonicalTableImmutableCanonicalTable.retrieveTo(Object... aToPathElements) Extracts a newPathTablefrom this instance's elements with the paths relocated to the provided "to-path".ImmutableCanonicalTable.retrieveTo(String aToPath) Extracts a newPathTablefrom this instance's elements with the paths relocated to the provided "to-path".default CanonicalTableImmutableCanonicalTable.retrieveTo(String... aToPathElements) Extracts a newPathTablefrom this instance's elements with the paths relocated to the provided "to-path".default CanonicalTableImmutableCanonicalTable.retrieveTo(Collection<?> aToPathElements) Extracts a newPathTablefrom this instance's elements with the paths relocated to the provided "to-path".MapCanonicalTable.retrieveTo(String aToPath) Extracts a newPathTablefrom this instance's elements with the paths relocated to the provided "to-path".UnmodifiableCanonicalTableDecorator.retrieveTo(String aToPath) Extracts a newPathTablefrom this instance's elements with the paths relocated to the provided "to-path".default CanonicalTableCanonicalTable.withInsert(Object aObj) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.insert(Object)method.default CanonicalTableCanonicalTable.withInsert(ImmutablePathTable<String> aFrom) Method to semantically emphasize that we support our own types.default CanonicalTableCanonicalTable.withInsertBetween(Object[] aToPathElements, Object aFrom, Object[] aFromPathElements) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.insertBetween(String, Object, String)method.default CanonicalTableCanonicalTable.withInsertBetween(Object[] aToPathElements, ImmutablePathTable<String> aFrom, Object[] aFromPathElements) Method to semantically emphasize that we support our own types.default CanonicalTableCanonicalTable.withInsertBetween(Object aToPath, Object aFrom, Object aFromPath) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.insertBetween(String, Object, String)method.default CanonicalTableCanonicalTable.withInsertBetween(Object aToPath, ImmutablePathTable<String> aFrom, Object aFromPath) Method to semantically emphasize that we support our own types.default CanonicalTableCanonicalTable.withInsertBetween(String[] aToPathElements, Object aFrom, String[] aFromPathElements) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.insertBetween(String, Object, String)method.default CanonicalTableCanonicalTable.withInsertBetween(String[] aToPathElements, ImmutablePathTable<String> aFrom, String[] aFromPathElements) Method to semantically emphasize that we support our own types.default CanonicalTableCanonicalTable.withInsertBetween(String aToPath, Object aFrom, String aFromPath) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.insertBetween(String, Object, String)method.default CanonicalTableCanonicalTable.withInsertBetween(String aToPath, ImmutablePathTable<String> aFrom, String aFromPath) Method to semantically emphasize that we support our own types.default CanonicalTableCanonicalTable.withInsertBetween(Collection<?> aToPathElements, Object aFrom, Collection<?> aFromPathElements) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.insertBetween(String, Object, String)method.default CanonicalTableCanonicalTable.withInsertBetween(Collection<?> aToPathElements, ImmutablePathTable<String> aFrom, Collection<?> aFromPathElements) Method to semantically emphasize that we support our own types.default CanonicalTableCanonicalTable.withInsertFrom(Object aFrom, Object aFromPath) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.insertFrom(Object, String)method.default CanonicalTableCanonicalTable.withInsertFrom(Object aFrom, Object... aFromPathElements) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.insertFrom(Object, String)method.default CanonicalTableCanonicalTable.withInsertFrom(Object aFrom, String aFromPath) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.insertFrom(Object, String)method.default CanonicalTableCanonicalTable.withInsertFrom(Object aFrom, String... aFromPathElements) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.insertFrom(Object, String)method.default CanonicalTableCanonicalTable.withInsertFrom(Object aFrom, Collection<?> aFromPathElements) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.insertFrom(Object, String)method.default CanonicalTableCanonicalTable.withInsertFrom(ImmutablePathTable<String> aFrom, Object aFromPath) Method to semantically emphasize that we support our own types.default CanonicalTableCanonicalTable.withInsertFrom(ImmutablePathTable<String> aFrom, Object... aFromPathElements) Method to semantically emphasize that we support our own types.default CanonicalTableCanonicalTable.withInsertFrom(ImmutablePathTable<String> aFrom, String aFromPath) Method to semantically emphasize that we support our own types.default CanonicalTableCanonicalTable.withInsertFrom(ImmutablePathTable<String> aFrom, String... aFromPathElements) Method to semantically emphasize that we support our own types.default CanonicalTableCanonicalTable.withInsertFrom(ImmutablePathTable<String> aFrom, Collection<?> aFromPathElements) Method to semantically emphasize that we support our own types.default CanonicalTableCanonicalTable.withInsertTo(Object[] aToPathElements, Object aFrom) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.insertTo(String, Object)method.default CanonicalTableCanonicalTable.withInsertTo(Object[] aToPathElements, ImmutablePathTable<String> aFrom) Method to semantically emphasize that we support our own types.default CanonicalTableCanonicalTable.withInsertTo(Object aToPath, Object aFrom) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.insertTo(String, Object)method.default CanonicalTableCanonicalTable.withInsertTo(Object aToPath, ImmutablePathTable<String> aFrom) Method to semantically emphasize that we support our own types.default CanonicalTableCanonicalTable.withInsertTo(String[] aToPathElements, Object aFrom) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.insertTo(String, Object)method.default CanonicalTableCanonicalTable.withInsertTo(String[] aToPathElements, ImmutablePathTable<String> aFrom) Method to semantically emphasize that we support our own types.default CanonicalTableCanonicalTable.withInsertTo(String aToPath, Object aFrom) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.insertTo(String, Object)method.default CanonicalTableCanonicalTable.withInsertTo(String aToPath, ImmutablePathTable<String> aFrom) Method to semantically emphasize that we support our own types.default CanonicalTableCanonicalTable.withInsertTo(Collection<?> aToPathElements, Object aFrom) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.insertTo(String, Object)method.default CanonicalTableCanonicalTable.withInsertTo(Collection<?> aToPathElements, ImmutablePathTable<String> aFrom) Method to semantically emphasize that we support our own types.default CanonicalTableConvenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.merge(Object)method.default CanonicalTableCanonicalTable.withMerge(ImmutablePathTable<String> aFrom) Method to semantically emphasize that we support our own types.default CanonicalTableCanonicalTable.withMergeBetween(Object[] aToPathElements, Object aFrom, Object[] aFromPathElements) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.mergeBetween(String, Object, String)method.default CanonicalTableCanonicalTable.withMergeBetween(Object[] aToPathElements, ImmutablePathTable<String> aFrom, Object[] aFromPathElements) Method to semantically emphasize that we support our own types.default CanonicalTableCanonicalTable.withMergeBetween(Object aToPath, Object aFrom, Object aFromPath) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.mergeBetween(String, Object, String)method.default CanonicalTableCanonicalTable.withMergeBetween(Object aToPath, ImmutablePathTable<String> aFrom, Object aFromPath) Method to semantically emphasize that we support our own types.default CanonicalTableCanonicalTable.withMergeBetween(String[] aToPathElements, Object aFrom, String[] aFromPathElements) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.mergeBetween(String, Object, String)method.default CanonicalTableCanonicalTable.withMergeBetween(String[] aToPathElements, ImmutablePathTable<String> aFrom, String[] aFromPathElements) Method to semantically emphasize that we support our own types.default CanonicalTableCanonicalTable.withMergeBetween(String aToPath, Object aFrom, String aFromPath) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.mergeBetween(String, Object, String)method.default CanonicalTableCanonicalTable.withMergeBetween(String aToPath, ImmutablePathTable<String> aFrom, String aFromPath) Method to semantically emphasize that we support our own types.default CanonicalTableCanonicalTable.withMergeBetween(Collection<?> aToPathElements, Object aFrom, Collection<?> aFromPathElements) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.mergeBetween(String, Object, String)method.default CanonicalTableCanonicalTable.withMergeBetween(Collection<?> aToPathElements, ImmutablePathTable<String> aFrom, Collection<?> aFromPathElements) Method to semantically emphasize that we support our own types.default CanonicalTableCanonicalTable.withMergeFrom(Object aFrom, Object aFromPath) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.mergeFrom(Object, String)method.default CanonicalTableCanonicalTable.withMergeFrom(Object aFrom, Object... aFromPathElements) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.mergeFrom(Object, String)method.default CanonicalTableCanonicalTable.withMergeFrom(Object aFrom, String aFromPath) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.mergeFrom(Object, String)method.default CanonicalTableCanonicalTable.withMergeFrom(Object aFrom, String... aFromPathElements) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.mergeFrom(Object, String)method.default CanonicalTableCanonicalTable.withMergeFrom(Object aFrom, Collection<?> aFromPathElements) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.mergeFrom(Object, String)method.default CanonicalTableCanonicalTable.withMergeFrom(ImmutablePathTable<String> aFrom, Object aFromPath) Method to semantically emphasize that we support our own types.default CanonicalTableCanonicalTable.withMergeFrom(ImmutablePathTable<String> aFrom, Object... aFromPathElements) Method to semantically emphasize that we support our own types.default CanonicalTableCanonicalTable.withMergeFrom(ImmutablePathTable<String> aFrom, String aFromPath) Method to semantically emphasize that we support our own types.default CanonicalTableCanonicalTable.withMergeFrom(ImmutablePathTable<String> aFrom, String... aFromPathElements) Method to semantically emphasize that we support our own types.default CanonicalTableCanonicalTable.withMergeFrom(ImmutablePathTable<String> aFrom, Collection<?> aFromPathElements) Method to semantically emphasize that we support our own types.default CanonicalTableCanonicalTable.withMergeTo(Object[] aToPathElements, Object aFrom) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.mergeTo(String, Object)method.default CanonicalTableCanonicalTable.withMergeTo(Object[] aToPathElements, ImmutablePathTable<String> aFrom) Method to semantically emphasize that we support our own types.default CanonicalTableCanonicalTable.withMergeTo(Object aToPath, Object aFrom) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.mergeTo(String, Object)method.default CanonicalTableCanonicalTable.withMergeTo(Object aToPath, ImmutablePathTable<String> aFrom) Method to semantically emphasize that we support our own types.default CanonicalTableCanonicalTable.withMergeTo(String[] aToPathElements, Object aFrom) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.mergeTo(String, Object)method.default CanonicalTableCanonicalTable.withMergeTo(String[] aToPathElements, ImmutablePathTable<String> aFrom) Method to semantically emphasize that we support our own types.default CanonicalTableCanonicalTable.withMergeTo(String aToPath, Object aFrom) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.mergeTo(String, Object)method.default CanonicalTableCanonicalTable.withMergeTo(String aToPath, ImmutablePathTable<String> aFrom) Method to semantically emphasize that we support our own types.default CanonicalTableCanonicalTable.withMergeTo(Collection<?> aToPathElements, Object aFrom) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.mergeTo(String, Object)method.default CanonicalTableCanonicalTable.withMergeTo(Collection<?> aToPathElements, ImmutablePathTable<String> aFrom) Method to semantically emphasize that we support our own types.default CanonicalTableBuilder method forKeys.MutableValues.put(Object, Object).default CanonicalTableBuilder method forKeys.MutableValues.put(Object, Object).default CanonicalTableCanonicalTable.withPut(Collection<?> aPathElements, String aValue) Builder method forKeys.MutableValues.put(Object, Object).default CanonicalTableBuilder method forImmutableCanonicalTable.MutableCanonicalTable.put(Property).default CanonicalTableBuilder method forImmutableTable.MutableTable.put(Relation).Builder method forKeys.MutableValues.put(Object, Object).default CanonicalTableCanonicalTable.withPutBoolean(Object[] aPathElements, Boolean aValue) Sets theBooleanvalue for the property referred to by the path elements representing the addressed path.default CanonicalTableCanonicalTable.withPutBoolean(Object aKey, Boolean aValue) Sets theBooleanvalue for the property referred to by the key.default CanonicalTableCanonicalTable.withPutBoolean(String[] aPathElements, Boolean aValue) Sets theBooleanvalue for the property referred to by the path elements representing the addressed path.default CanonicalTableCanonicalTable.withPutBoolean(String aKey, Boolean aValue) Sets theBooleanvalue for the property referred to by the key.default CanonicalTableCanonicalTable.withPutBoolean(Collection<?> aPathElements, Boolean aValue) Sets theBooleanvalue for the property referred to by the path elements representing the addressed path.default CanonicalTableCanonicalTable.withPutByte(Object[] aPathElements, Byte aValue) Sets theBytevalue for the property referred to by the path elements representing the addressed path.default CanonicalTableCanonicalTable.withPutByte(Object aKey, Byte aValue) Sets theBytevalue for the property referred to by the key.default CanonicalTableCanonicalTable.withPutByte(String[] aPathElements, Byte aValue) Sets theBytevalue for the property referred to by the path elements representing the addressed path.default CanonicalTableCanonicalTable.withPutByte(String aKey, Byte aValue) Sets theBytevalue for the property referred to by the key.default CanonicalTableCanonicalTable.withPutByte(Collection<?> aPathElements, Byte aValue) Sets theBytevalue for the property referred to by the path elements representing the addressed path.default CanonicalTableCanonicalTable.withPutChar(Object[] aPathElements, Character aValue) Sets theCharactervalue for the property referred to by the path elements representing the addressed path.default CanonicalTableCanonicalTable.withPutChar(Object aKey, Character aValue) Sets theCharactervalue for the property referred to by the key.default CanonicalTableCanonicalTable.withPutChar(String[] aPathElements, Character aValue) Sets theCharactervalue for the property referred to by the path elements representing the addressed path.default CanonicalTableCanonicalTable.withPutChar(String aKey, Character aValue) Sets theCharactervalue for the property referred to by the key.default CanonicalTableCanonicalTable.withPutChar(Collection<?> aPathElements, Character aValue) Sets theCharactervalue for the property referred to by the path elements representing the addressed path.default <C> CanonicalTableCanonicalTable.withPutClass(Object[] aPathElements, Class<C> aValue) Sets theClassvalue for the property referred to by the path elements representing the addressed path.default <C> CanonicalTableCanonicalTable.withPutClass(Object aKey, Class<C> aValue) Sets theClassvalue for the property referred to by the key.default <C> CanonicalTableCanonicalTable.withPutClass(String[] aPathElements, Class<C> aValue) Sets theClassvalue for the property referred to by the path elements representing the addressed path.default <C> CanonicalTableCanonicalTable.withPutClass(String aKey, Class<C> aValue) Sets theClassvalue for the property referred to by the key.default <C> CanonicalTableCanonicalTable.withPutClass(Collection<?> aPathElements, Class<C> aValue) Sets theClassvalue for the property referred to by the path elements representing the addressed path.default CanonicalTableCanonicalTable.withPutDirAt(int aIndex, Object aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default CanonicalTableCanonicalTable.withPutDirAt(int aIndex, ImmutablePathTable<String> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default CanonicalTableCanonicalTable.withPutDirAt(Object[] aPathElements, int aIndex, Object aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default CanonicalTableCanonicalTable.withPutDirAt(Object[] aPathElements, int aIndex, ImmutablePathTable<String> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default CanonicalTableCanonicalTable.withPutDirAt(Object aPath, int aIndex, Object aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default CanonicalTableCanonicalTable.withPutDirAt(Object aPath, int aIndex, ImmutablePathTable<String> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default CanonicalTableCanonicalTable.withPutDirAt(String[] aPathElements, int aIndex, Object aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default CanonicalTableCanonicalTable.withPutDirAt(String[] aPathElements, int aIndex, ImmutablePathTable<String> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default CanonicalTableCanonicalTable.withPutDirAt(String aPath, int aIndex, Object aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default CanonicalTableCanonicalTable.withPutDirAt(String aPath, int aIndex, ImmutablePathTable<String> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default CanonicalTableCanonicalTable.withPutDirAt(Collection<?> aPathElements, int aIndex, Object aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default CanonicalTableCanonicalTable.withPutDirAt(Collection<?> aPathElements, int aIndex, ImmutablePathTable<String> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default CanonicalTableCanonicalTable.withPutDouble(Object[] aPathElements, Double aValue) Sets theDoublevalue for the property referred to by the path elements representing the addressed path.default CanonicalTableCanonicalTable.withPutDouble(Object aKey, Double aValue) Sets theDoublevalue for the property referred to by the key.default CanonicalTableCanonicalTable.withPutDouble(String[] aPathElements, Double aValue) Sets theDoublevalue for the property referred to by the path elements representing the addressed path.default CanonicalTableCanonicalTable.withPutDouble(String aKey, Double aValue) Sets theDoublevalue for the property referred to by the key.default CanonicalTableCanonicalTable.withPutDouble(Collection<?> aPathElements, Double aValue) Sets theDoublevalue for the property referred to by the path elements representing the addressed path.default <E extends Enum<E>>
CanonicalTableCanonicalTable.withPutEnum(Object[] aPathElements, E aValue) Sets theEnumvalue for the property referred to by the path elements representing the addressed path.default <E extends Enum<E>>
CanonicalTableCanonicalTable.withPutEnum(Object aKey, E aValue) Sets theEnumvalue for the property referred to by the key.default <E extends Enum<E>>
CanonicalTableCanonicalTable.withPutEnum(String[] aPathElements, E aValue) Sets theEnumvalue for the property referred to by the path elements representing the addressed path.default <E extends Enum<E>>
CanonicalTableCanonicalTable.withPutEnum(String aKey, E aValue) Sets theEnumvalue for the property referred to by the key.default <E extends Enum<E>>
CanonicalTableCanonicalTable.withPutEnum(Collection<?> aPathElements, E aValue) Sets theEnumvalue for the property referred to by the path elements representing the addressed path.default CanonicalTableCanonicalTable.withPutFloat(Object[] aPathElements, Float aValue) Sets theFloatvalue for the property referred to by the path elements representing the addressed path.default CanonicalTableCanonicalTable.withPutFloat(Object aKey, Float aValue) Sets theFloatvalue for the property referred to by the key.default CanonicalTableCanonicalTable.withPutFloat(String[] aPathElements, Float aValue) Sets theFloatvalue for the property referred to by the path elements representing the addressed path.default CanonicalTableCanonicalTable.withPutFloat(String aKey, Float aValue) Sets theFloatvalue for the property referred to by the key.default CanonicalTableCanonicalTable.withPutFloat(Collection<?> aPathElements, Float aValue) Sets theFloatvalue for the property referred to by the path elements representing the addressed path.default CanonicalTableCanonicalTable.withPutInt(Object[] aPathElements, Integer aValue) Sets theIntegervalue for the property referred to by the path elements representing the addressed path.default CanonicalTableCanonicalTable.withPutInt(Object aKey, Integer aValue) Sets theIntegervalue for the property referred to by the key.default CanonicalTableCanonicalTable.withPutInt(String[] aPathElements, Integer aValue) Sets theIntegervalue for the property referred to by the path elements representing the addressed path.default CanonicalTableCanonicalTable.withPutInt(String aKey, Integer aValue) Sets theIntegervalue for the property referred to by the key.default CanonicalTableCanonicalTable.withPutInt(Collection<?> aPathElements, Integer aValue) Sets theIntegervalue for the property referred to by the path elements representing the addressed path.default CanonicalTableCanonicalTable.withPutLong(Object[] aPathElements, Long aValue) Sets theLongvalue for the property referred to by the path elements representing the addressed path.default CanonicalTableCanonicalTable.withPutLong(Object aKey, Long aValue) Sets theLongvalue for the property referred to by the key.default CanonicalTableCanonicalTable.withPutLong(String[] aPathElements, Long aValue) Sets theLongvalue for the property referred to by the path elements representing the addressed path.default CanonicalTableCanonicalTable.withPutLong(String aKey, Long aValue) Sets theLongvalue for the property referred to by the key.default CanonicalTableCanonicalTable.withPutLong(Collection<?> aPathElements, Long aValue) Sets theLongvalue for the property referred to by the path elements representing the addressed path.default CanonicalTableCanonicalTable.withPutShort(Object[] aPathElements, Short aValue) Sets theShortvalue for the property referred to by the path elements representing the addressed path.default CanonicalTableCanonicalTable.withPutShort(Object aKey, Short aValue) Sets theShortvalue for the property referred to by the key.default CanonicalTableCanonicalTable.withPutShort(String[] aPathElements, Short aValue) Sets theShortvalue for the property referred to by the path elements representing the addressed path.default CanonicalTableCanonicalTable.withPutShort(String aKey, Short aValue) Sets theShortvalue for the property referred to by the key.default CanonicalTableCanonicalTable.withPutShort(Collection<?> aPathElements, Short aValue) Sets theShortvalue for the property referred to by the path elements representing the addressed path.default CanonicalTableCanonicalTable.withPutString(Object[] aPathElements, String aValue) Sets theStringvalue for the property referred to by the path elements representing the addressed path.default CanonicalTableCanonicalTable.withPutString(Object aKey, String aValue) Sets theStringvalue for the property referred to by the key.default CanonicalTableCanonicalTable.withPutString(String[] aPathElements, String aValue) Sets theStringvalue for the property referred to by the path elements representing the addressed path.default CanonicalTableCanonicalTable.withPutString(String aKey, String aValue) Sets theStringvalue for the property referred to by the key.default CanonicalTableCanonicalTable.withPutString(Collection<?> aPathElements, String aValue) Sets theStringvalue for the property referred to by the path elements representing the addressed path.default CanonicalTableCanonicalTable.withRemoveFrom(Object aPath) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.removeFrom(String)method.default CanonicalTableCanonicalTable.withRemoveFrom(Object... aPathElements) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.removeFrom(String)method.default CanonicalTableCanonicalTable.withRemoveFrom(String aPath) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.removeFrom(String)method.default CanonicalTableCanonicalTable.withRemoveFrom(String... aPathElements) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.removeFrom(String)method.default CanonicalTableCanonicalTable.withRemoveFrom(Collection<?> aPathElements) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.removeFrom(String)method.default CanonicalTableCanonicalTable.withRemovePaths(String... aPathElements) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.removeFrom(String)method.Constructors in org.refcodes.struct with parameters of type CanonicalTableModifierConstructorDescriptionUnmodifiableCanonicalTableDecorator(CanonicalTable aCanonicalTable) Wraps the providedCanonicalTableinstance to be used as immutableImmutableCanonicalTableinstance.