Uses of Interface
org.refcodes.struct.ClassStructTable
-
Uses of ClassStructTable in org.refcodes.struct
Classes in org.refcodes.struct that implement ClassStructTableModifier and TypeClassDescriptionclassMethods in org.refcodes.struct that return ClassStructTableModifier and TypeMethodDescriptiondefault ClassStructTableImmutableClassStructTable.getCompositeArrayDir()Retrieves the directory of the composite type's array represented by the root path.default ClassStructTableImmutableClassStructTable.getCompositeArrayDir(Object aPath) Retrieves the directory of the composite type's array represented by the given path.default ClassStructTableImmutableClassStructTable.getCompositeArrayDir(Object... aPathElements) Retrieves the directory of the composite type's array represented by the given path.default ClassStructTableImmutableClassStructTable.getCompositeArrayDir(String aPath) Retrieves the directory of the composite type's array represented by the given path.default ClassStructTableImmutableClassStructTable.getCompositeArrayDir(String... aPathElements) Retrieves the directory of the composite type's array represented by the given path.default ClassStructTableImmutableClassStructTable.getCompositeArrayDir(Collection<?> aPathElements) Retrieves the directory of the composite type's array represented by the given path.default ClassStructTableImmutableClassStructTable.getCompositeDir()Retrieves the directory of the composite type represented by the root path.default ClassStructTableImmutableClassStructTable.getCompositeDir(Object aPath) Retrieves the directory of the composite type represented by the given path.default ClassStructTableImmutableClassStructTable.getCompositeDir(Object... aPathElements) Retrieves the directory of the composite type represented by the given path.default ClassStructTableImmutableClassStructTable.getCompositeDir(String aPath) Retrieves the directory of the composite type represented by the given path.default ClassStructTableImmutableClassStructTable.getCompositeDir(String... aPathElements) Retrieves the directory of the composite type represented by the given path.default ClassStructTableImmutableClassStructTable.getCompositeDir(Collection<?> aPathElements) Retrieves the directory of the composite type represented by the given path.default ClassStructTableGets the children elements of the provided parent's path, excluding the parent's path.default ClassStructTableGets the children elements of the provided parent's path elements, excluding the parent's path.default ClassStructTableGets the children elements of the provided parent's path elements, excluding the parent's path.default ClassStructTableGets the children elements of the provided parent's path elements, excluding the parent's path.default ClassStructTableImmutableClassStructTable.getDir(Collection<?> aPathElements) Gets the children elements of the provided parent's path elements, excluding the parent's path.default ClassStructTableImmutableClassStructTable.getDirAt(int aIndex) An indexed directory represents all elements which begin with a path which's last path element represents an index.default ClassStructTableAn indexed directory represents all elements which begin with a path which's last path element represents an index.default ClassStructTableAn indexed directory represents all elements which begin with a path which's last path element represents an index.default ClassStructTableAn indexed directory represents all elements which begin with a path which's last path element represents an index.default ClassStructTableAn indexed directory represents all elements which begin with a path which's last path element represents an index.default ClassStructTableImmutableClassStructTable.getDirAt(Collection<?> aPathElements, int aIndex) An indexed directory represents all elements which begin with a path which's last path element represents an index.default ClassStructTable[]Gets the children elements of the provided parent's path, excluding the parent's path.default ClassStructTable[]Gets the children elements of the provided parent's path elements, excluding the parent's path.default ClassStructTable[]Gets the children elements of the provided parent's path elements, excluding the parent's path.default ClassStructTable[]Gets the children elements of the provided parent's path elements, excluding the parent's path.default ClassStructTable[]ImmutableClassStructTable.getDirs(Collection<?> aPathElements) Gets the children elements of the provided parent's path, excluding the parent's path.default ClassStructTableAn indexed directory represents all elements which begin with a path which's last path element represents an index.default ClassStructTableImmutableClassStructTable.MutableClassStructTable.putDirAt(int aIndex, ImmutablePathTable<Class<?>> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default ClassStructTableImmutableClassStructTable.MutableClassStructTable.putDirAt(Object[] aPathElements, int aIndex, Object aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default ClassStructTableImmutableClassStructTable.MutableClassStructTable.putDirAt(Object[] aPathElements, int aIndex, ImmutablePathTable<Class<?>> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default ClassStructTableAn indexed directory represents all elements which begin with a path which's last path element represents an index.default ClassStructTableImmutableClassStructTable.MutableClassStructTable.putDirAt(Object aPath, int aIndex, ImmutablePathTable<Class<?>> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default ClassStructTableImmutableClassStructTable.MutableClassStructTable.putDirAt(String[] aPathElements, int aIndex, Object aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default ClassStructTableImmutableClassStructTable.MutableClassStructTable.putDirAt(String[] aPathElements, int aIndex, ImmutablePathTable<Class<?>> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default ClassStructTableAn indexed directory represents all elements which begin with a path which's last path element represents an index.default ClassStructTableImmutableClassStructTable.MutableClassStructTable.putDirAt(String aPath, int aIndex, ImmutablePathTable<Class<?>> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default ClassStructTableImmutableClassStructTable.MutableClassStructTable.putDirAt(Collection<?> aPathElements, int aIndex, Object aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default ClassStructTableImmutableClassStructTable.MutableClassStructTable.putDirAt(Collection<?> aPathElements, int aIndex, ImmutablePathTable<Class<?>> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default ClassStructTableQueries the keys of the instance using thePathMatcher' matching patterns, similar to the wildcards '*', '?'default ClassStructTableQueries the keys of the instance using thePathMatcher' matching patterns, similar to the wildcards '*', '?'default ClassStructTableQueries the keys of the instance using thePathMatcher' matching patterns, similar to the wildcards '*', '?'default ClassStructTableImmutableClassStructTable.query(Collection<?> aQueryElements) Queries the keys of the instance using thePathMatcher' matching patterns, similar to the wildcards '*', '?'default ClassStructTableQueries the keys of the instance using a regular expression as of the providedPatterninstance.default ClassStructTableImmutableClassStructTable.queryBetween(Object[] aFromPath, Object[] aPathQuery, Object[] aToPath) Queries the keys of the instance using thePathMatcher' matching patterns, similar to the wildcards '*', '?'default ClassStructTableImmutableClassStructTable.queryBetween(Object aFromPath, Object aPathQuery, Object aToPath) Queries the keys of the instance using thePathMatcher' matching patterns, similar to the wildcards '*', '?'default ClassStructTableImmutableClassStructTable.queryBetween(String[] aFromPath, String[] aPathQuery, String[] aToPath) Queries the keys of the instance using thePathMatcher' matching patterns, similar to the wildcards '*', '?'default ClassStructTableImmutableClassStructTable.queryBetween(String aFromPath, String aPathQuery, String aToPath) Queries the keys of the instance using thePathMatcher' matching patterns, similar to the wildcards '*', '?'default ClassStructTableImmutableClassStructTable.queryBetween(String aFromPath, Pattern aRegExp, String aToPath) Queries the keys of the instance using a regular expression as of the providedPattern.default ClassStructTableImmutableClassStructTable.queryBetween(Collection<?> aFromPath, Collection<?> aPathQuery, Collection<?> aToPath) Queries the keys of the instance using thePathMatcher' matching patterns, similar to the wildcards '*', '?'default ClassStructTableQueries the keys of the instance using thePathMatcher' matching patterns, similar to the wildcards '*', '?'default ClassStructTableQueries the keys of the instance using thePathMatcher' matching patterns, similar to the wildcards '*', '?'default ClassStructTableQueries the keys of the instance using thePathMatcher' matching patterns, similar to the wildcards '*', '?'default ClassStructTableQueries the keys of the instance using thePathMatcher' matching patterns, similar to the wildcards '*', '?'default ClassStructTableImmutableClassStructTable.queryFrom(Collection<?> aPathQuery, Collection<?> aFromPath) Queries the keys of the instance using thePathMatcher' matching patterns, similar to the wildcards '*', '?'default ClassStructTableQueries the keys of the instance using a regular expression as of the providedPattern.default ClassStructTableQueries the keys of the instance using thePathMatcher' matching patterns, similar to the wildcards '*', '?'default ClassStructTableQueries the keys of the instance using thePathMatcher' matching patterns, similar to the wildcards '*', '?'default ClassStructTableQueries the keys of the instance using thePathMatcher' matching patterns, similar to the wildcards '*', '?'default ClassStructTableQueries the keys of the instance using thePathMatcher' matching patterns, similar to the wildcards '*', '?'default ClassStructTableImmutableClassStructTable.queryTo(Collection<?> aPathQuery, String aToPath) Queries the keys of the instance using thePathMatcher' matching patterns, similar to the wildcards '*', '?'default ClassStructTableQueries the keys of the instance using a regular expression as of the providedPattern.default ClassStructTableRemoves all elements which's keys match the provided path query.default ClassStructTableRemoves all elements which's keys match the provided path query.default ClassStructTableRemoves all elements which's keys match the provided path query.default ClassStructTableRemoves all elements which's keys match the provided path query.default ClassStructTableImmutableClassStructTable.MutableClassStructTable.removeAll(Collection<?> aPathQueryElements) Removes all elements which's keys match the provided path query.default ClassStructTableRemoves all elements which's keys match the provided regular expression: Queries the keys of the instance using the providedPattern.default ClassStructTableImmutableClassStructTable.MutableClassStructTable.removeDirAt(int aIndex) An indexed directory represents all elements which begin with a path which's last path element represents an index.default ClassStructTableImmutableClassStructTable.MutableClassStructTable.removeDirAt(Object[] aPathElements, int aIndex) An indexed directory represents all elements which begin with a path which's last path element represents an index.default ClassStructTableImmutableClassStructTable.MutableClassStructTable.removeDirAt(Object aPath, int aIndex) An indexed directory represents all elements which begin with a path which's last path element represents an index.default ClassStructTableImmutableClassStructTable.MutableClassStructTable.removeDirAt(String[] aPathElements, int aIndex) An indexed directory represents all elements which begin with a path which's last path element represents an index.default ClassStructTableImmutableClassStructTable.MutableClassStructTable.removeDirAt(String aPath, int aIndex) An indexed directory represents all elements which begin with a path which's last path element represents an index.default ClassStructTableImmutableClassStructTable.MutableClassStructTable.removeFrom(Object aPath) Removes all properties below the provided path and returns thePathTablewith the removed elements, by which the paths exclude the parent's path.default ClassStructTableImmutableClassStructTable.MutableClassStructTable.removeFrom(Object... aPathElements) Removes all properties below the provided path and returns thePathTablewith the removed elements, by which the paths exclude the parent's path.default ClassStructTableImmutableClassStructTable.MutableClassStructTable.removeFrom(String aPath) Removes all properties below the provided path and returns thePathTablewith the removed elements, by which the paths exclude the parent's path.default ClassStructTableImmutableClassStructTable.MutableClassStructTable.removeFrom(String... aPathElements) Removes all properties below the provided path and returns thePathTablewith the removed elements, by which the paths exclude the parent's path.default ClassStructTableImmutableClassStructTable.MutableClassStructTable.removeFrom(Collection<?> aPathElements) Removes all properties below the provided path and returns thePathTablewith the removed elements, by which the paths exclude the parent's path.default ClassStructTableImmutableClassStructTable.MutableClassStructTable.removePaths(String... aPaths) Removes the paths contained in the provided collection.default ClassStructTableImmutableClassStructTable.MutableClassStructTable.removePaths(Collection<?> aPaths) Removes the paths contained in the provided collection.default ClassStructTableImmutableClassStructTable.retrieveBetween(Object[] aFromPath, Object[] aToPath) Extracts a newPathTablefrom the elements of this instance found below the "from-path".default ClassStructTableImmutableClassStructTable.retrieveBetween(Object aFromPath, Object aToPath) Extracts a newPathTablefrom the elements of this instance found below the "from-path".default ClassStructTableImmutableClassStructTable.retrieveBetween(String[] aFromPath, String[] aToPath) Extracts a newPathTablefrom the elements of this instance found below the "from-path".default ClassStructTableImmutableClassStructTable.retrieveBetween(String aFromPath, String aToPath) Extracts a newPathTablefrom the elements of this instance found below the "from-path".default ClassStructTableImmutableClassStructTable.retrieveBetween(Collection<?> aFromPath, Collection<?> aToPath) Extracts a newPathTablefrom the elements of this instance found below the "from-path".default ClassStructTableImmutableClassStructTable.retrieveFrom(Object aParentPath) Gets the children elements of the provided parent's path, excluding the parent's path.default ClassStructTableImmutableClassStructTable.retrieveFrom(Object... aPathElements) Gets the children elements of the provided parent's path elements, excluding the parent's path.ImmutableClassStructTable.retrieveFrom(String aFromPath) Extracts a newPathTablefrom the elements of this instance found below the "from-path".default ClassStructTableImmutableClassStructTable.retrieveFrom(String... aPathElements) Gets the children elements of the provided parent's path elements, excluding the parent's path.default ClassStructTableImmutableClassStructTable.retrieveFrom(Collection<?> aPathElements) Gets the children elements of the provided parent's path elements, excluding the parent's path.MapClassStructTable.retrieveFrom(String aFromPath) Extracts a newPathTablefrom the elements of this instance found below the "from-path".UnmodifiableClassStructTableDecorator.retrieveFrom(String aFromPath) Extracts a newPathTablefrom the elements of this instance found below the "from-path".default ClassStructTableImmutableClassStructTable.retrieveTo(Object aToPath) Extracts a newPathTablefrom this instance's elements with the paths relocated to the provided "to-path".default ClassStructTableImmutableClassStructTable.retrieveTo(Object... aToPathElements) Extracts a newPathTablefrom this instance's elements with the paths relocated to the provided "to-path".ImmutableClassStructTable.retrieveTo(String aToPath) Extracts a newPathTablefrom this instance's elements with the paths relocated to the provided "to-path".default ClassStructTableImmutableClassStructTable.retrieveTo(String... aToPathElements) Extracts a newPathTablefrom this instance's elements with the paths relocated to the provided "to-path".default ClassStructTableImmutableClassStructTable.retrieveTo(Collection<?> aToPathElements) Extracts a newPathTablefrom this instance's elements with the paths relocated to the provided "to-path".MapClassStructTable.retrieveTo(String aToPath) Extracts a newPathTablefrom this instance's elements with the paths relocated to the provided "to-path".UnmodifiableClassStructTableDecorator.retrieveTo(String aToPath) Extracts a newPathTablefrom this instance's elements with the paths relocated to the provided "to-path".default ClassStructTableClassStructTable.withInsert(Object aObj) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.insert(Object)method.default ClassStructTableClassStructTable.withInsert(ImmutablePathTable<Class<?>> aFrom) Method to semantically emphasize that we support our own types.default ClassStructTableClassStructTable.withInsertBetween(Object[] aToPathElements, Object aFrom, Object[] aFromPathElements) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.insertBetween(String, Object, String)method.default ClassStructTableClassStructTable.withInsertBetween(Object[] aToPathElements, ImmutablePathTable<Class<?>> aFrom, Object[] aFromPathElements) Method to semantically emphasize that we support our own types.default ClassStructTableClassStructTable.withInsertBetween(Object aToPath, Object aFrom, Object aFromPath) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.insertBetween(String, Object, String)method.default ClassStructTableClassStructTable.withInsertBetween(Object aToPath, ImmutablePathTable<Class<?>> aFrom, Object aFromPath) Method to semantically emphasize that we support our own types.default ClassStructTableClassStructTable.withInsertBetween(String[] aToPathElements, Object aFrom, String[] aFromPathElements) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.insertBetween(String, Object, String)method.default ClassStructTableClassStructTable.withInsertBetween(String[] aToPathElements, ImmutablePathTable<Class<?>> aFrom, String[] aFromPathElements) Method to semantically emphasize that we support our own types.default ClassStructTableClassStructTable.withInsertBetween(String aToPath, Object aFrom, String aFromPath) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.insertBetween(String, Object, String)method.default ClassStructTableClassStructTable.withInsertBetween(String aToPath, ImmutablePathTable<Class<?>> aFrom, String aFromPath) Method to semantically emphasize that we support our own types.default ClassStructTableClassStructTable.withInsertBetween(Collection<?> aToPathElements, Object aFrom, Collection<?> aFromPathElements) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.insertBetween(String, Object, String)method.default ClassStructTableClassStructTable.withInsertBetween(Collection<?> aToPathElements, ImmutablePathTable<Class<?>> aFrom, Collection<?> aFromPathElements) Method to semantically emphasize that we support our own types.default ClassStructTableClassStructTable.withInsertFrom(Object aFrom, Object aFromPath) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.insertFrom(Object, String)method.default ClassStructTableClassStructTable.withInsertFrom(Object aFrom, Object... aFromPathElements) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.insertFrom(Object, String)method.default ClassStructTableClassStructTable.withInsertFrom(Object aFrom, String aFromPath) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.insertFrom(Object, String)method.default ClassStructTableClassStructTable.withInsertFrom(Object aFrom, String... aFromPathElements) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.insertFrom(Object, String)method.default ClassStructTableClassStructTable.withInsertFrom(Object aFrom, Collection<?> aFromPathElements) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.insertFrom(Object, String)method.default ClassStructTableClassStructTable.withInsertFrom(ImmutablePathTable<Class<?>> aFrom, Object aFromPath) Method to semantically emphasize that we support our own types.default ClassStructTableClassStructTable.withInsertFrom(ImmutablePathTable<Class<?>> aFrom, Object... aFromPathElements) Method to semantically emphasize that we support our own types.default ClassStructTableClassStructTable.withInsertFrom(ImmutablePathTable<Class<?>> aFrom, String aFromPath) Method to semantically emphasize that we support our own types.default ClassStructTableClassStructTable.withInsertFrom(ImmutablePathTable<Class<?>> aFrom, String... aFromPathElements) Method to semantically emphasize that we support our own types.default ClassStructTableClassStructTable.withInsertFrom(ImmutablePathTable<Class<?>> aFrom, Collection<?> aFromPathElements) Method to semantically emphasize that we support our own types.default ClassStructTableClassStructTable.withInsertTo(Object[] aToPathElements, Object aFrom) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.insertTo(String, Object)method.default ClassStructTableClassStructTable.withInsertTo(Object[] aToPathElements, ImmutablePathTable<Class<?>> aFrom) Method to semantically emphasize that we support our own types.default ClassStructTableClassStructTable.withInsertTo(Object aToPath, Object aFrom) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.insertTo(String, Object)method.default ClassStructTableClassStructTable.withInsertTo(Object aToPath, ImmutablePathTable<Class<?>> aFrom) Method to semantically emphasize that we support our own types.default ClassStructTableClassStructTable.withInsertTo(String[] aToPathElements, Object aFrom) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.insertTo(String, Object)method.default ClassStructTableClassStructTable.withInsertTo(String[] aToPathElements, ImmutablePathTable<Class<?>> aFrom) Method to semantically emphasize that we support our own types.default ClassStructTableClassStructTable.withInsertTo(String aToPath, Object aFrom) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.insertTo(String, Object)method.default ClassStructTableClassStructTable.withInsertTo(String aToPath, ImmutablePathTable<Class<?>> aFrom) Method to semantically emphasize that we support our own types.default ClassStructTableClassStructTable.withInsertTo(Collection<?> aToPathElements, Object aFrom) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.insertTo(String, Object)method.default ClassStructTableClassStructTable.withInsertTo(Collection<?> aToPathElements, ImmutablePathTable<Class<?>> aFrom) Method to semantically emphasize that we support our own types.default ClassStructTableConvenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.merge(Object)method.default ClassStructTableClassStructTable.withMerge(ImmutablePathTable<Class<?>> aFrom) Method to semantically emphasize that we support our own types.default ClassStructTableClassStructTable.withMergeBetween(Object[] aToPathElements, Object aFrom, Object[] aFromPathElements) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.mergeBetween(String, Object, String)method.default ClassStructTableClassStructTable.withMergeBetween(Object[] aToPathElements, ImmutablePathTable<Class<?>> aFrom, Object[] aFromPathElements) Method to semantically emphasize that we support our own types.default ClassStructTableClassStructTable.withMergeBetween(Object aToPath, Object aFrom, Object aFromPath) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.mergeBetween(String, Object, String)method.default ClassStructTableClassStructTable.withMergeBetween(Object aToPath, ImmutablePathTable<Class<?>> aFrom, Object aFromPath) Method to semantically emphasize that we support our own types.default ClassStructTableClassStructTable.withMergeBetween(String[] aToPathElements, Object aFrom, String[] aFromPathElements) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.mergeBetween(String, Object, String)method.default ClassStructTableClassStructTable.withMergeBetween(String[] aToPathElements, ImmutablePathTable<Class<?>> aFrom, String[] aFromPathElements) Method to semantically emphasize that we support our own types.default ClassStructTableClassStructTable.withMergeBetween(String aToPath, Object aFrom, String aFromPath) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.mergeBetween(String, Object, String)method.default ClassStructTableClassStructTable.withMergeBetween(String aToPath, ImmutablePathTable<Class<?>> aFrom, String aFromPath) Method to semantically emphasize that we support our own types.default ClassStructTableClassStructTable.withMergeBetween(Collection<?> aToPathElements, Object aFrom, Collection<?> aFromPathElements) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.mergeBetween(String, Object, String)method.default ClassStructTableClassStructTable.withMergeBetween(Collection<?> aToPathElements, ImmutablePathTable<Class<?>> aFrom, Collection<?> aFromPathElements) Method to semantically emphasize that we support our own types.default ClassStructTableClassStructTable.withMergeFrom(Object aFrom, Object aFromPath) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.mergeFrom(Object, String)method.default ClassStructTableClassStructTable.withMergeFrom(Object aFrom, Object... aFromPathElements) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.mergeFrom(Object, String)method.default ClassStructTableClassStructTable.withMergeFrom(Object aFrom, String aFromPath) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.mergeFrom(Object, String)method.default ClassStructTableClassStructTable.withMergeFrom(Object aFrom, String... aFromPathElements) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.mergeFrom(Object, String)method.default ClassStructTableClassStructTable.withMergeFrom(Object aFrom, Collection<?> aFromPathElements) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.mergeFrom(Object, String)method.default ClassStructTableClassStructTable.withMergeFrom(ImmutablePathTable<Class<?>> aFrom, Object aFromPath) Method to semantically emphasize that we support our own types.default ClassStructTableClassStructTable.withMergeFrom(ImmutablePathTable<Class<?>> aFrom, Object... aFromPathElements) Method to semantically emphasize that we support our own types.default ClassStructTableClassStructTable.withMergeFrom(ImmutablePathTable<Class<?>> aFrom, String aFromPath) Method to semantically emphasize that we support our own types.default ClassStructTableClassStructTable.withMergeFrom(ImmutablePathTable<Class<?>> aFrom, String... aFromPathElements) Method to semantically emphasize that we support our own types.default ClassStructTableClassStructTable.withMergeFrom(ImmutablePathTable<Class<?>> aFrom, Collection<?> aFromPathElements) Method to semantically emphasize that we support our own types.default ClassStructTableClassStructTable.withMergeTo(Object[] aToPathElements, Object aFrom) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.mergeTo(String, Object)method.default ClassStructTableClassStructTable.withMergeTo(Object[] aToPathElements, ImmutablePathTable<Class<?>> aFrom) Method to semantically emphasize that we support our own types.default ClassStructTableClassStructTable.withMergeTo(Object aToPath, Object aFrom) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.mergeTo(String, Object)method.default ClassStructTableClassStructTable.withMergeTo(Object aToPath, ImmutablePathTable<Class<?>> aFrom) Method to semantically emphasize that we support our own types.default ClassStructTableClassStructTable.withMergeTo(String[] aToPathElements, Object aFrom) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.mergeTo(String, Object)method.default ClassStructTableClassStructTable.withMergeTo(String[] aToPathElements, ImmutablePathTable<Class<?>> aFrom) Method to semantically emphasize that we support our own types.default ClassStructTableClassStructTable.withMergeTo(String aToPath, Object aFrom) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.mergeTo(String, Object)method.default ClassStructTableClassStructTable.withMergeTo(String aToPath, ImmutablePathTable<Class<?>> aFrom) Method to semantically emphasize that we support our own types.default ClassStructTableClassStructTable.withMergeTo(Collection<?> aToPathElements, Object aFrom) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.mergeTo(String, Object)method.default ClassStructTableClassStructTable.withMergeTo(Collection<?> aToPathElements, ImmutablePathTable<Class<?>> aFrom) Method to semantically emphasize that we support our own types.default ClassStructTableBuilder method forKeys.MutableValues.put(Object, Object).default ClassStructTableBuilder method forKeys.MutableValues.put(Object, Object).default ClassStructTableClassStructTable.withPut(Collection<?> aPathElements, Class<?> aValue) Builder method forKeys.MutableValues.put(Object, Object).default ClassStructTableBuilder method forImmutableClassStructTable.MutableClassStructTable.put(Property).default ClassStructTableBuilder method forImmutableTable.MutableTable.put(Relation).Builder method forKeys.MutableValues.put(Object, Object).default ClassStructTableClassStructTable.withPutDirAt(int aIndex, Object aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default ClassStructTableClassStructTable.withPutDirAt(int aIndex, ImmutablePathTable<Class<?>> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default ClassStructTableClassStructTable.withPutDirAt(Object[] aPathElements, int aIndex, Object aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default ClassStructTableClassStructTable.withPutDirAt(Object[] aPathElements, int aIndex, ImmutablePathTable<Class<?>> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default ClassStructTableClassStructTable.withPutDirAt(Object aPath, int aIndex, Object aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default ClassStructTableClassStructTable.withPutDirAt(Object aPath, int aIndex, ImmutablePathTable<Class<?>> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default ClassStructTableClassStructTable.withPutDirAt(String[] aPathElements, int aIndex, Object aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default ClassStructTableClassStructTable.withPutDirAt(String[] aPathElements, int aIndex, ImmutablePathTable<Class<?>> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default ClassStructTableClassStructTable.withPutDirAt(String aPath, int aIndex, Object aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default ClassStructTableClassStructTable.withPutDirAt(String aPath, int aIndex, ImmutablePathTable<Class<?>> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default ClassStructTableClassStructTable.withPutDirAt(Collection<?> aPathElements, int aIndex, Object aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default ClassStructTableClassStructTable.withPutDirAt(Collection<?> aPathElements, int aIndex, ImmutablePathTable<Class<?>> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default ClassStructTableClassStructTable.withRemoveFrom(Object aPath) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.removeFrom(String)method.default ClassStructTableClassStructTable.withRemoveFrom(Object... aPathElements) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.removeFrom(String)method.default ClassStructTableClassStructTable.withRemoveFrom(String aPath) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.removeFrom(String)method.default ClassStructTableClassStructTable.withRemoveFrom(String... aPathElements) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.removeFrom(String)method.default ClassStructTableClassStructTable.withRemoveFrom(Collection<?> aPathElements) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.removeFrom(String)method.default ClassStructTableClassStructTable.withRemovePaths(String... aPathElements) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.removeFrom(String)method.Constructors in org.refcodes.struct with parameters of type ClassStructTableModifierConstructorDescriptionUnmodifiableClassStructTableDecorator(ClassStructTable aClassStructTable) Wraps the providedClassStructTableinstance to be used as immutableImmutableClassStructTableinstance.