Uses of Interface
org.refcodes.struct.Dictionary.MutableDictionary.DictionaryBuilder
-
Uses of Dictionary.MutableDictionary.DictionaryBuilder in org.refcodes.struct
Classes in org.refcodes.struct with type parameters of type Dictionary.MutableDictionary.DictionaryBuilderModifier and TypeInterfaceDescriptionstatic interfaceDictionary.MutableDictionary.DictionaryBuilder<K,V, B extends Dictionary.MutableDictionary.DictionaryBuilder<K, V, B>> Provides a builder method for aRelationproperty returning the builder for applying multiple build operations.Subinterfaces of Dictionary.MutableDictionary.DictionaryBuilder in org.refcodes.structModifier and TypeInterfaceDescriptionstatic interfaceThe Interface CanonicalMapBuilder.static interfaceThe Interface ClassStructMapBuilder.static interfaceTheInterOperableMap.InterOperableMapBuilderprovides convenience accessor default methods for supporting primitive data types.static interfaceThePathMap.PathMapBuilderadds builder functionality to thePathMap.MutablePathMap.static interfaceASimpleTypeMap.SimpleTypeMapBuildersets builder functionality (as of the builder pattern) on top of theSimpleTypeMap.MutableSimpleTypeMap.Classes in org.refcodes.struct that implement Dictionary.MutableDictionary.DictionaryBuilderModifier and TypeClassDescriptionclassThe Class CanonicalMapBuilderImpl.classThe Class ClassStructBuilderImpl.classThe Class PathMapBuilderImpl.classAn implementation of theSimpleTypeMap.SimpleTypeMapBuilder.