Uses of Interface
org.refcodes.struct.ImmutableCanonicalTable
-
Uses of ImmutableCanonicalTable in org.refcodes.struct
Subinterfaces of ImmutableCanonicalTable in org.refcodes.structModifier and TypeInterfaceDescriptioninterfaceThe Interface CanonicalTable.static interfaceTheImmutableCanonicalTable.MutableCanonicalTabletype extends theImmutableCanonicalTablewith mutable (writable) functionality and provides default mutator methods for supporting primitive data types.Classes in org.refcodes.struct that implement ImmutableCanonicalTableModifier and TypeClassDescriptionclassclassTheUnmodifiableCanonicalTableDecoratordecorates anImmutableCanonicalTableinstance for immutability (read only access).Methods in org.refcodes.struct with parameters of type ImmutableCanonicalTableModifier and TypeMethodDescriptiondefault voidImmutableCanonicalTable.MutableCanonicalTable.insert(ImmutableCanonicalTable aFrom) Method to semantically emphasize that we support our own types.default voidImmutableCanonicalTable.MutableCanonicalTable.insertBetween(String aToPath, ImmutableCanonicalTable aFrom, String aFromPath) Method to semantically emphasize that we support our own types.default voidImmutableCanonicalTable.MutableCanonicalTable.insertFrom(ImmutableCanonicalTable aFrom, String aFromPath) Method to semantically emphasize that we support our own types.default voidImmutableCanonicalTable.MutableCanonicalTable.insertTo(String aToPath, ImmutableCanonicalTable aFrom) Method to semantically emphasize that we support our own types.default voidImmutableCanonicalTable.MutableCanonicalTable.putAll(ImmutableCanonicalTable aProperties) This method inserts all elements (key/value-pairs) found in the providedImmutableCanonicalTableinstances of interoperability reasons.