Uses of Interface
org.refcodes.struct.ImmutableInterOperableTable
-
Uses of ImmutableInterOperableTable in org.refcodes.struct
Subinterfaces of ImmutableInterOperableTable in org.refcodes.structModifier and TypeInterfaceDescriptioninterfaceThe Interface CanonicalTable.interfaceTheImmutableCanonicalTableis an "intermediate" type adding type and Data-Structure related functionality to any implementing class.static interfaceTheImmutableCanonicalTable.MutableCanonicalTabletype extends theImmutableCanonicalTablewith mutable (writable) functionality and provides default mutator methods for supporting primitive data types.static interfaceTheImmutableInterOperableTable.MutableInterOperableTabletype extends theImmutableInterOperableTablewith mutable (writable) functionality and provides default mutator methods for supporting primitive data types.interfacestatic interfaceTheImmutableSimpleTypeTable.MutableSimpleTypeTabletype extends theImmutableSimpleTypeTableand provides mutator (write) as well as builder methods for manipulating the entries and provides default methods for supporting primitive data types.interfaceTheInterOperableTabletype extends theImmutableInterOperableTable.MutableInterOperableTableand provides mutator as well as builder methods for manipulating the entries supporting primitive data types.interfaceTheSimpleTypeTabletype extends theImmutableSimpleTypeTable.MutableSimpleTypeTableand provides mutator (write) as well as builder methods for manipulating the entries and provides default methods for supporting primitive data types.Classes in org.refcodes.struct that implement ImmutableInterOperableTableModifier and TypeClassDescriptionclassclassAn implementation of theSimpleTypeTable.classTheUnmodifiableCanonicalTableDecoratordecorates anImmutableCanonicalTableinstance for immutability (read only access).classTheUnmodifiableSimpleTypeTableDecoratordecorates anImmutableSimpleTypeTableinstance for immutability (read only access).