Uses of Interface
org.refcodes.struct.ImmutableInterOperableTable.MutableInterOperableTable
-
Uses of ImmutableInterOperableTable.MutableInterOperableTable in org.refcodes.struct
Subinterfaces of ImmutableInterOperableTable.MutableInterOperableTable in org.refcodes.structModifier and TypeInterfaceDescriptioninterfaceThe Interface CanonicalTable.static interfaceTheImmutableCanonicalTable.MutableCanonicalTabletype extends theImmutableCanonicalTablewith mutable (writable) functionality and provides default mutator methods for supporting primitive data types.static interfaceTheImmutableSimpleTypeTable.MutableSimpleTypeTabletype extends theImmutableSimpleTypeTableand provides mutator (write) as well as builder methods for manipulating the entries and provides default methods for supporting primitive data types.interfaceTheInterOperableTabletype extends theImmutableInterOperableTable.MutableInterOperableTableand provides mutator as well as builder methods for manipulating the entries supporting primitive data types.interfaceTheSimpleTypeTabletype extends theImmutableSimpleTypeTable.MutableSimpleTypeTableand provides mutator (write) as well as builder methods for manipulating the entries and provides default methods for supporting primitive data types.Classes in org.refcodes.struct that implement ImmutableInterOperableTable.MutableInterOperableTable