Uses of Interface
org.refcodes.struct.ImmutablePathTable
-
Uses of ImmutablePathTable in org.refcodes.struct
Subinterfaces of ImmutablePathTable in org.refcodes.structModifier and TypeInterfaceDescriptioninterfaceThe Interface CanonicalTable.interfaceTheClassStructTabletype extends theImmutableClassStructTable.MutableClassStructTableand provides mutator (write) as well as builder methods for manipulating the entries.interfaceTheImmutableCanonicalTableis an "intermediate" type adding type and Data-Structure related functionality to any implementing class.static interfaceTheImmutableCanonicalTable.MutableCanonicalTabletype extends theImmutableCanonicalTablewith mutable (writable) functionality and provides default mutator methods for supporting primitive data types.interfaceTheImmutableClassStructTabledisects aClassinto its simple types (consideringStringandEnumtypes as well as primitive types).static interfaceTheImmutableClassStructTable.MutableClassStructTabletype adds mutable functionality to theClassStructTable.interfaceTheImmutableInterOperableTabletype extends theImmutablePathTableand provides default accessor methods for supporting primitive data types.static interfaceTheImmutableInterOperableTable.MutableInterOperableTabletype extends theImmutableInterOperableTablewith mutable (writable) functionality and provides default mutator methods for supporting primitive data types.static interfaceTheImmutablePathTable.MutablePathTabletype adds mutable functionality to theImmutablePathTable.interfacestatic interfaceTheImmutableSimpleTypeTable.MutableSimpleTypeTabletype extends theImmutableSimpleTypeTableand provides mutator (write) as well as builder methods for manipulating the entries and provides default methods for supporting primitive data types.interfaceTheInterOperableTabletype extends theImmutableInterOperableTable.MutableInterOperableTableand provides mutator as well as builder methods for manipulating the entries supporting primitive data types.interfacePathTable<T>ThePathTabletype extends theImmutablePathTable.MutablePathTableand provides mutator (write) as well as builder methods for manipulating the entries.interfaceTheSimpleTypeTabletype extends theImmutableSimpleTypeTable.MutableSimpleTypeTableand provides mutator (write) as well as builder methods for manipulating the entries and provides default methods for supporting primitive data types.Classes in org.refcodes.struct that implement ImmutablePathTableModifier and TypeClassDescriptionclassclassclassMapPathTable<T>classAn implementation of theSimpleTypeTable.classTheUnmodifiableCanonicalTableDecoratordecorates anImmutableCanonicalTableinstance for immutability (read only access).classTheUnmodifiableClassStructTableDecoratordecorates anImmutableCanonicalTableinstance for immutability (read only access).classTheUnmodifiablePathTableDecoratordecorates anImmutablePathTableinstance for immutability (read only access).classTheUnmodifiableSimpleTypeTableDecoratordecorates anImmutableSimpleTypeTableinstance for immutability (read only access).Methods in org.refcodes.struct that return ImmutablePathTableModifier and TypeMethodDescriptionprotected ImmutablePathTable<String> MapCanonicalTable.fromObject(Object aFrom) Hook method when internally creatingImmutablePathTablesub-types in the accordingImmutablePathTablesub-type implementations.protected ImmutablePathTable<Class<?>> MapClassStructTable.fromObject(Object aFrom) Hook method when internally creatingImmutablePathTablesub-types in the accordingImmutablePathTablesub-type implementations.protected ImmutablePathTable<T> MapPathTable.fromObject(Object aFrom) Hook method when internally creatingImmutablePathTablesub-types in the accordingImmutablePathTablesub-type implementations.protected ImmutablePathTable<Object> MapSimpleTypeTable.fromObject(Object aFrom) Hook method when internally creatingImmutablePathTablesub-types in the accordingImmutablePathTablesub-type implementations.default ImmutablePathTable<T> PathTable.withPutDirAt(int aIndex, Object aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default ImmutablePathTable<T> PathTable.withPutDirAt(int aIndex, ImmutablePathTable<T> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default ImmutablePathTable<T> PathTable.withPutDirAt(Object[] aPathElements, int aIndex, Object aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default ImmutablePathTable<T> PathTable.withPutDirAt(Object[] aPathElements, int aIndex, ImmutablePathTable<T> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default ImmutablePathTable<T> PathTable.withPutDirAt(Object aPath, int aIndex, Object aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default ImmutablePathTable<T> PathTable.withPutDirAt(Object aPath, int aIndex, ImmutablePathTable<T> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default ImmutablePathTable<T> PathTable.withPutDirAt(String[] aPathElements, int aIndex, Object aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default ImmutablePathTable<T> PathTable.withPutDirAt(String[] aPathElements, int aIndex, ImmutablePathTable<T> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default ImmutablePathTable<T> PathTable.withPutDirAt(String aPath, int aIndex, Object aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default ImmutablePathTable<T> PathTable.withPutDirAt(String aPath, int aIndex, ImmutablePathTable<T> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default ImmutablePathTable<T> PathTable.withPutDirAt(Collection<?> aPathElements, int aIndex, Object aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default ImmutablePathTable<T> PathTable.withPutDirAt(Collection<?> aPathElements, int aIndex, ImmutablePathTable<T> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.Methods in org.refcodes.struct with parameters of type ImmutablePathTableModifier and TypeMethodDescriptiondefault voidImmutablePathTable.MutablePathTable.appendDirTo(Object[] aPathElements, ImmutablePathTable<T> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default voidImmutablePathTable.MutablePathTable.appendDirTo(Object aPath, ImmutablePathTable<T> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default voidImmutablePathTable.MutablePathTable.appendDirTo(String[] aPathElements, ImmutablePathTable<T> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default voidImmutablePathTable.MutablePathTable.appendDirTo(String aPath, ImmutablePathTable<T> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default voidImmutablePathTable.MutablePathTable.appendDirTo(Collection<?> aPathElements, ImmutablePathTable<T> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default voidImmutablePathTable.MutablePathTable.appendDirTo(ImmutablePathTable<T> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default voidImmutablePathTable.MutablePathTable.insertBetween(Object[] aToPathElements, ImmutablePathTable<T> aFrom, Object[] aFromPathElements) Method to semantically emphasize that we support our own types.default voidImmutablePathTable.MutablePathTable.insertBetween(Object aToPath, ImmutablePathTable<T> aFromTable, Object aFromPath) Method to semantically emphasize that we support our own types.default voidImmutablePathTable.MutablePathTable.insertBetween(String[] aToPathElements, ImmutablePathTable<T> aFrom, String[] aFromPathElements) Method to semantically emphasize that we support our own types.default voidImmutablePathTable.MutablePathTable.insertBetween(String aToPath, ImmutablePathTable<T> aFrom, String aFromPath) Method to semantically emphasize that we support our own types.default voidImmutablePathTable.MutablePathTable.insertBetween(Collection<?> aToPathElements, ImmutablePathTable<T> aFrom, Collection<?> aFromPathElements) Method to semantically emphasize that we support our own types.default voidImmutablePathTable.MutablePathTable.insertTo(Object[] aToPathElements, ImmutablePathTable<T> aFrom) Method to semantically emphasize that we support our own types.default voidImmutablePathTable.MutablePathTable.insertTo(Object aToPath, ImmutablePathTable<T> aFromTable) Method to semantically emphasize that we support our own types.default voidImmutablePathTable.MutablePathTable.insertTo(String[] aToPathElements, ImmutablePathTable<T> aFrom) Method to semantically emphasize that we support our own types.default voidImmutablePathTable.MutablePathTable.insertTo(String aToPath, ImmutablePathTable<T> aFrom) Method to semantically emphasize that we support our own types.default voidImmutablePathTable.MutablePathTable.insertTo(Collection<?> aToPathElements, ImmutablePathTable<T> aFrom) Method to semantically emphasize that we support our own types.default booleanImmutablePathTable.isEqualTo(ImmutablePathTable<?> aOther) Determines whether this instance contains the same paths and equal assigned values as the provided otherImmutablePathTable.default voidImmutablePathTable.MutablePathTable.mergeBetween(Object[] aToPathElements, ImmutablePathTable<T> aFrom, Object[] aFromPathElements) Method to semantically emphasize that we support our own types.default voidImmutablePathTable.MutablePathTable.mergeBetween(Object aToPath, ImmutablePathTable<T> aFromTable, Object aFromPath) Method to semantically emphasize that we support our own types.default voidImmutablePathTable.MutablePathTable.mergeBetween(String[] aToPathElements, ImmutablePathTable<T> aFrom, String[] aFromPathElements) Method to semantically emphasize that we support our own types.default voidImmutablePathTable.MutablePathTable.mergeBetween(String aToPath, ImmutablePathTable<T> aFrom, String aFromPath) Method to semantically emphasize that we support our own types.default voidImmutablePathTable.MutablePathTable.mergeBetween(Collection<?> aToPathElements, ImmutablePathTable<T> aFrom, Collection<?> aFromPathElements) Method to semantically emphasize that we support our own types.default voidImmutablePathTable.MutablePathTable.mergeTo(Object[] aToPathElements, ImmutablePathTable<T> aFrom) Method to semantically emphasize that we support our own types.default voidImmutablePathTable.MutablePathTable.mergeTo(Object aToPath, ImmutablePathTable<T> aFromTable) Method to semantically emphasize that we support our own types.default voidImmutablePathTable.MutablePathTable.mergeTo(String[] aToPathElements, ImmutablePathTable<T> aFrom) Method to semantically emphasize that we support our own types.default voidImmutablePathTable.MutablePathTable.mergeTo(String aToPath, ImmutablePathTable<T> aFrom) Method to semantically emphasize that we support our own types.default voidImmutablePathTable.MutablePathTable.mergeTo(Collection<?> aToPathElements, ImmutablePathTable<T> aFrom) Method to semantically emphasize that we support our own types.default CanonicalTableImmutableCanonicalTable.MutableCanonicalTable.putDirAt(int aIndex, ImmutablePathTable<String> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default CanonicalTableImmutableCanonicalTable.MutableCanonicalTable.putDirAt(Object[] aPathElements, int aIndex, ImmutablePathTable<String> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default CanonicalTableImmutableCanonicalTable.MutableCanonicalTable.putDirAt(Object aPath, int aIndex, ImmutablePathTable<String> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default CanonicalTableImmutableCanonicalTable.MutableCanonicalTable.putDirAt(String[] aPathElements, int aIndex, ImmutablePathTable<String> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default CanonicalTableImmutableCanonicalTable.MutableCanonicalTable.putDirAt(String aPath, int aIndex, ImmutablePathTable<String> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default CanonicalTableImmutableCanonicalTable.MutableCanonicalTable.putDirAt(Collection<?> aPathElements, int aIndex, ImmutablePathTable<String> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default ClassStructTableImmutableClassStructTable.MutableClassStructTable.putDirAt(int aIndex, ImmutablePathTable<Class<?>> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default ClassStructTableImmutableClassStructTable.MutableClassStructTable.putDirAt(Object[] aPathElements, int aIndex, ImmutablePathTable<Class<?>> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default ClassStructTableImmutableClassStructTable.MutableClassStructTable.putDirAt(Object aPath, int aIndex, ImmutablePathTable<Class<?>> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default ClassStructTableImmutableClassStructTable.MutableClassStructTable.putDirAt(String[] aPathElements, int aIndex, ImmutablePathTable<Class<?>> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default ClassStructTableImmutableClassStructTable.MutableClassStructTable.putDirAt(String aPath, int aIndex, ImmutablePathTable<Class<?>> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default ClassStructTableImmutableClassStructTable.MutableClassStructTable.putDirAt(Collection<?> aPathElements, int aIndex, ImmutablePathTable<Class<?>> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.ImmutablePathTable.MutablePathTable.putDirAt(int aIndex, ImmutablePathTable<T> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.ImmutablePathTable.MutablePathTable.putDirAt(Object[] aPathElements, int aIndex, ImmutablePathTable<T> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.ImmutablePathTable.MutablePathTable.putDirAt(Object aPath, int aIndex, ImmutablePathTable<T> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.ImmutablePathTable.MutablePathTable.putDirAt(String[] aPathElements, int aIndex, ImmutablePathTable<T> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.ImmutablePathTable.MutablePathTable.putDirAt(String aPath, int aIndex, ImmutablePathTable<T> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.ImmutablePathTable.MutablePathTable.putDirAt(Collection<?> aPathElements, int aIndex, ImmutablePathTable<T> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default SimpleTypeTableImmutableSimpleTypeTable.MutableSimpleTypeTable.putDirAt(int aIndex, ImmutablePathTable<Object> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default SimpleTypeTableImmutableSimpleTypeTable.MutableSimpleTypeTable.putDirAt(Object[] aPathElements, int aIndex, ImmutablePathTable<Object> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default SimpleTypeTableImmutableSimpleTypeTable.MutableSimpleTypeTable.putDirAt(Object aPath, int aIndex, ImmutablePathTable<Object> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default SimpleTypeTableImmutableSimpleTypeTable.MutableSimpleTypeTable.putDirAt(String[] aPathElements, int aIndex, ImmutablePathTable<Object> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default SimpleTypeTableImmutableSimpleTypeTable.MutableSimpleTypeTable.putDirAt(String aPath, int aIndex, ImmutablePathTable<Object> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default SimpleTypeTableImmutableSimpleTypeTable.MutableSimpleTypeTable.putDirAt(Collection<?> aPathElements, int aIndex, ImmutablePathTable<Object> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.static <T> voidStructureUtility.retrieveFrom(ImmutablePathTable<T> aFromPathTable, String aFromPath, PathTable<T> aToPathTable) Hook method for implementing theImmutablePathTable.retrieveFrom(String)method.static <T> voidStructureUtility.retrieveTo(ImmutablePathTable<T> aFromPathTable, String aToPath, PathTable<T> aToPathTable) Hook method for implementing theImmutablePathTable.retrieveTo(String)method.static ObjectStructureUtility.toDataStructure(ImmutablePathTable<?> aPathTable, String aFromPath) Hook method for implementing theImmutablePathTable.toDataStructure()method.static StringStructureUtility.toGenericPath(ImmutablePathTable<?> aPathTable, String aPath) Normalizes the path as ofImmutablePathTable.toNormalizedPath(String)and unifies it so that a path never ends with a delimiter (DelimiterAccessor.getDelimiter()).default CanonicalTableCanonicalTable.withInsert(ImmutablePathTable<String> aFrom) Method to semantically emphasize that we support our own types.default ClassStructTableClassStructTable.withInsert(ImmutablePathTable<Class<?>> aFrom) Method to semantically emphasize that we support our own types.default InterOperableTable<T> InterOperableTable.withInsert(ImmutablePathTable<T> aFrom) Method to semantically emphasize that we support our own types.PathTable.withInsert(ImmutablePathTable<T> aFrom) Method to semantically emphasize that we support our own types.default SimpleTypeTableSimpleTypeTable.withInsert(ImmutablePathTable<Object> aFrom) Method to semantically emphasize that we support our own types.default CanonicalTableCanonicalTable.withInsertBetween(Object[] aToPathElements, ImmutablePathTable<String> aFrom, Object[] aFromPathElements) Method to semantically emphasize that we support our own types.default CanonicalTableCanonicalTable.withInsertBetween(Object aToPath, ImmutablePathTable<String> aFrom, Object aFromPath) Method to semantically emphasize that we support our own types.default CanonicalTableCanonicalTable.withInsertBetween(String[] aToPathElements, ImmutablePathTable<String> aFrom, String[] aFromPathElements) Method to semantically emphasize that we support our own types.default CanonicalTableCanonicalTable.withInsertBetween(String aToPath, ImmutablePathTable<String> aFrom, String aFromPath) Method to semantically emphasize that we support our own types.default CanonicalTableCanonicalTable.withInsertBetween(Collection<?> aToPathElements, ImmutablePathTable<String> aFrom, Collection<?> aFromPathElements) Method to semantically emphasize that we support our own types.default ClassStructTableClassStructTable.withInsertBetween(Object[] aToPathElements, ImmutablePathTable<Class<?>> aFrom, Object[] aFromPathElements) Method to semantically emphasize that we support our own types.default ClassStructTableClassStructTable.withInsertBetween(Object aToPath, ImmutablePathTable<Class<?>> aFrom, Object aFromPath) Method to semantically emphasize that we support our own types.default ClassStructTableClassStructTable.withInsertBetween(String[] aToPathElements, ImmutablePathTable<Class<?>> aFrom, String[] aFromPathElements) Method to semantically emphasize that we support our own types.default ClassStructTableClassStructTable.withInsertBetween(String aToPath, ImmutablePathTable<Class<?>> aFrom, String aFromPath) Method to semantically emphasize that we support our own types.default ClassStructTableClassStructTable.withInsertBetween(Collection<?> aToPathElements, ImmutablePathTable<Class<?>> aFrom, Collection<?> aFromPathElements) Method to semantically emphasize that we support our own types.default InterOperableTable<T> InterOperableTable.withInsertBetween(Object[] aToPathElements, ImmutablePathTable<T> aFrom, Object[] aFromPathElements) Method to semantically emphasize that we support our own types.default InterOperableTable<T> InterOperableTable.withInsertBetween(Object aToPath, ImmutablePathTable<T> aFrom, Object aFromPath) Method to semantically emphasize that we support our own types.default InterOperableTable<T> InterOperableTable.withInsertBetween(String[] aToPathElements, ImmutablePathTable<T> aFrom, String[] aFromPathElements) Method to semantically emphasize that we support our own types.default InterOperableTable<T> InterOperableTable.withInsertBetween(String aToPath, ImmutablePathTable<T> aFrom, String aFromPath) Method to semantically emphasize that we support our own types.default InterOperableTable<T> InterOperableTable.withInsertBetween(Collection<?> aToPathElements, ImmutablePathTable<T> aFrom, Collection<?> aFromPathElements) Method to semantically emphasize that we support our own types.PathTable.withInsertBetween(Object[] aToPathElements, ImmutablePathTable<T> aFrom, Object[] aFromPathElements) Method to semantically emphasize that we support our own types.PathTable.withInsertBetween(Object aToPath, ImmutablePathTable<T> aFromTable, Object aFromPath) Method to semantically emphasize that we support our own types.PathTable.withInsertBetween(String[] aToPathElements, ImmutablePathTable<T> aFrom, String[] aFromPathElements) Method to semantically emphasize that we support our own types.PathTable.withInsertBetween(String aToPath, ImmutablePathTable<T> aFrom, String aFromPath) Method to semantically emphasize that we support our own types.PathTable.withInsertBetween(Collection<?> aToPathElements, ImmutablePathTable<T> aFrom, Collection<?> aFromPathElements) Method to semantically emphasize that we support our own types.default SimpleTypeTableSimpleTypeTable.withInsertBetween(Object[] aToPathElements, ImmutablePathTable<Object> aFrom, Object[] aFromPathElements) Method to semantically emphasize that we support our own types.default SimpleTypeTableSimpleTypeTable.withInsertBetween(Object aToPath, ImmutablePathTable<Object> aFrom, Object aFromPath) Method to semantically emphasize that we support our own types.default SimpleTypeTableSimpleTypeTable.withInsertBetween(String[] aToPathElements, ImmutablePathTable<Object> aFrom, String[] aFromPathElements) Method to semantically emphasize that we support our own types.default SimpleTypeTableSimpleTypeTable.withInsertBetween(String aToPath, ImmutablePathTable<Object> aFrom, String aFromPath) Method to semantically emphasize that we support our own types.default SimpleTypeTableSimpleTypeTable.withInsertBetween(Collection<?> aToPathElements, ImmutablePathTable<Object> aFrom, Collection<?> aFromPathElements) Method to semantically emphasize that we support our own types.default CanonicalTableCanonicalTable.withInsertFrom(ImmutablePathTable<String> aFrom, Object aFromPath) Method to semantically emphasize that we support our own types.default CanonicalTableCanonicalTable.withInsertFrom(ImmutablePathTable<String> aFrom, Object... aFromPathElements) Method to semantically emphasize that we support our own types.default CanonicalTableCanonicalTable.withInsertFrom(ImmutablePathTable<String> aFrom, String aFromPath) Method to semantically emphasize that we support our own types.default CanonicalTableCanonicalTable.withInsertFrom(ImmutablePathTable<String> aFrom, String... aFromPathElements) Method to semantically emphasize that we support our own types.default CanonicalTableCanonicalTable.withInsertFrom(ImmutablePathTable<String> aFrom, Collection<?> aFromPathElements) Method to semantically emphasize that we support our own types.default ClassStructTableClassStructTable.withInsertFrom(ImmutablePathTable<Class<?>> aFrom, Object aFromPath) Method to semantically emphasize that we support our own types.default ClassStructTableClassStructTable.withInsertFrom(ImmutablePathTable<Class<?>> aFrom, Object... aFromPathElements) Method to semantically emphasize that we support our own types.default ClassStructTableClassStructTable.withInsertFrom(ImmutablePathTable<Class<?>> aFrom, String aFromPath) Method to semantically emphasize that we support our own types.default ClassStructTableClassStructTable.withInsertFrom(ImmutablePathTable<Class<?>> aFrom, String... aFromPathElements) Method to semantically emphasize that we support our own types.default ClassStructTableClassStructTable.withInsertFrom(ImmutablePathTable<Class<?>> aFrom, Collection<?> aFromPathElements) Method to semantically emphasize that we support our own types.default InterOperableTable<T> InterOperableTable.withInsertFrom(ImmutablePathTable<T> aFrom, Object aFromPath) Method to semantically emphasize that we support our own types.default InterOperableTable<T> InterOperableTable.withInsertFrom(ImmutablePathTable<T> aFrom, Object... aFromPathElements) Method to semantically emphasize that we support our own types.default InterOperableTable<T> InterOperableTable.withInsertFrom(ImmutablePathTable<T> aFrom, String aFromPath) Method to semantically emphasize that we support our own types.default InterOperableTable<T> InterOperableTable.withInsertFrom(ImmutablePathTable<T> aFrom, String... aFromPathElements) Method to semantically emphasize that we support our own types.default InterOperableTable<T> InterOperableTable.withInsertFrom(ImmutablePathTable<T> aFrom, Collection<?> aFromPathElements) Method to semantically emphasize that we support our own types.PathTable.withInsertFrom(ImmutablePathTable<T> aFrom, Object aFromPath) Method to semantically emphasize that we support our own types.PathTable.withInsertFrom(ImmutablePathTable<T> aFrom, Object... aFromPathElements) Method to semantically emphasize that we support our own types.PathTable.withInsertFrom(ImmutablePathTable<T> aFrom, String aFromPath) Method to semantically emphasize that we support our own types.PathTable.withInsertFrom(ImmutablePathTable<T> aFrom, String... aFromPathElements) Method to semantically emphasize that we support our own types.PathTable.withInsertFrom(ImmutablePathTable<T> aFrom, Collection<?> aFromPathElements) Method to semantically emphasize that we support our own types.default SimpleTypeTableSimpleTypeTable.withInsertFrom(ImmutablePathTable<Object> aFrom, Object aFromPath) Method to semantically emphasize that we support our own types.default SimpleTypeTableSimpleTypeTable.withInsertFrom(ImmutablePathTable<Object> aFrom, Object... aFromPathElements) Method to semantically emphasize that we support our own types.default SimpleTypeTableSimpleTypeTable.withInsertFrom(ImmutablePathTable<Object> aFrom, String aFromPath) Method to semantically emphasize that we support our own types.default SimpleTypeTableSimpleTypeTable.withInsertFrom(ImmutablePathTable<Object> aFrom, String... aFromPathElements) Method to semantically emphasize that we support our own types.default SimpleTypeTableSimpleTypeTable.withInsertFrom(ImmutablePathTable<Object> aFrom, Collection<?> aFromPathElements) Method to semantically emphasize that we support our own types.default CanonicalTableCanonicalTable.withInsertTo(Object[] aToPathElements, ImmutablePathTable<String> aFrom) Method to semantically emphasize that we support our own types.default CanonicalTableCanonicalTable.withInsertTo(Object aToPath, ImmutablePathTable<String> aFrom) Method to semantically emphasize that we support our own types.default CanonicalTableCanonicalTable.withInsertTo(String[] aToPathElements, ImmutablePathTable<String> aFrom) Method to semantically emphasize that we support our own types.default CanonicalTableCanonicalTable.withInsertTo(String aToPath, ImmutablePathTable<String> aFrom) Method to semantically emphasize that we support our own types.default CanonicalTableCanonicalTable.withInsertTo(Collection<?> aToPathElements, ImmutablePathTable<String> aFrom) Method to semantically emphasize that we support our own types.default ClassStructTableClassStructTable.withInsertTo(Object[] aToPathElements, ImmutablePathTable<Class<?>> aFrom) Method to semantically emphasize that we support our own types.default ClassStructTableClassStructTable.withInsertTo(Object aToPath, ImmutablePathTable<Class<?>> aFrom) Method to semantically emphasize that we support our own types.default ClassStructTableClassStructTable.withInsertTo(String[] aToPathElements, ImmutablePathTable<Class<?>> aFrom) Method to semantically emphasize that we support our own types.default ClassStructTableClassStructTable.withInsertTo(String aToPath, ImmutablePathTable<Class<?>> aFrom) Method to semantically emphasize that we support our own types.default ClassStructTableClassStructTable.withInsertTo(Collection<?> aToPathElements, ImmutablePathTable<Class<?>> aFrom) Method to semantically emphasize that we support our own types.default InterOperableTable<T> InterOperableTable.withInsertTo(Object[] aToPathElements, ImmutablePathTable<T> aFrom) Method to semantically emphasize that we support our own types.default InterOperableTable<T> InterOperableTable.withInsertTo(Object aToPath, ImmutablePathTable<T> aFrom) Method to semantically emphasize that we support our own types.default InterOperableTable<T> InterOperableTable.withInsertTo(String[] aToPathElements, ImmutablePathTable<T> aFrom) Method to semantically emphasize that we support our own types.default InterOperableTable<T> InterOperableTable.withInsertTo(String aToPath, ImmutablePathTable<T> aFrom) Method to semantically emphasize that we support our own types.default InterOperableTable<T> InterOperableTable.withInsertTo(Collection<?> aToPathElements, ImmutablePathTable<T> aFrom) Method to semantically emphasize that we support our own types.PathTable.withInsertTo(Object[] aToPathElements, ImmutablePathTable<T> aFrom) Method to semantically emphasize that we support our own types.PathTable.withInsertTo(Object aToPath, ImmutablePathTable<T> aFromTable) Method to semantically emphasize that we support our own types.PathTable.withInsertTo(String[] aToPathElements, ImmutablePathTable<T> aFrom) Method to semantically emphasize that we support our own types.PathTable.withInsertTo(String aToPath, ImmutablePathTable<T> aFrom) Method to semantically emphasize that we support our own types.PathTable.withInsertTo(Collection<?> aToPathElements, ImmutablePathTable<T> aFrom) Method to semantically emphasize that we support our own types.default SimpleTypeTableSimpleTypeTable.withInsertTo(Object[] aToPathElements, ImmutablePathTable<Object> aFrom) Method to semantically emphasize that we support our own types.default SimpleTypeTableSimpleTypeTable.withInsertTo(Object aToPath, ImmutablePathTable<Object> aFrom) Method to semantically emphasize that we support our own types.default SimpleTypeTableSimpleTypeTable.withInsertTo(String[] aToPathElements, ImmutablePathTable<Object> aFrom) Method to semantically emphasize that we support our own types.default SimpleTypeTableSimpleTypeTable.withInsertTo(String aToPath, ImmutablePathTable<Object> aFrom) Method to semantically emphasize that we support our own types.default SimpleTypeTableSimpleTypeTable.withInsertTo(Collection<?> aToPathElements, ImmutablePathTable<Object> aFrom) Method to semantically emphasize that we support our own types.default CanonicalTableCanonicalTable.withMerge(ImmutablePathTable<String> aFrom) Method to semantically emphasize that we support our own types.default ClassStructTableClassStructTable.withMerge(ImmutablePathTable<Class<?>> aFrom) Method to semantically emphasize that we support our own types.default InterOperableTable<T> InterOperableTable.withMerge(ImmutablePathTable<T> aFrom) Method to semantically emphasize that we support our own types.PathTable.withMerge(ImmutablePathTable<T> aFrom) Method to semantically emphasize that we support our own types.default SimpleTypeTableSimpleTypeTable.withMerge(ImmutablePathTable<Object> aFrom) Method to semantically emphasize that we support our own types.default CanonicalTableCanonicalTable.withMergeBetween(Object[] aToPathElements, ImmutablePathTable<String> aFrom, Object[] aFromPathElements) Method to semantically emphasize that we support our own types.default CanonicalTableCanonicalTable.withMergeBetween(Object aToPath, ImmutablePathTable<String> aFrom, Object aFromPath) Method to semantically emphasize that we support our own types.default CanonicalTableCanonicalTable.withMergeBetween(String[] aToPathElements, ImmutablePathTable<String> aFrom, String[] aFromPathElements) Method to semantically emphasize that we support our own types.default CanonicalTableCanonicalTable.withMergeBetween(String aToPath, ImmutablePathTable<String> aFrom, String aFromPath) Method to semantically emphasize that we support our own types.default CanonicalTableCanonicalTable.withMergeBetween(Collection<?> aToPathElements, ImmutablePathTable<String> aFrom, Collection<?> aFromPathElements) Method to semantically emphasize that we support our own types.default ClassStructTableClassStructTable.withMergeBetween(Object[] aToPathElements, ImmutablePathTable<Class<?>> aFrom, Object[] aFromPathElements) Method to semantically emphasize that we support our own types.default ClassStructTableClassStructTable.withMergeBetween(Object aToPath, ImmutablePathTable<Class<?>> aFrom, Object aFromPath) Method to semantically emphasize that we support our own types.default ClassStructTableClassStructTable.withMergeBetween(String[] aToPathElements, ImmutablePathTable<Class<?>> aFrom, String[] aFromPathElements) Method to semantically emphasize that we support our own types.default ClassStructTableClassStructTable.withMergeBetween(String aToPath, ImmutablePathTable<Class<?>> aFrom, String aFromPath) Method to semantically emphasize that we support our own types.default ClassStructTableClassStructTable.withMergeBetween(Collection<?> aToPathElements, ImmutablePathTable<Class<?>> aFrom, Collection<?> aFromPathElements) Method to semantically emphasize that we support our own types.default InterOperableTable<T> InterOperableTable.withMergeBetween(Object[] aToPathElements, ImmutablePathTable<T> aFrom, Object[] aFromPathElements) Method to semantically emphasize that we support our own types.default InterOperableTable<T> InterOperableTable.withMergeBetween(Object aToPath, ImmutablePathTable<T> aFrom, Object aFromPath) Method to semantically emphasize that we support our own types.default InterOperableTable<T> InterOperableTable.withMergeBetween(String[] aToPathElements, ImmutablePathTable<T> aFrom, String[] aFromPathElements) Method to semantically emphasize that we support our own types.default InterOperableTable<T> InterOperableTable.withMergeBetween(String aToPath, ImmutablePathTable<T> aFrom, String aFromPath) Method to semantically emphasize that we support our own types.default InterOperableTable<T> InterOperableTable.withMergeBetween(Collection<?> aToPathElements, ImmutablePathTable<T> aFrom, Collection<?> aFromPathElements) Method to semantically emphasize that we support our own types.PathTable.withMergeBetween(Object[] aToPathElements, ImmutablePathTable<T> aFrom, Object[] aFromPathElements) Method to semantically emphasize that we support our own types.PathTable.withMergeBetween(Object aToPath, ImmutablePathTable<T> aFromTable, Object aFromPath) Method to semantically emphasize that we support our own types.PathTable.withMergeBetween(String[] aToPathElements, ImmutablePathTable<T> aFrom, String[] aFromPathElements) Method to semantically emphasize that we support our own types.PathTable.withMergeBetween(String aToPath, ImmutablePathTable<T> aFrom, String aFromPath) Method to semantically emphasize that we support our own types.PathTable.withMergeBetween(Collection<?> aToPathElements, ImmutablePathTable<T> aFrom, Collection<?> aFromPathElements) Method to semantically emphasize that we support our own types.default SimpleTypeTableSimpleTypeTable.withMergeBetween(Object[] aToPathElements, ImmutablePathTable<Object> aFrom, Object[] aFromPathElements) Method to semantically emphasize that we support our own types.default SimpleTypeTableSimpleTypeTable.withMergeBetween(Object aToPath, ImmutablePathTable<Object> aFrom, Object aFromPath) Method to semantically emphasize that we support our own types.default SimpleTypeTableSimpleTypeTable.withMergeBetween(String[] aToPathElements, ImmutablePathTable<Object> aFrom, String[] aFromPathElements) Method to semantically emphasize that we support our own types.default SimpleTypeTableSimpleTypeTable.withMergeBetween(String aToPath, ImmutablePathTable<Object> aFrom, String aFromPath) Method to semantically emphasize that we support our own types.default SimpleTypeTableSimpleTypeTable.withMergeBetween(Collection<?> aToPathElements, ImmutablePathTable<Object> aFrom, Collection<?> aFromPathElements) Method to semantically emphasize that we support our own types.default CanonicalTableCanonicalTable.withMergeFrom(ImmutablePathTable<String> aFrom, Object aFromPath) Method to semantically emphasize that we support our own types.default CanonicalTableCanonicalTable.withMergeFrom(ImmutablePathTable<String> aFrom, Object... aFromPathElements) Method to semantically emphasize that we support our own types.default CanonicalTableCanonicalTable.withMergeFrom(ImmutablePathTable<String> aFrom, String aFromPath) Method to semantically emphasize that we support our own types.default CanonicalTableCanonicalTable.withMergeFrom(ImmutablePathTable<String> aFrom, String... aFromPathElements) Method to semantically emphasize that we support our own types.default CanonicalTableCanonicalTable.withMergeFrom(ImmutablePathTable<String> aFrom, Collection<?> aFromPathElements) Method to semantically emphasize that we support our own types.default ClassStructTableClassStructTable.withMergeFrom(ImmutablePathTable<Class<?>> aFrom, Object aFromPath) Method to semantically emphasize that we support our own types.default ClassStructTableClassStructTable.withMergeFrom(ImmutablePathTable<Class<?>> aFrom, Object... aFromPathElements) Method to semantically emphasize that we support our own types.default ClassStructTableClassStructTable.withMergeFrom(ImmutablePathTable<Class<?>> aFrom, String aFromPath) Method to semantically emphasize that we support our own types.default ClassStructTableClassStructTable.withMergeFrom(ImmutablePathTable<Class<?>> aFrom, String... aFromPathElements) Method to semantically emphasize that we support our own types.default ClassStructTableClassStructTable.withMergeFrom(ImmutablePathTable<Class<?>> aFrom, Collection<?> aFromPathElements) Method to semantically emphasize that we support our own types.default InterOperableTable<T> InterOperableTable.withMergeFrom(ImmutablePathTable<T> aFrom, Object aFromPath) Method to semantically emphasize that we support our own types.default InterOperableTable<T> InterOperableTable.withMergeFrom(ImmutablePathTable<T> aFrom, Object... aFromPathElements) Method to semantically emphasize that we support our own types.default InterOperableTable<T> InterOperableTable.withMergeFrom(ImmutablePathTable<T> aFrom, String aFromPath) Method to semantically emphasize that we support our own types.default InterOperableTable<T> InterOperableTable.withMergeFrom(ImmutablePathTable<T> aFrom, String... aFromPathElements) Method to semantically emphasize that we support our own types.default InterOperableTable<T> InterOperableTable.withMergeFrom(ImmutablePathTable<T> aFrom, Collection<?> aFromPathElements) Method to semantically emphasize that we support our own types.PathTable.withMergeFrom(ImmutablePathTable<T> aFrom, Object aFromPath) Method to semantically emphasize that we support our own types.PathTable.withMergeFrom(ImmutablePathTable<T> aFrom, Object... aFromPathElements) Method to semantically emphasize that we support our own types.PathTable.withMergeFrom(ImmutablePathTable<T> aFrom, String aFromPath) Method to semantically emphasize that we support our own types.PathTable.withMergeFrom(ImmutablePathTable<T> aFrom, String... aFromPathElements) Method to semantically emphasize that we support our own types.PathTable.withMergeFrom(ImmutablePathTable<T> aFrom, Collection<?> aFromPathElements) Method to semantically emphasize that we support our own types.default SimpleTypeTableSimpleTypeTable.withMergeFrom(ImmutablePathTable<Object> aFrom, Object aFromPath) Method to semantically emphasize that we support our own types.default SimpleTypeTableSimpleTypeTable.withMergeFrom(ImmutablePathTable<Object> aFrom, Object... aFromPathElements) Method to semantically emphasize that we support our own types.default SimpleTypeTableSimpleTypeTable.withMergeFrom(ImmutablePathTable<Object> aFrom, String aFromPath) Method to semantically emphasize that we support our own types.default SimpleTypeTableSimpleTypeTable.withMergeFrom(ImmutablePathTable<Object> aFrom, String... aFromPathElements) Method to semantically emphasize that we support our own types.default SimpleTypeTableSimpleTypeTable.withMergeFrom(ImmutablePathTable<Object> aFrom, Collection<?> aFromPathElements) Method to semantically emphasize that we support our own types.default CanonicalTableCanonicalTable.withMergeTo(Object[] aToPathElements, ImmutablePathTable<String> aFrom) Method to semantically emphasize that we support our own types.default CanonicalTableCanonicalTable.withMergeTo(Object aToPath, ImmutablePathTable<String> aFrom) Method to semantically emphasize that we support our own types.default CanonicalTableCanonicalTable.withMergeTo(String[] aToPathElements, ImmutablePathTable<String> aFrom) Method to semantically emphasize that we support our own types.default CanonicalTableCanonicalTable.withMergeTo(String aToPath, ImmutablePathTable<String> aFrom) Method to semantically emphasize that we support our own types.default CanonicalTableCanonicalTable.withMergeTo(Collection<?> aToPathElements, ImmutablePathTable<String> aFrom) Method to semantically emphasize that we support our own types.default ClassStructTableClassStructTable.withMergeTo(Object[] aToPathElements, ImmutablePathTable<Class<?>> aFrom) Method to semantically emphasize that we support our own types.default ClassStructTableClassStructTable.withMergeTo(Object aToPath, ImmutablePathTable<Class<?>> aFrom) Method to semantically emphasize that we support our own types.default ClassStructTableClassStructTable.withMergeTo(String[] aToPathElements, ImmutablePathTable<Class<?>> aFrom) Method to semantically emphasize that we support our own types.default ClassStructTableClassStructTable.withMergeTo(String aToPath, ImmutablePathTable<Class<?>> aFrom) Method to semantically emphasize that we support our own types.default ClassStructTableClassStructTable.withMergeTo(Collection<?> aToPathElements, ImmutablePathTable<Class<?>> aFrom) Method to semantically emphasize that we support our own types.default InterOperableTable<T> InterOperableTable.withMergeTo(Object[] aToPathElements, ImmutablePathTable<T> aFrom) Method to semantically emphasize that we support our own types.default InterOperableTable<T> InterOperableTable.withMergeTo(Object aToPath, ImmutablePathTable<T> aFrom) Method to semantically emphasize that we support our own types.default InterOperableTable<T> InterOperableTable.withMergeTo(String[] aToPathElements, ImmutablePathTable<T> aFrom) Method to semantically emphasize that we support our own types.default InterOperableTable<T> InterOperableTable.withMergeTo(String aToPath, ImmutablePathTable<T> aFrom) Method to semantically emphasize that we support our own types.default InterOperableTable<T> InterOperableTable.withMergeTo(Collection<?> aToPathElements, ImmutablePathTable<T> aFrom) Method to semantically emphasize that we support our own types.PathTable.withMergeTo(Object[] aToPathElements, ImmutablePathTable<T> aFrom) Method to semantically emphasize that we support our own types.PathTable.withMergeTo(Object aToPath, ImmutablePathTable<T> aFromTable) Method to semantically emphasize that we support our own types.PathTable.withMergeTo(String[] aToPathElements, ImmutablePathTable<T> aFrom) Method to semantically emphasize that we support our own types.PathTable.withMergeTo(String aToPath, ImmutablePathTable<T> aFrom) Method to semantically emphasize that we support our own types.PathTable.withMergeTo(Collection<?> aToPathElements, ImmutablePathTable<T> aFrom) Method to semantically emphasize that we support our own types.default SimpleTypeTableSimpleTypeTable.withMergeTo(Object[] aToPathElements, ImmutablePathTable<Object> aFrom) Method to semantically emphasize that we support our own types.default SimpleTypeTableSimpleTypeTable.withMergeTo(Object aToPath, ImmutablePathTable<Object> aFrom) Method to semantically emphasize that we support our own types.default SimpleTypeTableSimpleTypeTable.withMergeTo(String[] aToPathElements, ImmutablePathTable<Object> aFrom) Method to semantically emphasize that we support our own types.default SimpleTypeTableSimpleTypeTable.withMergeTo(String aToPath, ImmutablePathTable<Object> aFrom) Method to semantically emphasize that we support our own types.default SimpleTypeTableSimpleTypeTable.withMergeTo(Collection<?> aToPathElements, ImmutablePathTable<Object> aFrom) Method to semantically emphasize that we support our own types.default CanonicalTableCanonicalTable.withPutDirAt(int aIndex, ImmutablePathTable<String> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default CanonicalTableCanonicalTable.withPutDirAt(Object[] aPathElements, int aIndex, ImmutablePathTable<String> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default CanonicalTableCanonicalTable.withPutDirAt(Object aPath, int aIndex, ImmutablePathTable<String> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default CanonicalTableCanonicalTable.withPutDirAt(String[] aPathElements, int aIndex, ImmutablePathTable<String> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default CanonicalTableCanonicalTable.withPutDirAt(String aPath, int aIndex, ImmutablePathTable<String> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default CanonicalTableCanonicalTable.withPutDirAt(Collection<?> aPathElements, int aIndex, ImmutablePathTable<String> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default ClassStructTableClassStructTable.withPutDirAt(int aIndex, ImmutablePathTable<Class<?>> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default ClassStructTableClassStructTable.withPutDirAt(Object[] aPathElements, int aIndex, ImmutablePathTable<Class<?>> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default ClassStructTableClassStructTable.withPutDirAt(Object aPath, int aIndex, ImmutablePathTable<Class<?>> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default ClassStructTableClassStructTable.withPutDirAt(String[] aPathElements, int aIndex, ImmutablePathTable<Class<?>> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default ClassStructTableClassStructTable.withPutDirAt(String aPath, int aIndex, ImmutablePathTable<Class<?>> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default ClassStructTableClassStructTable.withPutDirAt(Collection<?> aPathElements, int aIndex, ImmutablePathTable<Class<?>> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default InterOperableTable<T> InterOperableTable.withPutDirAt(int aIndex, ImmutablePathTable<T> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default InterOperableTable<T> InterOperableTable.withPutDirAt(Object[] aPathElements, int aIndex, ImmutablePathTable<T> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default InterOperableTable<T> InterOperableTable.withPutDirAt(Object aPath, int aIndex, ImmutablePathTable<T> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default InterOperableTable<T> InterOperableTable.withPutDirAt(String[] aPathElements, int aIndex, ImmutablePathTable<T> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default InterOperableTable<T> InterOperableTable.withPutDirAt(String aPath, int aIndex, ImmutablePathTable<T> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default ImmutablePathTable<T> PathTable.withPutDirAt(int aIndex, ImmutablePathTable<T> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default ImmutablePathTable<T> PathTable.withPutDirAt(Object[] aPathElements, int aIndex, ImmutablePathTable<T> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default ImmutablePathTable<T> PathTable.withPutDirAt(Object aPath, int aIndex, ImmutablePathTable<T> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default ImmutablePathTable<T> PathTable.withPutDirAt(String[] aPathElements, int aIndex, ImmutablePathTable<T> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default ImmutablePathTable<T> PathTable.withPutDirAt(String aPath, int aIndex, ImmutablePathTable<T> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default ImmutablePathTable<T> PathTable.withPutDirAt(Collection<?> aPathElements, int aIndex, ImmutablePathTable<T> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default SimpleTypeTableSimpleTypeTable.withPutDirAt(int aIndex, ImmutablePathTable<Object> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default SimpleTypeTableSimpleTypeTable.withPutDirAt(Object[] aPathElements, int aIndex, ImmutablePathTable<Object> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default SimpleTypeTableSimpleTypeTable.withPutDirAt(Object aPath, int aIndex, ImmutablePathTable<Object> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default SimpleTypeTableSimpleTypeTable.withPutDirAt(String[] aPathElements, int aIndex, ImmutablePathTable<Object> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default SimpleTypeTableSimpleTypeTable.withPutDirAt(String aPath, int aIndex, ImmutablePathTable<Object> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default SimpleTypeTableSimpleTypeTable.withPutDirAt(Collection<?> aPathElements, int aIndex, ImmutablePathTable<Object> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.