Uses of Interface
org.refcodes.struct.ImmutableTable
-
Uses of ImmutableTable in org.refcodes.struct
Subinterfaces of ImmutableTable in org.refcodes.structModifier and TypeInterfaceDescriptioninterfaceThe Interface CanonicalTable.interfaceTheClassStructTabletype extends theImmutableClassStructTable.MutableClassStructTableand provides mutator (write) as well as builder methods for manipulating the entries.interfaceTheImmutableCanonicalTableis an "intermediate" type adding type and Data-Structure related functionality to any implementing class.static interfaceTheImmutableCanonicalTable.MutableCanonicalTabletype extends theImmutableCanonicalTablewith mutable (writable) functionality and provides default mutator methods for supporting primitive data types.interfaceTheImmutableClassStructTabledisects aClassinto its simple types (consideringStringandEnumtypes as well as primitive types).static interfaceTheImmutableClassStructTable.MutableClassStructTabletype adds mutable functionality to theClassStructTable.interfaceTheImmutableInterOperableTabletype extends theImmutablePathTableand provides default accessor methods for supporting primitive data types.static interfaceTheImmutableInterOperableTable.MutableInterOperableTabletype extends theImmutableInterOperableTablewith mutable (writable) functionality and provides default mutator methods for supporting primitive data types.interfaceAImmutablePathTableis a flat read-only (immutable) map by which each element is addressed by a path; represented by theImmutablePathTable's keys.static interfaceTheImmutablePathTable.MutablePathTabletype adds mutable functionality to theImmutablePathTable.interfacestatic interfaceTheImmutableSimpleTypeTable.MutableSimpleTypeTabletype extends theImmutableSimpleTypeTableand provides mutator (write) as well as builder methods for manipulating the entries and provides default methods for supporting primitive data types.static interfaceTheImmutableTable.MutableTabletype extends theImmutableTabletype with mutable (writable) functionality and provides mutator methods such asKeys.MutableValues.put(Object, Object)andImmutableTable.MutableTable.delete(String)methods.interfaceTheInterOperableTabletype extends theImmutableInterOperableTable.MutableInterOperableTableand provides mutator as well as builder methods for manipulating the entries supporting primitive data types.interfacePathTable<T>ThePathTabletype extends theImmutablePathTable.MutablePathTableand provides mutator (write) as well as builder methods for manipulating the entries.interfaceTheSimpleTypeTabletype extends theImmutableSimpleTypeTable.MutableSimpleTypeTableand provides mutator (write) as well as builder methods for manipulating the entries and provides default methods for supporting primitive data types.interfaceTheTabletype extends theImmutableTable.MutableTabletype and provides mutator as well as builder methods for manipulating the entries.Classes in org.refcodes.struct that implement ImmutableTableModifier and TypeClassDescriptionclassclassclassMapPathTable<T>classAn implementation of theSimpleTypeTable.classTheUnmodifiableCanonicalTableDecoratordecorates anImmutableCanonicalTableinstance for immutability (read only access).classTheUnmodifiableClassStructTableDecoratordecorates anImmutableCanonicalTableinstance for immutability (read only access).classTheUnmodifiablePathTableDecoratordecorates anImmutablePathTableinstance for immutability (read only access).classTheUnmodifiableSimpleTypeTableDecoratordecorates anImmutableSimpleTypeTableinstance for immutability (read only access).