Uses of Interface
org.refcodes.struct.ImmutableTable.MutableTable
-
Uses of ImmutableTable.MutableTable in org.refcodes.struct
Subinterfaces of ImmutableTable.MutableTable in org.refcodes.structModifier and TypeInterfaceDescriptioninterfaceThe Interface CanonicalTable.interfaceTheClassStructTabletype extends theImmutableClassStructTable.MutableClassStructTableand provides mutator (write) as well as builder methods for manipulating the entries.static interfaceTheImmutableCanonicalTable.MutableCanonicalTabletype extends theImmutableCanonicalTablewith mutable (writable) functionality and provides default mutator methods for supporting primitive data types.static interfaceTheImmutableClassStructTable.MutableClassStructTabletype adds mutable functionality to theClassStructTable.static interfaceTheImmutableInterOperableTable.MutableInterOperableTabletype extends theImmutableInterOperableTablewith mutable (writable) functionality and provides default mutator methods for supporting primitive data types.static interfaceTheImmutablePathTable.MutablePathTabletype adds mutable functionality to theImmutablePathTable.static interfaceTheImmutableSimpleTypeTable.MutableSimpleTypeTabletype extends theImmutableSimpleTypeTableand provides mutator (write) as well as builder methods for manipulating the entries and provides default methods for supporting primitive data types.interfaceTheInterOperableTabletype extends theImmutableInterOperableTable.MutableInterOperableTableand provides mutator as well as builder methods for manipulating the entries supporting primitive data types.interfacePathTable<T>ThePathTabletype extends theImmutablePathTable.MutablePathTableand provides mutator (write) as well as builder methods for manipulating the entries.interfaceTheSimpleTypeTabletype extends theImmutableSimpleTypeTable.MutableSimpleTypeTableand provides mutator (write) as well as builder methods for manipulating the entries and provides default methods for supporting primitive data types.interfaceTheTabletype extends theImmutableTable.MutableTabletype and provides mutator as well as builder methods for manipulating the entries.Classes in org.refcodes.struct that implement ImmutableTable.MutableTableModifier and TypeClassDescriptionclassclassclassMapPathTable<T>classAn implementation of theSimpleTypeTable.