Uses of Interface
org.refcodes.struct.Keys.MutableValues
-
Uses of Keys.MutableValues in org.refcodes.struct
Subinterfaces of Keys.MutableValues in org.refcodes.structModifier and TypeInterfaceDescriptioninterfaceThe Interface CanonicalTable.interfaceTheClassStructTabletype extends theImmutableClassStructTable.MutableClassStructTableand provides mutator (write) as well as builder methods for manipulating the entries.static interfaceTheImmutableCanonicalTable.MutableCanonicalTabletype extends theImmutableCanonicalTablewith mutable (writable) functionality and provides default mutator methods for supporting primitive data types.static interfaceTheImmutableClassStructTable.MutableClassStructTabletype adds mutable functionality to theClassStructTable.static interfaceTheImmutableInterOperableTable.MutableInterOperableTabletype extends theImmutableInterOperableTablewith mutable (writable) functionality and provides default mutator methods for supporting primitive data types.static interfaceTheImmutablePathTable.MutablePathTabletype adds mutable functionality to theImmutablePathTable.static interfaceTheImmutableSimpleTypeTable.MutableSimpleTypeTabletype extends theImmutableSimpleTypeTableand provides mutator (write) as well as builder methods for manipulating the entries and provides default methods for supporting primitive data types.static interfaceTheImmutableTable.MutableTabletype extends theImmutableTabletype with mutable (writable) functionality and provides mutator methods such asKeys.MutableValues.put(Object, Object)andImmutableTable.MutableTable.delete(String)methods.interfaceTheInterOperableTabletype extends theImmutableInterOperableTable.MutableInterOperableTableand provides mutator as well as builder methods for manipulating the entries supporting primitive data types.interfacePathTable<T>ThePathTabletype extends theImmutablePathTable.MutablePathTableand provides mutator (write) as well as builder methods for manipulating the entries.interfaceTheSimpleTypeTabletype extends theImmutableSimpleTypeTable.MutableSimpleTypeTableand provides mutator (write) as well as builder methods for manipulating the entries and provides default methods for supporting primitive data types.interfaceTheTabletype extends theImmutableTable.MutableTabletype and provides mutator as well as builder methods for manipulating the entries.Classes in org.refcodes.struct that implement Keys.MutableValuesModifier and TypeClassDescriptionclassclassclassMapPathTable<T>classAn implementation of theSimpleTypeTable.