Uses of Interface
org.refcodes.struct.PathMap.PathMapBuilder
-
Uses of PathMap.PathMapBuilder in org.refcodes.struct
Subinterfaces of PathMap.PathMapBuilder in org.refcodes.structModifier and TypeInterfaceDescriptionstatic interfaceThe Interface CanonicalMapBuilder.static interfaceThe Interface ClassStructMapBuilder.static interfaceTheInterOperableMap.InterOperableMapBuilderprovides convenience accessor default methods for supporting primitive data types.static interfaceASimpleTypeMap.SimpleTypeMapBuildersets builder functionality (as of the builder pattern) on top of theSimpleTypeMap.MutableSimpleTypeMap.Classes in org.refcodes.struct that implement PathMap.PathMapBuilderModifier and TypeClassDescriptionclassThe Class CanonicalMapBuilderImpl.classThe Class ClassStructBuilderImpl.classThePathMapBuilderImplclass implements thePathMap.PathMapBuilderinterface and provides a hookPathMapBuilderImpl.createBackingMap()method which may be overridden for providing anotherMaptype as backing map than the default one.classAn implementation of theSimpleTypeMap.SimpleTypeMapBuilder.Subinterfaces with type arguments of type PathMap.PathMapBuilder in org.refcodes.structModifier and TypeInterfaceDescriptionstatic interfaceThePathMap.PathMapBuilderadds builder functionality to thePathMap.MutablePathMap.Methods in org.refcodes.struct that return PathMap.PathMapBuilderModifier and TypeMethodDescriptiondefault PathMap.PathMapBuilder<T> PathMap.PathMapBuilder.withInsert(Object aObj) Convenience method for providing builder functionality to thePathMap.MutablePathMap.insert(Object)method.default PathMap.PathMapBuilder<T> PathMap.PathMapBuilder.withInsert(PathMap<T> aFrom) Method to semantically emphasize that we support our own types.default PathMap.PathMapBuilder<T> PathMap.PathMapBuilder.withInsertBetween(Object[] aToPathElements, Object aFrom, Object[] aFromPathElements) Convenience method for providing builder functionality to thePathMap.MutablePathMap.insertBetween(String, Object, String)method.default PathMap.PathMapBuilder<T> PathMap.PathMapBuilder.withInsertBetween(Object[] aToPathElements, PathMap<T> aFrom, Object[] aFromPathElements) Method to semantically emphasize that we support our own types.default PathMap.PathMapBuilder<T> PathMap.PathMapBuilder.withInsertBetween(Object aToPath, Object aFromObj, Object aFromPath) Convenience method for providing builder functionality to thePathMap.MutablePathMap.insertBetween(String, Object, String)method.default PathMap.PathMapBuilder<T> PathMap.PathMapBuilder.withInsertBetween(Object aToPath, PathMap<T> aFromMap, Object aFromPath) Method to semantically emphasize that we support our own types.default PathMap.PathMapBuilder<T> PathMap.PathMapBuilder.withInsertBetween(String[] aToPathElements, Object aFrom, String[] aFromPathElements) Convenience method for providing builder functionality to thePathMap.MutablePathMap.insertBetween(String, Object, String)method.default PathMap.PathMapBuilder<T> PathMap.PathMapBuilder.withInsertBetween(String[] aToPathElements, PathMap<T> aFrom, String[] aFromPathElements) Method to semantically emphasize that we support our own types.default PathMap.PathMapBuilder<T> PathMap.PathMapBuilder.withInsertBetween(String aToPath, Object aFrom, String aFromPath) Convenience method for providing builder functionality to thePathMap.MutablePathMap.insertBetween(String, Object, String)method.default PathMap.PathMapBuilder<T> PathMap.PathMapBuilder.withInsertBetween(String aToPath, PathMap<T> aFrom, String aFromPath) Method to semantically emphasize that we support our own types.default PathMap.PathMapBuilder<T> PathMap.PathMapBuilder.withInsertBetween(Collection<?> aToPathElements, Object aFrom, Collection<?> aFromPathElements) Convenience method for providing builder functionality to thePathMap.MutablePathMap.insertBetween(String, Object, String)method.default PathMap.PathMapBuilder<T> PathMap.PathMapBuilder.withInsertBetween(Collection<?> aToPathElements, PathMap<T> aFrom, Collection<?> aFromPathElements) Method to semantically emphasize that we support our own types.default PathMap.PathMapBuilder<T> PathMap.PathMapBuilder.withInsertFrom(Object aFrom, Object aFromPath) Convenience method for providing builder functionality to thePathMap.MutablePathMap.insertFrom(Object, String)method.default PathMap.PathMapBuilder<T> PathMap.PathMapBuilder.withInsertFrom(Object aFrom, Object... aFromPathElements) Convenience method for providing builder functionality to thePathMap.MutablePathMap.insertFrom(Object, String)method.default PathMap.PathMapBuilder<T> PathMap.PathMapBuilder.withInsertFrom(Object aFrom, String aFromPath) Convenience method for providing builder functionality to thePathMap.MutablePathMap.insertFrom(Object, String)method.default PathMap.PathMapBuilder<T> PathMap.PathMapBuilder.withInsertFrom(Object aFrom, String... aFromPathElements) Convenience method for providing builder functionality to thePathMap.MutablePathMap.insertFrom(Object, String)method.default PathMap.PathMapBuilder<T> PathMap.PathMapBuilder.withInsertFrom(Object aFrom, Collection<?> aFromPathElements) Convenience method for providing builder functionality to thePathMap.MutablePathMap.insertFrom(Object, String)method.default PathMap.PathMapBuilder<T> PathMap.PathMapBuilder.withInsertFrom(PathMap<T> aFrom, Object aFromPath) Method to semantically emphasize that we support our own types.default PathMap.PathMapBuilder<T> PathMap.PathMapBuilder.withInsertFrom(PathMap<T> aFrom, Object... aFromPathElements) Method to semantically emphasize that we support our own types.default PathMap.PathMapBuilder<T> PathMap.PathMapBuilder.withInsertFrom(PathMap<T> aFrom, String aFromPath) Method to semantically emphasize that we support our own types.default PathMap.PathMapBuilder<T> PathMap.PathMapBuilder.withInsertFrom(PathMap<T> aFrom, String... aFromPathElements) Method to semantically emphasize that we support our own types.default PathMap.PathMapBuilder<T> PathMap.PathMapBuilder.withInsertFrom(PathMap<T> aFrom, Collection<?> aFromPathElements) Method to semantically emphasize that we support our own types.default PathMap.PathMapBuilder<T> PathMap.PathMapBuilder.withInsertTo(Object[] aToPathElements, Object aFrom) Convenience method for providing builder functionality to thePathMap.MutablePathMap.insertTo(String, Object)method.default PathMap.PathMapBuilder<T> PathMap.PathMapBuilder.withInsertTo(Object[] aToPathElements, PathMap<T> aFrom) Method to semantically emphasize that we support our own types.default PathMap.PathMapBuilder<T> PathMap.PathMapBuilder.withInsertTo(Object aToPath, Object aFromObj) Convenience method for providing builder functionality to thePathMap.MutablePathMap.insertTo(String, Object)method.default PathMap.PathMapBuilder<T> PathMap.PathMapBuilder.withInsertTo(Object aToPath, PathMap<T> aFromMap) Method to semantically emphasize that we support our own types.default PathMap.PathMapBuilder<T> PathMap.PathMapBuilder.withInsertTo(String[] aToPathElements, Object aFrom) Convenience method for providing builder functionality to thePathMap.MutablePathMap.insertTo(String, Object)method.default PathMap.PathMapBuilder<T> PathMap.PathMapBuilder.withInsertTo(String[] aToPathElements, PathMap<T> aFrom) Method to semantically emphasize that we support our own types.default PathMap.PathMapBuilder<T> PathMap.PathMapBuilder.withInsertTo(String aToPath, Object aFrom) Convenience method for providing builder functionality to thePathMap.MutablePathMap.insertTo(String, Object)method.default PathMap.PathMapBuilder<T> PathMap.PathMapBuilder.withInsertTo(String aToPath, PathMap<T> aFrom) Method to semantically emphasize that we support our own types.default PathMap.PathMapBuilder<T> PathMap.PathMapBuilder.withInsertTo(Collection<?> aToPathElements, Object aFrom) Convenience method for providing builder functionality to thePathMap.MutablePathMap.insertTo(String, Object)method.default PathMap.PathMapBuilder<T> PathMap.PathMapBuilder.withInsertTo(Collection<?> aToPathElements, PathMap<T> aFrom) Method to semantically emphasize that we support our own types.default PathMap.PathMapBuilder<T> Convenience method for providing builder functionality to thePathMap.MutablePathMap.merge(Object)method.default PathMap.PathMapBuilder<T> Method to semantically emphasize that we support our own types.default PathMap.PathMapBuilder<T> PathMap.PathMapBuilder.withMergeBetween(Object[] aToPathElements, Object aFrom, Object[] aFromPathElements) Convenience method for providing builder functionality to thePathMap.MutablePathMap.mergeBetween(String, Object, String)method.default PathMap.PathMapBuilder<T> PathMap.PathMapBuilder.withMergeBetween(Object[] aToPathElements, PathMap<T> aFrom, Object[] aFromPathElements) Method to semantically emphasize that we support our own types.default PathMap.PathMapBuilder<T> PathMap.PathMapBuilder.withMergeBetween(Object aToPath, Object aFromObj, Object aFromPath) Convenience method for providing builder functionality to thePathMap.MutablePathMap.mergeBetween(String, Object, String)method.default PathMap.PathMapBuilder<T> PathMap.PathMapBuilder.withMergeBetween(Object aToPath, PathMap<T> aFromMap, Object aFromPath) Method to semantically emphasize that we support our own types.default PathMap.PathMapBuilder<T> PathMap.PathMapBuilder.withMergeBetween(String[] aToPathElements, Object aFrom, String[] aFromPathElements) Convenience method for providing builder functionality to thePathMap.MutablePathMap.mergeBetween(String, Object, String)method.default PathMap.PathMapBuilder<T> PathMap.PathMapBuilder.withMergeBetween(String[] aToPathElements, PathMap<T> aFrom, String[] aFromPathElements) Method to semantically emphasize that we support our own types.default PathMap.PathMapBuilder<T> PathMap.PathMapBuilder.withMergeBetween(String aToPath, Object aFrom, String aFromPath) Convenience method for providing builder functionality to thePathMap.MutablePathMap.mergeBetween(String, Object, String)method.default PathMap.PathMapBuilder<T> PathMap.PathMapBuilder.withMergeBetween(String aToPath, PathMap<T> aFrom, String aFromPath) Method to semantically emphasize that we support our own types.default PathMap.PathMapBuilder<T> PathMap.PathMapBuilder.withMergeBetween(Collection<?> aToPathElements, Object aFrom, Collection<?> aFromPathElements) Convenience method for providing builder functionality to thePathMap.MutablePathMap.mergeBetween(String, Object, String)method.default PathMap.PathMapBuilder<T> PathMap.PathMapBuilder.withMergeBetween(Collection<?> aToPathElements, PathMap<T> aFrom, Collection<?> aFromPathElements) Method to semantically emphasize that we support our own types.default PathMap.PathMapBuilder<T> PathMap.PathMapBuilder.withMergeFrom(Object aFrom, Object aFromPath) Convenience method for providing builder functionality to thePathMap.MutablePathMap.mergeFrom(Object, String)method.default PathMap.PathMapBuilder<T> PathMap.PathMapBuilder.withMergeFrom(Object aFrom, Object... aFromPathElements) Convenience method for providing builder functionality to thePathMap.MutablePathMap.mergeFrom(Object, String)method.default PathMap.PathMapBuilder<T> PathMap.PathMapBuilder.withMergeFrom(Object aFrom, String aFromPath) Convenience method for providing builder functionality to thePathMap.MutablePathMap.mergeFrom(Object, String)method.default PathMap.PathMapBuilder<T> PathMap.PathMapBuilder.withMergeFrom(Object aFrom, String... aFromPathElements) Convenience method for providing builder functionality to thePathMap.MutablePathMap.mergeFrom(Object, String)method.default PathMap.PathMapBuilder<T> PathMap.PathMapBuilder.withMergeFrom(Object aFrom, Collection<?> aFromPathElements) Convenience method for providing builder functionality to thePathMap.MutablePathMap.mergeFrom(Object, String)method.default PathMap.PathMapBuilder<T> PathMap.PathMapBuilder.withMergeFrom(PathMap<T> aFrom, Object aFromPath) Method to semantically emphasize that we support our own types.default PathMap.PathMapBuilder<T> PathMap.PathMapBuilder.withMergeFrom(PathMap<T> aFrom, Object... aFromPathElements) Method to semantically emphasize that we support our own types.default PathMap.PathMapBuilder<T> PathMap.PathMapBuilder.withMergeFrom(PathMap<T> aFrom, String aFromPath) Method to semantically emphasize that we support our own types.default PathMap.PathMapBuilder<T> PathMap.PathMapBuilder.withMergeFrom(PathMap<T> aFrom, String... aFromPathElements) Method to semantically emphasize that we support our own types.default PathMap.PathMapBuilder<T> PathMap.PathMapBuilder.withMergeFrom(PathMap<T> aFrom, Collection<?> aFromPathElements) Method to semantically emphasize that we support our own types.default PathMap.PathMapBuilder<T> PathMap.PathMapBuilder.withMergeTo(Object[] aToPathElements, Object aFrom) Convenience method for providing builder functionality to thePathMap.MutablePathMap.mergeTo(String, Object)method.default PathMap.PathMapBuilder<T> PathMap.PathMapBuilder.withMergeTo(Object[] aToPathElements, PathMap<T> aFrom) Method to semantically emphasize that we support our own types.default PathMap.PathMapBuilder<T> PathMap.PathMapBuilder.withMergeTo(Object aToPath, Object aFromObj) Convenience method for providing builder functionality to thePathMap.MutablePathMap.mergeTo(String, Object)method.default PathMap.PathMapBuilder<T> PathMap.PathMapBuilder.withMergeTo(Object aToPath, PathMap<T> aFromMap) Method to semantically emphasize that we support our own types.default PathMap.PathMapBuilder<T> PathMap.PathMapBuilder.withMergeTo(String[] aToPathElements, Object aFrom) Convenience method for providing builder functionality to thePathMap.MutablePathMap.mergeTo(String, Object)method.default PathMap.PathMapBuilder<T> PathMap.PathMapBuilder.withMergeTo(String[] aToPathElements, PathMap<T> aFrom) Method to semantically emphasize that we support our own types.default PathMap.PathMapBuilder<T> PathMap.PathMapBuilder.withMergeTo(String aToPath, Object aFrom) Convenience method for providing builder functionality to thePathMap.MutablePathMap.mergeTo(String, Object)method.default PathMap.PathMapBuilder<T> PathMap.PathMapBuilder.withMergeTo(String aToPath, PathMap<T> aFrom) Method to semantically emphasize that we support our own types.default PathMap.PathMapBuilder<T> PathMap.PathMapBuilder.withMergeTo(Collection<?> aToPathElements, Object aFrom) Convenience method for providing builder functionality to thePathMap.MutablePathMap.mergeTo(String, Object)method.default PathMap.PathMapBuilder<T> PathMap.PathMapBuilder.withMergeTo(Collection<?> aToPathElements, PathMap<T> aFrom) Method to semantically emphasize that we support our own types.default PathMap.PathMapBuilder<T> Builder method forKeys.MutableValues.put(Object, Object).default PathMap.PathMapBuilder<T> Builder method forKeys.MutableValues.put(Object, Object).default PathMap.PathMapBuilder<T> PathMap.PathMapBuilder.withPut(Collection<?> aPathElements, T aValue) Builder method forKeys.MutableValues.put(Object, Object).default PathMap.PathMapBuilder<T> Builder method forTable.TableDictionary.put(Relation).Builder method forKeys.MutableValues.put(Object, Object).default PathMap.PathMapBuilder<T> PathMap.PathMapBuilder.withRemoveFrom(Object aPath) Convenience method for providing builder functionality to thePathMap.MutablePathMap.removeFrom(String)method.default PathMap.PathMapBuilder<T> PathMap.PathMapBuilder.withRemoveFrom(Object... aPathElements) Convenience method for providing builder functionality to thePathMap.MutablePathMap.removeFrom(String)method.default PathMap.PathMapBuilder<T> PathMap.PathMapBuilder.withRemoveFrom(String aPath) Convenience method for providing builder functionality to thePathMap.MutablePathMap.removeFrom(String)method.default PathMap.PathMapBuilder<T> PathMap.PathMapBuilder.withRemoveFrom(String... aPathElements) Convenience method for providing builder functionality to thePathMap.MutablePathMap.removeFrom(String)method.default PathMap.PathMapBuilder<T> PathMap.PathMapBuilder.withRemoveFrom(Collection<?> aPathElements) Convenience method for providing builder functionality to thePathMap.MutablePathMap.removeFrom(String)method.default PathMap.PathMapBuilder<T> PathMap.PathMapBuilder.withRemovePaths(String... aPathElements) Convenience method for providing builder functionality to thePathMap.MutablePathMap.removeFrom(String)method.Methods in org.refcodes.struct with parameters of type PathMap.PathMapBuilderModifier and TypeMethodDescriptionstatic <T> voidStructureUtility.retrieveFrom(PathMap<T> aFromPathMap, String aFromPath, PathMap.PathMapBuilder<T> aToPathMap) Hook method for implementing thePathMap.retrieveFrom(String)method.static <T> voidStructureUtility.retrieveTo(PathMap<T> aFromPathMap, String aToPath, PathMap.PathMapBuilder<T> aToPathMap) Hook method for implementing thePathMap.retrieveTo(String)method.