Uses of Interface
org.refcodes.struct.PathTable
-
Uses of PathTable in org.refcodes.struct
Subinterfaces of PathTable in org.refcodes.structModifier and TypeInterfaceDescriptioninterfaceThe Interface CanonicalTable.interfaceTheClassStructTabletype extends theImmutableClassStructTable.MutableClassStructTableand provides mutator (write) as well as builder methods for manipulating the entries.interfaceTheInterOperableTabletype extends theImmutableInterOperableTable.MutableInterOperableTableand provides mutator as well as builder methods for manipulating the entries supporting primitive data types.interfaceTheSimpleTypeTabletype extends theImmutableSimpleTypeTable.MutableSimpleTypeTableand provides mutator (write) as well as builder methods for manipulating the entries and provides default methods for supporting primitive data types.Classes in org.refcodes.struct that implement PathTableModifier and TypeClassDescriptionclassclassclassMapPathTable<T>classAn implementation of theSimpleTypeTable.Subinterfaces with type arguments of type PathTable in org.refcodes.structModifier and TypeInterfaceDescriptioninterfacePathTable<T>ThePathTabletype extends theImmutablePathTable.MutablePathTableand provides mutator (write) as well as builder methods for manipulating the entries.Methods in org.refcodes.struct that return PathTableModifier and TypeMethodDescriptionGets the children elements of the provided parent's path, excluding the parent's path.Gets the children elements of the provided parent's path elements, excluding the parent's path.Gets the children elements of the provided parent's path elements, excluding the parent's path.Gets the children elements of the provided parent's path elements, excluding the parent's path.ImmutablePathTable.getDir(Collection<?> aPathElements) Gets the children elements of the provided parent's path elements, excluding the parent's path.ImmutablePathTable.getDirAt(int aIndex) An indexed directory represents all elements which begin with a path which's last path element represents an index.An indexed directory represents all elements which begin with a path which's last path element represents an index.An indexed directory represents all elements which begin with a path which's last path element represents an index.An indexed directory represents all elements which begin with a path which's last path element represents an index.An indexed directory represents all elements which begin with a path which's last path element represents an index.ImmutablePathTable.getDirAt(Collection<?> aPathElements, int aIndex) An indexed directory represents all elements which begin with a path which's last path element represents an index.Gets the children elements of the provided parent's path, excluding the parent's path.Gets the children elements of the provided parent's path elements, excluding the parent's path.Gets the children elements of the provided parent's path elements, excluding the parent's path.Gets the children elements of the provided parent's path elements, excluding the parent's path.ImmutablePathTable.getDirs(Collection<?> aPathElements) Gets the children elements of the provided parent's path, excluding the parent's path.An indexed directory represents all elements which begin with a path which's last path element represents an index.ImmutablePathTable.MutablePathTable.putDirAt(int aIndex, ImmutablePathTable<T> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.An indexed directory represents all elements which begin with a path which's last path element represents an index.ImmutablePathTable.MutablePathTable.putDirAt(Object[] aPathElements, int aIndex, ImmutablePathTable<T> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.An indexed directory represents all elements which begin with a path which's last path element represents an index.ImmutablePathTable.MutablePathTable.putDirAt(Object aPath, int aIndex, ImmutablePathTable<T> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.An indexed directory represents all elements which begin with a path which's last path element represents an index.ImmutablePathTable.MutablePathTable.putDirAt(String[] aPathElements, int aIndex, ImmutablePathTable<T> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.An indexed directory represents all elements which begin with a path which's last path element represents an index.ImmutablePathTable.MutablePathTable.putDirAt(String aPath, int aIndex, ImmutablePathTable<T> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.ImmutablePathTable.MutablePathTable.putDirAt(Collection<?> aPathElements, int aIndex, Object aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.ImmutablePathTable.MutablePathTable.putDirAt(Collection<?> aPathElements, int aIndex, ImmutablePathTable<T> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.Queries the keys of the instance using thePathMatcher' matching patterns, similar to the wildcards '*', '?'Queries the keys of the instance using thePathMatcher' matching patterns, similar to the wildcards '*', '?'Queries the keys of the instance using thePathMatcher' matching patterns, similar to the wildcards '*', '?'ImmutablePathTable.query(Collection<?> aQueryElements) Queries the keys of the instance using thePathMatcher' matching patterns, similar to the wildcards '*', '?'Queries the keys of the instance using a regular expression as of the providedPatterninstance.ImmutablePathTable.queryBetween(Object[] aFromPath, Object[] aPathQuery, Object[] aToPath) Queries the keys of the instance using thePathMatcher' matching patterns, similar to the wildcards '*', '?'ImmutablePathTable.queryBetween(Object aFromPath, Object aPathQuery, Object aToPath) Queries the keys of the instance using thePathMatcher' matching patterns, similar to the wildcards '*', '?'ImmutablePathTable.queryBetween(String[] aFromPath, String[] aPathQuery, String[] aToPath) Queries the keys of the instance using thePathMatcher' matching patterns, similar to the wildcards '*', '?'ImmutablePathTable.queryBetween(String aFromPath, String aPathQuery, String aToPath) Queries the keys of the instance using thePathMatcher' matching patterns, similar to the wildcards '*', '?'ImmutablePathTable.queryBetween(String aFromPath, Pattern aRegExp, String aToPath) Queries the keys of the instance using a regular expression as of the providedPattern.ImmutablePathTable.queryBetween(Collection<?> aFromPath, Collection<?> aPathQuery, Collection<?> aToPath) Queries the keys of the instance using thePathMatcher' matching patterns, similar to the wildcards '*', '?'Queries the keys of the instance using thePathMatcher' matching patterns, similar to the wildcards '*', '?'Queries the keys of the instance using thePathMatcher' matching patterns, similar to the wildcards '*', '?'Queries the keys of the instance using thePathMatcher' matching patterns, similar to the wildcards '*', '?'Queries the keys of the instance using thePathMatcher' matching patterns, similar to the wildcards '*', '?'ImmutablePathTable.queryFrom(Collection<?> aPathQuery, Collection<?> aFromPath) Queries the keys of the instance using thePathMatcher' matching patterns, similar to the wildcards '*', '?'Queries the keys of the instance using a regular expression as of the providedPattern.Queries the keys of the instance using thePathMatcher' matching patterns, similar to the wildcards '*', '?'Queries the keys of the instance using thePathMatcher' matching patterns, similar to the wildcards '*', '?'Queries the keys of the instance using thePathMatcher' matching patterns, similar to the wildcards '*', '?'Queries the keys of the instance using thePathMatcher' matching patterns, similar to the wildcards '*', '?'ImmutablePathTable.queryTo(Collection<?> aPathQuery, String aToPath) Queries the keys of the instance using thePathMatcher' matching patterns, similar to the wildcards '*', '?'Queries the keys of the instance using a regular expression as of the providedPattern.Removes all elements which's keys match the provided path query.Removes all elements which's keys match the provided path query.Removes all elements which's keys match the provided path query.Removes all elements which's keys match the provided path query.ImmutablePathTable.MutablePathTable.removeAll(Collection<?> aPathQueryElements) Removes all elements which's keys match the provided path query.Removes all elements which's keys match the provided regular expression: Queries the keys of the instance using the providedPattern.ImmutablePathTable.MutablePathTable.removeDirAt(int aIndex) An indexed directory represents all elements which begin with a path which's last path element represents an index.ImmutablePathTable.MutablePathTable.removeDirAt(Object[] aPathElements, int aIndex) An indexed directory represents all elements which begin with a path which's last path element represents an index.ImmutablePathTable.MutablePathTable.removeDirAt(Object aPath, int aIndex) An indexed directory represents all elements which begin with a path which's last path element represents an index.ImmutablePathTable.MutablePathTable.removeDirAt(String[] aPathElements, int aIndex) An indexed directory represents all elements which begin with a path which's last path element represents an index.ImmutablePathTable.MutablePathTable.removeDirAt(String aPath, int aIndex) An indexed directory represents all elements which begin with a path which's last path element represents an index.ImmutablePathTable.MutablePathTable.removeFrom(Object aPath) Removes all properties below the provided path and returns thePathTablewith the removed elements, by which the paths exclude the parent's path.ImmutablePathTable.MutablePathTable.removeFrom(Object... aPathElements) Removes all properties below the provided path and returns thePathTablewith the removed elements, by which the paths exclude the parent's path.ImmutablePathTable.MutablePathTable.removeFrom(String aPath) Removes all properties below the provided path and returns thePathTablewith the removed elements, by which the paths exclude the parent's path.ImmutablePathTable.MutablePathTable.removeFrom(String... aPathElements) Removes all properties below the provided path and returns thePathTablewith the removed elements, by which the paths exclude the parent's path.ImmutablePathTable.MutablePathTable.removeFrom(Collection<?> aPathElements) Removes all properties below the provided path and returns thePathTablewith the removed elements, by which the paths exclude the parent's path.ImmutablePathTable.MutablePathTable.removePaths(String... aPaths) Removes the paths contained in the provided collection.ImmutablePathTable.MutablePathTable.removePaths(Collection<?> aPaths) Removes the paths contained in the provided collection.ImmutablePathTable.retrieveBetween(Object[] aFromPath, Object[] aToPath) Extracts a newPathTablefrom the elements of this instance found below the "from-path".ImmutablePathTable.retrieveBetween(Object aFromPath, Object aToPath) Extracts a newPathTablefrom the elements of this instance found below the "from-path".ImmutablePathTable.retrieveBetween(String[] aFromPath, String[] aToPath) Extracts a newPathTablefrom the elements of this instance found below the "from-path".ImmutablePathTable.retrieveBetween(String aFromPath, String aToPath) Extracts a newPathTablefrom the elements of this instance found below the "from-path".ImmutablePathTable.retrieveBetween(Collection<?> aFromPath, Collection<?> aToPath) Extracts a newPathTablefrom the elements of this instance found below the "from-path".ImmutablePathTable.retrieveFrom(Object aFromPath) Gets the children elements of the provided parent's path, excluding the parent's path.ImmutablePathTable.retrieveFrom(Object... aPathElements) Gets the children elements of the provided parent's path elements, excluding the parent's path.ImmutablePathTable.retrieveFrom(String aFromPath) Extracts a newPathTablefrom the elements of this instance found below the "from-path".ImmutablePathTable.retrieveFrom(String... aPathElements) Gets the children elements of the provided parent's path elements, excluding the parent's path.ImmutablePathTable.retrieveFrom(Collection<?> aPathElements) Gets the children elements of the provided parent's path elements, excluding the parent's path.MapPathTable.retrieveFrom(String aFromPath) Extracts a newPathTablefrom the elements of this instance found below the "from-path".UnmodifiablePathTableDecorator.retrieveFrom(String aFromPath) Extracts a newPathTablefrom the elements of this instance found below the "from-path".ImmutablePathTable.retrieveTo(Object aToPath) Extracts a newPathTablefrom this instance's elements with the paths relocated to the provided "to-path".ImmutablePathTable.retrieveTo(Object... aToPathElements) Extracts a newPathTablefrom this instance's elements with the paths relocated to the provided "to-path".ImmutablePathTable.retrieveTo(String aToPath) Extracts a newPathTablefrom this instance's elements with the paths relocated to the provided "to-path".ImmutablePathTable.retrieveTo(String... aToPathElements) Extracts a newPathTablefrom this instance's elements with the paths relocated to the provided "to-path".ImmutablePathTable.retrieveTo(Collection<?> aToPathElements) Extracts a newPathTablefrom this instance's elements with the paths relocated to the provided "to-path".MapPathTable.retrieveTo(String aToPath) Extracts a newPathTablefrom this instance's elements with the paths relocated to the provided "to-path".UnmodifiablePathTableDecorator.retrieveTo(String aToPath) Extracts a newPathTablefrom this instance's elements with the paths relocated to the provided "to-path".PathTable.withInsert(Object aObj) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.insert(Object)method.PathTable.withInsert(ImmutablePathTable<T> aFrom) Method to semantically emphasize that we support our own types.PathTable.withInsertBetween(Object[] aToPathElements, Object aFrom, Object[] aFromPathElements) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.insertBetween(String, Object, String)method.PathTable.withInsertBetween(Object[] aToPathElements, ImmutablePathTable<T> aFrom, Object[] aFromPathElements) Method to semantically emphasize that we support our own types.PathTable.withInsertBetween(Object aToPath, Object aFromObj, Object aFromPath) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.insertBetween(String, Object, String)method.PathTable.withInsertBetween(Object aToPath, ImmutablePathTable<T> aFromTable, Object aFromPath) Method to semantically emphasize that we support our own types.PathTable.withInsertBetween(String[] aToPathElements, Object aFrom, String[] aFromPathElements) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.insertBetween(String, Object, String)method.PathTable.withInsertBetween(String[] aToPathElements, ImmutablePathTable<T> aFrom, String[] aFromPathElements) Method to semantically emphasize that we support our own types.PathTable.withInsertBetween(String aToPath, Object aFrom, String aFromPath) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.insertBetween(String, Object, String)method.PathTable.withInsertBetween(String aToPath, ImmutablePathTable<T> aFrom, String aFromPath) Method to semantically emphasize that we support our own types.PathTable.withInsertBetween(Collection<?> aToPathElements, Object aFrom, Collection<?> aFromPathElements) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.insertBetween(String, Object, String)method.PathTable.withInsertBetween(Collection<?> aToPathElements, ImmutablePathTable<T> aFrom, Collection<?> aFromPathElements) Method to semantically emphasize that we support our own types.PathTable.withInsertFrom(Object aFrom, Object aFromPath) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.insertFrom(Object, String)method.PathTable.withInsertFrom(Object aFrom, Object... aFromPathElements) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.insertFrom(Object, String)method.PathTable.withInsertFrom(Object aFrom, String aFromPath) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.insertFrom(Object, String)method.PathTable.withInsertFrom(Object aFrom, String... aFromPathElements) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.insertFrom(Object, String)method.PathTable.withInsertFrom(Object aFrom, Collection<?> aFromPathElements) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.insertFrom(Object, String)method.PathTable.withInsertFrom(ImmutablePathTable<T> aFrom, Object aFromPath) Method to semantically emphasize that we support our own types.PathTable.withInsertFrom(ImmutablePathTable<T> aFrom, Object... aFromPathElements) Method to semantically emphasize that we support our own types.PathTable.withInsertFrom(ImmutablePathTable<T> aFrom, String aFromPath) Method to semantically emphasize that we support our own types.PathTable.withInsertFrom(ImmutablePathTable<T> aFrom, String... aFromPathElements) Method to semantically emphasize that we support our own types.PathTable.withInsertFrom(ImmutablePathTable<T> aFrom, Collection<?> aFromPathElements) Method to semantically emphasize that we support our own types.PathTable.withInsertTo(Object[] aToPathElements, Object aFrom) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.insertTo(String, Object)method.PathTable.withInsertTo(Object[] aToPathElements, ImmutablePathTable<T> aFrom) Method to semantically emphasize that we support our own types.PathTable.withInsertTo(Object aToPath, Object aFromObj) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.insertTo(String, Object)method.PathTable.withInsertTo(Object aToPath, ImmutablePathTable<T> aFromTable) Method to semantically emphasize that we support our own types.PathTable.withInsertTo(String[] aToPathElements, Object aFrom) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.insertTo(String, Object)method.PathTable.withInsertTo(String[] aToPathElements, ImmutablePathTable<T> aFrom) Method to semantically emphasize that we support our own types.PathTable.withInsertTo(String aToPath, Object aFrom) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.insertTo(String, Object)method.PathTable.withInsertTo(String aToPath, ImmutablePathTable<T> aFrom) Method to semantically emphasize that we support our own types.PathTable.withInsertTo(Collection<?> aToPathElements, Object aFrom) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.insertTo(String, Object)method.PathTable.withInsertTo(Collection<?> aToPathElements, ImmutablePathTable<T> aFrom) Method to semantically emphasize that we support our own types.Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.merge(Object)method.PathTable.withMerge(ImmutablePathTable<T> aFrom) Method to semantically emphasize that we support our own types.PathTable.withMergeBetween(Object[] aToPathElements, Object aFrom, Object[] aFromPathElements) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.mergeBetween(String, Object, String)method.PathTable.withMergeBetween(Object[] aToPathElements, ImmutablePathTable<T> aFrom, Object[] aFromPathElements) Method to semantically emphasize that we support our own types.PathTable.withMergeBetween(Object aToPath, Object aFromObj, Object aFromPath) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.mergeBetween(String, Object, String)method.PathTable.withMergeBetween(Object aToPath, ImmutablePathTable<T> aFromTable, Object aFromPath) Method to semantically emphasize that we support our own types.PathTable.withMergeBetween(String[] aToPathElements, Object aFrom, String[] aFromPathElements) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.mergeBetween(String, Object, String)method.PathTable.withMergeBetween(String[] aToPathElements, ImmutablePathTable<T> aFrom, String[] aFromPathElements) Method to semantically emphasize that we support our own types.PathTable.withMergeBetween(String aToPath, Object aFrom, String aFromPath) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.mergeBetween(String, Object, String)method.PathTable.withMergeBetween(String aToPath, ImmutablePathTable<T> aFrom, String aFromPath) Method to semantically emphasize that we support our own types.PathTable.withMergeBetween(Collection<?> aToPathElements, Object aFrom, Collection<?> aFromPathElements) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.mergeBetween(String, Object, String)method.PathTable.withMergeBetween(Collection<?> aToPathElements, ImmutablePathTable<T> aFrom, Collection<?> aFromPathElements) Method to semantically emphasize that we support our own types.PathTable.withMergeFrom(Object aFrom, Object aFromPath) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.mergeFrom(Object, String)method.PathTable.withMergeFrom(Object aFrom, Object... aFromPathElements) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.mergeFrom(Object, String)method.PathTable.withMergeFrom(Object aFrom, String aFromPath) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.mergeFrom(Object, String)method.PathTable.withMergeFrom(Object aFrom, String... aFromPathElements) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.mergeFrom(Object, String)method.PathTable.withMergeFrom(Object aFrom, Collection<?> aFromPathElements) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.mergeFrom(Object, String)method.PathTable.withMergeFrom(ImmutablePathTable<T> aFrom, Object aFromPath) Method to semantically emphasize that we support our own types.PathTable.withMergeFrom(ImmutablePathTable<T> aFrom, Object... aFromPathElements) Method to semantically emphasize that we support our own types.PathTable.withMergeFrom(ImmutablePathTable<T> aFrom, String aFromPath) Method to semantically emphasize that we support our own types.PathTable.withMergeFrom(ImmutablePathTable<T> aFrom, String... aFromPathElements) Method to semantically emphasize that we support our own types.PathTable.withMergeFrom(ImmutablePathTable<T> aFrom, Collection<?> aFromPathElements) Method to semantically emphasize that we support our own types.PathTable.withMergeTo(Object[] aToPathElements, Object aFrom) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.mergeTo(String, Object)method.PathTable.withMergeTo(Object[] aToPathElements, ImmutablePathTable<T> aFrom) Method to semantically emphasize that we support our own types.PathTable.withMergeTo(Object aToPath, Object aFromObj) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.mergeTo(String, Object)method.PathTable.withMergeTo(Object aToPath, ImmutablePathTable<T> aFromTable) Method to semantically emphasize that we support our own types.PathTable.withMergeTo(String[] aToPathElements, Object aFrom) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.mergeTo(String, Object)method.PathTable.withMergeTo(String[] aToPathElements, ImmutablePathTable<T> aFrom) Method to semantically emphasize that we support our own types.PathTable.withMergeTo(String aToPath, Object aFrom) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.mergeTo(String, Object)method.PathTable.withMergeTo(String aToPath, ImmutablePathTable<T> aFrom) Method to semantically emphasize that we support our own types.PathTable.withMergeTo(Collection<?> aToPathElements, Object aFrom) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.mergeTo(String, Object)method.PathTable.withMergeTo(Collection<?> aToPathElements, ImmutablePathTable<T> aFrom) Method to semantically emphasize that we support our own types.Builder method forKeys.MutableValues.put(Object, Object).Builder method forKeys.MutableValues.put(Object, Object).Builder method forKeys.MutableValues.put(Object, Object).PathTable.withPut(Collection<?> aPathElements, T aValue) Builder method forKeys.MutableValues.put(Object, Object).Builder method forImmutableTable.MutableTable.put(Relation).PathTable.withRemoveFrom(Object aPath) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.removeFrom(String)method.PathTable.withRemoveFrom(Object... aPathElements) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.removeFrom(String)method.PathTable.withRemoveFrom(String aPath) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.removeFrom(String)method.PathTable.withRemoveFrom(String... aPathElements) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.removeFrom(String)method.PathTable.withRemoveFrom(Collection<?> aPathElements) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.removeFrom(String)method.PathTable.withRemovePaths(String... aPathElements) Convenience method for providing builder functionality to theImmutablePathTable.MutablePathTable.removeFrom(String)method.Methods in org.refcodes.struct with parameters of type PathTableModifier and TypeMethodDescriptiondefault voidMethod to semantically emphasize that we support our own types.default voidImmutablePathTable.MutablePathTable.insertFrom(PathTable<T> aFrom, Object aFromPath) Method to semantically emphasize that we support our own types.default voidImmutablePathTable.MutablePathTable.insertFrom(PathTable<T> aFrom, Object... aFromPathElements) Method to semantically emphasize that we support our own types.default voidImmutablePathTable.MutablePathTable.insertFrom(PathTable<T> aFrom, String aFromPath) Method to semantically emphasize that we support our own types.default voidImmutablePathTable.MutablePathTable.insertFrom(PathTable<T> aFrom, String... aFromPathElements) Method to semantically emphasize that we support our own types.default voidImmutablePathTable.MutablePathTable.insertFrom(PathTable<T> aFrom, Collection<?> aFromPathElements) Method to semantically emphasize that we support our own types.default voidMethod to semantically emphasize that we support our own types.default voidMethod to semantically emphasize that we support our own types.default voidMethod to semantically emphasize that we support our own types.default voidMethod to semantically emphasize that we support our own types.default voidMethod to semantically emphasize that we support our own types.default voidImmutablePathTable.MutablePathTable.mergeFrom(PathTable<T> aFrom, Collection<?> aFromPathElements) Method to semantically emphasize that we support our own types.static <T> voidStructureUtility.retrieveFrom(ImmutablePathTable<T> aFromPathTable, String aFromPath, PathTable<T> aToPathTable) Hook method for implementing theImmutablePathTable.retrieveFrom(String)method.static <T> voidStructureUtility.retrieveTo(ImmutablePathTable<T> aFromPathTable, String aToPath, PathTable<T> aToPathTable) Hook method for implementing theImmutablePathTable.retrieveTo(String)method.Constructors in org.refcodes.struct with parameters of type PathTableModifierConstructorDescriptionUnmodifiablePathTableDecorator(PathTable<T> aPathTable) Wraps the providedPathTableinstance to be used as immutableImmutablePathTableinstance.