Uses of Interface
org.refcodes.struct.Property
-
-
Uses of Property in org.refcodes.struct
Subinterfaces of Property in org.refcodes.struct Modifier and Type Interface Description static interfaceProperty.PropertyBuilderAdds builder functionality to aProperty.Classes in org.refcodes.struct that implement Property Modifier and Type Class Description classPropertyImplImplementation of thePropertyinterface.static classPropertyImpl.PropertyBuilderImplImplementation of theProperty.PropertyBuilderinterface.Methods in org.refcodes.struct with parameters of type Property Modifier and Type Method Description default StringCanonicalMap.MutableCanonicalMap. put(Property aProperty)Puts the key/value-pair from the providedProperty.default StringClassStructMap.MutableClassStructMap. put(Property aProperty)Puts the key/value-pair from the providedProperty.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder. withPut(Property aProperty)Builder method forCanonicalMap.MutableCanonicalMap.put(Property).default ClassStructMap.ClassStructMapBuilderClassStructMap.ClassStructMapBuilder. withPut(Property aProperty)Builder method forClassStructMap.MutableClassStructMap.put(Property).
-