Uses of Interface
org.refcodes.struct.Relation
-
Uses of Relation in org.refcodes.struct
Subinterfaces of Relation in org.refcodes.structModifier and TypeInterfaceDescriptioninterfaceInterface describing a bean's attribute with a key represented by aStringand the value being of any type.static interfaceAdds builder functionality to anAttribute.interfacestatic interfaceAdds builder functionality to aProperty.static interfaceAdds builder functionality to aRelation.Classes in org.refcodes.struct that implement RelationModifier and TypeClassDescriptionclassClass describing a beans's attribute.static classImplementation of theProperty.PropertyBuilderinterface.classImplementation of thePropertyinterface.static classImplementation of theProperty.PropertyBuilderinterface.classRelationImpl<K,V> Implementation of theRelationinterface.static classImplementation of theRelation.RelationBuilderinterface.Methods in org.refcodes.struct with parameters of type RelationModifier and TypeMethodDescriptiondefault StringAdds the given element related to the given key.default Class<?>Adds the given element related to the given key.default TAdds the given element related to the given key.default ObjectAdds the given element related to the given key.Adds the given element related to the given key.default CanonicalMap.CanonicalMapBuilderBuilder method forTable.TableDictionary.put(Relation).Builder method forTable.TableDictionary.put(Relation).Builder method forTable.TableDictionary.put(Relation).default PathMap.PathMapBuilder<T>Builder method forTable.TableDictionary.put(Relation).Builder method forTable.TableDictionary.put(Relation).Builder method forTable.TableDictionary.put(Relation).