Uses of Interface
org.refcodes.struct.Table.TableDictionary
-
Uses of Table.TableDictionary in org.refcodes.struct
Subinterfaces of Table.TableDictionary in org.refcodes.structModifier and TypeInterfaceDescriptionstatic interfaceThe Interface CanonicalMapBuilder.static interfaceThe Interface MutableCanonicalMap.static interfaceThe Interface ClassStructMapBuilder.static interfaceThe Interface MutableClassStructMap.static interfaceTheInterOperableMap.InterOperableMapBuilderprovides convenience accessor default methods for supporting primitive data types.static interfaceTheInterOperableMap.InterOperableMapBuilderprovides convenience accessor default methods for supporting primitive data types.static interfaceThePathMap.MutablePathMapadds mutable functionality to thePathMap.static interfaceThePathMap.PathMapBuilderadds builder functionality to thePathMap.MutablePathMap.static interfaceTheSimpleTypeMap.MutableSimpleTypeMapadds functionality for manipulating the internal state to theSimpleTypeMap.static interfaceASimpleTypeMap.SimpleTypeMapBuildersets builder functionality (as of the builder pattern) on top of theSimpleTypeMap.MutableSimpleTypeMap.static interfaceTable.TableDictionary.TableBuilder<K, V, B extends Table.TableDictionary.TableBuilder<K,V, B>> Provides a builder method for aRelationproperty returning the builder for applying multiple build operations.Classes in org.refcodes.struct that implement Table.TableDictionaryModifier and TypeClassDescriptionclassThe Class CanonicalMapBuilderImpl.classThe Class ClassStructBuilderImpl.classThePathMapBuilderImplclass implements thePathMap.PathMapBuilderinterface and provides a hookPathMapBuilderImpl.createBackingMap()method which may be overridden for providing anotherMaptype as backing map than the default one.classAn implementation of theSimpleTypeMap.SimpleTypeMapBuilder.