Uses of Interface
org.refcodes.struct.Table.TableDictionary.TableBuilder
-
Uses of Table.TableDictionary.TableBuilder in org.refcodes.struct
Classes in org.refcodes.struct with type parameters of type Table.TableDictionary.TableBuilderModifier and TypeInterfaceDescriptionstatic interfaceTable.TableDictionary.TableBuilder<K,V, B extends Table.TableDictionary.TableBuilder<K, V, B>> Provides a builder method for aRelationproperty returning the builder for applying multiple build operations.Subinterfaces of Table.TableDictionary.TableBuilder in org.refcodes.structModifier and TypeInterfaceDescriptionstatic interfaceThe Interface CanonicalMapBuilder.static interfaceThe Interface ClassStructMapBuilder.static interfaceTheInterOperableMap.InterOperableMapBuilderprovides convenience accessor default methods for supporting primitive data types.static interfaceThePathMap.PathMapBuilderadds builder functionality to thePathMap.MutablePathMap.static interfaceASimpleTypeMap.SimpleTypeMapBuildersets builder functionality (as of the builder pattern) on top of theSimpleTypeMap.MutableSimpleTypeMap.Classes in org.refcodes.struct that implement Table.TableDictionary.TableBuilderModifier and TypeClassDescriptionclassThe Class CanonicalMapBuilderImpl.classThe Class ClassStructBuilderImpl.classThePathMapBuilderImplclass implements thePathMap.PathMapBuilderinterface and provides a hookPathMapBuilderImpl.createBackingMap()method which may be overridden for providing anotherMaptype as backing map than the default one.classAn implementation of theSimpleTypeMap.SimpleTypeMapBuilder.