Package org.refcodes.struct
package org.refcodes.struct
This artifact contains base definitions regarding collections being used
throughout the `REFCODES.ORG` artifacts; to unify management of various kinds
of collections.
Please note the ImmutablePathTable, which's
extension, the HttpBodyMap (found in the
refcodes-web artifact) is used to represent dynamic data types
produced e.g. by JavaScript clients.
-
ClassDescriptionThrown in case this instance does not contain the requested element (no such key found in the collection).Interface describing a bean's attribute with a key represented by a
Stringand the value being of any type.Adds builder functionality to anAttribute.Class describing a beans's attribute.Implementation of theProperty.PropertyBuilderinterface.Provides an accessor for a boolean array property.Provides a builder method for a boolean array property returning the builder for applying multiple build operations.Provides a mutator for a boolean array property.Provides a boolean array property.TheBoundedIteratordecorates anIteratorto limit its element to a maximum number.Provides an accessor for a byte array property.Provides a builder method for a byte array property returning the builder for applying multiple build operations.Provides a mutator for a byte array property.Provides a byte array property.The Interface CanonicalTable.TheClassStructTabletype extends theImmutableClassStructTable.MutableClassStructTableand provides mutator (write) as well as builder methods for manipulating the entries.AContainableis the base functionality provided container (collection).Container<E>Basic functionality being provided by anyContainer(collection) style class.Extends theContainerwith mutable (writable) functionality, ehttps://www.metacodes.proly by enabling theIterator.remove()method in theIteratorprovided viaElements.iterator().Provides an accessor for a double array property.Provides a builder method for a double array property returning the builder for applying multiple build operations.Provides a mutator for a double array property.Provides a double array property.Elements<E>Basic functionality being provided by anyElements(collection) style class.Extends theElementswith mutable (writable) functionality, ehttps://www.metacodes.proly by enabling theIterator.remove()method in theIteratorprovided viaElements.MutableElements.iterator()and by providing theElements.MutableElements.add(Object)and theElements.MutableElements.remove(Object)methods.Provides an accessor for a float array property.Provides a builder method for a float array property returning the builder for applying multiple build operations.Provides a mutator for a float array property.Provides a float array property.TheImmutableCanonicalTableis an "intermediate" type adding type and Data-Structure related functionality to any implementing class.TheImmutableCanonicalTable.MutableCanonicalTabletype extends theImmutableCanonicalTablewith mutable (writable) functionality and provides default mutator methods for supporting primitive data types.TheImmutableClassStructTabledisects aClassinto its simple types (consideringStringandEnumtypes as well as primitive types).TheImmutableClassStructTable.MutableClassStructTabletype adds mutable functionality to theClassStructTable.TheImmutableInterOperableTabletype extends theImmutablePathTableand provides default accessor methods for supporting primitive data types.TheImmutableInterOperableTable.MutableInterOperableTabletype extends theImmutableInterOperableTablewith mutable (writable) functionality and provides default mutator methods for supporting primitive data types.AImmutablePathTableis a flat read-only (immutable) map by which each element is addressed by a path; represented by theImmutablePathTable's keys.TheImmutablePathTable.MutablePathTabletype adds mutable functionality to theImmutablePathTable.TheImmutableSimpleTypeTable.MutableSimpleTypeTabletype extends theImmutableSimpleTypeTableand provides mutator (write) as well as builder methods for manipulating the entries and provides default methods for supporting primitive data types.ImmutableTable<K,V> TheImmutableTabletype defines read-only functionality being provided by any immutableImmutableTable(map) style class.TheImmutableTable.MutableTabletype extends theImmutableTabletype with mutable (writable) functionality and provides mutator methods such asKeys.MutableValues.put(Object, Object)andKeys.MutableKeys.delete(String)methods.TheInterOperableTabletype extends theImmutableInterOperableTable.MutableInterOperableTableand provides mutator as well as builder methods for manipulating the entries supporting primitive data types.Thrown in case this instance does not contain the requested element (no such key found in the collection).Thrown in case this instance does not contain the requested element (no such key found in the collection).Keys<K,V> This interface provides functionality for working with keys.Keys.MutableKeys<K,V> Adds mutable functionality to theKeysinterface.Keys.MutableValues<K,V> Mixin for mutable functionality accompanying theKeysinterface.MapPathTable<T>An implementation of theSimpleTypeTable.Comparator for path elements, it takes care to sort index values correctly, e.g. "1000" must come after "9": The paths "/foo/bar/1000/wow" and "/foo/bar/9/wow" should be sorted as follows:ThePathSortStrategydefines strategies to use when sorting e.g. when using aPathComparatoror the methodImmutablePathTable.sortedKeys(PathSortStrategy)PathTable<T>ThePathTabletype extends theImmutablePathTable.MutablePathTableand provides mutator (write) as well as builder methods for manipulating the entries.ThePrimitiveArrayTypeenumeration contains theClassrepresentation of the primitive array types.Adds builder functionality to aProperty.Implementation of thePropertyinterface.Implementation of theProperty.PropertyBuilderinterface.Interface describing a range with a minimum value and a maximum value.Adds builder functionality to aRange.Implementation of theRangeinterface.Implementation of theRange.RangeBuilderinterface.Referencee<T>AReferenceeencapsulates a reference to an instance which might be null at the time of the referencee's creation.Relation<K,V> Provides an accessor for a key-to-value property useful in some occasions.Adds builder functionality to aRelation.RelationImpl<K,V> Implementation of theRelationinterface.Implementation of theRelation.RelationBuilderinterface.Provides an accessor for a short array property.Provides a builder method for a short array property returning the builder for applying multiple build operations.Provides a mutator for a short array property.Provides a short array property.TheSimpleTypeTabletype extends theImmutableSimpleTypeTable.MutableSimpleTypeTableand provides mutator (write) as well as builder methods for manipulating the entries and provides default methods for supporting primitive data types.Provides an accessor for a String array property.Provides a builder method for a String array property returning the builder for applying multiple build operations.Provides a mutator for a String array property.Provides a String array property.TheStructureExceptionis the base checked exception for this package.TheStructureRuntimeExceptionis the base runtime exception for this package.Utility class to avoid redundant code regarding variousImmutablePathTableimplementations.TheTabletype extends theImmutableTable.MutableTabletype and provides mutator as well as builder methods for manipulating the entries.Provides an accessor for a type mode property.Provides a builder method for a type mode property returning the builder for applying multiple build operations.Provides a mutator for a type mode property.Provides a type mode property.TheTypeUtilityuses reflection to fiddle around with primitives, types, classes, instances and the like.Extension of theNoSuchMethodExceptionwith an additional aCauseTypeUtility.NoSuchMethodNotInvokedException.getCause()TheUnmodifiableCanonicalTableDecoratordecorates anImmutableCanonicalTableinstance for immutability (read only access).TheUnmodifiableClassStructTableDecoratordecorates anImmutableCanonicalTableinstance for immutability (read only access).TheUnmodifiablePathTableDecoratordecorates anImmutablePathTableinstance for immutability (read only access).TheUnmodifiableSimpleTypeTableDecoratordecorates anImmutableSimpleTypeTableinstance for immutability (read only access).