Uses of Package
org.refcodes.struct
-
Classes in org.refcodes.struct used by org.refcodes.structClassDescriptionInterface describing a bean's attribute with a key represented by a
Stringand the value being of any type.Adds builder functionality to anAttribute.Class describing a beans's attribute.Provides an accessor for a boolean array property.Provides a builder method for a boolean array property returning the builder for applying multiple build operations.Provides a mutator for a boolean array property.Provides an accessor for a byte array property.Provides a builder method for a byte array property returning the builder for applying multiple build operations.Provides a mutator for a byte array property.The Interface CanonicalTable.TheClassStructTabletype extends theImmutableClassStructTable.MutableClassStructTableand provides mutator (write) as well as builder methods for manipulating the entries.AContainableis the base functionality provided container (collection).Basic functionality being provided by anyContainer(collection) style class.Provides an accessor for a double array property.Provides a builder method for a double array property returning the builder for applying multiple build operations.Provides a mutator for a double array property.Basic functionality being provided by anyElements(collection) style class.Extends theElementswith mutable (writable) functionality, ehttps://www.metacodes.proly by enabling theIterator.remove()method in theIteratorprovided viaElements.MutableElements.iterator()and by providing theElements.MutableElements.add(Object)and theElements.MutableElements.remove(Object)methods.Provides an accessor for a float array property.Provides a builder method for a float array property returning the builder for applying multiple build operations.Provides a mutator for a float array property.TheImmutableCanonicalTableis an "intermediate" type adding type and Data-Structure related functionality to any implementing class.TheImmutableCanonicalTable.MutableCanonicalTabletype extends theImmutableCanonicalTablewith mutable (writable) functionality and provides default mutator methods for supporting primitive data types.TheImmutableClassStructTabledisects aClassinto its simple types (consideringStringandEnumtypes as well as primitive types).TheImmutableClassStructTable.MutableClassStructTabletype adds mutable functionality to theClassStructTable.TheImmutableInterOperableTabletype extends theImmutablePathTableand provides default accessor methods for supporting primitive data types.TheImmutableInterOperableTable.MutableInterOperableTabletype extends theImmutableInterOperableTablewith mutable (writable) functionality and provides default mutator methods for supporting primitive data types.AImmutablePathTableis a flat read-only (immutable) map by which each element is addressed by a path; represented by theImmutablePathTable's keys.TheImmutablePathTable.MutablePathTabletype adds mutable functionality to theImmutablePathTable.TheImmutableSimpleTypeTable.MutableSimpleTypeTabletype extends theImmutableSimpleTypeTableand provides mutator (write) as well as builder methods for manipulating the entries and provides default methods for supporting primitive data types.TheImmutableTabletype defines read-only functionality being provided by any immutableImmutableTable(map) style class.TheImmutableTable.MutableTabletype extends theImmutableTabletype with mutable (writable) functionality and provides mutator methods such asKeys.MutableValues.put(Object, Object)andImmutableTable.MutableTable.delete(String)methods.TheInterOperableTabletype extends theImmutableInterOperableTable.MutableInterOperableTableand provides mutator as well as builder methods for manipulating the entries supporting primitive data types.This interface provides functionality for working with keys.Adds mutable functionality to theKeysinterface.Mixin for mutable functionality accompanying theKeysinterface.ThePathSortStrategydefines strategies to use when sorting e.g. when using aPathComparatoror the methodImmutablePathTable.sortedKeys(PathSortStrategy)ThePathTabletype extends theImmutablePathTable.MutablePathTableand provides mutator (write) as well as builder methods for manipulating the entries.ThePrimitiveArrayTypeenumeration contains theClassrepresentation of the primitive array types.Adds builder functionality to aProperty.Implementation of thePropertyinterface.Interface describing a range with a minimum value and a maximum value.Adds builder functionality to aRange.Implementation of theRangeinterface.Provides an accessor for a key-to-value property useful in some occasions.Adds builder functionality to aRelation.Implementation of theRelationinterface.Provides an accessor for a short array property.Provides a builder method for a short array property returning the builder for applying multiple build operations.Provides a mutator for a short array property.TheSimpleTypeTabletype extends theImmutableSimpleTypeTable.MutableSimpleTypeTableand provides mutator (write) as well as builder methods for manipulating the entries and provides default methods for supporting primitive data types.Provides an accessor for a String array property.Provides a builder method for a String array property returning the builder for applying multiple build operations.Provides a mutator for a String array property.TheStructureExceptionis the base checked exception for this package.TheStructureRuntimeExceptionis the base runtime exception for this package.TheTabletype extends theImmutableTable.MutableTabletype and provides mutator as well as builder methods for manipulating the entries.Provides an accessor for a type mode property.Provides a builder method for a type mode property returning the builder for applying multiple build operations.Provides a mutator for a type mode property.