B - The builder to return in order to be able to apply multiple
build operations.public static interface BooleanArrayAccessor.BooleanArrayBuilder<B extends BooleanArrayAccessor.BooleanArrayBuilder<B>>
| Modifier and Type | Method | Description |
|---|---|---|
B |
withBooleans(boolean[] aBooleans) |
Sets the boolean array for the boolean array property.
|
B withBooleans(boolean[] aBooleans)
aBooleans - The boolean array to be stored by the boolean array
property.Copyright © 2021. All rights reserved.