Serializable, Map<String,T>, org.refcodes.mixin.AnnotatorAccessor, org.refcodes.mixin.Clearable, org.refcodes.mixin.DelimiterAccessor, org.refcodes.mixin.Dumpable, org.refcodes.mixin.TypeAccessor<String>, CanonicalMap, CanonicalMap.CanonicalMapBuilder, CanonicalMap.MutableCanonicalMap, Containable, Dictionary<String,T>, Dictionary.MutableDictionary<String,T>, Dictionary.MutableDictionary.DictionaryBuilder<String,T,PathMap.PathMapBuilder<T>>, InterOperableMap<String>, InterOperableMap.InterOperableMapBuilder<String>, InterOperableMap.MutableInterOperableMap<String>, Keys<String,T>, Keys.MutableKeys<String,T>, Keys.MutableValues<String,T>, PathMap<String>, PathMap.MutablePathMap<String>, PathMap.PathMapBuilder<String>public class CanonicalMapBuilderImpl extends PathMapBuilderImpl<String> implements CanonicalMap.CanonicalMapBuilder
org.refcodes.mixin.AnnotatorAccessor.AnnotatorBuilder<B extends org.refcodes.mixin.AnnotatorAccessor.AnnotatorBuilder<B>>, org.refcodes.mixin.AnnotatorAccessor.AnnotatorMutator, org.refcodes.mixin.AnnotatorAccessor.AnnotatorPropertyCanonicalMap.CanonicalMapBuilder, CanonicalMap.MutableCanonicalMaporg.refcodes.mixin.DelimiterAccessor.DelimiterBuilder<B extends org.refcodes.mixin.DelimiterAccessor.DelimiterBuilder<B>>, org.refcodes.mixin.DelimiterAccessor.DelimiterMutator, org.refcodes.mixin.DelimiterAccessor.DelimiterPropertyDictionary.MutableDictionary<K,V>Dictionary.MutableDictionary.DictionaryBuilder<K,V,B extends Dictionary.MutableDictionary.DictionaryBuilder<K,V,B>>InterOperableMap.InterOperableMapBuilder<T>, InterOperableMap.MutableInterOperableMap<T>Map.Entry<K extends Object,V extends Object>PathMap.MutablePathMap<T>, PathMap.PathMapBuilder<T>org.refcodes.mixin.TypeAccessor.TypeBuilder<T extends Object,B extends org.refcodes.mixin.TypeAccessor.TypeBuilder<T,B>>, org.refcodes.mixin.TypeAccessor.TypeMutator<T extends Object>, org.refcodes.mixin.TypeAccessor.TypeProperty<T extends Object>_backingMap| Constructor | Description |
|---|---|
CanonicalMapBuilderImpl() |
Create an empty
CanonicalMap.CanonicalMapBuilder instance using the default
path delimiter "/" (Delimiter.PATH) for the path declarations. |
CanonicalMapBuilderImpl(char aDelimiter) |
Create a
CanonicalMap.CanonicalMapBuilder instance using the provided path
delimiter for the path declarations. |
CanonicalMapBuilderImpl(Object aObj) |
Create a
CanonicalMap.CanonicalMapBuilder instance containing the elements as
of PathMap.MutablePathMap.insert(Object) using the default path delimiter
"/" (Delimiter.PATH) for the path declarations. |
CanonicalMapBuilderImpl(Object aObj,
char aDelimiter) |
Creates a
CanonicalMap.CanonicalMapBuilder instance containing the elements as
of PathMap.MutablePathMap.insert(Object). |
CanonicalMapBuilderImpl(Object aObj,
String aFromPath) |
Creates a
CanonicalMap.CanonicalMapBuilder instance containing the elements as
of PathMap.MutablePathMap.insert(Object) using the default path delimiter
"/" (Delimiter.PATH) for the path declarations. |
CanonicalMapBuilderImpl(Object aObj,
String aFromPath,
char aDelimiter) |
Creates a
CanonicalMap.CanonicalMapBuilder instance containing the elements as
of PathMap.MutablePathMap.insert(Object). |
CanonicalMapBuilderImpl(String aToPath,
Object aObj) |
Create a
CanonicalMap.CanonicalMapBuilder instance containing the elements as
of PathMap.MutablePathMap.insert(Object) using the default path delimiter
"/" (Delimiter.PATH) for the path declarations. |
CanonicalMapBuilderImpl(String aToPath,
Object aObj,
char aDelimiter) |
Creates a
CanonicalMap.CanonicalMapBuilder instance containing the elements as
of PathMap.MutablePathMap.insert(Object). |
CanonicalMapBuilderImpl(String aToPath,
Object aObj,
String aFromPath) |
Creates a
CanonicalMap.CanonicalMapBuilder instance containing the elements as
of PathMap.MutablePathMap.insert(Object) using the default path delimiter
"/" (Delimiter.PATH for the path declarations. |
CanonicalMapBuilderImpl(String aToPath,
Object aObj,
String aFromPath,
char aDelimiter) |
Create a
CanonicalMap.CanonicalMapBuilder instance containing the elements as
of PathMap.MutablePathMap.insert(Object). |
| Modifier and Type | Method | Description |
|---|---|---|
protected PathMap<String> |
fromObject(Object aFrom) |
|
CanonicalMap.CanonicalMapBuilder |
retrieveFrom(String aFromPath) |
|
CanonicalMap.CanonicalMapBuilder |
retrieveTo(String aToPath) |
|
protected String |
toTypeInstance(Object aObj) |
Hook method when introspecting an object to help conversion of that
object to the target types.
|
CanonicalMap.CanonicalMapBuilder |
withPut(String aKey,
String aValue) |
Builder method for
Keys.MutableValues.put(Object, Object). |
asArray, asArray, asArray, asArray, asBooleanArray, asBooleanArray, asBooleanArray, asBooleanArray, asByteArray, asByteArray, asByteArray, asByteArray, asCharArray, asCharArray, asCharArray, asCharArray, asDoubleArray, asDoubleArray, asDoubleArray, asDoubleArray, asFloatArray, asFloatArray, asFloatArray, asFloatArray, asIntArray, asIntArray, asIntArray, asIntArray, asLongArray, asLongArray, asLongArray, asLongArray, asShortArray, asShortArray, asShortArray, asShortArray, getDir, getDir, getDir, getDir, getDir, getDirAt, getDirAt, getDirAt, getDirAt, getDirAt, getDirAt, query, query, query, query, query, queryBetween, queryBetween, queryBetween, queryBetween, queryBetween, queryBetween, queryFrom, queryFrom, queryFrom, queryFrom, queryFrom, queryFrom, queryTo, queryTo, queryTo, queryTo, queryTo, queryTo, retrieveBetween, retrieveBetween, retrieveBetween, retrieveBetween, retrieveBetween, retrieveFrom, retrieveFrom, retrieveFrom, retrieveFrom, retrieveTo, retrieveTo, retrieveTo, retrieveTo, toMap, toPropertieswithInsert, withInsert, withInsertBetween, withInsertBetween, withInsertBetween, withInsertBetween, withInsertBetween, withInsertBetween, withInsertBetween, withInsertBetween, withInsertBetween, withInsertBetween, withInsertFrom, withInsertFrom, withInsertFrom, withInsertFrom, withInsertFrom, withInsertFrom, withInsertFrom, withInsertFrom, withInsertFrom, withInsertFrom, withInsertTo, withInsertTo, withInsertTo, withInsertTo, withInsertTo, withInsertTo, withInsertTo, withInsertTo, withInsertTo, withInsertTo, withMerge, withMerge, withMergeBetween, withMergeBetween, withMergeBetween, withMergeBetween, withMergeBetween, withMergeBetween, withMergeBetween, withMergeBetween, withMergeBetween, withMergeBetween, withMergeFrom, withMergeFrom, withMergeFrom, withMergeFrom, withMergeFrom, withMergeFrom, withMergeFrom, withMergeFrom, withMergeFrom, withMergeFrom, withMergeTo, withMergeTo, withMergeTo, withMergeTo, withMergeTo, withMergeTo, withMergeTo, withMergeTo, withMergeTo, withMergeTo, withPut, withPut, withPut, withPut, withPut, withPutBoolean, withPutBoolean, withPutBoolean, withPutBoolean, withPutBoolean, withPutByte, withPutByte, withPutByte, withPutByte, withPutByte, withPutChar, withPutChar, withPutChar, withPutChar, withPutChar, withPutClass, withPutClass, withPutClass, withPutClass, withPutClass, withPutDirAt, withPutDirAt, withPutDirAt, withPutDirAt, withPutDirAt, withPutDirAt, withPutDirAt, withPutDirAt, withPutDirAt, withPutDirAt, withPutDirAt, withPutDirAt, withPutDouble, withPutDouble, withPutDouble, withPutDouble, withPutDouble, withPutEnum, withPutEnum, withPutEnum, withPutEnum, withPutEnum, withPutFloat, withPutFloat, withPutFloat, withPutFloat, withPutFloat, withPutInt, withPutInt, withPutInt, withPutInt, withPutInt, withPutLong, withPutLong, withPutLong, withPutLong, withPutLong, withPutShort, withPutShort, withPutShort, withPutShort, withPutShort, withPutString, withPutString, withPutString, withPutString, withPutString, withRemoveFrom, withRemoveFrom, withRemoveFrom, withRemoveFrom, withRemoveFrom, withRemovePathscontainsValue, insert, insertBetween, insertFrom, insertTo, put, put, put, put, put, putAll, putAll, putAll, putDirAt, putDirAt, putDirAt, putDirAt, putDirAt, putDirAt, putDirAt, putDirAt, putDirAt, putDirAt, putDirAt, putDirAt, removeAll, removeAll, removeAll, removeAll, removeAll, removeAll, removeDirAt, removeDirAt, removeDirAt, removeDirAt, removeDirAt, removeFrom, removeFrom, removeFrom, removeFrom, removeFrom, removePaths, removePaths, toDumpisEmpty, sizegetBoolean, getBoolean, getBoolean, getBoolean, getBoolean, getBooleanOr, getBooleanOr, getBooleanOr, getBooleanOr, getBooleanOr, getByte, getByte, getByte, getByte, getByte, getByteOr, getByteOr, getByteOr, getByteOr, getByteOr, getChar, getChar, getChar, getChar, getChar, getCharOr, getCharOr, getCharOr, getCharOr, getCharOr, getClass, getClass, getClass, getClass, getClass, getClassOr, getClassOr, getClassOr, getClassOr, getClassOr, getDouble, getDouble, getDouble, getDouble, getDouble, getDoubleOr, getDoubleOr, getDoubleOr, getDoubleOr, getDoubleOr, getEnum, getEnum, getEnum, getEnum, getEnum, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getFloat, getFloat, getFloat, getFloat, getFloat, getFloatOr, getFloatOr, getFloatOr, getFloatOr, getFloatOr, getInt, getInt, getInt, getInt, getInt, getIntOr, getIntOr, getIntOr, getIntOr, getIntOr, getLong, getLong, getLong, getLong, getLong, getLongOr, getLongOr, getLongOr, getLongOr, getLongOr, getShort, getShort, getShort, getShort, getShort, getShortOr, getShortOr, getShortOr, getShortOr, getShortOr, getString, getString, getString, getString, getString, getStringOr, getStringOr, getStringOr, getStringOr, getStringOrinsert, insertBetween, insertFrom, insertTo, putBoolean, putBoolean, putBoolean, putBoolean, putBoolean, putByte, putByte, putByte, putByte, putByte, putChar, putChar, putChar, putChar, putChar, putClass, putClass, putClass, putClass, putClass, putDouble, putDouble, putDouble, putDouble, putDouble, putEnum, putEnum, putEnum, putEnum, putEnum, putFloat, putFloat, putFloat, putFloat, putFloat, putInt, putInt, putInt, putInt, putInt, putLong, putLong, putLong, putLong, putLong, putShort, putShort, putShort, putShort, putShort, putString, putString, putString, putString, putStringputclear, compute, computeIfAbsent, computeIfPresent, containsKey, entry, entrySet, equals, forEach, get, getOrDefault, hashCode, isEmpty, keySet, merge, of, of, of, of, of, of, of, of, of, of, of, ofEntries, put, putIfAbsent, remove, remove, replace, replace, replaceAll, size, valuesclone, finalize, getClass, notify, notifyAll, wait, wait, waitchildren, children, children, children, children, children, containsKey, containsKey, containsKey, dirs, dirs, dirs, dirs, dirs, dirs, findPaths, fromExternalPath, get, get, get, getArray, getArray, getArray, getArray, getArray, getArrayIndexes, getArrayIndexes, getArrayIndexes, getArrayIndexes, getArrayIndexes, getDirIndexes, getDirIndexes, getDirIndexes, getDirIndexes, getDirIndexes, getRootPath, getValueAt, getValueAt, getValueAt, getValueAt, getValueAt, getValueAt, hasChildren, hasChildren, hasChildren, hasChildren, hasChildren, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasParentPath, hasPath, hasPath, hasPath, hasPath, hasSubDirs, hasSubDirs, hasSubDirs, hasSubDirs, hasValue, hasValue, hasValue, hasValue, hasValue, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, isArray, isArray, isArray, isArray, isArray, isArray, isChild, isChild, isChild, isChild, isDir, isDir, isDir, isDir, isDir, isEqualTo, isIndexDir, isIndexDir, isIndexDir, isIndexDir, isIndexDir, isLeaf, isLeaf, isLeaf, isLeaf, isLeaf, isRootPath, keySet, keySet, keySet, keySet, keySet, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastDirIndex, lastDirIndex, lastDirIndex, lastDirIndex, lastDirIndex, lastDirIndex, leaves, leaves, leaves, leaves, leaves, leaves, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextDirIndex, nextDirIndex, nextDirIndex, nextDirIndex, nextDirIndex, nextDirIndex, paths, paths, paths, paths, paths, paths, queryPaths, queryPaths, queryPaths, queryPaths, queryPaths, queryPaths, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, toDataStructure, toDataStructure, toExternalPath, toInstance, toInstance, toLeaf, toMap, toNormalizedPath, toParentPath, toPath, toPath, toPath, toPathElements, toPathList, toPathStack, toPropertyPath, toType, toTypeadd, add, add, add, add, add, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendValueTo, appendValueTo, appendValueTo, appendValueTo, appendValueTo, appendValueTo, delete, delete, delete, delete, delete, insert, insert, insertBetween, insertBetween, insertBetween, insertBetween, insertBetween, insertBetween, insertBetween, insertBetween, insertBetween, insertBetween, insertFrom, insertFrom, insertFrom, insertFrom, insertFrom, insertFrom, insertFrom, insertFrom, insertFrom, insertFrom, insertTo, insertTo, insertTo, insertTo, insertTo, insertTo, insertTo, insertTo, insertTo, insertTo, merge, merge, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeTo, mergeTo, mergeTo, mergeTo, mergeTo, mergeTo, mergeTo, mergeTo, mergeTo, mergeTo, put, putArray, putArray, putArray, putArray, putArray, putArray, putArray, putArray, putArray, putArray, putArray, putArray, putValueAt, putValueAt, putValueAt, putValueAt, putValueAt, putValueAt, remove, remove, remove, removeValueAt, removeValueAt, removeValueAt, removeValueAt, removeValueAt, toSourceCode, toSourceCodeclear, compute, computeIfAbsent, computeIfPresent, containsKey, containsValue, createBackingMap, entrySet, equals, forEach, fromValue, fromValue, get, getAnnotator, getDelimiter, getOrDefault, getType, hashCode, insert, insertBetween, insertFrom, insertTo, isEmpty, keySet, merge, merge, mergeBetween, mergeFrom, mergeTo, put, putAll, putIfAbsent, remove, remove, replace, replace, replaceAll, size, toDataStructure, toString, valuespublic CanonicalMapBuilderImpl()
CanonicalMap.CanonicalMapBuilder instance using the default
path delimiter "/" (Delimiter.PATH) for the path declarations.public CanonicalMapBuilderImpl(char aDelimiter)
CanonicalMap.CanonicalMapBuilder instance using the provided path
delimiter for the path declarations.aDelimiter - The path delimiter to be used for the path
declarations.public CanonicalMapBuilderImpl(Object aObj)
CanonicalMap.CanonicalMapBuilder instance containing the elements as
of PathMap.MutablePathMap.insert(Object) using the default path delimiter
"/" (Delimiter.PATH) for the path declarations.aObj - The object from which the elements are to be added.public CanonicalMapBuilderImpl(String aToPath, Object aObj)
CanonicalMap.CanonicalMapBuilder instance containing the elements as
of PathMap.MutablePathMap.insert(Object) using the default path delimiter
"/" (Delimiter.PATH) for the path declarations.aToPath - The sub-path where to insert the object's introspected
values to.aObj - The object from which the elements are to be added.public CanonicalMapBuilderImpl(Object aObj, String aFromPath)
CanonicalMap.CanonicalMapBuilder instance containing the elements as
of PathMap.MutablePathMap.insert(Object) using the default path delimiter
"/" (Delimiter.PATH) for the path declarations.aObj - The object from which the elements are to be added.aFromPath - The path from where to start adding elements of the
provided object.public CanonicalMapBuilderImpl(String aToPath, Object aObj, String aFromPath)
CanonicalMap.CanonicalMapBuilder instance containing the elements as
of PathMap.MutablePathMap.insert(Object) using the default path delimiter
"/" (Delimiter.PATH for the path declarations.aToPath - The sub-path where to insert the object's introspected
values to.aObj - The object from which the elements are to be added.aFromPath - The path from where to start adding elements of the
provided object.public CanonicalMapBuilderImpl(Object aObj, char aDelimiter)
CanonicalMap.CanonicalMapBuilder instance containing the elements as
of PathMap.MutablePathMap.insert(Object).aObj - The object from which the elements are to be added.aDelimiter - The path delimiter to be used for the path
declarations.public CanonicalMapBuilderImpl(String aToPath, Object aObj, char aDelimiter)
CanonicalMap.CanonicalMapBuilder instance containing the elements as
of PathMap.MutablePathMap.insert(Object).aToPath - The sub-path where to insert the object's introspected
values to.aObj - The object from which the elements are to be added.aDelimiter - The path delimiter to be used for the path
declarations.public CanonicalMapBuilderImpl(Object aObj, String aFromPath, char aDelimiter)
CanonicalMap.CanonicalMapBuilder instance containing the elements as
of PathMap.MutablePathMap.insert(Object).aObj - The object from which the elements are to be added.aFromPath - The path from where to start adding elements of the
provided object.aDelimiter - The path delimiter to be used for the path
declarations.public CanonicalMapBuilderImpl(String aToPath, Object aObj, String aFromPath, char aDelimiter)
CanonicalMap.CanonicalMapBuilder instance containing the elements as
of PathMap.MutablePathMap.insert(Object).aToPath - The sub-path where to insert the object's introspected
values to.aObj - The object from which the elements are to be added.aFromPath - The path from where to start adding elements of the
provided object.aDelimiter - The path delimiter to be used for the path
declarations.public CanonicalMap.CanonicalMapBuilder retrieveFrom(String aFromPath)
PathMap from the elements of this PathMap
found below the "from-path". The sub-paths will be the root paths for the
new PathMap. Given we have a value for path "/dog/cat" in the
PathMap and we call PathMap.retrieveFrom(String) with "/dog",
then the resulting PathMap will contain the path "/cat" for that
value.retrieveFrom in interface CanonicalMapretrieveFrom in interface PathMap<String>retrieveFrom in class PathMapBuilderImpl<String>aFromPath - The path from where to start extracting the paths.PathMap with the elements below the provided path
which are root elements in the new PathMap.public CanonicalMap.CanonicalMapBuilder retrieveTo(String aToPath)
PathMap from this PathMap's elements with
the paths relocated to the provided "to-path". Given we have a value for
path "/dog/cat" in the PathMap and we call
PathMap.retrieveTo(String) with "/animals", then the resulting
PathMap will contain the path "/animals/dog/cat" for that value.retrieveTo in interface CanonicalMapretrieveTo in interface PathMap<String>retrieveTo in class PathMapBuilderImpl<String>aToPath - The path where to relocate the paths of this
PathMap to.PathMap with the elements from the provided
PathMap with accordingly relocated paths.public CanonicalMap.CanonicalMapBuilder withPut(String aKey, String aValue)
Keys.MutableValues.put(Object, Object).withPut in interface Dictionary.MutableDictionary.DictionaryBuilder<String,T,PathMap.PathMapBuilder<T>>withPut in interface InterOperableMap.InterOperableMapBuilder<String>withPut in class PathMapBuilderImpl<String>aKey - the key for the property to be put.aValue - the value for the property to be put.protected PathMap<String> fromObject(Object aFrom)
PathMap sub-types in the
according PathMap sub-type implementations.fromObject in class PathMapBuilderImpl<String>aFrom - The Object from which to create a PathMap
(sub-type) instance.PathMap (sub-type) instance.protected String toTypeInstance(Object aObj)
Class.isAssignableFrom(Class) with
the type retrieved by PathMapBuilderImpl.getType().toTypeInstance in class PathMapBuilderImpl<String>aObj - The object which is to be transformed to the expected type as
of PathMapBuilderImpl.getType().Copyright © 2021. All rights reserved.