Serializable, Map<String,T>, org.refcodes.mixin.AnnotatorAccessor, org.refcodes.mixin.Clearable, org.refcodes.mixin.DelimiterAccessor, org.refcodes.mixin.Dumpable, org.refcodes.mixin.TypeAccessor<Class<?>>, ClassStructMap, ClassStructMap.ClassStructMapBuilder, ClassStructMap.MutableClassStructMap, Containable, Dictionary<String,T>, Dictionary.MutableDictionary<String,T>, Dictionary.MutableDictionary.DictionaryBuilder<String,T,PathMap.PathMapBuilder<T>>, Keys<String,T>, Keys.MutableKeys<String,T>, Keys.MutableValues<String,T>, PathMap<Class<?>>, PathMap.MutablePathMap<Class<?>>, PathMap.PathMapBuilder<Class<?>>, TypeModeAccessorpublic class ClassStructMapBuilderImpl extends PathMapBuilderImpl<Class<?>> implements ClassStructMap.ClassStructMapBuilder
org.refcodes.mixin.AnnotatorAccessor.AnnotatorBuilder<B extends org.refcodes.mixin.AnnotatorAccessor.AnnotatorBuilder<B>>, org.refcodes.mixin.AnnotatorAccessor.AnnotatorMutator, org.refcodes.mixin.AnnotatorAccessor.AnnotatorPropertyClassStructMap.ClassStructMapBuilder, ClassStructMap.MutableClassStructMaporg.refcodes.mixin.DelimiterAccessor.DelimiterBuilder<B extends org.refcodes.mixin.DelimiterAccessor.DelimiterBuilder<B>>, org.refcodes.mixin.DelimiterAccessor.DelimiterMutator, org.refcodes.mixin.DelimiterAccessor.DelimiterPropertyDictionary.MutableDictionary<K,V>Dictionary.MutableDictionary.DictionaryBuilder<K,V,B extends Dictionary.MutableDictionary.DictionaryBuilder<K,V,B>>PathMap.MutablePathMap<T>, PathMap.PathMapBuilder<T>org.refcodes.mixin.TypeAccessor.TypeBuilder<T extends Object,B extends org.refcodes.mixin.TypeAccessor.TypeBuilder<T,B>>, org.refcodes.mixin.TypeAccessor.TypeMutator<T extends Object>, org.refcodes.mixin.TypeAccessor.TypeProperty<T extends Object>TypeModeAccessor.TypeModeBuilder<B extends TypeModeAccessor.TypeModeBuilder<B>>, TypeModeAccessor.TypeModeMutator, TypeModeAccessor.TypeModePropertyARRAY_SELECTOR_backingMap| Constructor | Description |
|---|---|
ClassStructMapBuilderImpl() |
Create an empty
ClassStructMap.ClassStructMapBuilder instance using the default
path delimiter "/" (Delimiter.PATH) for the path declarations. |
ClassStructMapBuilderImpl(char aDelimiter) |
Create a
ClassStructMap.ClassStructMapBuilder instance using the provided path
delimiter for the path declarations. |
ClassStructMapBuilderImpl(char aDelimiter,
SimpleType aTypeMode) |
Create a
ClassStructMap.ClassStructMapBuilder instance using the provided path
delimiter for the path declarations. |
ClassStructMapBuilderImpl(Object aObj) |
Create a
ClassStructMap.ClassStructMapBuilder instance containing the elements
as of PathMap.MutablePathMap.insert(Object) using the default path
delimiter "/" (Delimiter.PATH) for the path declarations. |
ClassStructMapBuilderImpl(Object aObj,
char aDelimiter) |
Creates a
ClassStructMap.ClassStructMapBuilder instance containing the elements
as of PathMap.MutablePathMap.insert(Object). |
ClassStructMapBuilderImpl(Object aObj,
char aDelimiter,
SimpleType aTypeMode) |
Creates a
ClassStructMap.ClassStructMapBuilder instance containing the elements
as of PathMap.MutablePathMap.insert(Object). |
ClassStructMapBuilderImpl(Object aObj,
String aFromPath) |
Creates a
ClassStructMap.ClassStructMapBuilder instance containing the elements
as of PathMap.MutablePathMap.insert(Object) using the default path
delimiter "/" (Delimiter.PATH) for the path declarations. |
ClassStructMapBuilderImpl(Object aObj,
String aFromPath,
char aDelimiter) |
Creates a
ClassStructMap.ClassStructMapBuilder instance containing the elements
as of PathMap.MutablePathMap.insert(Object). |
ClassStructMapBuilderImpl(Object aObj,
String aFromPath,
char aDelimiter,
SimpleType aTypeMode) |
Creates a
ClassStructMap.ClassStructMapBuilder instance containing the elements
as of PathMap.MutablePathMap.insert(Object). |
ClassStructMapBuilderImpl(Object aObj,
String aFromPath,
SimpleType aTypeMode) |
Creates a
ClassStructMap.ClassStructMapBuilder instance containing the elements
as of PathMap.MutablePathMap.insert(Object) using the default path
delimiter "/" (Delimiter.PATH) for the path declarations. |
ClassStructMapBuilderImpl(Object aObj,
SimpleType aTypeMode) |
Create a
ClassStructMap.ClassStructMapBuilder instance containing the elements
as of PathMap.MutablePathMap.insert(Object) using the default path
delimiter "/" (Delimiter.PATH) for the path declarations. |
ClassStructMapBuilderImpl(String aToPath,
Object aObj) |
Create a
ClassStructMap.ClassStructMapBuilder instance containing the elements
as of PathMap.MutablePathMap.insert(Object) using the default path
delimiter "/" (Delimiter.PATH) for the path declarations. |
ClassStructMapBuilderImpl(String aToPath,
Object aObj,
char aDelimiter) |
Creates a
ClassStructMap.ClassStructMapBuilder instance containing the elements
as of PathMap.MutablePathMap.insert(Object). |
ClassStructMapBuilderImpl(String aToPath,
Object aObj,
char aDelimiter,
SimpleType aTypeMode) |
Creates a
ClassStructMap.ClassStructMapBuilder instance containing the elements
as of PathMap.MutablePathMap.insert(Object). |
ClassStructMapBuilderImpl(String aToPath,
Object aObj,
String aFromPath) |
Creates a
ClassStructMap.ClassStructMapBuilder instance containing the elements
as of PathMap.MutablePathMap.insert(Object) using the default path
delimiter "/" (Delimiter.PATH for the path declarations. |
ClassStructMapBuilderImpl(String aToPath,
Object aObj,
String aFromPath,
char aDelimiter) |
Create a
ClassStructMap.ClassStructMapBuilder instance containing the elements
as of PathMap.MutablePathMap.insert(Object). |
ClassStructMapBuilderImpl(String aToPath,
Object aObj,
String aFromPath,
char aDelimiter,
SimpleType aTypeMode) |
Create a
ClassStructMap.ClassStructMapBuilder instance containing the elements
as of PathMap.MutablePathMap.insert(Object). |
ClassStructMapBuilderImpl(String aToPath,
Object aObj,
String aFromPath,
SimpleType aTypeMode) |
Creates a
ClassStructMap.ClassStructMapBuilder instance containing the elements
as of PathMap.MutablePathMap.insert(Object) using the default path
delimiter "/" (Delimiter.PATH for the path declarations. |
ClassStructMapBuilderImpl(String aToPath,
Object aObj,
SimpleType aTypeMode) |
Create a
ClassStructMap.ClassStructMapBuilder instance containing the elements
as of PathMap.MutablePathMap.insert(Object) using the default path
delimiter "/" (Delimiter.PATH) for the path declarations. |
ClassStructMapBuilderImpl(SimpleType aTypeMode) |
Create an empty
ClassStructMap.ClassStructMapBuilder instance using the default
path delimiter "/" (Delimiter.PATH) for the path declarations. |
| Modifier and Type | Method | Description |
|---|---|---|
protected PathMap<Class<?>> |
fromObject(Object aFrom) |
|
protected void |
fromValue(String aToPath,
Object aObj) |
Hook method for intercepting or modifying the process of object
introspection.
|
SimpleType |
getTypeMode() |
Retrieves the type mode from the type mode property.
|
ClassStructMap.ClassStructMapBuilder |
retrieveFrom(String aFromPath) |
|
ClassStructMap.ClassStructMapBuilder |
retrieveTo(String aToPath) |
|
protected Class<?> |
toTypeInstance(Object aObj) |
Hook method when introspecting an object to help conversion of that
object to the target types.
|
ClassStructMap.ClassStructMapBuilder |
withPut(String aKey,
Class<?> aValue) |
Builder method for
Keys.MutableValues.put(Object, Object). |
getArraySelector, getCompositeArrayDir, getCompositeArrayDir, getCompositeArrayDir, getCompositeArrayDir, getCompositeArrayDir, getCompositeArrayDir, getCompositeDir, getCompositeDir, getCompositeDir, getCompositeDir, getCompositeDir, getCompositeDir, getDir, getDir, getDir, getDir, getDir, getDirAt, getDirAt, getDirAt, getDirAt, getDirAt, getDirAt, getPrimitiveArrayType, getPrimitiveArrayType, getPrimitiveArrayType, getPrimitiveArrayType, getPrimitiveArrayType, getPrimitiveArrayType, getPrimitiveType, getPrimitiveType, getPrimitiveType, getPrimitiveType, getPrimitiveType, getPrimitiveType, getSimpleArrayType, getSimpleArrayType, getSimpleArrayType, getSimpleArrayType, getSimpleArrayType, getSimpleArrayType, getSimpleType, getSimpleType, getSimpleType, getSimpleType, getSimpleType, getSimpleType, getWrapperArrayType, getWrapperArrayType, getWrapperArrayType, getWrapperArrayType, getWrapperArrayType, getWrapperArrayType, getWrapperType, getWrapperType, getWrapperType, getWrapperType, getWrapperType, getWrapperType, isArrayType, isArrayType, isArrayType, isArrayType, isArrayType, isArrayType, isCompositeArrayDir, isCompositeArrayDir, isCompositeArrayDir, isCompositeArrayDir, isCompositeArrayDir, isCompositeArrayDir, isCompositeDir, isCompositeDir, isCompositeDir, isCompositeDir, isCompositeDir, isCompositeDir, isPrimitiveArrayType, isPrimitiveArrayType, isPrimitiveArrayType, isPrimitiveArrayType, isPrimitiveArrayType, isPrimitiveArrayType, isPrimitiveType, isPrimitiveType, isPrimitiveType, isPrimitiveType, isPrimitiveType, isPrimitiveType, isSimpleArrayType, isSimpleArrayType, isSimpleArrayType, isSimpleArrayType, isSimpleArrayType, isSimpleArrayType, isSimpleType, isSimpleType, isSimpleType, isSimpleType, isSimpleType, isSimpleType, isWrapperArrayType, isWrapperArrayType, isWrapperArrayType, isWrapperArrayType, isWrapperArrayType, isWrapperArrayType, isWrapperType, isWrapperType, isWrapperType, isWrapperType, isWrapperType, isWrapperType, query, query, query, query, query, queryBetween, queryBetween, queryBetween, queryBetween, queryBetween, queryBetween, queryFrom, queryFrom, queryFrom, queryFrom, queryFrom, queryFrom, queryTo, queryTo, queryTo, queryTo, queryTo, queryTo, retrieveBetween, retrieveBetween, retrieveBetween, retrieveBetween, retrieveBetween, retrieveFrom, retrieveFrom, retrieveFrom, retrieveFrom, retrieveTo, retrieveTo, retrieveTo, retrieveTo, toMap, toPropertieswithInsert, withInsert, withInsertBetween, withInsertBetween, withInsertBetween, withInsertBetween, withInsertBetween, withInsertBetween, withInsertBetween, withInsertBetween, withInsertBetween, withInsertBetween, withInsertFrom, withInsertFrom, withInsertFrom, withInsertFrom, withInsertFrom, withInsertFrom, withInsertFrom, withInsertFrom, withInsertFrom, withInsertFrom, withInsertTo, withInsertTo, withInsertTo, withInsertTo, withInsertTo, withInsertTo, withInsertTo, withInsertTo, withInsertTo, withInsertTo, withMerge, withMerge, withMergeBetween, withMergeBetween, withMergeBetween, withMergeBetween, withMergeBetween, withMergeBetween, withMergeBetween, withMergeBetween, withMergeBetween, withMergeBetween, withMergeFrom, withMergeFrom, withMergeFrom, withMergeFrom, withMergeFrom, withMergeFrom, withMergeFrom, withMergeFrom, withMergeFrom, withMergeFrom, withMergeTo, withMergeTo, withMergeTo, withMergeTo, withMergeTo, withMergeTo, withMergeTo, withMergeTo, withMergeTo, withMergeTo, withPut, withPut, withPut, withPut, withPut, withPutDirAt, withPutDirAt, withPutDirAt, withPutDirAt, withPutDirAt, withPutDirAt, withPutDirAt, withPutDirAt, withPutDirAt, withPutDirAt, withPutDirAt, withPutDirAt, withRemoveFrom, withRemoveFrom, withRemoveFrom, withRemoveFrom, withRemoveFrom, withRemovePathscontainsValue, insert, insertBetween, insertFrom, insertTo, put, put, put, put, put, putAll, putAll, putAll, putDirAt, putDirAt, putDirAt, putDirAt, putDirAt, putDirAt, putDirAt, putDirAt, putDirAt, putDirAt, putDirAt, putDirAt, removeAll, removeAll, removeAll, removeAll, removeAll, removeAll, removeDirAt, removeDirAt, removeDirAt, removeDirAt, removeDirAt, removeFrom, removeFrom, removeFrom, removeFrom, removeFrom, removePaths, removePaths, toDumpisEmpty, sizeputclone, finalize, getClass, notify, notifyAll, wait, wait, waitchildren, children, children, children, children, children, containsKey, containsKey, containsKey, dirs, dirs, dirs, dirs, dirs, dirs, findPaths, fromExternalPath, get, get, get, getArray, getArray, getArray, getArray, getArray, getArrayIndexes, getArrayIndexes, getArrayIndexes, getArrayIndexes, getArrayIndexes, getDirIndexes, getDirIndexes, getDirIndexes, getDirIndexes, getDirIndexes, getRootPath, getValueAt, getValueAt, getValueAt, getValueAt, getValueAt, getValueAt, hasChildren, hasChildren, hasChildren, hasChildren, hasChildren, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasParentPath, hasPath, hasPath, hasPath, hasPath, hasSubDirs, hasSubDirs, hasSubDirs, hasSubDirs, hasValue, hasValue, hasValue, hasValue, hasValue, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, isArray, isArray, isArray, isArray, isArray, isArray, isChild, isChild, isChild, isChild, isDir, isDir, isDir, isDir, isDir, isEqualTo, isIndexDir, isIndexDir, isIndexDir, isIndexDir, isIndexDir, isLeaf, isLeaf, isLeaf, isLeaf, isLeaf, isRootPath, keySet, keySet, keySet, keySet, keySet, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastDirIndex, lastDirIndex, lastDirIndex, lastDirIndex, lastDirIndex, lastDirIndex, leaves, leaves, leaves, leaves, leaves, leaves, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextDirIndex, nextDirIndex, nextDirIndex, nextDirIndex, nextDirIndex, nextDirIndex, paths, paths, paths, paths, paths, paths, queryPaths, queryPaths, queryPaths, queryPaths, queryPaths, queryPaths, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, toDataStructure, toDataStructure, toExternalPath, toInstance, toInstance, toLeaf, toMap, toNormalizedPath, toParentPath, toPath, toPath, toPath, toPathElements, toPathList, toPathStack, toPropertyPath, toType, toTypeadd, add, add, add, add, add, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendValueTo, appendValueTo, appendValueTo, appendValueTo, appendValueTo, appendValueTo, delete, delete, delete, delete, delete, insert, insert, insertBetween, insertBetween, insertBetween, insertBetween, insertBetween, insertBetween, insertBetween, insertBetween, insertBetween, insertBetween, insertFrom, insertFrom, insertFrom, insertFrom, insertFrom, insertFrom, insertFrom, insertFrom, insertFrom, insertFrom, insertTo, insertTo, insertTo, insertTo, insertTo, insertTo, insertTo, insertTo, insertTo, insertTo, merge, merge, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeTo, mergeTo, mergeTo, mergeTo, mergeTo, mergeTo, mergeTo, mergeTo, mergeTo, mergeTo, put, putArray, putArray, putArray, putArray, putArray, putArray, putArray, putArray, putArray, putArray, putArray, putArray, putValueAt, putValueAt, putValueAt, putValueAt, putValueAt, putValueAt, remove, remove, remove, removeValueAt, removeValueAt, removeValueAt, removeValueAt, removeValueAt, toSourceCode, toSourceCodeclear, compute, computeIfAbsent, computeIfPresent, containsKey, containsValue, createBackingMap, entrySet, equals, forEach, fromValue, get, getAnnotator, getDelimiter, getOrDefault, getType, hashCode, insert, insertBetween, insertFrom, insertTo, isEmpty, keySet, merge, merge, mergeBetween, mergeFrom, mergeTo, put, putAll, putIfAbsent, remove, remove, replace, replace, replaceAll, size, toDataStructure, toString, valuespublic ClassStructMapBuilderImpl()
ClassStructMap.ClassStructMapBuilder instance using the default
path delimiter "/" (Delimiter.PATH) for the path declarations.public ClassStructMapBuilderImpl(char aDelimiter)
ClassStructMap.ClassStructMapBuilder instance using the provided path
delimiter for the path declarations.aDelimiter - The path delimiter to be used for the path
declarations.public ClassStructMapBuilderImpl(Object aObj)
ClassStructMap.ClassStructMapBuilder instance containing the elements
as of PathMap.MutablePathMap.insert(Object) using the default path
delimiter "/" (Delimiter.PATH) for the path declarations.aObj - The object from which the elements are to be added.public ClassStructMapBuilderImpl(String aToPath, Object aObj)
ClassStructMap.ClassStructMapBuilder instance containing the elements
as of PathMap.MutablePathMap.insert(Object) using the default path
delimiter "/" (Delimiter.PATH) for the path declarations.aToPath - The sub-path where to insert the object's introspected
values to.aObj - The object from which the elements are to be added.public ClassStructMapBuilderImpl(Object aObj, String aFromPath)
ClassStructMap.ClassStructMapBuilder instance containing the elements
as of PathMap.MutablePathMap.insert(Object) using the default path
delimiter "/" (Delimiter.PATH) for the path declarations.aObj - The object from which the elements are to be added.aFromPath - The path from where to start adding elements of the
provided object.public ClassStructMapBuilderImpl(String aToPath, Object aObj, String aFromPath)
ClassStructMap.ClassStructMapBuilder instance containing the elements
as of PathMap.MutablePathMap.insert(Object) using the default path
delimiter "/" (Delimiter.PATH for the path declarations.aToPath - The sub-path where to insert the object's introspected
values to.aObj - The object from which the elements are to be added.aFromPath - The path from where to start adding elements of the
provided object.public ClassStructMapBuilderImpl(Object aObj, char aDelimiter)
ClassStructMap.ClassStructMapBuilder instance containing the elements
as of PathMap.MutablePathMap.insert(Object).aObj - The object from which the elements are to be added.aDelimiter - The path delimiter to be used for the path
declarations.public ClassStructMapBuilderImpl(String aToPath, Object aObj, char aDelimiter)
ClassStructMap.ClassStructMapBuilder instance containing the elements
as of PathMap.MutablePathMap.insert(Object).aToPath - The sub-path where to insert the object's introspected
values to.aObj - The object from which the elements are to be added.aDelimiter - The path delimiter to be used for the path
declarations.public ClassStructMapBuilderImpl(Object aObj, String aFromPath, char aDelimiter)
ClassStructMap.ClassStructMapBuilder instance containing the elements
as of PathMap.MutablePathMap.insert(Object).aObj - The object from which the elements are to be added.aFromPath - The path from where to start adding elements of the
provided object.aDelimiter - The path delimiter to be used for the path
declarations.public ClassStructMapBuilderImpl(String aToPath, Object aObj, String aFromPath, char aDelimiter)
ClassStructMap.ClassStructMapBuilder instance containing the elements
as of PathMap.MutablePathMap.insert(Object).aToPath - The sub-path where to insert the object's introspected
values to.aObj - The object from which the elements are to be added.aFromPath - The path from where to start adding elements of the
provided object.aDelimiter - The path delimiter to be used for the path
declarations.public ClassStructMapBuilderImpl(SimpleType aTypeMode)
ClassStructMap.ClassStructMapBuilder instance using the default
path delimiter "/" (Delimiter.PATH) for the path declarations.aTypeMode - The SimpleType to use when processing primitive
types, wrapper types or complex types.public ClassStructMapBuilderImpl(char aDelimiter,
SimpleType aTypeMode)
ClassStructMap.ClassStructMapBuilder instance using the provided path
delimiter for the path declarations.aDelimiter - The path delimiter to be used for the path
declarations.aTypeMode - The SimpleType to use when processing primitive
types, wrapper types or complex types.public ClassStructMapBuilderImpl(Object aObj, SimpleType aTypeMode)
ClassStructMap.ClassStructMapBuilder instance containing the elements
as of PathMap.MutablePathMap.insert(Object) using the default path
delimiter "/" (Delimiter.PATH) for the path declarations.aObj - The object from which the elements are to be added.aTypeMode - The SimpleType to use when processing primitive
types, wrapper types or complex types.public ClassStructMapBuilderImpl(String aToPath, Object aObj, SimpleType aTypeMode)
ClassStructMap.ClassStructMapBuilder instance containing the elements
as of PathMap.MutablePathMap.insert(Object) using the default path
delimiter "/" (Delimiter.PATH) for the path declarations.aToPath - The sub-path where to insert the object's introspected
values to.aObj - The object from which the elements are to be added.aTypeMode - The SimpleType to use when processing primitive
types, wrapper types or complex types.public ClassStructMapBuilderImpl(Object aObj, String aFromPath, SimpleType aTypeMode)
ClassStructMap.ClassStructMapBuilder instance containing the elements
as of PathMap.MutablePathMap.insert(Object) using the default path
delimiter "/" (Delimiter.PATH) for the path declarations.aObj - The object from which the elements are to be added.aFromPath - The path from where to start adding elements of the
provided object.aTypeMode - The SimpleType to use when processing primitive
types, wrapper types or complex types.public ClassStructMapBuilderImpl(String aToPath, Object aObj, String aFromPath, SimpleType aTypeMode)
ClassStructMap.ClassStructMapBuilder instance containing the elements
as of PathMap.MutablePathMap.insert(Object) using the default path
delimiter "/" (Delimiter.PATH for the path declarations.aToPath - The sub-path where to insert the object's introspected
values to.aObj - The object from which the elements are to be added.aFromPath - The path from where to start adding elements of the
provided object.aTypeMode - The SimpleType to use when processing primitive
types, wrapper types or complex types.public ClassStructMapBuilderImpl(Object aObj, char aDelimiter, SimpleType aTypeMode)
ClassStructMap.ClassStructMapBuilder instance containing the elements
as of PathMap.MutablePathMap.insert(Object).aObj - The object from which the elements are to be added.aDelimiter - The path delimiter to be used for the path
declarations.aTypeMode - The SimpleType to use when processing primitive
types, wrapper types or complex types.public ClassStructMapBuilderImpl(String aToPath, Object aObj, char aDelimiter, SimpleType aTypeMode)
ClassStructMap.ClassStructMapBuilder instance containing the elements
as of PathMap.MutablePathMap.insert(Object).aToPath - The sub-path where to insert the object's introspected
values to.aObj - The object from which the elements are to be added.aDelimiter - The path delimiter to be used for the path
declarations.aTypeMode - The SimpleType to use when processing primitive
types, wrapper types or complex types.public ClassStructMapBuilderImpl(Object aObj, String aFromPath, char aDelimiter, SimpleType aTypeMode)
ClassStructMap.ClassStructMapBuilder instance containing the elements
as of PathMap.MutablePathMap.insert(Object).aObj - The object from which the elements are to be added.aFromPath - The path from where to start adding elements of the
provided object.aDelimiter - The path delimiter to be used for the path
declarations.aTypeMode - The SimpleType to use when processing primitive
types, wrapper types or complex types.public ClassStructMapBuilderImpl(String aToPath, Object aObj, String aFromPath, char aDelimiter, SimpleType aTypeMode)
ClassStructMap.ClassStructMapBuilder instance containing the elements
as of PathMap.MutablePathMap.insert(Object).aToPath - The sub-path where to insert the object's introspected
values to.aObj - The object from which the elements are to be added.aFromPath - The path from where to start adding elements of the
provided object.aDelimiter - The path delimiter to be used for the path
declarations.aTypeMode - The SimpleType to use when processing primitive
types, wrapper types or complex types.public SimpleType getTypeMode()
getTypeMode in interface TypeModeAccessorpublic ClassStructMap.ClassStructMapBuilder retrieveFrom(String aFromPath)
PathMap from the elements of this PathMap
found below the "from-path". The sub-paths will be the root paths for the
new PathMap. Given we have a value for path "/dog/cat" in the
PathMap and we call PathMap.retrieveFrom(String) with "/dog",
then the resulting PathMap will contain the path "/cat" for that
value.retrieveFrom in interface ClassStructMapretrieveFrom in interface PathMap<Class<?>>retrieveFrom in class PathMapBuilderImpl<Class<?>>aFromPath - The path from where to start extracting the paths.PathMap with the elements below the provided path
which are root elements in the new PathMap.public ClassStructMap.ClassStructMapBuilder retrieveTo(String aToPath)
PathMap from this PathMap's elements with
the paths relocated to the provided "to-path". Given we have a value for
path "/dog/cat" in the PathMap and we call
PathMap.retrieveTo(String) with "/animals", then the resulting
PathMap will contain the path "/animals/dog/cat" for that value.retrieveTo in interface ClassStructMapretrieveTo in interface PathMap<Class<?>>retrieveTo in class PathMapBuilderImpl<Class<?>>aToPath - The path where to relocate the paths of this
PathMap to.PathMap with the elements from the provided
PathMap with accordingly relocated paths.public ClassStructMap.ClassStructMapBuilder withPut(String aKey, Class<?> aValue)
Keys.MutableValues.put(Object, Object).withPut in interface Dictionary.MutableDictionary.DictionaryBuilder<String,T,PathMap.PathMapBuilder<T>>withPut in class PathMapBuilderImpl<Class<?>>aKey - the key for the property to be put.aValue - the value for the property to be put.protected void fromValue(String aToPath, Object aObj)
fromValue in class PathMapBuilderImpl<Class<?>>aToPath - The sub-path where to insert the object's introspected
values to.aObj - The object from which the elements are to be added.protected PathMap<Class<?>> fromObject(Object aFrom)
PathMap sub-types in the
according PathMap sub-type implementations.fromObject in class PathMapBuilderImpl<Class<?>>aFrom - The Object from which to create a PathMap
(sub-type) instance.PathMap (sub-type) instance.protected Class<?> toTypeInstance(Object aObj)
Class.isAssignableFrom(Class) with
the type retrieved by PathMapBuilderImpl.getType().toTypeInstance in class PathMapBuilderImpl<Class<?>>aObj - The object which is to be transformed to the expected type as
of PathMapBuilderImpl.getType().Copyright © 2021. All rights reserved.