org.refcodes.mixin.AnnotatorAccessor, org.refcodes.mixin.DelimiterAccessor, org.refcodes.mixin.Dumpable, org.refcodes.mixin.TypeAccessor<Class<?>>, ClassStructMap, Containable, Dictionary<String,T>, Keys<String,T>, PathMap<Class<?>>, TypeModeAccessorpublic class ClassStructMapImpl extends Object implements ClassStructMap
org.refcodes.mixin.AnnotatorAccessor.AnnotatorBuilder<B extends org.refcodes.mixin.AnnotatorAccessor.AnnotatorBuilder<B>>, org.refcodes.mixin.AnnotatorAccessor.AnnotatorMutator, org.refcodes.mixin.AnnotatorAccessor.AnnotatorPropertyClassStructMap.ClassStructMapBuilder, ClassStructMap.MutableClassStructMaporg.refcodes.mixin.DelimiterAccessor.DelimiterBuilder<B extends org.refcodes.mixin.DelimiterAccessor.DelimiterBuilder<B>>, org.refcodes.mixin.DelimiterAccessor.DelimiterMutator, org.refcodes.mixin.DelimiterAccessor.DelimiterPropertyDictionary.MutableDictionary<K,V>Keys.MutableKeys<K,V>, Keys.MutableValues<K,V>PathMap.MutablePathMap<T>, PathMap.PathMapBuilder<T>org.refcodes.mixin.TypeAccessor.TypeBuilder<T extends Object,B extends org.refcodes.mixin.TypeAccessor.TypeBuilder<T,B>>, org.refcodes.mixin.TypeAccessor.TypeMutator<T extends Object>, org.refcodes.mixin.TypeAccessor.TypeProperty<T extends Object>TypeModeAccessor.TypeModeBuilder<B extends TypeModeAccessor.TypeModeBuilder<B>>, TypeModeAccessor.TypeModeMutator, TypeModeAccessor.TypeModeProperty| Modifier and Type | Field | Description |
|---|---|---|
protected org.refcodes.struct.ClassStructMapImpl.OverridableClassStructMapBuilderImpl |
_classStructMap |
ARRAY_SELECTOR| Constructor | Description |
|---|---|
ClassStructMapImpl() |
Create an empty
ClassStructMap instance using the default path
delimiter "/" (Delimiter.PATH) for the path declarations. |
ClassStructMapImpl(char aDelimiter) |
Create a
ClassStructMap instance using the provided path
delimiter for the path declarations. |
ClassStructMapImpl(char aDelimiter,
SimpleType aTypeMode) |
Create a
ClassStructMap instance using the provided path
delimiter for the path declarations. |
ClassStructMapImpl(Object aObj) |
Create a
ClassStructMap instance containing the elements as of
PathMap.MutablePathMap.insert(Object) using the default path delimiter
"/" (Delimiter.PATH) for the path declarations. |
ClassStructMapImpl(Object aObj,
char aDelimiter) |
Creates a
ClassStructMap instance containing the elements as of
PathMap.MutablePathMap.insert(Object). |
ClassStructMapImpl(Object aObj,
char aDelimiter,
SimpleType aTypeMode) |
Creates a
ClassStructMap instance containing the elements as of
PathMap.MutablePathMap.insert(Object). |
ClassStructMapImpl(Object aObj,
String aFromPath) |
Creates a
ClassStructMap instance containing the elements as of
PathMap.MutablePathMap.insert(Object) using the default path delimiter
"/" (Delimiter.PATH) for the path declarations. |
ClassStructMapImpl(Object aObj,
String aFromPath,
char aDelimiter) |
Creates a
ClassStructMap instance containing the elements as of
PathMap.MutablePathMap.insert(Object). |
ClassStructMapImpl(Object aObj,
String aFromPath,
char aDelimiter,
SimpleType aTypeMode) |
Creates a
ClassStructMap instance containing the elements as of
PathMap.MutablePathMap.insert(Object). |
ClassStructMapImpl(Object aObj,
String aFromPath,
SimpleType aTypeMode) |
Creates a
ClassStructMap instance containing the elements as of
PathMap.MutablePathMap.insert(Object) using the default path delimiter
"/" (Delimiter.PATH) for the path declarations. |
ClassStructMapImpl(Object aObj,
SimpleType aTypeMode) |
Create a
ClassStructMap instance containing the elements as of
PathMap.MutablePathMap.insert(Object) using the default path delimiter
"/" (Delimiter.PATH) for the path declarations. |
ClassStructMapImpl(String aToPath,
Object aObj) |
Create a
ClassStructMap instance containing the elements as of
PathMap.MutablePathMap.insert(Object) using the default path delimiter
"/" (Delimiter.PATH) for the path declarations. |
ClassStructMapImpl(String aToPath,
Object aObj,
char aDelimiter) |
Creates a
ClassStructMap instance containing the elements as of
PathMap.MutablePathMap.insert(Object). |
ClassStructMapImpl(String aToPath,
Object aObj,
char aDelimiter,
SimpleType aTypeMode) |
Creates a
ClassStructMap instance containing the elements as of
PathMap.MutablePathMap.insert(Object). |
ClassStructMapImpl(String aToPath,
Object aObj,
String aFromPath) |
Creates a
ClassStructMap instance containing the elements as of
PathMap.MutablePathMap.insert(Object) using the default path delimiter
"/" (Delimiter.PATH for the path declarations. |
ClassStructMapImpl(String aToPath,
Object aObj,
String aFromPath,
char aDelimiter) |
Create a
ClassStructMap instance containing the elements as of
PathMap.MutablePathMap.insert(Object). |
ClassStructMapImpl(String aToPath,
Object aObj,
String aFromPath,
char aDelimiter,
SimpleType aTypeMode) |
Create a
ClassStructMap instance containing the elements as of
PathMap.MutablePathMap.insert(Object). |
ClassStructMapImpl(String aToPath,
Object aObj,
String aFromPath,
SimpleType aTypeMode) |
Creates a
ClassStructMap instance containing the elements as of
PathMap.MutablePathMap.insert(Object) using the default path delimiter
"/" (Delimiter.PATH for the path declarations. |
ClassStructMapImpl(String aToPath,
Object aObj,
SimpleType aTypeMode) |
Create a
ClassStructMap instance containing the elements as of
PathMap.MutablePathMap.insert(Object) using the default path delimiter
"/" (Delimiter.PATH) for the path declarations. |
ClassStructMapImpl(SimpleType aTypeMode) |
Create an empty
ClassStructMap instance using the default path
delimiter "/" (Delimiter.PATH) for the path declarations. |
| Modifier and Type | Method | Description |
|---|---|---|
boolean |
containsKey(Object aKey) |
Tests whether there is an element with the given key.
|
Class<?> |
get(Object aKey) |
Retrieves the element assigned to the given key.
|
char |
getAnnotator() |
|
String |
getArraySelector() |
Returns the array selector used in paths to identify an array type.
|
char |
getDelimiter() |
|
Class<Class<?>> |
getType() |
|
SimpleType |
getTypeMode() |
Retrieves the type mode from the type mode property.
|
boolean |
isEmpty() |
Tests whether the accumulation is empty or not.
|
Set<String> |
keySet() |
Retrieves a collection containing all the keys found in the elements of
this collection.
|
ClassStructMap |
retrieveFrom(String aFromPath) |
|
ClassStructMap |
retrieveTo(String aToPath) |
|
int |
size() |
Returns the number of data elements contained in the collection.
|
Object |
toDataStructure(String aFromPath) |
Similar to the
PathMap.toMap(String) method, though in case all the keys
of a nested Map instance (applicable to the root Map as
well) represent an array (as of PathMap.getArray( String)), then an
array is generated where the index of each value in the Map is
represented by the number representation of the Map's key for
that value. |
String |
toString() |
|
Collection<Class<?>> |
values() |
Returns a
Collection view of the values related to the contained
keys. |
containsValue, getCompositeArrayDir, getCompositeArrayDir, getCompositeArrayDir, getCompositeArrayDir, getCompositeArrayDir, getCompositeArrayDir, getCompositeDir, getCompositeDir, getCompositeDir, getCompositeDir, getCompositeDir, getCompositeDir, getDir, getDir, getDir, getDir, getDir, getDirAt, getDirAt, getDirAt, getDirAt, getDirAt, getDirAt, getPrimitiveArrayType, getPrimitiveArrayType, getPrimitiveArrayType, getPrimitiveArrayType, getPrimitiveArrayType, getPrimitiveArrayType, getPrimitiveType, getPrimitiveType, getPrimitiveType, getPrimitiveType, getPrimitiveType, getPrimitiveType, getSimpleArrayType, getSimpleArrayType, getSimpleArrayType, getSimpleArrayType, getSimpleArrayType, getSimpleArrayType, getSimpleType, getSimpleType, getSimpleType, getSimpleType, getSimpleType, getSimpleType, getWrapperArrayType, getWrapperArrayType, getWrapperArrayType, getWrapperArrayType, getWrapperArrayType, getWrapperArrayType, getWrapperType, getWrapperType, getWrapperType, getWrapperType, getWrapperType, getWrapperType, isArrayType, isArrayType, isArrayType, isArrayType, isArrayType, isArrayType, isCompositeArrayDir, isCompositeArrayDir, isCompositeArrayDir, isCompositeArrayDir, isCompositeArrayDir, isCompositeArrayDir, isCompositeDir, isCompositeDir, isCompositeDir, isCompositeDir, isCompositeDir, isCompositeDir, isPrimitiveArrayType, isPrimitiveArrayType, isPrimitiveArrayType, isPrimitiveArrayType, isPrimitiveArrayType, isPrimitiveArrayType, isPrimitiveType, isPrimitiveType, isPrimitiveType, isPrimitiveType, isPrimitiveType, isPrimitiveType, isSimpleArrayType, isSimpleArrayType, isSimpleArrayType, isSimpleArrayType, isSimpleArrayType, isSimpleArrayType, isSimpleType, isSimpleType, isSimpleType, isSimpleType, isSimpleType, isSimpleType, isWrapperArrayType, isWrapperArrayType, isWrapperArrayType, isWrapperArrayType, isWrapperArrayType, isWrapperArrayType, isWrapperType, isWrapperType, isWrapperType, isWrapperType, isWrapperType, isWrapperType, query, query, query, query, query, queryBetween, queryBetween, queryBetween, queryBetween, queryBetween, queryBetween, queryFrom, queryFrom, queryFrom, queryFrom, queryFrom, queryFrom, queryTo, queryTo, queryTo, queryTo, queryTo, queryTo, retrieveBetween, retrieveBetween, retrieveBetween, retrieveBetween, retrieveBetween, retrieveFrom, retrieveFrom, retrieveFrom, retrieveFrom, retrieveTo, retrieveTo, retrieveTo, retrieveTo, toMap, toPropertiesclone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitchildren, children, children, children, children, children, containsKey, containsKey, containsKey, dirs, dirs, dirs, dirs, dirs, dirs, findPaths, fromExternalPath, get, get, get, getArray, getArray, getArray, getArray, getArray, getArrayIndexes, getArrayIndexes, getArrayIndexes, getArrayIndexes, getArrayIndexes, getDirIndexes, getDirIndexes, getDirIndexes, getDirIndexes, getDirIndexes, getRootPath, getValueAt, getValueAt, getValueAt, getValueAt, getValueAt, getValueAt, hasChildren, hasChildren, hasChildren, hasChildren, hasChildren, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasParentPath, hasPath, hasPath, hasPath, hasPath, hasSubDirs, hasSubDirs, hasSubDirs, hasSubDirs, hasValue, hasValue, hasValue, hasValue, hasValue, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, isArray, isArray, isArray, isArray, isArray, isArray, isChild, isChild, isChild, isChild, isDir, isDir, isDir, isDir, isDir, isEqualTo, isIndexDir, isIndexDir, isIndexDir, isIndexDir, isIndexDir, isLeaf, isLeaf, isLeaf, isLeaf, isLeaf, isRootPath, keySet, keySet, keySet, keySet, keySet, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastDirIndex, lastDirIndex, lastDirIndex, lastDirIndex, lastDirIndex, lastDirIndex, leaves, leaves, leaves, leaves, leaves, leaves, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextDirIndex, nextDirIndex, nextDirIndex, nextDirIndex, nextDirIndex, nextDirIndex, paths, paths, paths, paths, paths, paths, queryPaths, queryPaths, queryPaths, queryPaths, queryPaths, queryPaths, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, toDataStructure, toExternalPath, toInstance, toInstance, toLeaf, toMap, toNormalizedPath, toParentPath, toPath, toPath, toPath, toPathElements, toPathList, toPathStack, toPropertyPath, toType, toTypeprotected org.refcodes.struct.ClassStructMapImpl.OverridableClassStructMapBuilderImpl _classStructMap
public ClassStructMapImpl()
ClassStructMap instance using the default path
delimiter "/" (Delimiter.PATH) for the path declarations.public ClassStructMapImpl(char aDelimiter)
ClassStructMap instance using the provided path
delimiter for the path declarations.aDelimiter - The path delimiter to be used for the path
declarations.public ClassStructMapImpl(Object aObj)
ClassStructMap instance containing the elements as of
PathMap.MutablePathMap.insert(Object) using the default path delimiter
"/" (Delimiter.PATH) for the path declarations.aObj - The object from which the elements are to be added.public ClassStructMapImpl(String aToPath, Object aObj)
ClassStructMap instance containing the elements as of
PathMap.MutablePathMap.insert(Object) using the default path delimiter
"/" (Delimiter.PATH) for the path declarations.aToPath - The sub-path where to insert the object's introspected
values to.aObj - The object from which the elements are to be added.public ClassStructMapImpl(Object aObj, String aFromPath)
ClassStructMap instance containing the elements as of
PathMap.MutablePathMap.insert(Object) using the default path delimiter
"/" (Delimiter.PATH) for the path declarations.aObj - The object from which the elements are to be added.aFromPath - The path from where to start adding elements of the
provided object.public ClassStructMapImpl(String aToPath, Object aObj, String aFromPath)
ClassStructMap instance containing the elements as of
PathMap.MutablePathMap.insert(Object) using the default path delimiter
"/" (Delimiter.PATH for the path declarations.aToPath - The sub-path where to insert the object's introspected
values to.aObj - The object from which the elements are to be added.aFromPath - The path from where to start adding elements of the
provided object.public ClassStructMapImpl(Object aObj, char aDelimiter)
ClassStructMap instance containing the elements as of
PathMap.MutablePathMap.insert(Object).aObj - The object from which the elements are to be added.aDelimiter - The path delimiter to be used for the path
declarations.public ClassStructMapImpl(String aToPath, Object aObj, char aDelimiter)
ClassStructMap instance containing the elements as of
PathMap.MutablePathMap.insert(Object).aToPath - The sub-path where to insert the object's introspected
values to.aObj - The object from which the elements are to be added.aDelimiter - The path delimiter to be used for the path
declarations.public ClassStructMapImpl(Object aObj, String aFromPath, char aDelimiter)
ClassStructMap instance containing the elements as of
PathMap.MutablePathMap.insert(Object).aObj - The object from which the elements are to be added.aFromPath - The path from where to start adding elements of the
provided object.aDelimiter - The path delimiter to be used for the path
declarations.public ClassStructMapImpl(String aToPath, Object aObj, String aFromPath, char aDelimiter)
ClassStructMap instance containing the elements as of
PathMap.MutablePathMap.insert(Object).aToPath - The sub-path where to insert the object's introspected
values to.aObj - The object from which the elements are to be added.aFromPath - The path from where to start adding elements of the
provided object.aDelimiter - The path delimiter to be used for the path
declarations.public ClassStructMapImpl(SimpleType aTypeMode)
ClassStructMap instance using the default path
delimiter "/" (Delimiter.PATH) for the path declarations.aTypeMode - The SimpleType to use when processing primitive
types, wrapper types or complex types.public ClassStructMapImpl(char aDelimiter,
SimpleType aTypeMode)
ClassStructMap instance using the provided path
delimiter for the path declarations.aDelimiter - The path delimiter to be used for the path
declarations.aTypeMode - The SimpleType to use when processing primitive
types, wrapper types or complex types.public ClassStructMapImpl(Object aObj, SimpleType aTypeMode)
ClassStructMap instance containing the elements as of
PathMap.MutablePathMap.insert(Object) using the default path delimiter
"/" (Delimiter.PATH) for the path declarations.aObj - The object from which the elements are to be added.aTypeMode - The SimpleType to use when processing primitive
types, wrapper types or complex types.public ClassStructMapImpl(String aToPath, Object aObj, SimpleType aTypeMode)
ClassStructMap instance containing the elements as of
PathMap.MutablePathMap.insert(Object) using the default path delimiter
"/" (Delimiter.PATH) for the path declarations.aToPath - The sub-path where to insert the object's introspected
values to.aObj - The object from which the elements are to be added.aTypeMode - The SimpleType to use when processing primitive
types, wrapper types or complex types.public ClassStructMapImpl(Object aObj, String aFromPath, SimpleType aTypeMode)
ClassStructMap instance containing the elements as of
PathMap.MutablePathMap.insert(Object) using the default path delimiter
"/" (Delimiter.PATH) for the path declarations.aObj - The object from which the elements are to be added.aFromPath - The path from where to start adding elements of the
provided object.aTypeMode - The SimpleType to use when processing primitive
types, wrapper types or complex types.public ClassStructMapImpl(String aToPath, Object aObj, String aFromPath, SimpleType aTypeMode)
ClassStructMap instance containing the elements as of
PathMap.MutablePathMap.insert(Object) using the default path delimiter
"/" (Delimiter.PATH for the path declarations.aToPath - The sub-path where to insert the object's introspected
values to.aObj - The object from which the elements are to be added.aFromPath - The path from where to start adding elements of the
provided object.aTypeMode - The SimpleType to use when processing primitive
types, wrapper types or complex types.public ClassStructMapImpl(Object aObj, char aDelimiter, SimpleType aTypeMode)
ClassStructMap instance containing the elements as of
PathMap.MutablePathMap.insert(Object).aObj - The object from which the elements are to be added.aDelimiter - The path delimiter to be used for the path
declarations.aTypeMode - The SimpleType to use when processing primitive
types, wrapper types or complex types.public ClassStructMapImpl(String aToPath, Object aObj, char aDelimiter, SimpleType aTypeMode)
ClassStructMap instance containing the elements as of
PathMap.MutablePathMap.insert(Object).aToPath - The sub-path where to insert the object's introspected
values to.aObj - The object from which the elements are to be added.aDelimiter - The path delimiter to be used for the path
declarations.aTypeMode - The SimpleType to use when processing primitive
types, wrapper types or complex types.public ClassStructMapImpl(Object aObj, String aFromPath, char aDelimiter, SimpleType aTypeMode)
ClassStructMap instance containing the elements as of
PathMap.MutablePathMap.insert(Object).aObj - The object from which the elements are to be added.aFromPath - The path from where to start adding elements of the
provided object.aDelimiter - The path delimiter to be used for the path
declarations.aTypeMode - The SimpleType to use when processing primitive
types, wrapper types or complex types.public ClassStructMapImpl(String aToPath, Object aObj, String aFromPath, char aDelimiter, SimpleType aTypeMode)
ClassStructMap instance containing the elements as of
PathMap.MutablePathMap.insert(Object).aToPath - The sub-path where to insert the object's introspected
values to.aObj - The object from which the elements are to be added.aFromPath - The path from where to start adding elements of the
provided object.aDelimiter - The path delimiter to be used for the path
declarations.aTypeMode - The SimpleType to use when processing primitive
types, wrapper types or complex types.public SimpleType getTypeMode()
getTypeMode in interface TypeModeAccessorpublic String getArraySelector()
getArraySelector in interface ClassStructMappublic boolean containsKey(Object aKey)
containsKey in interface Keys<String,T>aKey - The key for which to test whether there is an element.public Set<String> keySet()
public Collection<Class<?>> values()
Collection view of the values related to the contained
keys.values in interface Keys<String,T>Collection view of the values related to the contained
keys.public int size()
size in interface Containablepublic boolean isEmpty()
isEmpty in interface Containablepublic ClassStructMap retrieveFrom(String aFromPath)
PathMap from the elements of this PathMap
found below the "from-path". The sub-paths will be the root paths for the
new PathMap. Given we have a value for path "/dog/cat" in the
PathMap and we call PathMap.retrieveFrom(String) with "/dog",
then the resulting PathMap will contain the path "/cat" for that
value.retrieveFrom in interface ClassStructMapretrieveFrom in interface PathMap<Class<?>>aFromPath - The path from where to start extracting the paths.PathMap with the elements below the provided path
which are root elements in the new PathMap.public ClassStructMap retrieveTo(String aToPath)
PathMap from this PathMap's elements with
the paths relocated to the provided "to-path". Given we have a value for
path "/dog/cat" in the PathMap and we call
PathMap.retrieveTo(String) with "/animals", then the resulting
PathMap will contain the path "/animals/dog/cat" for that value.retrieveTo in interface ClassStructMapretrieveTo in interface PathMap<Class<?>>aToPath - The path where to relocate the paths of this
PathMap to.PathMap with the elements from the provided
PathMap with accordingly relocated paths.public char getAnnotator()
getAnnotator in interface org.refcodes.mixin.AnnotatorAccessorpublic char getDelimiter()
getDelimiter in interface org.refcodes.mixin.DelimiterAccessorpublic Class<Class<?>> getType()
getType in interface org.refcodes.mixin.TypeAccessor<Class<?>>public Object toDataStructure(String aFromPath)
PathMap.toMap(String) method, though in case all the keys
of a nested Map instance (applicable to the root Map as
well) represent an array (as of PathMap.getArray( String)), then an
array is generated where the index of each value in the Map is
represented by the number representation of the Map's key for
that value. The result is a data structure consisting of Map
instances and arrays.toDataStructure in interface PathMap<Class<?>>aFromPath - The path below which the PathMap to be converted
into a data structure.Map instances and
arrays representing the data below the given path.Copyright © 2021. All rights reserved.