CanonicalMap, CanonicalMap.CanonicalMapBuilder, CanonicalMap.MutableCanonicalMap, ClassStructMap, ClassStructMap.ClassStructMapBuilder, ClassStructMap.MutableClassStructMap, Container<E>, Container.ClearableContainer<E>, Container.MutableContainer<E>, Dictionary<K,V>, Dictionary.MutableDictionary<K,V>, Dictionary.MutableDictionary.DictionaryBuilder<K,V,B>, InterOperableMap<T>, InterOperableMap.InterOperableMapBuilder<T>, InterOperableMap.MutableInterOperableMap<T>, PathMap<T>, PathMap.MutablePathMap<T>, PathMap.PathMapBuilder<T>, SimpleTypeMap, SimpleTypeMap.MutableSimpleTypeMap, SimpleTypeMap.SimpleTypeMapBuilderCanonicalMapBuilderImpl, CanonicalMapImpl, ClassStructMapBuilderImpl, ClassStructMapImpl, PathMapBuilderImpl, PathMapImpl, SimpleTypeMapBuilderImpl, SimpleTypeMapImplpublic interface Containable
Containable is the base functionality provided container
(collection). The Containableit just informs about the metrics of a
container.| Modifier and Type | Method | Description |
|---|---|---|
boolean |
isEmpty() |
Tests whether the accumulation is empty or not.
|
int |
size() |
Returns the number of data elements contained in the collection.
|
int size()
boolean isEmpty()
Copyright © 2021. All rights reserved.