K - the key typeV - The type of the value which relates to a key.B - The builder to return in order to be able to apply
multiple build operations.org.refcodes.mixin.Clearable, Containable, Dictionary<K,V>, Dictionary.MutableDictionary<K,V>, Keys<K,V>, Keys.MutableKeys<K,V>, Keys.MutableValues<K,V>CanonicalMap.CanonicalMapBuilder, ClassStructMap.ClassStructMapBuilder, InterOperableMap.InterOperableMapBuilder<T>, PathMap.PathMapBuilder<T>, SimpleTypeMap.SimpleTypeMapBuilderCanonicalMapBuilderImpl, ClassStructMapBuilderImpl, PathMapBuilderImpl, SimpleTypeMapBuilderImplpublic static interface Dictionary.MutableDictionary.DictionaryBuilder<K,V,B extends Dictionary.MutableDictionary.DictionaryBuilder<K,V,B>> extends Dictionary.MutableDictionary<K,V>
Relation property returning
the builder for applying multiple build operations.Dictionary.MutableDictionary<K,V>Dictionary.MutableDictionary.DictionaryBuilder<K,V,B extends Dictionary.MutableDictionary.DictionaryBuilder<K,V,B>>Keys.MutableKeys<K,V>, Keys.MutableValues<K,V>| Modifier and Type | Method | Description |
|---|---|---|
B |
withPut(K aKey,
V aValue) |
Builder method for
Keys.MutableValues.put(Object, Object). |
B |
withPut(Relation<K,V> aRelation) |
Builder method for
Dictionary.MutableDictionary.put(Relation). |
isEmpty, sizeputcontainsKey, containsValue, get, getOr, keySet, use, valuesdeleteputB withPut(K aKey, V aValue)
Keys.MutableValues.put(Object, Object).aKey - the key for the property to be put.aValue - the value for the property to be put.B withPut(Relation<K,V> aRelation)
Dictionary.MutableDictionary.put(Relation).aRelation - the property to be put.Copyright © 2021. All rights reserved.