B - The builder to return in order to be able to apply multiple
build operations.public static interface DoubleArrayAccessor.DoubleArrayBuilder<B extends DoubleArrayAccessor.DoubleArrayBuilder<B>>
| Modifier and Type | Method | Description |
|---|---|---|
B |
withDoubles(double[] aDoubles) |
Sets the double array for the double array property.
|
B withDoubles(double[] aDoubles)
aDoubles - The double array to be stored by the double array
property.Copyright © 2021. All rights reserved.