E - The type of the elements being stored in the
Elements.MutableElements.Container<E>, Container.ClearableContainer<E>, Container.MutableContainer<E>, Elements.ClearableElements<E>, Elements.MutableElements<E>public interface Elements<E>
Elements (collection) style
class.| Modifier and Type | Interface | Description |
|---|---|---|
static interface |
Elements.ClearableElements<E> |
|
static interface |
Elements.MutableElements<E> |
Extends the
Elements with mutable (writable) functionality,
especially by enabling the Iterator.remove() method in the
Iterator provided via Elements.MutableElements.iterator() and by providing the
Elements.MutableElements.add(Object) and the Elements.MutableElements.remove(Object) methods. |
| Modifier and Type | Method | Description |
|---|---|---|
boolean |
contains(Object aElement) |
Tests whether the specified object is an element of the
Elements
(collection). |
Iterator<E> |
iterator() |
Returns an
Iterator instance of all the data elements contained
in the Elements (collection).
-------------------------------------------------------------------------
ATTENTION: The Iterator.remove() method may be disabled in the
returned Iterator instance as the Elements is supposed to
be read-only. |
Iterator<E> iterator()
Iterator instance of all the data elements contained
in the Elements (collection).
-------------------------------------------------------------------------
ATTENTION: The Iterator.remove() method may be disabled in the
returned Iterator instance as the Elements is supposed to
be read-only.boolean contains(Object aElement)
Copyright © 2021. All rights reserved.