T - The type of the terminating elements.org.refcodes.mixin.AnnotatorAccessor, org.refcodes.mixin.Clearable, Containable, org.refcodes.mixin.DelimiterAccessor, Dictionary<String,T>, Dictionary.MutableDictionary<String,T>, Dictionary.MutableDictionary.DictionaryBuilder<String,T,PathMap.PathMapBuilder<T>>, org.refcodes.mixin.Dumpable, Keys<K,V>, Keys.MutableKeys<K,V>, Keys.MutableValues<K,V>, Map<String,T>, PathMap<T>, PathMap.MutablePathMap<T>, org.refcodes.mixin.TypeAccessor<T>CanonicalMap.CanonicalMapBuilder, ClassStructMap.ClassStructMapBuilder, InterOperableMap.InterOperableMapBuilder<T>, SimpleTypeMap.SimpleTypeMapBuilderCanonicalMapBuilderImpl, ClassStructMapBuilderImpl, PathMapBuilderImpl, SimpleTypeMapBuilderImplpublic static interface PathMap.PathMapBuilder<T> extends PathMap.MutablePathMap<T>, Dictionary.MutableDictionary.DictionaryBuilder<String,T,PathMap.PathMapBuilder<T>>
PathMap.PathMapBuilder adds builder functionality to the
PathMap.MutablePathMap.org.refcodes.mixin.AnnotatorAccessor.AnnotatorBuilder<B extends org.refcodes.mixin.AnnotatorAccessor.AnnotatorBuilder<B>>, org.refcodes.mixin.AnnotatorAccessor.AnnotatorMutator, org.refcodes.mixin.AnnotatorAccessor.AnnotatorPropertyorg.refcodes.mixin.DelimiterAccessor.DelimiterBuilder<B extends org.refcodes.mixin.DelimiterAccessor.DelimiterBuilder<B>>, org.refcodes.mixin.DelimiterAccessor.DelimiterMutator, org.refcodes.mixin.DelimiterAccessor.DelimiterPropertyDictionary.MutableDictionary<K,V>Dictionary.MutableDictionary.DictionaryBuilder<K,V,B extends Dictionary.MutableDictionary.DictionaryBuilder<K,V,B>>Map.Entry<K extends Object,V extends Object>PathMap.MutablePathMap<T>, PathMap.PathMapBuilder<T>org.refcodes.mixin.TypeAccessor.TypeBuilder<T extends Object,B extends org.refcodes.mixin.TypeAccessor.TypeBuilder<T,B>>, org.refcodes.mixin.TypeAccessor.TypeMutator<T extends Object>, org.refcodes.mixin.TypeAccessor.TypeProperty<T extends Object>| Modifier and Type | Method | Description |
|---|---|---|
default PathMap.PathMapBuilder<T> |
withInsert(Object aObj) |
Convenience method for providing builder functionality to the
PathMap.MutablePathMap.insert(Object) method. |
default PathMap.PathMapBuilder<T> |
withInsert(PathMap<T> aFrom) |
Method to semantically emphasize that we support our own types.
|
default PathMap.PathMapBuilder<T> |
withInsertBetween(Object[] aToPathElements,
Object aFrom,
Object[] aFromPathElements) |
Convenience method for providing builder functionality to the
PathMap.MutablePathMap.insertBetween(String, Object, String) method. |
default PathMap.PathMapBuilder<T> |
withInsertBetween(Object[] aToPathElements,
PathMap<T> aFrom,
Object[] aFromPathElements) |
Method to semantically emphasize that we support our own types.
|
default PathMap.PathMapBuilder<T> |
withInsertBetween(Object aToPath,
Object aFrom,
Object aFromPath) |
Convenience method for providing builder functionality to the
PathMap.MutablePathMap.insertBetween(String, Object, String) method. |
default PathMap.PathMapBuilder<T> |
withInsertBetween(Object aToPath,
PathMap<T> aFrom,
Object aFromPath) |
Method to semantically emphasize that we support our own types.
|
default PathMap.PathMapBuilder<T> |
withInsertBetween(String[] aToPathElements,
Object aFrom,
String[] aFromPathElements) |
Convenience method for providing builder functionality to the
PathMap.MutablePathMap.insertBetween(String, Object, String) method. |
default PathMap.PathMapBuilder<T> |
withInsertBetween(String[] aToPathElements,
PathMap<T> aFrom,
String[] aFromPathElements) |
Method to semantically emphasize that we support our own types.
|
default PathMap.PathMapBuilder<T> |
withInsertBetween(String aToPath,
Object aFrom,
String aFromPath) |
Convenience method for providing builder functionality to the
PathMap.MutablePathMap.insertBetween(String, Object, String) method. |
default PathMap.PathMapBuilder<T> |
withInsertBetween(String aToPath,
PathMap<T> aFrom,
String aFromPath) |
Method to semantically emphasize that we support our own types.
|
default PathMap.PathMapBuilder<T> |
withInsertBetween(Collection<?> aToPathElements,
Object aFrom,
Collection<?> aFromPathElements) |
Convenience method for providing builder functionality to the
PathMap.MutablePathMap.insertBetween(String, Object, String) method. |
default PathMap.PathMapBuilder<T> |
withInsertBetween(Collection<?> aToPathElements,
PathMap<T> aFrom,
Collection<?> aFromPathElements) |
Method to semantically emphasize that we support our own types.
|
default PathMap.PathMapBuilder<T> |
withInsertFrom(Object aFrom,
Object aFromPath) |
Convenience method for providing builder functionality to the
PathMap.MutablePathMap.insertFrom(Object, String) method. |
default PathMap.PathMapBuilder<T> |
withInsertFrom(Object aFrom,
Object... aFromPathElements) |
Convenience method for providing builder functionality to the
PathMap.MutablePathMap.insertFrom(Object, String) method. |
default PathMap.PathMapBuilder<T> |
withInsertFrom(Object aFrom,
String aFromPath) |
Convenience method for providing builder functionality to the
PathMap.MutablePathMap.insertFrom(Object, String) method. |
default PathMap.PathMapBuilder<T> |
withInsertFrom(Object aFrom,
String... aFromPathElements) |
Convenience method for providing builder functionality to the
PathMap.MutablePathMap.insertFrom(Object, String) method. |
default PathMap.PathMapBuilder<T> |
withInsertFrom(Object aFrom,
Collection<?> aFromPathElements) |
Convenience method for providing builder functionality to the
PathMap.MutablePathMap.insertFrom(Object, String) method. |
default PathMap.PathMapBuilder<T> |
withInsertFrom(PathMap<T> aFrom,
Object aFromPath) |
Method to semantically emphasize that we support our own types.
|
default PathMap.PathMapBuilder<T> |
withInsertFrom(PathMap<T> aFrom,
Object... aFromPathElements) |
Method to semantically emphasize that we support our own types.
|
default PathMap.PathMapBuilder<T> |
withInsertFrom(PathMap<T> aFrom,
String aFromPath) |
Method to semantically emphasize that we support our own types.
|
default PathMap.PathMapBuilder<T> |
withInsertFrom(PathMap<T> aFrom,
String... aFromPathElements) |
Method to semantically emphasize that we support our own types.
|
default PathMap.PathMapBuilder<T> |
withInsertFrom(PathMap<T> aFrom,
Collection<?> aFromPathElements) |
Method to semantically emphasize that we support our own types.
|
default PathMap.PathMapBuilder<T> |
withInsertTo(Object[] aToPathElements,
Object aFrom) |
Convenience method for providing builder functionality to the
PathMap.MutablePathMap.insertTo(String, Object) method. |
default PathMap.PathMapBuilder<T> |
withInsertTo(Object[] aToPathElements,
PathMap<T> aFrom) |
Method to semantically emphasize that we support our own types.
|
default PathMap.PathMapBuilder<T> |
withInsertTo(Object aToPath,
Object aFrom) |
Convenience method for providing builder functionality to the
PathMap.MutablePathMap.insertTo(String, Object) method. |
default PathMap.PathMapBuilder<T> |
withInsertTo(Object aToPath,
PathMap<T> aFrom) |
Method to semantically emphasize that we support our own types.
|
default PathMap.PathMapBuilder<T> |
withInsertTo(String[] aToPathElements,
Object aFrom) |
Convenience method for providing builder functionality to the
PathMap.MutablePathMap.insertTo(String, Object) method. |
default PathMap.PathMapBuilder<T> |
withInsertTo(String[] aToPathElements,
PathMap<T> aFrom) |
Method to semantically emphasize that we support our own types.
|
default PathMap.PathMapBuilder<T> |
withInsertTo(String aToPath,
Object aFrom) |
Convenience method for providing builder functionality to the
PathMap.MutablePathMap.insertTo(String, Object) method. |
default PathMap.PathMapBuilder<T> |
withInsertTo(String aToPath,
PathMap<T> aFrom) |
Method to semantically emphasize that we support our own types.
|
default PathMap.PathMapBuilder<T> |
withInsertTo(Collection<?> aToPathElements,
Object aFrom) |
Convenience method for providing builder functionality to the
PathMap.MutablePathMap.insertTo(String, Object) method. |
default PathMap.PathMapBuilder<T> |
withInsertTo(Collection<?> aToPathElements,
PathMap<T> aFrom) |
Method to semantically emphasize that we support our own types.
|
default PathMap.PathMapBuilder<T> |
withMerge(Object aObj) |
Convenience method for providing builder functionality to the
PathMap.MutablePathMap.merge(Object) method. |
default PathMap.PathMapBuilder<T> |
withMerge(PathMap<T> aFrom) |
Method to semantically emphasize that we support our own types.
|
default PathMap.PathMapBuilder<T> |
withMergeBetween(Object[] aToPathElements,
Object aFrom,
Object[] aFromPathElements) |
Convenience method for providing builder functionality to the
PathMap.MutablePathMap.mergeBetween(String, Object, String) method. |
default PathMap.PathMapBuilder<T> |
withMergeBetween(Object[] aToPathElements,
PathMap<T> aFrom,
Object[] aFromPathElements) |
Method to semantically emphasize that we support our own types.
|
default PathMap.PathMapBuilder<T> |
withMergeBetween(Object aToPath,
Object aFrom,
Object aFromPath) |
Convenience method for providing builder functionality to the
PathMap.MutablePathMap.mergeBetween(String, Object, String) method. |
default PathMap.PathMapBuilder<T> |
withMergeBetween(Object aToPath,
PathMap<T> aFrom,
Object aFromPath) |
Method to semantically emphasize that we support our own types.
|
default PathMap.PathMapBuilder<T> |
withMergeBetween(String[] aToPathElements,
Object aFrom,
String[] aFromPathElements) |
Convenience method for providing builder functionality to the
PathMap.MutablePathMap.mergeBetween(String, Object, String) method. |
default PathMap.PathMapBuilder<T> |
withMergeBetween(String[] aToPathElements,
PathMap<T> aFrom,
String[] aFromPathElements) |
Method to semantically emphasize that we support our own types.
|
default PathMap.PathMapBuilder<T> |
withMergeBetween(String aToPath,
Object aFrom,
String aFromPath) |
Convenience method for providing builder functionality to the
PathMap.MutablePathMap.mergeBetween(String, Object, String) method. |
default PathMap.PathMapBuilder<T> |
withMergeBetween(String aToPath,
PathMap<T> aFrom,
String aFromPath) |
Method to semantically emphasize that we support our own types.
|
default PathMap.PathMapBuilder<T> |
withMergeBetween(Collection<?> aToPathElements,
Object aFrom,
Collection<?> aFromPathElements) |
Convenience method for providing builder functionality to the
PathMap.MutablePathMap.mergeBetween(String, Object, String) method. |
default PathMap.PathMapBuilder<T> |
withMergeBetween(Collection<?> aToPathElements,
PathMap<T> aFrom,
Collection<?> aFromPathElements) |
Method to semantically emphasize that we support our own types.
|
default PathMap.PathMapBuilder<T> |
withMergeFrom(Object aFrom,
Object aFromPath) |
Convenience method for providing builder functionality to the
PathMap.MutablePathMap.mergeFrom(Object, String) method. |
default PathMap.PathMapBuilder<T> |
withMergeFrom(Object aFrom,
Object... aFromPathElements) |
Convenience method for providing builder functionality to the
PathMap.MutablePathMap.mergeFrom(Object, String) method. |
default PathMap.PathMapBuilder<T> |
withMergeFrom(Object aFrom,
String aFromPath) |
Convenience method for providing builder functionality to the
PathMap.MutablePathMap.mergeFrom(Object, String) method. |
default PathMap.PathMapBuilder<T> |
withMergeFrom(Object aFrom,
String... aFromPathElements) |
Convenience method for providing builder functionality to the
PathMap.MutablePathMap.mergeFrom(Object, String) method. |
default PathMap.PathMapBuilder<T> |
withMergeFrom(Object aFrom,
Collection<?> aFromPathElements) |
Convenience method for providing builder functionality to the
PathMap.MutablePathMap.mergeFrom(Object, String) method. |
default PathMap.PathMapBuilder<T> |
withMergeFrom(PathMap<T> aFrom,
Object aFromPath) |
Method to semantically emphasize that we support our own types.
|
default PathMap.PathMapBuilder<T> |
withMergeFrom(PathMap<T> aFrom,
Object... aFromPathElements) |
Method to semantically emphasize that we support our own types.
|
default PathMap.PathMapBuilder<T> |
withMergeFrom(PathMap<T> aFrom,
String aFromPath) |
Method to semantically emphasize that we support our own types.
|
default PathMap.PathMapBuilder<T> |
withMergeFrom(PathMap<T> aFrom,
String... aFromPathElements) |
Method to semantically emphasize that we support our own types.
|
default PathMap.PathMapBuilder<T> |
withMergeFrom(PathMap<T> aFrom,
Collection<?> aFromPathElements) |
Method to semantically emphasize that we support our own types.
|
default PathMap.PathMapBuilder<T> |
withMergeTo(Object[] aToPathElements,
Object aFrom) |
Convenience method for providing builder functionality to the
PathMap.MutablePathMap.mergeTo(String, Object) method. |
default PathMap.PathMapBuilder<T> |
withMergeTo(Object[] aToPathElements,
PathMap<T> aFrom) |
Method to semantically emphasize that we support our own types.
|
default PathMap.PathMapBuilder<T> |
withMergeTo(Object aToPath,
Object aFrom) |
Convenience method for providing builder functionality to the
PathMap.MutablePathMap.mergeTo(String, Object) method. |
default PathMap.PathMapBuilder<T> |
withMergeTo(Object aToPath,
PathMap<T> aFrom) |
Method to semantically emphasize that we support our own types.
|
default PathMap.PathMapBuilder<T> |
withMergeTo(String[] aToPathElements,
Object aFrom) |
Convenience method for providing builder functionality to the
PathMap.MutablePathMap.mergeTo(String, Object) method. |
default PathMap.PathMapBuilder<T> |
withMergeTo(String[] aToPathElements,
PathMap<T> aFrom) |
Method to semantically emphasize that we support our own types.
|
default PathMap.PathMapBuilder<T> |
withMergeTo(String aToPath,
Object aFrom) |
Convenience method for providing builder functionality to the
PathMap.MutablePathMap.mergeTo(String, Object) method. |
default PathMap.PathMapBuilder<T> |
withMergeTo(String aToPath,
PathMap<T> aFrom) |
Method to semantically emphasize that we support our own types.
|
default PathMap.PathMapBuilder<T> |
withMergeTo(Collection<?> aToPathElements,
Object aFrom) |
Convenience method for providing builder functionality to the
PathMap.MutablePathMap.mergeTo(String, Object) method. |
default PathMap.PathMapBuilder<T> |
withMergeTo(Collection<?> aToPathElements,
PathMap<T> aFrom) |
Method to semantically emphasize that we support our own types.
|
default PathMap.PathMapBuilder<T> |
withPut(Object[] aPathElements,
T aValue) |
Builder method for
Keys.MutableValues.put(Object, Object). |
default PathMap.PathMapBuilder<T> |
withPut(String[] aPathElements,
T aValue) |
Builder method for
Keys.MutableValues.put(Object, Object). |
default PathMap.PathMapBuilder<T> |
withPut(Collection<?> aPathElements,
T aValue) |
Builder method for
Keys.MutableValues.put(Object, Object). |
default PathMap.PathMapBuilder<T> |
withPut(Relation<String,T> aRelation) |
Builder method for
Dictionary.MutableDictionary.put(Relation). |
default PathMap<T> |
withPutDirAt(int aIndex,
Object aDir) |
An indexed directory represents all elements which begin with a path
which's last path element represents an index.
|
default PathMap<T> |
withPutDirAt(int aIndex,
PathMap<T> aDir) |
An indexed directory represents all elements which begin with a path
which's last path element represents an index.
|
default PathMap<T> |
withPutDirAt(Object[] aPathElements,
int aIndex,
Object aDir) |
An indexed directory represents all elements which begin with a path
which's last path element represents an index.
|
default PathMap<T> |
withPutDirAt(Object[] aPathElements,
int aIndex,
PathMap<T> aDir) |
An indexed directory represents all elements which begin with a path
which's last path element represents an index.
|
default PathMap<T> |
withPutDirAt(Object aPath,
int aIndex,
Object aDir) |
An indexed directory represents all elements which begin with a path
which's last path element represents an index.
|
default PathMap<T> |
withPutDirAt(Object aPath,
int aIndex,
PathMap<T> aDir) |
An indexed directory represents all elements which begin with a path
which's last path element represents an index.
|
default PathMap<T> |
withPutDirAt(String[] aPathElements,
int aIndex,
Object aDir) |
An indexed directory represents all elements which begin with a path
which's last path element represents an index.
|
default PathMap<T> |
withPutDirAt(String[] aPathElements,
int aIndex,
PathMap<T> aDir) |
An indexed directory represents all elements which begin with a path
which's last path element represents an index.
|
default PathMap<T> |
withPutDirAt(String aPath,
int aIndex,
Object aDir) |
An indexed directory represents all elements which begin with a path
which's last path element represents an index.
|
default PathMap<T> |
withPutDirAt(String aPath,
int aIndex,
PathMap<T> aDir) |
An indexed directory represents all elements which begin with a path
which's last path element represents an index.
|
default PathMap<T> |
withPutDirAt(Collection<?> aPathElements,
int aIndex,
Object aDir) |
An indexed directory represents all elements which begin with a path
which's last path element represents an index.
|
default PathMap<T> |
withPutDirAt(Collection<?> aPathElements,
int aIndex,
PathMap<T> aDir) |
An indexed directory represents all elements which begin with a path
which's last path element represents an index.
|
default PathMap.PathMapBuilder<T> |
withRemoveFrom(Object aPath) |
Convenience method for providing builder functionality to the
PathMap.MutablePathMap.removeFrom( String) method. |
default PathMap.PathMapBuilder<T> |
withRemoveFrom(Object... aPathElements) |
Convenience method for providing builder functionality to the
PathMap.MutablePathMap.removeFrom( String) method. |
default PathMap.PathMapBuilder<T> |
withRemoveFrom(String aPath) |
Convenience method for providing builder functionality to the
PathMap.MutablePathMap.removeFrom( String) method. |
default PathMap.PathMapBuilder<T> |
withRemoveFrom(String... aPathElements) |
Convenience method for providing builder functionality to the
PathMap.MutablePathMap.removeFrom( String) method. |
default PathMap.PathMapBuilder<T> |
withRemoveFrom(Collection<?> aPathElements) |
Convenience method for providing builder functionality to the
PathMap.MutablePathMap.removeFrom( String) method. |
default PathMap.PathMapBuilder<T> |
withRemovePaths(String... aPathElements) |
Convenience method for providing builder functionality to the
PathMap.MutablePathMap.removeFrom( String) method. |
isEmpty, sizewithPutputclear, compute, computeIfAbsent, computeIfPresent, containsKey, containsValue, entry, entrySet, equals, forEach, get, getOrDefault, hashCode, isEmpty, keySet, merge, of, of, of, of, of, of, of, of, of, of, of, ofEntries, put, putAll, putIfAbsent, remove, remove, replace, replace, replaceAll, size, valueschildren, children, children, children, children, children, containsKey, containsKey, containsKey, dirs, dirs, dirs, dirs, dirs, dirs, findPaths, fromExternalPath, get, get, get, getArray, getArray, getArray, getArray, getArray, getArrayIndexes, getArrayIndexes, getArrayIndexes, getArrayIndexes, getArrayIndexes, getDir, getDir, getDir, getDir, getDir, getDirAt, getDirAt, getDirAt, getDirAt, getDirAt, getDirAt, getDirIndexes, getDirIndexes, getDirIndexes, getDirIndexes, getDirIndexes, getRootPath, getValueAt, getValueAt, getValueAt, getValueAt, getValueAt, getValueAt, hasChildren, hasChildren, hasChildren, hasChildren, hasChildren, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasParentPath, hasPath, hasPath, hasPath, hasPath, hasSubDirs, hasSubDirs, hasSubDirs, hasSubDirs, hasValue, hasValue, hasValue, hasValue, hasValue, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, isArray, isArray, isArray, isArray, isArray, isArray, isChild, isChild, isChild, isChild, isDir, isDir, isDir, isDir, isDir, isEqualTo, isIndexDir, isIndexDir, isIndexDir, isIndexDir, isIndexDir, isLeaf, isLeaf, isLeaf, isLeaf, isLeaf, isRootPath, keySet, keySet, keySet, keySet, keySet, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastDirIndex, lastDirIndex, lastDirIndex, lastDirIndex, lastDirIndex, lastDirIndex, leaves, leaves, leaves, leaves, leaves, leaves, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextDirIndex, nextDirIndex, nextDirIndex, nextDirIndex, nextDirIndex, nextDirIndex, paths, paths, paths, paths, paths, paths, query, query, query, query, query, queryBetween, queryBetween, queryBetween, queryBetween, queryBetween, queryBetween, queryFrom, queryFrom, queryFrom, queryFrom, queryFrom, queryFrom, queryPaths, queryPaths, queryPaths, queryPaths, queryPaths, queryPaths, queryTo, queryTo, queryTo, queryTo, queryTo, queryTo, retrieveBetween, retrieveBetween, retrieveBetween, retrieveBetween, retrieveBetween, retrieveFrom, retrieveFrom, retrieveFrom, retrieveFrom, retrieveFrom, retrieveTo, retrieveTo, retrieveTo, retrieveTo, retrieveTo, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, toDataStructure, toDataStructure, toExternalPath, toInstance, toInstance, toLeaf, toMap, toMap, toNormalizedPath, toParentPath, toPath, toPath, toPath, toPathElements, toPathList, toPathStack, toPropertyPath, toType, toTypeadd, add, add, add, add, add, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendValueTo, appendValueTo, appendValueTo, appendValueTo, appendValueTo, appendValueTo, delete, delete, delete, delete, delete, insert, insert, insertBetween, insertBetween, insertBetween, insertBetween, insertBetween, insertBetween, insertBetween, insertBetween, insertBetween, insertBetween, insertFrom, insertFrom, insertFrom, insertFrom, insertFrom, insertFrom, insertFrom, insertFrom, insertFrom, insertFrom, insertTo, insertTo, insertTo, insertTo, insertTo, insertTo, insertTo, insertTo, insertTo, insertTo, merge, merge, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeTo, mergeTo, mergeTo, mergeTo, mergeTo, mergeTo, mergeTo, mergeTo, mergeTo, mergeTo, put, put, put, put, putArray, putArray, putArray, putArray, putArray, putArray, putArray, putArray, putArray, putArray, putArray, putArray, putDirAt, putDirAt, putDirAt, putDirAt, putDirAt, putDirAt, putDirAt, putDirAt, putDirAt, putDirAt, putDirAt, putDirAt, putValueAt, putValueAt, putValueAt, putValueAt, putValueAt, putValueAt, remove, remove, remove, removeAll, removeAll, removeAll, removeAll, removeAll, removeAll, removeDirAt, removeDirAt, removeDirAt, removeDirAt, removeDirAt, removeFrom, removeFrom, removeFrom, removeFrom, removeFrom, removePaths, removePaths, removeValueAt, removeValueAt, removeValueAt, removeValueAt, removeValueAt, toSourceCode, toSourceCodedefault PathMap.PathMapBuilder<T> withInsert(Object aObj)
PathMap.MutablePathMap.insert(Object) method.aObj - the objPathMap.MutablePathMap.insert(Object)default PathMap.PathMapBuilder<T> withInsert(PathMap<T> aFrom)
PathMap.MutablePathMap.insert(Object).aFrom - The PathMap which is to be inspected with the
therein contained values being added with their according
determined paths.PathMap.MutablePathMap.insert(Object)default PathMap.PathMapBuilder<T> withInsertBetween(Collection<?> aToPathElements, Object aFrom, Collection<?> aFromPathElements)
PathMap.MutablePathMap.insertBetween(String, Object, String) method.aToPathElements - The path elements of the to-path.aFrom - the fromaFromPathElements - The path elements of the from-path.PathMap.MutablePathMap.insertBetween(String, Object, String)default PathMap.PathMapBuilder<T> withInsertBetween(Collection<?> aToPathElements, PathMap<T> aFrom, Collection<?> aFromPathElements)
PathMap.MutablePathMap.insertBetween(String, Object, String).aToPathElements - The path elements of the sub-path where to
insert the object's introspected values to.aFrom - The PathMap which is to be inspected with the
therein contained values being added with their according
determined paths.aFromPathElements - The path elements of the path from where to
start adding elements of the provided object.PathMap.MutablePathMap.insertBetween(String, Object, String)default PathMap.PathMapBuilder<T> withInsertBetween(Object aToPath, Object aFrom, Object aFromPath)
PathMap.MutablePathMap.insertBetween(String, Object, String) method.aToPath - The to-path.aFrom - the fromaFromPath - The from-path.PathMap.MutablePathMap.insertBetween(String, Object, String)default PathMap.PathMapBuilder<T> withInsertBetween(Object aToPath, PathMap<T> aFrom, Object aFromPath)
PathMap.MutablePathMap.insertBetween(String, Object, String).aToPath - The sub-path where to insert the object's introspected
values to.aFrom - The PathMap which is to be inspected with the
therein contained values being added with their according
determined paths.aFromPath - The path from where to start adding elements of the
provided object.PathMap.MutablePathMap.insertBetween(String, Object, String)default PathMap.PathMapBuilder<T> withInsertBetween(Object[] aToPathElements, Object aFrom, Object[] aFromPathElements)
PathMap.MutablePathMap.insertBetween(String, Object, String) method.aToPathElements - The path elements of the to-path.aFrom - the fromaFromPathElements - The path elements of the from-path.PathMap.MutablePathMap.insertBetween(String, Object, String)default PathMap.PathMapBuilder<T> withInsertBetween(Object[] aToPathElements, PathMap<T> aFrom, Object[] aFromPathElements)
PathMap.MutablePathMap.insertBetween(String, Object, String).aToPathElements - The path elements of the sub-path where to
insert the object's introspected values to.aFrom - The PathMap which is to be inspected with the
therein contained values being added with their according
determined paths.aFromPathElements - The path elements of the path from where to
start adding elements of the provided object.PathMap.MutablePathMap.insertBetween(String, Object, String)default PathMap.PathMapBuilder<T> withInsertBetween(String aToPath, Object aFrom, String aFromPath)
PathMap.MutablePathMap.insertBetween(String, Object, String) method.aToPath - The to-path.aFrom - the fromaFromPath - The from-path.PathMap.MutablePathMap.insertBetween(String, Object, String)default PathMap.PathMapBuilder<T> withInsertBetween(String aToPath, PathMap<T> aFrom, String aFromPath)
PathMap.MutablePathMap.insertBetween(String, Object, String).aToPath - The sub-path where to insert the object's introspected
values to.aFrom - The PathMap which is to be inspected with the
therein contained values being added with their according
determined paths.aFromPath - The path from where to start adding elements of the
provided object.PathMap.MutablePathMap.insertBetween(String, Object, String)default PathMap.PathMapBuilder<T> withInsertBetween(String[] aToPathElements, Object aFrom, String[] aFromPathElements)
PathMap.MutablePathMap.insertBetween(String, Object, String) method.aToPathElements - The path elements of the to-path.aFrom - the fromaFromPathElements - The path elements of the from-path.PathMap.MutablePathMap.insertBetween(String, Object, String)default PathMap.PathMapBuilder<T> withInsertBetween(String[] aToPathElements, PathMap<T> aFrom, String[] aFromPathElements)
PathMap.MutablePathMap.insertBetween(String, Object, String).aToPathElements - The path elements of the sub-path where to
insert the object's introspected values to.aFrom - The PathMap which is to be inspected with the
therein contained values being added with their according
determined paths.aFromPathElements - The path elements of the path from where to
start adding elements of the provided object.PathMap.MutablePathMap.insertBetween(String, Object, String)default PathMap.PathMapBuilder<T> withInsertFrom(Object aFrom, Collection<?> aFromPathElements)
PathMap.MutablePathMap.insertFrom(Object, String) method.aFrom - the fromaFromPathElements - The path elements representing the
from-path.PathMap.MutablePathMap.insertFrom(Object, String)default PathMap.PathMapBuilder<T> withInsertFrom(Object aFrom, Object aFromPath)
PathMap.MutablePathMap.insertFrom(Object, String) method.aFrom - the fromaFromPath - The from-path.PathMap.MutablePathMap.insertFrom(Object, String)default PathMap.PathMapBuilder<T> withInsertFrom(Object aFrom, Object... aFromPathElements)
PathMap.MutablePathMap.insertFrom(Object, String) method.aFrom - the fromaFromPathElements - The path elements representing the
from-path.PathMap.MutablePathMap.insertFrom(Object, String)default PathMap.PathMapBuilder<T> withInsertFrom(Object aFrom, String aFromPath)
PathMap.MutablePathMap.insertFrom(Object, String) method.aFrom - the fromaFromPath - The from-path.PathMap.MutablePathMap.insertFrom(Object, String)default PathMap.PathMapBuilder<T> withInsertFrom(Object aFrom, String... aFromPathElements)
PathMap.MutablePathMap.insertFrom(Object, String) method.aFrom - the fromaFromPathElements - The path elements representing the
from-path.PathMap.MutablePathMap.insertFrom(Object, String)default PathMap.PathMapBuilder<T> withInsertFrom(PathMap<T> aFrom, Collection<?> aFromPathElements)
PathMap.MutablePathMap.insertFrom(Object, String).aFrom - The PathMap which is to be inspected with the
therein contained values being added with their according
determined paths.aFromPathElements - The path elements representing the path from
where to start adding elements of the provided object.PathMap.MutablePathMap.insertFrom(Object, String)default PathMap.PathMapBuilder<T> withInsertFrom(PathMap<T> aFrom, Object aFromPath)
PathMap.MutablePathMap.insertFrom(Object, String).aFrom - The PathMap which is to be inspected with the
therein contained values being added with their according
determined paths.aFromPath - The path from where to start adding elements of the
provided object.PathMap.MutablePathMap.insertFrom(Object, String)default PathMap.PathMapBuilder<T> withInsertFrom(PathMap<T> aFrom, Object... aFromPathElements)
PathMap.MutablePathMap.insertFrom(Object, String).aFrom - The PathMap which is to be inspected with the
therein contained values being added with their according
determined paths.aFromPathElements - The path elements representing the path from
where to start adding elements of the provided object.PathMap.MutablePathMap.insertFrom(Object, String)default PathMap.PathMapBuilder<T> withInsertFrom(PathMap<T> aFrom, String aFromPath)
PathMap.MutablePathMap.insertFrom(Object, String).aFrom - The PathMap which is to be inspected with the
therein contained values being added with their according
determined paths.aFromPath - The path from where to start adding elements of the
provided object.PathMap.MutablePathMap.insertFrom(Object, String)default PathMap.PathMapBuilder<T> withInsertFrom(PathMap<T> aFrom, String... aFromPathElements)
PathMap.MutablePathMap.insertFrom(Object, String).aFrom - The PathMap which is to be inspected with the
therein contained values being added with their according
determined paths.aFromPathElements - The path elements representing the path from
where to start adding elements of the provided object.PathMap.MutablePathMap.insertFrom(Object, String)default PathMap.PathMapBuilder<T> withInsertTo(Collection<?> aToPathElements, Object aFrom)
PathMap.MutablePathMap.insertTo(String, Object) method.aToPathElements - The path elements representing the to-path.aFrom - the fromPathMap.MutablePathMap.insertTo(String, Object)default PathMap.PathMapBuilder<T> withInsertTo(Collection<?> aToPathElements, PathMap<T> aFrom)
PathMap.MutablePathMap.insertTo(String, Object).aToPathElements - The path elements representing the sub-path
where to insert the object's introspected values to.aFrom - The PathMap which is to be inspected with the
therein contained values being added with their according
determined paths.PathMap.MutablePathMap.insertTo(String, Object)default PathMap.PathMapBuilder<T> withInsertTo(Object aToPath, Object aFrom)
PathMap.MutablePathMap.insertTo(String, Object) method.aToPath - The to-path.aFrom - the fromPathMap.MutablePathMap.insertTo(String, Object)default PathMap.PathMapBuilder<T> withInsertTo(Object aToPath, PathMap<T> aFrom)
PathMap.MutablePathMap.insertTo(String, Object).aToPath - The sub-path where to insert the object's introspected
values to.aFrom - The PathMap which is to be inspected with the
therein contained values being added with their according
determined paths.PathMap.MutablePathMap.insertTo(String, Object)default PathMap.PathMapBuilder<T> withInsertTo(Object[] aToPathElements, Object aFrom)
PathMap.MutablePathMap.insertTo(String, Object) method.aToPathElements - The path elements representing the to-path.aFrom - the fromPathMap.MutablePathMap.insertTo(String, Object)default PathMap.PathMapBuilder<T> withInsertTo(Object[] aToPathElements, PathMap<T> aFrom)
PathMap.MutablePathMap.insertTo(String, Object).aToPathElements - The path elements representing the sub-path
where to insert the object's introspected values to.aFrom - The PathMap which is to be inspected with the
therein contained values being added with their according
determined paths.PathMap.MutablePathMap.insertTo(String, Object)default PathMap.PathMapBuilder<T> withInsertTo(String aToPath, Object aFrom)
PathMap.MutablePathMap.insertTo(String, Object) method.aToPath - The to-path.aFrom - the fromPathMap.MutablePathMap.insertTo(String, Object)default PathMap.PathMapBuilder<T> withInsertTo(String aToPath, PathMap<T> aFrom)
PathMap.MutablePathMap.insertTo(String, Object).aToPath - The sub-path where to insert the object's introspected
values to.aFrom - The PathMap which is to be inspected with the
therein contained values being added with their according
determined paths.PathMap.MutablePathMap.insertTo(String, Object)default PathMap.PathMapBuilder<T> withInsertTo(String[] aToPathElements, Object aFrom)
PathMap.MutablePathMap.insertTo(String, Object) method.aToPathElements - The path elements representing the to-path.aFrom - the fromPathMap.MutablePathMap.insertTo(String, Object)default PathMap.PathMapBuilder<T> withInsertTo(String[] aToPathElements, PathMap<T> aFrom)
PathMap.MutablePathMap.insertTo(String, Object).aToPathElements - The path elements representing the sub-path
where to insert the object's introspected values to.aFrom - The PathMap which is to be inspected with the
therein contained values being added with their according
determined paths.PathMap.MutablePathMap.insertTo(String, Object)default PathMap.PathMapBuilder<T> withMerge(Object aObj)
PathMap.MutablePathMap.merge(Object) method.aObj - the objPathMap.MutablePathMap.merge(Object)default PathMap.PathMapBuilder<T> withMerge(PathMap<T> aFrom)
PathMap.MutablePathMap.merge(Object).aFrom - The PathMap which is to be inspected with the
therein contained values being added with their according
determined paths.PathMap.MutablePathMap.merge(Object)default PathMap.PathMapBuilder<T> withMergeBetween(Collection<?> aToPathElements, Object aFrom, Collection<?> aFromPathElements)
PathMap.MutablePathMap.mergeBetween(String, Object, String) method.aToPathElements - The path elements of the to-path.aFrom - the fromaFromPathElements - The path elements of the from-path.PathMap.MutablePathMap.mergeBetween(String, Object, String)default PathMap.PathMapBuilder<T> withMergeBetween(Collection<?> aToPathElements, PathMap<T> aFrom, Collection<?> aFromPathElements)
PathMap.MutablePathMap.mergeBetween(String, Object, String).aToPathElements - The path elements of the sub-path where to
merge the object's introspected values to.aFrom - The PathMap which is to be inspected with the
therein contained values being added with their according
determined paths.aFromPathElements - The path elements of the path from where to
start adding elements of the provided object.PathMap.MutablePathMap.mergeBetween(String, Object, String)default PathMap.PathMapBuilder<T> withMergeBetween(Object aToPath, Object aFrom, Object aFromPath)
PathMap.MutablePathMap.mergeBetween(String, Object, String) method.aToPath - The to-path.aFrom - the fromaFromPath - The from-path.PathMap.MutablePathMap.mergeBetween(String, Object, String)default PathMap.PathMapBuilder<T> withMergeBetween(Object aToPath, PathMap<T> aFrom, Object aFromPath)
PathMap.MutablePathMap.mergeBetween(String, Object, String).aToPath - The sub-path where to merge the object's introspected
values to.aFrom - The PathMap which is to be inspected with the
therein contained values being added with their according
determined paths.aFromPath - The path from where to start adding elements of the
provided object.PathMap.MutablePathMap.mergeBetween(String, Object, String)default PathMap.PathMapBuilder<T> withMergeBetween(Object[] aToPathElements, Object aFrom, Object[] aFromPathElements)
PathMap.MutablePathMap.mergeBetween(String, Object, String) method.aToPathElements - The path elements of the to-path.aFrom - the fromaFromPathElements - The path elements of the from-path.PathMap.MutablePathMap.mergeBetween(String, Object, String)default PathMap.PathMapBuilder<T> withMergeBetween(Object[] aToPathElements, PathMap<T> aFrom, Object[] aFromPathElements)
PathMap.MutablePathMap.mergeBetween(String, Object, String).aToPathElements - The path elements of the sub-path where to
merge the object's introspected values to.aFrom - The PathMap which is to be inspected with the
therein contained values being added with their according
determined paths.aFromPathElements - The path elements of the path from where to
start adding elements of the provided object.PathMap.MutablePathMap.mergeBetween(String, Object, String)default PathMap.PathMapBuilder<T> withMergeBetween(String aToPath, Object aFrom, String aFromPath)
PathMap.MutablePathMap.mergeBetween(String, Object, String) method.aToPath - The to-path.aFrom - the fromaFromPath - The from-path.PathMap.MutablePathMap.mergeBetween(String, Object, String)default PathMap.PathMapBuilder<T> withMergeBetween(String aToPath, PathMap<T> aFrom, String aFromPath)
PathMap.MutablePathMap.mergeBetween(String, Object, String).aToPath - The sub-path where to merge the object's introspected
values to.aFrom - The PathMap which is to be inspected with the
therein contained values being added with their according
determined paths.aFromPath - The path from where to start adding elements of the
provided object.PathMap.MutablePathMap.mergeBetween(String, Object, String)default PathMap.PathMapBuilder<T> withMergeBetween(String[] aToPathElements, Object aFrom, String[] aFromPathElements)
PathMap.MutablePathMap.mergeBetween(String, Object, String) method.aToPathElements - The path elements of the to-path.aFrom - the fromaFromPathElements - The path elements of the from-path.PathMap.MutablePathMap.mergeBetween(String, Object, String)default PathMap.PathMapBuilder<T> withMergeBetween(String[] aToPathElements, PathMap<T> aFrom, String[] aFromPathElements)
PathMap.MutablePathMap.mergeBetween(String, Object, String).aToPathElements - The path elements of the sub-path where to
merge the object's introspected values to.aFrom - The PathMap which is to be inspected with the
therein contained values being added with their according
determined paths.aFromPathElements - The path elements of the path from where to
start adding elements of the provided object.PathMap.MutablePathMap.mergeBetween(String, Object, String)default PathMap.PathMapBuilder<T> withMergeFrom(Object aFrom, Collection<?> aFromPathElements)
PathMap.MutablePathMap.mergeFrom(Object, String) method.aFrom - the fromaFromPathElements - The path elements representing the
from-path.PathMap.MutablePathMap.mergeFrom(Object, String)default PathMap.PathMapBuilder<T> withMergeFrom(Object aFrom, Object aFromPath)
PathMap.MutablePathMap.mergeFrom(Object, String) method.aFrom - the fromaFromPath - The from-path.PathMap.MutablePathMap.mergeFrom(Object, String)default PathMap.PathMapBuilder<T> withMergeFrom(Object aFrom, Object... aFromPathElements)
PathMap.MutablePathMap.mergeFrom(Object, String) method.aFrom - the fromaFromPathElements - The path elements representing the
from-path.PathMap.MutablePathMap.mergeFrom(Object, String)default PathMap.PathMapBuilder<T> withMergeFrom(Object aFrom, String aFromPath)
PathMap.MutablePathMap.mergeFrom(Object, String) method.aFrom - the fromaFromPath - The from-path.PathMap.MutablePathMap.mergeFrom(Object, String)default PathMap.PathMapBuilder<T> withMergeFrom(Object aFrom, String... aFromPathElements)
PathMap.MutablePathMap.mergeFrom(Object, String) method.aFrom - the fromaFromPathElements - The path elements representing the
from-path.PathMap.MutablePathMap.mergeFrom(Object, String)default PathMap.PathMapBuilder<T> withMergeFrom(PathMap<T> aFrom, Collection<?> aFromPathElements)
PathMap.MutablePathMap.mergeFrom(Object, String).aFrom - The PathMap which is to be inspected with the
therein contained values being added with their according
determined paths.aFromPathElements - The path elements representing the path from
where to start adding elements of the provided object.PathMap.MutablePathMap.mergeFrom(Object, String)default PathMap.PathMapBuilder<T> withMergeFrom(PathMap<T> aFrom, Object aFromPath)
PathMap.MutablePathMap.mergeFrom(Object, String).aFrom - The PathMap which is to be inspected with the
therein contained values being added with their according
determined paths.aFromPath - The path from where to start adding elements of the
provided object.PathMap.MutablePathMap.mergeFrom(Object, String)default PathMap.PathMapBuilder<T> withMergeFrom(PathMap<T> aFrom, Object... aFromPathElements)
PathMap.MutablePathMap.mergeFrom(Object, String).aFrom - The PathMap which is to be inspected with the
therein contained values being added with their according
determined paths.aFromPathElements - The path elements representing the path from
where to start adding elements of the provided object.PathMap.MutablePathMap.mergeFrom(Object, String)default PathMap.PathMapBuilder<T> withMergeFrom(PathMap<T> aFrom, String aFromPath)
PathMap.MutablePathMap.mergeFrom(Object, String).aFrom - The PathMap which is to be inspected with the
therein contained values being added with their according
determined paths.aFromPath - The path from where to start adding elements of the
provided object.PathMap.MutablePathMap.mergeFrom(Object, String)default PathMap.PathMapBuilder<T> withMergeFrom(PathMap<T> aFrom, String... aFromPathElements)
PathMap.MutablePathMap.mergeFrom(Object, String).aFrom - The PathMap which is to be inspected with the
therein contained values being added with their according
determined paths.aFromPathElements - The path elements representing the path from
where to start adding elements of the provided object.PathMap.MutablePathMap.mergeFrom(Object, String)default PathMap.PathMapBuilder<T> withMergeTo(Collection<?> aToPathElements, Object aFrom)
PathMap.MutablePathMap.mergeTo(String, Object) method.aToPathElements - The path elements representing the to-path.aFrom - the fromPathMap.MutablePathMap.mergeTo(String, Object)default PathMap.PathMapBuilder<T> withMergeTo(Collection<?> aToPathElements, PathMap<T> aFrom)
PathMap.MutablePathMap.mergeTo(String, Object).aToPathElements - The path elements representing the sub-path
where to merge the object's introspected values to.aFrom - The PathMap which is to be inspected with the
therein contained values being added with their according
determined paths.PathMap.MutablePathMap.mergeTo(String, Object)default PathMap.PathMapBuilder<T> withMergeTo(Object aToPath, Object aFrom)
PathMap.MutablePathMap.mergeTo(String, Object) method.aToPath - The to-path.aFrom - the fromPathMap.MutablePathMap.mergeTo(String, Object)default PathMap.PathMapBuilder<T> withMergeTo(Object aToPath, PathMap<T> aFrom)
PathMap.MutablePathMap.mergeTo(String, Object).aToPath - The sub-path where to merge the object's introspected
values to.aFrom - The PathMap which is to be inspected with the
therein contained values being added with their according
determined paths.PathMap.MutablePathMap.mergeTo(String, Object)default PathMap.PathMapBuilder<T> withMergeTo(Object[] aToPathElements, Object aFrom)
PathMap.MutablePathMap.mergeTo(String, Object) method.aToPathElements - The path elements representing the to-path.aFrom - the fromPathMap.MutablePathMap.mergeTo(String, Object)default PathMap.PathMapBuilder<T> withMergeTo(Object[] aToPathElements, PathMap<T> aFrom)
PathMap.MutablePathMap.mergeTo(String, Object).aToPathElements - The path elements representing the sub-path
where to merge the object's introspected values to.aFrom - The PathMap which is to be inspected with the
therein contained values being added with their according
determined paths.PathMap.MutablePathMap.mergeTo(String, Object)default PathMap.PathMapBuilder<T> withMergeTo(String aToPath, Object aFrom)
PathMap.MutablePathMap.mergeTo(String, Object) method.aToPath - The to-path.aFrom - the fromPathMap.MutablePathMap.mergeTo(String, Object)default PathMap.PathMapBuilder<T> withMergeTo(String aToPath, PathMap<T> aFrom)
PathMap.MutablePathMap.mergeTo(String, Object).aToPath - The sub-path where to merge the object's introspected
values to.aFrom - The PathMap which is to be inspected with the
therein contained values being added with their according
determined paths.PathMap.MutablePathMap.mergeTo(String, Object)default PathMap.PathMapBuilder<T> withMergeTo(String[] aToPathElements, Object aFrom)
PathMap.MutablePathMap.mergeTo(String, Object) method.aToPathElements - The path elements representing the to-path.aFrom - the fromPathMap.MutablePathMap.mergeTo(String, Object)default PathMap.PathMapBuilder<T> withMergeTo(String[] aToPathElements, PathMap<T> aFrom)
PathMap.MutablePathMap.mergeTo(String, Object).aToPathElements - The path elements representing the sub-path
where to merge the object's introspected values to.aFrom - The PathMap which is to be inspected with the
therein contained values being added with their according
determined paths.PathMap.MutablePathMap.mergeTo(String, Object)default PathMap.PathMapBuilder<T> withPut(Collection<?> aPathElements, T aValue)
Keys.MutableValues.put(Object, Object).aPathElements - the path elements for the property to be put.aValue - the value for the property to be put.default PathMap.PathMapBuilder<T> withPut(Object[] aPathElements, T aValue)
Keys.MutableValues.put(Object, Object).aPathElements - the path elements for the property to be put.aValue - the value for the property to be put.default PathMap.PathMapBuilder<T> withPut(Relation<String,T> aRelation)
Dictionary.MutableDictionary.put(Relation).withPut in interface Dictionary.MutableDictionary.DictionaryBuilder<String,T,PathMap.PathMapBuilder<T>>aRelation - the property to be put.default PathMap.PathMapBuilder<T> withPut(String[] aPathElements, T aValue)
Keys.MutableValues.put(Object, Object).aPathElements - the path elements for the property to be put.aValue - the value for the property to be put.default PathMap<T> withPutDirAt(Collection<?> aPathElements, int aIndex, Object aDir) throws IllegalArgumentException
aPathElements - The path elements of the path where to put the
indexed element.aIndex - The index of the indexed element.aDir - The values to be put at the index.IllegalArgumentException - in case the path does not represent
indexed elements as of PathMap.isIndexDir(String).default PathMap<T> withPutDirAt(Collection<?> aPathElements, int aIndex, PathMap<T> aDir) throws IllegalArgumentException
aPathElements - The path elements of the path where to put the
indexed element.aIndex - The index of the indexed element.aDir - The values to be put at the index.IllegalArgumentException - in case the path does not represent
indexed elements as of PathMap.isIndexDir(String).default PathMap<T> withPutDirAt(int aIndex, Object aDir) throws IllegalArgumentException
aIndex - The index of the indexed element.aDir - The values to be put at the index.IllegalArgumentException - in case the path does not represent
indexed elements as of PathMap.isIndexDir(String).default PathMap<T> withPutDirAt(int aIndex, PathMap<T> aDir) throws IllegalArgumentException
aIndex - The index of the indexed element.aDir - The values to be put at the index.IllegalArgumentException - in case the path does not represent
indexed elements as of PathMap.isIndexDir(String).default PathMap<T> withPutDirAt(Object aPath, int aIndex, Object aDir) throws IllegalArgumentException
aPath - The path where to put the indexed element.aIndex - The index of the indexed element.aDir - The values to be put at the index.IllegalArgumentException - in case the path does not represent
indexed elements as of PathMap.isIndexDir(String).default PathMap<T> withPutDirAt(Object aPath, int aIndex, PathMap<T> aDir) throws IllegalArgumentException
aPath - The path where to put the indexed element.aIndex - The index of the indexed element.aDir - The values to be put at the index.IllegalArgumentException - in case the path does not represent
indexed elements as of PathMap.isIndexDir(String).default PathMap<T> withPutDirAt(Object[] aPathElements, int aIndex, Object aDir) throws IllegalArgumentException
aPathElements - The path elements of the path where to put the
indexed element.aIndex - The index of the indexed element.aDir - The values to be put at the index.IllegalArgumentException - in case the path does not represent
indexed elements as of PathMap.isIndexDir(String).default PathMap<T> withPutDirAt(Object[] aPathElements, int aIndex, PathMap<T> aDir) throws IllegalArgumentException
aPathElements - The path elements of the path where to put the
indexed element.aIndex - The index of the indexed element.aDir - The values to be put at the index.IllegalArgumentException - in case the path does not represent
indexed elements as of PathMap.isIndexDir(String).default PathMap<T> withPutDirAt(String aPath, int aIndex, Object aDir) throws IllegalArgumentException
aPath - The path where to put the indexed element.aIndex - The index of the indexed element.aDir - The values to be put at the index.IllegalArgumentException - in case the path does not represent
indexed elements as of PathMap.isIndexDir(String).default PathMap<T> withPutDirAt(String aPath, int aIndex, PathMap<T> aDir) throws IllegalArgumentException
aPath - The path where to put the indexed element.aIndex - The index of the indexed element.aDir - The values to be put at the index.IllegalArgumentException - in case the path does not represent
indexed elements as of PathMap.isIndexDir(String).default PathMap<T> withPutDirAt(String[] aPathElements, int aIndex, Object aDir) throws IllegalArgumentException
aPathElements - The path elements of the path where to put the
indexed element.aIndex - The index of the indexed element.aDir - The values to be put at the index.IllegalArgumentException - in case the path does not represent
indexed elements as of PathMap.isIndexDir(String).default PathMap<T> withPutDirAt(String[] aPathElements, int aIndex, PathMap<T> aDir) throws IllegalArgumentException
aPathElements - The path elements of the path where to put the
indexed element.aIndex - The index of the indexed element.aDir - The values to be put at the index.IllegalArgumentException - in case the path does not represent
indexed elements as of PathMap.isIndexDir(String).default PathMap.PathMapBuilder<T> withRemoveFrom(Collection<?> aPathElements)
PathMap.MutablePathMap.removeFrom( String) method.aPathElements - The path elements of the path from where to
remove all properties.default PathMap.PathMapBuilder<T> withRemoveFrom(Object aPath)
PathMap.MutablePathMap.removeFrom( String) method.aPath - The path from where to remove all properties.default PathMap.PathMapBuilder<T> withRemoveFrom(Object... aPathElements)
PathMap.MutablePathMap.removeFrom( String) method.aPathElements - The path elements of the path from where to
remove all properties.default PathMap.PathMapBuilder<T> withRemoveFrom(String aPath)
PathMap.MutablePathMap.removeFrom( String) method.aPath - The path from where to remove all properties.default PathMap.PathMapBuilder<T> withRemoveFrom(String... aPathElements)
PathMap.MutablePathMap.removeFrom( String) method.aPathElements - The path elements of the path from where to
remove all properties.default PathMap.PathMapBuilder<T> withRemovePaths(String... aPathElements)
PathMap.MutablePathMap.removeFrom( String) method.aPathElements - The path elements of the path from where to
remove all properties.Copyright © 2021. All rights reserved.