T - the generic typeorg.refcodes.mixin.AnnotatorAccessor, org.refcodes.mixin.DelimiterAccessor, org.refcodes.mixin.Dumpable, org.refcodes.mixin.TypeAccessor<T>, Containable, Dictionary<String,T>, Keys<K,V>, PathMap<T>public class PathMapImpl<T> extends Object implements PathMap<T>
org.refcodes.mixin.AnnotatorAccessor.AnnotatorBuilder<B extends org.refcodes.mixin.AnnotatorAccessor.AnnotatorBuilder<B>>, org.refcodes.mixin.AnnotatorAccessor.AnnotatorMutator, org.refcodes.mixin.AnnotatorAccessor.AnnotatorPropertyorg.refcodes.mixin.DelimiterAccessor.DelimiterBuilder<B extends org.refcodes.mixin.DelimiterAccessor.DelimiterBuilder<B>>, org.refcodes.mixin.DelimiterAccessor.DelimiterMutator, org.refcodes.mixin.DelimiterAccessor.DelimiterPropertyDictionary.MutableDictionary<K,V>Keys.MutableKeys<K,V>, Keys.MutableValues<K,V>PathMap.MutablePathMap<T>, PathMap.PathMapBuilder<T>org.refcodes.mixin.TypeAccessor.TypeBuilder<T extends Object,B extends org.refcodes.mixin.TypeAccessor.TypeBuilder<T,B>>, org.refcodes.mixin.TypeAccessor.TypeMutator<T extends Object>, org.refcodes.mixin.TypeAccessor.TypeProperty<T extends Object>| Modifier | Constructor | Description |
|---|---|---|
|
PathMapImpl(char aDelimiter,
Class<T> aType) |
Create a
PathMap instance using the provided path delimiter for
the path declarations. |
|
PathMapImpl(Object aObj,
char aDelimiter,
Class<T> aType) |
Creates a
PathMap instance containing the elements as of
PathMap.MutablePathMap.insert(Object). |
|
PathMapImpl(Object aObj,
Class<T> aType) |
Create a
PathMap instance containing the elements as of
PathMap.MutablePathMap.insert(Object) using the default path delimiter
"/" (Delimiter.PATH) for the path declarations. |
|
PathMapImpl(Object aObj,
String aFromPath,
char aDelimiter,
Class<T> aType) |
Creates a
PathMap instance containing the elements as of
PathMap.MutablePathMap.insert(Object). |
|
PathMapImpl(Object aObj,
String aFromPath,
Class<T> aType) |
Creates a
PathMap instance containing the elements as of
PathMap.MutablePathMap.insert(Object) using the default path delimiter
"/" (Delimiter.PATH) for the path declarations. |
|
PathMapImpl(String aToPath,
Object aObj,
char aDelimiter,
Class<T> aType) |
Creates a
PathMap instance containing the elements as of
PathMap.MutablePathMap.insert(Object). |
|
PathMapImpl(String aToPath,
Object aObj,
Class<T> aType) |
Create a
PathMap instance containing the elements as of
PathMap.MutablePathMap.insert(Object) using the default path delimiter
"/" (Delimiter.PATH) for the path declarations. |
|
PathMapImpl(String aToPath,
Object aObj,
String aFromPath,
char aDelimiter,
Class<T> aType) |
Create a
PathMap instance containing the elements as of
PathMap.MutablePathMap.insert(Object). |
|
PathMapImpl(String aToPath,
Object aObj,
String aFromPath,
Class<T> aType) |
Creates a
PathMap instance containing the elements as of
PathMap.MutablePathMap.insert(Object) using the default path delimiter
"/" (Delimiter.PATH for the path declarations. |
protected |
PathMapImpl(PathMap<T> aPathMap) |
Create a
PathMap instance from the provided PathMap
instance containing the elements as of
PathMap.MutablePathMap.insert(Object) using the PathMap's path
delimiter for the path declarations the the type of the PathMap. |
| Modifier and Type | Method | Description |
|---|---|---|
boolean |
containsKey(Object aKey) |
Tests whether there is an element with the given key.
|
boolean |
containsValue(Object aValue) |
This method is defined for the sake of
Map conformity. |
T |
get(Object aKey) |
Retrieves the element assigned to the given key.
|
char |
getAnnotator() |
|
char |
getDelimiter() |
|
Class<T> |
getType() |
|
boolean |
isEmpty() |
Tests whether the accumulation is empty or not.
|
Set<String> |
keySet() |
Retrieves a collection containing all the keys found in the elements of
this collection.
|
PathMap<T> |
retrieveFrom(String aFromPath) |
|
PathMap<T> |
retrieveTo(String aToPath) |
|
int |
size() |
Returns the number of data elements contained in the collection.
|
Object |
toDataStructure(String aFromPath) |
Similar to the
PathMap.toMap(String) method, though in case all the keys
of a nested Map instance (applicable to the root Map as
well) represent an array (as of PathMap.getArray( String)), then an
array is generated where the index of each value in the Map is
represented by the number representation of the Map's key for
that value. |
String |
toString() |
|
Collection<T> |
values() |
Returns a
Collection view of the values related to the contained
keys. |
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitchildren, children, children, children, children, children, containsKey, containsKey, containsKey, dirs, dirs, dirs, dirs, dirs, dirs, findPaths, fromExternalPath, get, get, get, getArray, getArray, getArray, getArray, getArray, getArrayIndexes, getArrayIndexes, getArrayIndexes, getArrayIndexes, getArrayIndexes, getDir, getDir, getDir, getDir, getDir, getDirAt, getDirAt, getDirAt, getDirAt, getDirAt, getDirAt, getDirIndexes, getDirIndexes, getDirIndexes, getDirIndexes, getDirIndexes, getRootPath, getValueAt, getValueAt, getValueAt, getValueAt, getValueAt, getValueAt, hasChildren, hasChildren, hasChildren, hasChildren, hasChildren, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasParentPath, hasPath, hasPath, hasPath, hasPath, hasSubDirs, hasSubDirs, hasSubDirs, hasSubDirs, hasValue, hasValue, hasValue, hasValue, hasValue, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, isArray, isArray, isArray, isArray, isArray, isArray, isChild, isChild, isChild, isChild, isDir, isDir, isDir, isDir, isDir, isEqualTo, isIndexDir, isIndexDir, isIndexDir, isIndexDir, isIndexDir, isLeaf, isLeaf, isLeaf, isLeaf, isLeaf, isRootPath, keySet, keySet, keySet, keySet, keySet, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastDirIndex, lastDirIndex, lastDirIndex, lastDirIndex, lastDirIndex, lastDirIndex, leaves, leaves, leaves, leaves, leaves, leaves, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextDirIndex, nextDirIndex, nextDirIndex, nextDirIndex, nextDirIndex, nextDirIndex, paths, paths, paths, paths, paths, paths, query, query, query, query, query, queryBetween, queryBetween, queryBetween, queryBetween, queryBetween, queryBetween, queryFrom, queryFrom, queryFrom, queryFrom, queryFrom, queryFrom, queryPaths, queryPaths, queryPaths, queryPaths, queryPaths, queryPaths, queryTo, queryTo, queryTo, queryTo, queryTo, queryTo, retrieveBetween, retrieveBetween, retrieveBetween, retrieveBetween, retrieveBetween, retrieveFrom, retrieveFrom, retrieveFrom, retrieveFrom, retrieveTo, retrieveTo, retrieveTo, retrieveTo, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, toDataStructure, toExternalPath, toInstance, toInstance, toLeaf, toMap, toMap, toNormalizedPath, toParentPath, toPath, toPath, toPath, toPathElements, toPathList, toPathStack, toPropertyPath, toType, toTypeprotected PathMapImpl(PathMap<T> aPathMap)
PathMap instance from the provided PathMap
instance containing the elements as of
PathMap.MutablePathMap.insert(Object) using the PathMap's path
delimiter for the path declarations the the type of the PathMap.aPathMap - The PathMap from which the elements are to be
added.public PathMapImpl(char aDelimiter,
Class<T> aType)
PathMap instance using the provided path delimiter for
the path declarations.aDelimiter - The path delimiter to be used for the path
declarations.aType - The type of the values being referenced by the paths.public PathMapImpl(Object aObj, Class<T> aType)
PathMap instance containing the elements as of
PathMap.MutablePathMap.insert(Object) using the default path delimiter
"/" (Delimiter.PATH) for the path declarations.aObj - The object from which the elements are to be added.aType - The type of the values being referenced by the paths.public PathMapImpl(String aToPath, Object aObj, Class<T> aType)
PathMap instance containing the elements as of
PathMap.MutablePathMap.insert(Object) using the default path delimiter
"/" (Delimiter.PATH) for the path declarations.aToPath - The sub-path where to insert the object's introspected
values to.aObj - The object from which the elements are to be added.aType - The type of the values being referenced by the paths.public PathMapImpl(Object aObj, String aFromPath, Class<T> aType)
PathMap instance containing the elements as of
PathMap.MutablePathMap.insert(Object) using the default path delimiter
"/" (Delimiter.PATH) for the path declarations.aObj - The object from which the elements are to be added.aFromPath - The path from where to start adding elements of the
provided object.aType - The type of the values being referenced by the paths.public PathMapImpl(String aToPath, Object aObj, String aFromPath, Class<T> aType)
PathMap instance containing the elements as of
PathMap.MutablePathMap.insert(Object) using the default path delimiter
"/" (Delimiter.PATH for the path declarations.aToPath - The sub-path where to insert the object's introspected
values to.aObj - The object from which the elements are to be added.aFromPath - The path from where to start adding elements of the
provided object.aType - The type of the values being referenced by the paths.public PathMapImpl(Object aObj, char aDelimiter, Class<T> aType)
PathMap instance containing the elements as of
PathMap.MutablePathMap.insert(Object).aObj - The object from which the elements are to be added.aDelimiter - The path delimiter to be used for the path
declarations.aType - The type of the values being referenced by the paths.public PathMapImpl(String aToPath, Object aObj, char aDelimiter, Class<T> aType)
PathMap instance containing the elements as of
PathMap.MutablePathMap.insert(Object).aToPath - The sub-path where to insert the object's introspected
values to.aObj - The object from which the elements are to be added.aDelimiter - The path delimiter to be used for the path
declarations.aType - The type of the values being referenced by the paths.public PathMapImpl(Object aObj, String aFromPath, char aDelimiter, Class<T> aType)
PathMap instance containing the elements as of
PathMap.MutablePathMap.insert(Object).aObj - The object from which the elements are to be added.aFromPath - The path from where to start adding elements of the
provided object.aDelimiter - The path delimiter to be used for the path
declarations.aType - The type of the values being referenced by the paths.public PathMapImpl(String aToPath, Object aObj, String aFromPath, char aDelimiter, Class<T> aType)
PathMap instance containing the elements as of
PathMap.MutablePathMap.insert(Object).aToPath - The sub-path where to insert the object's introspected
values to.aObj - The object from which the elements are to be added.aFromPath - The path from where to start adding elements of the
provided object.aDelimiter - The path delimiter to be used for the path
declarations.aType - The type of the values being referenced by the paths.public boolean containsKey(Object aKey)
containsKey in interface Keys<K,V>aKey - The key for which to test whether there is an element.public boolean containsValue(Object aValue)
Map conformity. Tests
whether the provided value has a key assigned.containsValue in interface Keys<K,V>aValue - The value to test if a key references this value.public Set<String> keySet()
public Collection<T> values()
Collection view of the values related to the contained
keys.values in interface Keys<K,V>Collection view of the values related to the contained
keys.public int size()
size in interface Containablepublic boolean isEmpty()
isEmpty in interface Containablepublic char getDelimiter()
getDelimiter in interface org.refcodes.mixin.DelimiterAccessorpublic char getAnnotator()
getAnnotator in interface org.refcodes.mixin.AnnotatorAccessorpublic PathMap<T> retrieveFrom(String aFromPath)
PathMap from the elements of this PathMap
found below the "from-path". The sub-paths will be the root paths for the
new PathMap. Given we have a value for path "/dog/cat" in the
PathMap and we call PathMap.retrieveFrom(String) with "/dog",
then the resulting PathMap will contain the path "/cat" for that
value.retrieveFrom in interface PathMap<T>aFromPath - The path from where to start extracting the paths.PathMap with the elements below the provided path
which are root elements in the new PathMap.public PathMap<T> retrieveTo(String aToPath)
PathMap from this PathMap's elements with
the paths relocated to the provided "to-path". Given we have a value for
path "/dog/cat" in the PathMap and we call
PathMap.retrieveTo(String) with "/animals", then the resulting
PathMap will contain the path "/animals/dog/cat" for that value.public Class<T> getType()
getType in interface org.refcodes.mixin.TypeAccessor<T>public Object toDataStructure(String aFromPath)
PathMap.toMap(String) method, though in case all the keys
of a nested Map instance (applicable to the root Map as
well) represent an array (as of PathMap.getArray( String)), then an
array is generated where the index of each value in the Map is
represented by the number representation of the Map's key for
that value. The result is a data structure consisting of Map
instances and arrays.toDataStructure in interface PathMap<T>aFromPath - The path below which the PathMap to be converted
into a data structure.Map instances and
arrays representing the data below the given path.Copyright © 2021. All rights reserved.