Serializable, Comparable<PathSortStrategy>public enum PathSortStrategy extends Enum<PathSortStrategy>
PathSortStrategy defines strategies to use when sorting e.g. when
using a PathComparator or the method
PathMap.sortedKeys(PathSortStrategy)| Enum Constant | Description |
|---|---|
ALPHABETIC |
Sort alphabetically, differentiating between upper case and lower case,
e.g. "10" will be sorted before "2".
|
ALPHABETIC_IGNORE_CASE |
Sort alphabetically, not differentiating between upper case and lower
case, e.g. "10" will be sorted before "2".
|
ALPHANUMERIC |
Sort alphabetically, differentiating between upper case and lower case
and considering any path elements representing an integral number, e.g
|
ALPHANUMERIC_IGNORE_CASE |
Sort alphabetically, not differentiating between upper case and lower
case and considering any path elements representing an integral number,
e.g. "10" will be sorted below "2".
|
DEFAULT |
Default sort strategy being
ALPHANUMERIC_IGNORE_CASE |
| Modifier and Type | Method | Description |
|---|---|---|
boolean |
isAlphanumeric() |
Determines whether to sort alphabetically and considering any path
elements representing an integral number, e.g. "10" will be sorted below
"2".
|
boolean |
isIgnoreCase() |
Determines whether to sort by not differentiating between upper case and
lower case.
|
static PathSortStrategy |
valueOf(String name) |
Returns the enum constant of this type with the specified name.
|
static PathSortStrategy[] |
values() |
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final PathSortStrategy DEFAULT
ALPHANUMERIC_IGNORE_CASEpublic static final PathSortStrategy ALPHABETIC
public static final PathSortStrategy ALPHABETIC_IGNORE_CASE
public static final PathSortStrategy ALPHANUMERIC
public static final PathSortStrategy ALPHANUMERIC_IGNORE_CASE
public static PathSortStrategy[] values()
for (PathSortStrategy c : PathSortStrategy.values()) System.out.println(c);
public static PathSortStrategy valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullpublic boolean isAlphanumeric()
public boolean isIgnoreCase()
Copyright © 2021. All rights reserved.