org.refcodes.mixin.KeyAccessor<String>, org.refcodes.mixin.ValueAccessor<String>, Property, Relation<String,String>PropertyImpl.PropertyBuilderImplpublic class PropertyImpl extends RelationImpl<String,String> implements Property
Property interface.| Modifier and Type | Class | Description |
|---|---|---|
static class |
PropertyImpl.PropertyBuilderImpl |
Implementation of the
Property.PropertyBuilder interface. |
org.refcodes.mixin.KeyAccessor.KeyBuilder<K extends Object,B extends org.refcodes.mixin.KeyAccessor.KeyBuilder<K,B>>, org.refcodes.mixin.KeyAccessor.KeyMutator<K extends Object>, org.refcodes.mixin.KeyAccessor.KeyProperty<K extends Object>Property.PropertyBuilderRelation.RelationBuilder<K,V>RelationImpl.RelationBuilderImpl<K,V>org.refcodes.mixin.ValueAccessor.ValueBuilder<V extends Object,B extends org.refcodes.mixin.ValueAccessor.ValueBuilder<V,B>>, org.refcodes.mixin.ValueAccessor.ValueMutator<V extends Object>, org.refcodes.mixin.ValueAccessor.ValueProperty<V extends Object>_key, _value| Modifier | Constructor | Description |
|---|---|---|
protected |
PropertyImpl() |
Instantiates a new property impl.
|
|
PropertyImpl(String aTupel) |
Initializes the
PropertyImpl with the given values. |
|
PropertyImpl(String aTupel,
char aTupelDelimeter) |
Initializes the
PropertyImpl with the given values. |
|
PropertyImpl(String aKey,
String aValue) |
Initializes the
PropertyImpl with the given values. |
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waittoPropertygetKey, getValue, toStringprotected PropertyImpl()
public PropertyImpl(String aKey, String aValue)
PropertyImpl with the given values.aKey - The according key to set.aValue - The according value to set.public PropertyImpl(String aTupel)
PropertyImpl with the given values.aTupel - A tupel is a key and a value with the assignment operator
"=" inbetween, e.g. "a=5" (the key would be a, the value would be
5).public PropertyImpl(String aTupel, char aTupelDelimeter)
PropertyImpl with the given values.aTupel - A tupel is a key and a value with the assignment operator
"=" inbetween, e.g. "a=5" (the key would be a, the value would be
5).aTupelDelimeter - The delimiter to be used for dividing the
key/value-pair.Copyright © 2021. All rights reserved.