T - The type of the referencee to be encapsulated by this
Referencee.public class Referencee<T> extends Object
Referencee encapsulates a reference to an instance which might be
null at the time of the referencee's creation. This way a reference to a non
yet existing object can be provided.| Constructor | Description |
|---|---|
Referencee() |
| Modifier and Type | Method | Description |
|---|---|---|
T |
getReference() |
Retrieves the according reference.
|
T |
referTo(T aReference) |
Sets the according reference and returns the reference being set.
|
void |
setReference(T aReference) |
Sets the according reference.
|
public T getReference()
public void setReference(T aReference)
aReference - The according reference.public T referTo(T aReference)
Referencee can be introduced in places where the
actual reference is being created and expected.aReference - The according reference to be set.Copyright © 2021. All rights reserved.