| Modifier and Type | Method | Description |
|---|---|---|
static PathSortStrategy |
PathSortStrategy.valueOf(String name) |
Returns the enum constant of this type with the specified name.
|
static PathSortStrategy[] |
PathSortStrategy.values() |
Returns an array containing the constants of this enum type, in
the order they are declared.
|
| Modifier and Type | Method | Description |
|---|---|---|
default List<String> |
PathMap.sortedKeys(PathSortStrategy aPathSortStrategy) |
Retrieves a sorted list as of the provided
PathSortStrategy
containing all the keys found in the elements of this collection. |
default List<String> |
PathMap.sortedKeys(PathSortStrategy aPathSortStrategy,
Object aPath) |
Retrieves a sorted list as of the provided
PathSortStrategy
containing all the keys found below the given path of this collection. |
default List<String> |
PathMap.sortedKeys(PathSortStrategy aPathSortStrategy,
Object... aPathElements) |
Retrieves a sorted list as of the provided
PathSortStrategy
containing all the keys found below the given path of this collection. |
default List<String> |
PathMap.sortedKeys(PathSortStrategy aPathSortStrategy,
String aPath) |
Retrieves a sorted list as of the provided
PathSortStrategy
containing all the keys found below the given path of this collection. |
default List<String> |
PathMap.sortedKeys(PathSortStrategy aPathSortStrategy,
String... aPathElements) |
Retrieves a sorted list as of the provided
PathSortStrategy
containing all the keys found below the given path of this collection. |
default List<String> |
PathMap.sortedKeys(PathSortStrategy aPathSortStrategy,
Collection<?> aPathElements) |
Retrieves a sorted list as of the provided
PathSortStrategy
containing all the keys found below the given path of this collection. |
| Constructor | Description |
|---|---|
PathComparator(char aDelimiter,
PathSortStrategy aPathSortStrategy) |
Constructs the
PathComparator with the given path delimiter. |
Copyright © 2021. All rights reserved.