| Modifier and Type | Class | Description |
|---|---|---|
class |
AmbigousKeyRuntimeException |
Thrown in case this instance does not contain the requested element (no such
key found in the collection).
|
class |
KeyNotFoundRuntimeException |
Thrown in case this instance does not contain the requested element (no such
key found in the collection).
|
Copyright © 2021. All rights reserved.