| Class | Description |
|---|---|
| Attribute |
Interface describing a bean's attribute with a key represented by a
String and the value being of any type. |
| Attribute.AttributeBuilder |
Adds builder functionality to an
Attribute. |
| AttributeImpl |
Class describing a beans's attribute.
|
| BooleanArrayAccessor |
Provides an accessor for a boolean array property.
|
| BooleanArrayAccessor.BooleanArrayBuilder |
Provides a builder method for a boolean array property returning the
builder for applying multiple build operations.
|
| BooleanArrayAccessor.BooleanArrayMutator |
Provides a mutator for a boolean array property.
|
| ByteArrayAccessor |
Provides an accessor for a byte array property.
|
| ByteArrayAccessor.ByteArrayBuilder |
Provides a builder method for a byte array property returning the builder
for applying multiple build operations.
|
| ByteArrayAccessor.ByteArrayMutator |
Provides a mutator for a byte array property.
|
| CanonicalMap |
The
CanonicalMap is an "intermediate" type adding type and
Data-Structure related functionality to any implementing class. |
| CanonicalMap.CanonicalMapBuilder |
The Interface CanonicalMapBuilder.
|
| CanonicalMap.MutableCanonicalMap |
The Interface MutableCanonicalMap.
|
| ClassStructMap |
The
ClassStructMap disects a Class into its simple types
(considering String and Enum types as well as primitive
types). |
| ClassStructMap.ClassStructMapBuilder |
The Interface ClassStructMapBuilder.
|
| ClassStructMap.MutableClassStructMap |
The Interface MutableClassStructMap.
|
| Containable |
A
Containable is the base functionality provided container
(collection). |
| Container |
Basic functionality being provided by any
Container (collection)
style class. |
| Container.ClearableContainer | |
| Dictionary |
Basic functionality being provided by any
Dictionary (map) style
class. |
| Dictionary.MutableDictionary |
Extends the
Dictionary with mutable (writable) functionality,
especially by providing Keys.MutableValues.put(Object, Object) and
Keys.MutableKeys.delete(String) methods. |
| Dictionary.MutableDictionary.DictionaryBuilder |
Provides a builder method for a
Relation property returning
the builder for applying multiple build operations. |
| DoubleArrayAccessor |
Provides an accessor for a double array property.
|
| DoubleArrayAccessor.DoubleArrayBuilder |
Provides a builder method for a double array property returning the
builder for applying multiple build operations.
|
| DoubleArrayAccessor.DoubleArrayMutator |
Provides a mutator for a double array property.
|
| Elements |
Basic functionality being provided by any
Elements (collection) style
class. |
| Elements.ClearableElements | |
| Elements.MutableElements |
Extends the
Elements with mutable (writable) functionality,
especially by enabling the Iterator.remove() method in the
Iterator provided via Elements.MutableElements.iterator() and by providing the
Elements.MutableElements.add(Object) and the Elements.MutableElements.remove(Object) methods. |
| FloatArrayAccessor |
Provides an accessor for a float array property.
|
| FloatArrayAccessor.FloatArrayBuilder |
Provides a builder method for a float array property returning the
builder for applying multiple build operations.
|
| FloatArrayAccessor.FloatArrayMutator |
Provides a mutator for a float array property.
|
| InterOperableMap |
The
InterOperableMap provides convenience accessor default methods
for supporting primitive data types. |
| InterOperableMap.InterOperableMapBuilder |
The
InterOperableMap.InterOperableMapBuilder provides convenience accessor default
methods for supporting primitive data types. |
| InterOperableMap.MutableInterOperableMap |
The
InterOperableMap.InterOperableMapBuilder provides convenience accessor default
methods for supporting primitive data types. |
| KeyNotFoundException |
Thrown in case this instance does not contain the requested element (no such
key found in the collection).
|
| Keys |
This interface provides functionality for working with keys.
|
| Keys.MutableKeys |
Adds mutable functionality to the
Keys interface. |
| Keys.MutableValues |
Mixin for mutable functionality accompanying the
Keys interface. |
| PathMap | |
| PathMap.MutablePathMap |
The
PathMap.MutablePathMap adds mutable functionality to the
PathMap. |
| PathMap.PathMapBuilder |
The
PathMap.PathMapBuilder adds builder functionality to the
PathMap.MutablePathMap. |
| PathMapBuilderImpl |
The Class PathMapBuilderImpl.
|
| PathSortStrategy |
The
PathSortStrategy defines strategies to use when sorting e.g. when
using a PathComparator or the method
PathMap.sortedKeys(PathSortStrategy) |
| PrimitiveArrayType |
The
PrimitiveArrayType enumeration contains the Class
representation of the primitive array types. |
| Property | |
| Property.PropertyBuilder |
Adds builder functionality to a
Property. |
| PropertyImpl |
Implementation of the
Property interface. |
| Range |
Interface describing a range with a minimum value and a maximum value.
|
| Range.RangeBuilder |
Adds builder functionality to a
Range. |
| RangeImpl |
Implementation of the
Range interface. |
| Relation |
Provides an accessor for a key-to-value property useful in some occasions.
|
| Relation.RelationBuilder |
Adds builder functionality to a
Relation. |
| RelationImpl |
Implementation of the
Relation interface. |
| ShortArrayAccessor |
Provides an accessor for a short array property.
|
| ShortArrayAccessor.ShortArrayBuilder |
Provides a builder method for a short array property returning the
builder for applying multiple build operations.
|
| ShortArrayAccessor.ShortArrayMutator |
Provides a mutator for a short array property.
|
| SimpleType |
The introspection mode defines on how a type (class) is to be processed when
being introspected, especially when working with primitive types and their
wrapper types as well as when working with the according array types.
|
| SimpleTypeMap | |
| SimpleTypeMap.MutableSimpleTypeMap |
The
SimpleTypeMap.MutableSimpleTypeMap adds functionality for manipulating the
internal state to the SimpleTypeMap. |
| SimpleTypeMap.SimpleTypeMapBuilder |
A
SimpleTypeMap.SimpleTypeMapBuilder sets builder functionality (as of the
builder pattern) on top of the SimpleTypeMap.MutableSimpleTypeMap. |
| SimpleTypeMapBuilderImpl |
An implementation of the
SimpleTypeMap.SimpleTypeMapBuilder. |
| StringArrayAccessor |
Provides an accessor for a String array property.
|
| StringArrayAccessor.StringArrayBuilder |
Provides a builder method for a String array property returning the
builder for applying multiple build operations.
|
| StringArrayAccessor.StringArrayMutator |
Provides a mutator for a String array property.
|
| StructureException |
The
StructureException is the base checked exception for this
package. |
| StructureRuntimeException |
The
StructureRuntimeException is the base runtime exception for this
package. |
| TypeModeAccessor |
Provides an accessor for a type mode property.
|
| TypeModeAccessor.TypeModeBuilder |
Provides a builder method for a type mode property returning the builder
for applying multiple build operations.
|
| TypeModeAccessor.TypeModeMutator |
Provides a mutator for a type mode property.
|
Copyright © 2021. All rights reserved.