All Classes Interface Summary Class Summary Enum Summary Exception Summary
| Class |
Description |
| AmbigousKeyRuntimeException |
Thrown in case this instance does not contain the requested element (no such
key found in the collection).
|
| Attribute |
Interface describing a bean's attribute with a key represented by a
String and the value being of any type.
|
| Attribute.AttributeBuilder |
|
| AttributeImpl |
Class describing a beans's attribute.
|
| AttributeImpl.AttributeBuilderImpl |
|
| BooleanArrayAccessor |
Provides an accessor for a boolean array property.
|
| BooleanArrayAccessor.BooleanArrayBuilder<B extends BooleanArrayAccessor.BooleanArrayBuilder<B>> |
Provides a builder method for a boolean array property returning the
builder for applying multiple build operations.
|
| BooleanArrayAccessor.BooleanArrayMutator |
Provides a mutator for a boolean array property.
|
| BooleanArrayAccessor.BooleanArrayProperty |
Provides a boolean array property.
|
| BoundedIterator<T> |
|
| ByteArrayAccessor |
Provides an accessor for a byte array property.
|
| ByteArrayAccessor.ByteArrayBuilder<B extends ByteArrayAccessor.ByteArrayBuilder<B>> |
Provides a builder method for a byte array property returning the builder
for applying multiple build operations.
|
| ByteArrayAccessor.ByteArrayMutator |
Provides a mutator for a byte array property.
|
| ByteArrayAccessor.ByteArrayProperty |
Provides a byte array property.
|
| CanonicalMap |
The CanonicalMap is an "intermediate" type adding type and
Data-Structure related functionality to any implementing class.
|
| CanonicalMap.CanonicalMapBuilder |
The Interface CanonicalMapBuilder.
|
| CanonicalMap.MutableCanonicalMap |
The Interface MutableCanonicalMap.
|
| CanonicalMapBuilderImpl |
The Class CanonicalMapBuilderImpl.
|
| CanonicalMapImpl |
The Class CanonicalMapImpl.
|
| ClassStructMap |
|
| ClassStructMap.ClassStructMapBuilder |
The Interface ClassStructMapBuilder.
|
| ClassStructMap.MutableClassStructMap |
The Interface MutableClassStructMap.
|
| ClassStructMapBuilderImpl |
The Class ClassStructBuilderImpl.
|
| ClassStructMapImpl |
The Class ClassStructMapImpl.
|
| Containable |
A Containable is the base functionality provided container
(collection).
|
| Container<E> |
Basic functionality being provided by any Container (collection)
style class.
|
| Container.ClearableContainer<E> |
Extends the Container interface with Clearable
functionality (as of Clearable.clear()).
|
| Container.MutableContainer<E> |
|
| Dictionary<K,V> |
Basic functionality being provided by any Dictionary (map) style
class.
|
| Dictionary.MutableDictionary<K,V> |
|
| Dictionary.MutableDictionary.DictionaryBuilder<K,V,B extends Dictionary.MutableDictionary.DictionaryBuilder<K,V,B>> |
Provides a builder method for a Relation property returning
the builder for applying multiple build operations.
|
| DoubleArrayAccessor |
Provides an accessor for a double array property.
|
| DoubleArrayAccessor.DoubleArrayBuilder<B extends DoubleArrayAccessor.DoubleArrayBuilder<B>> |
Provides a builder method for a double array property returning the
builder for applying multiple build operations.
|
| DoubleArrayAccessor.DoubleArrayMutator |
Provides a mutator for a double array property.
|
| DoubleArrayAccessor.DoubleArrayProperty |
Provides a double array property.
|
| Elements<E> |
Basic functionality being provided by any Elements (collection) style
class.
|
| Elements.ClearableElements<E> |
Extends the Elements interface with Clearable
functionality (as of Clearable.clear()).
|
| Elements.MutableElements<E> |
|
| FloatArrayAccessor |
Provides an accessor for a float array property.
|
| FloatArrayAccessor.FloatArrayBuilder<B extends FloatArrayAccessor.FloatArrayBuilder<B>> |
Provides a builder method for a float array property returning the
builder for applying multiple build operations.
|
| FloatArrayAccessor.FloatArrayMutator |
Provides a mutator for a float array property.
|
| FloatArrayAccessor.FloatArrayProperty |
Provides a float array property.
|
| InterOperableMap<T> |
The InterOperableMap provides convenience accessor default methods
for supporting primitive data types.
|
| InterOperableMap.InterOperableMapBuilder<T> |
|
| InterOperableMap.MutableInterOperableMap<T> |
|
| KeyNotFoundException |
Thrown in case this instance does not contain the requested element (no such
key found in the collection).
|
| KeyNotFoundRuntimeException |
Thrown in case this instance does not contain the requested element (no such
key found in the collection).
|
| Keys<K,V> |
This interface provides functionality for working with keys.
|
| Keys.MutableKeys<K,V> |
Adds mutable functionality to the Keys interface.
|
| Keys.MutableValues<K,V> |
Mixin for mutable functionality accompanying the Keys interface.
|
| PathComparator |
Comparator for path elements, it takes care to sort index values correctly,
e.g. "1000" must come after "9": The paths "/foo/bar/1000/wow" and
"/foo/bar/9/wow" should be sorted as follows:
"/foo/bar/9/wow"
"/foo/bar/1000/wow"
|
| PathMap<T> |
A PathMap is a flat map by which each element is addressed by a path;
represented by the PathMap's keys.
|
| PathMap.MutablePathMap<T> |
|
| PathMap.PathMapBuilder<T> |
|
| PathMapBuilderImpl<T> |
The Class PathMapBuilderImpl.
|
| PathMapImpl<T> |
The Class PathMapImpl.
|
| PathSortStrategy |
|
| PrimitiveArrayType |
|
| Property |
A Property is defined as being String representing a
property's key and a String representing the proprty's value.
|
| Property.PropertyBuilder |
Adds builder functionality to a Property.
|
| PropertyImpl |
Implementation of the Property interface.
|
| PropertyImpl.PropertyBuilderImpl |
|
| Range<V extends Number & Comparable<V>> |
Interface describing a range with a minimum value and a maximum value.
|
| Range.RangeBuilder<V extends Number & Comparable<V>> |
Adds builder functionality to a Range.
|
| RangeImpl<V extends Number & Comparable<V>> |
Implementation of the Range interface.
|
| RangeImpl.RangeBuilderImpl<V extends Number & Comparable<V>> |
|
| Referencee<T> |
A Referencee encapsulates a reference to an instance which might be
null at the time of the referencee's creation.
|
| Relation<K,V> |
Provides an accessor for a key-to-value property useful in some occasions.
|
| Relation.RelationBuilder<K,V> |
Adds builder functionality to a Relation.
|
| RelationImpl<K,V> |
Implementation of the Relation interface.
|
| RelationImpl.RelationBuilderImpl<K,V> |
|
| ShortArrayAccessor |
Provides an accessor for a short array property.
|
| ShortArrayAccessor.ShortArrayBuilder<B extends ShortArrayAccessor.ShortArrayBuilder<B>> |
Provides a builder method for a short array property returning the
builder for applying multiple build operations.
|
| ShortArrayAccessor.ShortArrayMutator |
Provides a mutator for a short array property.
|
| ShortArrayAccessor.ShortArrayProperty |
Provides a short array property.
|
| SimpleType |
The SimpleType enumeration provides functionality useful when working
wit Java's primitive types, their wrapper counterparts as well as with some
other crucial types such as String, Date, Enum,
Class or Locale types.
|
| SimpleTypeMap |
|
| SimpleTypeMap.MutableSimpleTypeMap |
|
| SimpleTypeMap.SimpleTypeMapBuilder |
|
| SimpleTypeMapBuilderImpl |
|
| SimpleTypeMapImpl |
|
| StringArrayAccessor |
Provides an accessor for a String array property.
|
| StringArrayAccessor.StringArrayBuilder<B extends StringArrayAccessor.StringArrayBuilder<B>> |
Provides a builder method for a String array property returning the
builder for applying multiple build operations.
|
| StringArrayAccessor.StringArrayMutator |
Provides a mutator for a String array property.
|
| StringArrayAccessor.StringArrayProperty |
Provides a String array property.
|
| StructureException |
|
| StructureRuntimeException |
|
| StructureUtility |
Utility class to avoid redundant code regarding various PathMap
implementations.
|
| TypeModeAccessor |
Provides an accessor for a type mode property.
|
| TypeModeAccessor.TypeModeBuilder<B extends TypeModeAccessor.TypeModeBuilder<B>> |
Provides a builder method for a type mode property returning the builder
for applying multiple build operations.
|
| TypeModeAccessor.TypeModeMutator |
Provides a mutator for a type mode property.
|
| TypeModeAccessor.TypeModeProperty |
Provides a type mode property.
|
| TypeUtility |
The Class TypeUtility.
|
| TypeUtility.NoSuchMethodNotInvokedException |
|