All Classes and Interfaces
Class
Description
Thrown in case this instance does not contain the requested element (no such
key found in the collection).
Interface describing a bean's attribute with a key represented by a
String and the value being of any type.Adds builder functionality to an
Attribute.Class describing a beans's attribute.
Implementation of the
Property.PropertyBuilder interface.Provides an accessor for a boolean array property.
Provides a builder method for a boolean array property returning the
builder for applying multiple build operations.
Provides a mutator for a boolean array property.
Provides a boolean array property.
The
BoundedIterator decorates an Iterator to limit its
element to a maximum number.Provides an accessor for a byte array property.
Provides a builder method for a byte array property returning the builder
for applying multiple build operations.
Provides a mutator for a byte array property.
Provides a byte array property.
The Interface CanonicalTable.
The
ClassStructTable type extends the ImmutableClassStructTable.MutableClassStructTable
and provides mutator (write) as well as builder methods for manipulating the
entries.A
Containable is the base functionality provided container
(collection).Basic functionality being provided by any
Container (collection)
style class.Extends the
Container with mutable (writable) functionality,
ehttps://www.metacodes.proly by enabling the Iterator.remove()
method in the Iterator provided via Elements.iterator().Provides an accessor for a double array property.
Provides a builder method for a double array property returning the
builder for applying multiple build operations.
Provides a mutator for a double array property.
Provides a double array property.
Basic functionality being provided by any
Elements (collection) style
class.Extends the
Elements with mutable (writable) functionality,
ehttps://www.metacodes.proly by enabling the Iterator.remove()
method in the Iterator provided via Elements.MutableElements.iterator() and by
providing the Elements.MutableElements.add(Object) and the Elements.MutableElements.remove(Object)
methods.Provides an accessor for a float array property.
Provides a builder method for a float array property returning the
builder for applying multiple build operations.
Provides a mutator for a float array property.
Provides a float array property.
The
ImmutableCanonicalTable is an "intermediate" type adding type and
Data-Structure related functionality to any implementing class.The
ImmutableCanonicalTable.MutableCanonicalTable type extends the
ImmutableCanonicalTable with mutable (writable) functionality and
provides default mutator methods for supporting primitive data types.The
ImmutableClassStructTable disects a Class into its simple
types (considering String and Enum types as well as primitive
types).The
ImmutableClassStructTable.MutableClassStructTable type adds mutable functionality to
the ClassStructTable.The
ImmutableInterOperableTable type extends the
ImmutablePathTable and provides default accessor methods for
supporting primitive data types.The
ImmutableInterOperableTable.MutableInterOperableTable type extends the
ImmutableInterOperableTable with mutable (writable) functionality
and provides default mutator methods for supporting primitive data types.A
ImmutablePathTable is a flat read-only (immutable) map by which
each element is addressed by a path; represented by the
ImmutablePathTable's keys.The
ImmutablePathTable.MutablePathTable type adds mutable functionality to the
ImmutablePathTable.The
ImmutableSimpleTypeTable.MutableSimpleTypeTable type extends the
ImmutableSimpleTypeTable and provides mutator (write) as well as
builder methods for manipulating the entries and provides default methods
for supporting primitive data types.The
ImmutableTable type defines read-only functionality being
provided by any immutable ImmutableTable (map) style class.The
ImmutableTable.MutableTable type extends the ImmutableTable type
with mutable (writable) functionality and provides mutator methods such
as Keys.MutableValues.put(Object, Object) and Keys.MutableKeys.delete(String) methods.The
InterOperableTable type extends the
ImmutableInterOperableTable.MutableInterOperableTable and provides mutator as well as builder
methods for manipulating the entries supporting primitive data types.Thrown in case this instance does not contain the requested element (no such
key found in the collection).
Thrown in case this instance does not contain the requested element (no such
key found in the collection).
This interface provides functionality for working with keys.
Adds mutable functionality to the
Keys interface.Mixin for mutable functionality accompanying the
Keys interface.An implementation of the
SimpleTypeTable.
Comparator for path elements, it takes care to sort index values correctly,
e.g. "1000" must come after "9": The paths "/foo/bar/1000/wow" and
"/foo/bar/9/wow" should be sorted as follows:
The
PathSortStrategy defines strategies to use when sorting e.g. when
using a PathComparator or the method
ImmutablePathTable.sortedKeys(PathSortStrategy)The
PathTable type extends the ImmutablePathTable.MutablePathTable and provides
mutator (write) as well as builder methods for manipulating the entries.The
PrimitiveArrayType enumeration contains the Class
representation of the primitive array types.Adds builder functionality to a
Property.Implementation of the
Property interface.Implementation of the
Property.PropertyBuilder interface.Interface describing a range with a minimum value and a maximum value.
Adds builder functionality to a
Range.Implementation of the
Range interface.Implementation of the
Range.RangeBuilder interface.A
Referencee encapsulates a reference to an instance which might be
null at the time of the referencee's creation.Provides an accessor for a key-to-value property useful in some occasions.
Adds builder functionality to a
Relation.Implementation of the
Relation interface.Implementation of the
Relation.RelationBuilder interface.Provides an accessor for a short array property.
Provides a builder method for a short array property returning the
builder for applying multiple build operations.
Provides a mutator for a short array property.
Provides a short array property.
The
SimpleTypeTable type extends the ImmutableSimpleTypeTable.MutableSimpleTypeTable
and provides mutator (write) as well as builder methods for manipulating the
entries and provides default methods for supporting primitive data types.Provides an accessor for a String array property.
Provides a builder method for a String array property returning the
builder for applying multiple build operations.
Provides a mutator for a String array property.
Provides a String array property.
The
StructureException is the base checked exception for this
package.The
StructureRuntimeException is the base runtime exception for this
package.Utility class to avoid redundant code regarding various
ImmutablePathTable implementations.The
Table type extends the ImmutableTable.MutableTable type and provides
mutator as well as builder methods for manipulating the entries.Provides an accessor for a type mode property.
Provides a builder method for a type mode property returning the builder
for applying multiple build operations.
Provides a mutator for a type mode property.
Provides a type mode property.
The
TypeUtility uses reflection to fiddle around with primitives,
types, classes, instances and the like.Extension of the
NoSuchMethodException with an additional aCause
TypeUtility.NoSuchMethodNotInvokedException.getCause()The
UnmodifiableCanonicalTableDecorator decorates an
ImmutableCanonicalTable instance for immutability (read only access).The
UnmodifiableClassStructTableDecorator decorates an
ImmutableCanonicalTable instance for immutability (read only access).The
UnmodifiablePathTableDecorator decorates an
ImmutablePathTable instance for immutability (read only access).The
UnmodifiableSimpleTypeTableDecorator decorates an
ImmutableSimpleTypeTable instance for immutability (read only
access).