Interface Containable
- All Superinterfaces:
org.refcodes.mixin.EmptyAccessor
- All Known Subinterfaces:
CanonicalMap, CanonicalMap.CanonicalMapBuilder, CanonicalMap.MutableCanonicalMap, ClassStructMap, ClassStructMap.ClassStructMapBuilder, ClassStructMap.MutableClassStructMap, Container<E>, Container.ClearableContainer<E>, Container.MutableContainer<E>, InterOperableMap<T>, InterOperableMap.InterOperableMapBuilder<T>, InterOperableMap.MutableInterOperableMap<T>, PathMap<T>, PathMap.MutablePathMap<T>, PathMap.PathMapBuilder<T>, SimpleTypeMap, SimpleTypeMap.MutableSimpleTypeMap, SimpleTypeMap.SimpleTypeMapBuilder, Table<K,V>, Table.TableDictionary<K, V>, Table.TableDictionary.TableBuilder<K, V, B>
- All Known Implementing Classes:
CanonicalMapBuilderImpl, CanonicalMapImpl, ClassStructMapBuilderImpl, ClassStructMapImpl, PathMapBuilderImpl, PathMapImpl, SimpleTypeMapBuilderImpl, SimpleTypeMapImpl
public interface Containable
extends org.refcodes.mixin.EmptyAccessor
A
Containable is the base functionality provided container
(collection). The Containableit just informs about the metrics of a
container.-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.mixin.EmptyAccessor
org.refcodes.mixin.EmptyAccessor.EmptyBuilder<B>, org.refcodes.mixin.EmptyAccessor.EmptyMutator, org.refcodes.mixin.EmptyAccessor.EmptyProperty -
Method Summary
Modifier and TypeMethodDescriptionintsize()Returns the number of data elements contained in the collection.Methods inherited from interface org.refcodes.mixin.EmptyAccessor
isEmpty
-
Method Details
-
size
int size()Returns the number of data elements contained in the collection.- Returns:
- An integer representing the number of items stored in the accumulation.
-