-
- All Superinterfaces:
org.refcodes.mixin.EmptyAccessor
- All Known Subinterfaces:
CanonicalMap,CanonicalMap.CanonicalMapBuilder,CanonicalMap.MutableCanonicalMap,ClassStructMap,ClassStructMap.ClassStructMapBuilder,ClassStructMap.MutableClassStructMap,Container<E>,Container.ClearableContainer<E>,Container.MutableContainer<E>,Dictionary<K,V>,Dictionary.MutableDictionary<K,V>,Dictionary.MutableDictionary.DictionaryBuilder<K,V,B>,InterOperableMap<T>,InterOperableMap.InterOperableMapBuilder<T>,InterOperableMap.MutableInterOperableMap<T>,PathMap<T>,PathMap.MutablePathMap<T>,PathMap.PathMapBuilder<T>,SimpleTypeMap,SimpleTypeMap.MutableSimpleTypeMap,SimpleTypeMap.SimpleTypeMapBuilder
- All Known Implementing Classes:
CanonicalMapBuilderImpl,CanonicalMapImpl,ClassStructMapBuilderImpl,ClassStructMapImpl,PathMapBuilderImpl,PathMapImpl,SimpleTypeMapBuilderImpl,SimpleTypeMapImpl
public interface Containable extends org.refcodes.mixin.EmptyAccessorAContainableis the base functionality provided container (collection). TheContainableit just informs about the metrics of a container.
-
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description intsize()Returns the number of data elements contained in the collection.
-