-
- Type Parameters:
K- The type of the key.V- The type of the value which relates to a key.
- All Superinterfaces:
org.refcodes.mixin.Clearable,Containable,Dictionary<K,V>,org.refcodes.mixin.EmptyAccessor,Keys<K,V>,Keys.MutableKeys<K,V>,Keys.MutableValues<K,V>
- All Known Subinterfaces:
CanonicalMap.CanonicalMapBuilder,CanonicalMap.MutableCanonicalMap,ClassStructMap.ClassStructMapBuilder,ClassStructMap.MutableClassStructMap,Dictionary.MutableDictionary.DictionaryBuilder<K,V,B>,InterOperableMap.InterOperableMapBuilder<T>,InterOperableMap.MutableInterOperableMap<T>,PathMap.MutablePathMap<T>,PathMap.PathMapBuilder<T>,SimpleTypeMap.MutableSimpleTypeMap,SimpleTypeMap.SimpleTypeMapBuilder
- All Known Implementing Classes:
CanonicalMapBuilderImpl,ClassStructMapBuilderImpl,PathMapBuilderImpl,SimpleTypeMapBuilderImpl
- Enclosing interface:
- Dictionary<K,V>
public static interface Dictionary.MutableDictionary<K,V> extends Dictionary<K,V>, Keys.MutableValues<K,V>
Extends theDictionarywith mutable (writable) functionality, especially by providingKeys.MutableValues.put(Object, Object)andKeys.MutableKeys.delete(String)methods.
-
-
Nested Class Summary
Nested Classes Modifier and Type Interface Description static interfaceDictionary.MutableDictionary.DictionaryBuilder<K,V,B extends Dictionary.MutableDictionary.DictionaryBuilder<K,V,B>>Provides a builder method for aRelationproperty returning the builder for applying multiple build operations.-
Nested classes/interfaces inherited from interface org.refcodes.struct.Dictionary
Dictionary.MutableDictionary<K,V>
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.EmptyAccessor
org.refcodes.mixin.EmptyAccessor.EmptyMutator, org.refcodes.mixin.EmptyAccessor.EmptyProperty
-
Nested classes/interfaces inherited from interface org.refcodes.struct.Keys
Keys.MutableKeys<K,V>, Keys.MutableValues<K,V>
-
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description Vput(Relation<K,V> aRelation)Adds the given element related to the given key.-
Methods inherited from interface org.refcodes.struct.Containable
size
-
Methods inherited from interface org.refcodes.struct.Keys
containsKey, containsValue, get, getOr, keySet, use, values
-
Methods inherited from interface org.refcodes.struct.Keys.MutableKeys
delete
-
Methods inherited from interface org.refcodes.struct.Keys.MutableValues
put
-
-