-
- Type Parameters:
E- The type of the elements being stored in theElements.MutableElements.
- All Superinterfaces:
org.refcodes.mixin.Clearable,Elements<E>,Elements.ClearableElements<E>
- All Known Subinterfaces:
Container.MutableContainer<E>
public static interface Elements.MutableElements<E> extends Elements.ClearableElements<E>
Extends theElementswith mutable (writable) functionality, especially by enabling theIterator.remove()method in theIteratorprovided viaiterator()and by providing theadd(Object)and theremove(Object)methods.
-
-
Nested Class Summary
-
Nested classes/interfaces inherited from interface org.refcodes.struct.Elements
Elements.ClearableElements<E>, Elements.MutableElements<E>
-
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description booleanadd(E aElement)Same asCollection.add(Object).Iterator<E>iterator()Returns anIteratorinstance of all the data elements contained in the container (collection). --------------------------------------------------------------------- ATTENTION: TheIterator.remove()method is enabled in the returnedIteratorinstance as theElements.MutableElementsis possibly readable and writable.booleanremove(Object aElement)Same asCollection.remove(Object).
-
-
-
Method Detail
-
add
boolean add(E aElement)
Same asCollection.add(Object).- Parameters:
aElement- the element whose presence in this collection is to be ensured- Returns:
- True if this collection changed as a result of the call
- See Also:
Collection.add(Object)
-
remove
boolean remove(Object aElement)
Same asCollection.remove(Object).- Parameters:
aElement- The element to be removed from this collection, if present- Returns:
- True if an element was removed as a result of this call.
- See Also:
Collection.remove(Object)
-
iterator
Iterator<E> iterator()
Returns anIteratorinstance of all the data elements contained in the container (collection). --------------------------------------------------------------------- ATTENTION: TheIterator.remove()method is enabled in the returnedIteratorinstance as theElements.MutableElementsis possibly readable and writable.
-
-