Interface ImmutableClassStructTable.MutableClassStructTable
- All Superinterfaces:
org.refcodes.mixin.AnnotatorAccessor,org.refcodes.mixin.Clearable,Containable,org.refcodes.mixin.DelimiterAccessor,org.refcodes.mixin.EmptyAccessor,ImmutableClassStructTable,ImmutablePathTable<Class<?>>,ImmutablePathTable.MutablePathTable<Class<?>>,ImmutableTable<String,,Class<?>> ImmutableTable.MutableTable<String,,Class<?>> Keys<String,,Class<?>> Keys.MutableKeys<String,,Class<?>> Keys.MutableValues<String,,Class<?>> Map<String,,Class<?>> org.refcodes.mixin.TypeAccessor<Class<?>>,TypeModeAccessor
- All Known Subinterfaces:
ClassStructTable
- All Known Implementing Classes:
MapClassStructTable
- Enclosing interface:
ImmutableClassStructTable
public static interface ImmutableClassStructTable.MutableClassStructTable
extends ImmutableClassStructTable, ImmutablePathTable.MutablePathTable<Class<?>>, Map<String,Class<?>>
The
ImmutableClassStructTable.MutableClassStructTable type adds mutable functionality to
the ClassStructTable.-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.mixin.AnnotatorAccessor
org.refcodes.mixin.AnnotatorAccessor.AnnotatorBuilder<B extends org.refcodes.mixin.AnnotatorAccessor.AnnotatorBuilder<B>>, org.refcodes.mixin.AnnotatorAccessor.AnnotatorMutator, org.refcodes.mixin.AnnotatorAccessor.AnnotatorPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.DelimiterAccessor
org.refcodes.mixin.DelimiterAccessor.DelimiterBuilder<B extends org.refcodes.mixin.DelimiterAccessor.DelimiterBuilder<B>>, org.refcodes.mixin.DelimiterAccessor.DelimiterMutator, org.refcodes.mixin.DelimiterAccessor.DelimiterPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.EmptyAccessor
org.refcodes.mixin.EmptyAccessor.EmptyBuilder<B extends org.refcodes.mixin.EmptyAccessor.EmptyBuilder<B>>, org.refcodes.mixin.EmptyAccessor.EmptyMutator, org.refcodes.mixin.EmptyAccessor.EmptyPropertyNested classes/interfaces inherited from interface org.refcodes.struct.ImmutableClassStructTable
ImmutableClassStructTable.MutableClassStructTableNested classes/interfaces inherited from interface org.refcodes.struct.ImmutablePathTable
ImmutablePathTable.MutablePathTable<T>Nested classes/interfaces inherited from interface org.refcodes.struct.ImmutableTable
ImmutableTable.MutableTable<K,V> Nested classes/interfaces inherited from interface org.refcodes.struct.Keys
Keys.MutableKeys<K,V>, Keys.MutableValues<K, V> Nested classes/interfaces inherited from interface org.refcodes.mixin.TypeAccessor
org.refcodes.mixin.TypeAccessor.TypeBuilder<T,B extends org.refcodes.mixin.TypeAccessor.TypeBuilder<T, B>>, org.refcodes.mixin.TypeAccessor.TypeMutator<T>, org.refcodes.mixin.TypeAccessor.TypeProperty<T> Nested classes/interfaces inherited from interface org.refcodes.struct.TypeModeAccessor
TypeModeAccessor.TypeModeBuilder<B extends TypeModeAccessor.TypeModeBuilder<B>>, TypeModeAccessor.TypeModeMutator, TypeModeAccessor.TypeModeProperty -
Field Summary
Fields inherited from interface org.refcodes.struct.ImmutableClassStructTable
ARRAY_SELECTORFields inherited from interface org.refcodes.struct.ImmutablePathTable
ANNOTATOR, DELIMITER -
Method Summary
Modifier and TypeMethodDescriptiondefault booleancontainsValue(Object value) This method is defined for the sake ofMapconformity.default voidinsert(ImmutableClassStructTable aFrom) Method to semantically emphasize that we support our own types.default voidinsertBetween(String aToPath, ImmutableClassStructTable aFrom, String aFromPath) Method to semantically emphasize that we support our own types.default voidinsertFrom(ImmutableClassStructTable aFrom, String aFromPath) Method to semantically emphasize that we support our own types.default voidinsertTo(String aToPath, ImmutableClassStructTable aFrom) Method to semantically emphasize that we support our own types.default Class<?> Puts the given value into the child's path, relative to the given parent's path.default StringAdds the given element related to the given key.default Class<?> Puts the given value into the child's path, relative to the given parent's path.default StringPuts the key/value-pair from the providedProperty.default Class<?> Adds the given element related to the given key.default voiddefault voidputAll(Properties aProperties) This method inserts all elements (key/value-pairs) found in the providedPropertiesinstances of interoperability reasons.default voidputAll(ImmutableClassStructTable aProperties) This method inserts all elements (key/value-pairs) found in the providedImmutableClassStructTableinstances of interoperability reasons.default ClassStructTableAn indexed directory represents all elements which begin with a path which's last path element represents an index.default ClassStructTableputDirAt(int aIndex, ImmutablePathTable<Class<?>> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default ClassStructTableAn indexed directory represents all elements which begin with a path which's last path element represents an index.default ClassStructTableputDirAt(Object[] aPathElements, int aIndex, ImmutablePathTable<Class<?>> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default ClassStructTableAn indexed directory represents all elements which begin with a path which's last path element represents an index.default ClassStructTableputDirAt(Object aPath, int aIndex, ImmutablePathTable<Class<?>> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default ClassStructTableAn indexed directory represents all elements which begin with a path which's last path element represents an index.default ClassStructTableputDirAt(String[] aPathElements, int aIndex, ImmutablePathTable<Class<?>> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default ClassStructTableAn indexed directory represents all elements which begin with a path which's last path element represents an index.default ClassStructTableputDirAt(String aPath, int aIndex, ImmutablePathTable<Class<?>> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default ClassStructTableputDirAt(Collection<?> aPathElements, int aIndex, Object aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default ClassStructTableputDirAt(Collection<?> aPathElements, int aIndex, ImmutablePathTable<Class<?>> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index.default ClassStructTableRemoves all elements which's keys match the provided path query.default ClassStructTableRemoves all elements which's keys match the provided path query.default ClassStructTableRemoves all elements which's keys match the provided path query.default ClassStructTableRemoves all elements which's keys match the provided path query.default ClassStructTableremoveAll(Collection<?> aPathQueryElements) Removes all elements which's keys match the provided path query.default ClassStructTableRemoves all elements which's keys match the provided regular expression: Queries the keys of the instance using the providedPattern.default ClassStructTableremoveDirAt(int aIndex) An indexed directory represents all elements which begin with a path which's last path element represents an index.default ClassStructTableremoveDirAt(Object[] aPathElements, int aIndex) An indexed directory represents all elements which begin with a path which's last path element represents an index.default ClassStructTableremoveDirAt(Object aPath, int aIndex) An indexed directory represents all elements which begin with a path which's last path element represents an index.default ClassStructTableremoveDirAt(String[] aPathElements, int aIndex) An indexed directory represents all elements which begin with a path which's last path element represents an index.default ClassStructTableremoveDirAt(String aPath, int aIndex) An indexed directory represents all elements which begin with a path which's last path element represents an index.default ClassStructTableremoveFrom(Object aPath) Removes all properties below the provided path and returns thePathTablewith the removed elements, by which the paths exclude the parent's path.default ClassStructTableremoveFrom(Object... aPathElements) Removes all properties below the provided path and returns thePathTablewith the removed elements, by which the paths exclude the parent's path.default ClassStructTableremoveFrom(String aPath) Removes all properties below the provided path and returns thePathTablewith the removed elements, by which the paths exclude the parent's path.default ClassStructTableremoveFrom(String... aPathElements) Removes all properties below the provided path and returns thePathTablewith the removed elements, by which the paths exclude the parent's path.default ClassStructTableremoveFrom(Collection<?> aPathElements) Removes all properties below the provided path and returns thePathTablewith the removed elements, by which the paths exclude the parent's path.default ClassStructTableremovePaths(String... aPaths) Removes the paths contained in the provided collection.default ClassStructTableremovePaths(Collection<?> aPaths) Removes the paths contained in the provided collection.Methods inherited from interface org.refcodes.mixin.AnnotatorAccessor
getAnnotatorMethods inherited from interface org.refcodes.mixin.Clearable
clearMethods inherited from interface org.refcodes.struct.Containable
sizeMethods inherited from interface org.refcodes.mixin.DelimiterAccessor
getDelimiterMethods inherited from interface org.refcodes.mixin.EmptyAccessor
isEmptyMethods inherited from interface org.refcodes.struct.ImmutableClassStructTable
getArraySelector, getCompositeArrayDir, getCompositeArrayDir, getCompositeArrayDir, getCompositeArrayDir, getCompositeArrayDir, getCompositeArrayDir, getCompositeDir, getCompositeDir, getCompositeDir, getCompositeDir, getCompositeDir, getCompositeDir, getDir, getDir, getDir, getDir, getDir, getDirAt, getDirAt, getDirAt, getDirAt, getDirAt, getDirAt, getDirs, getDirs, getDirs, getDirs, getDirs, getPrimitiveArrayType, getPrimitiveArrayType, getPrimitiveArrayType, getPrimitiveArrayType, getPrimitiveArrayType, getPrimitiveArrayType, getPrimitiveType, getPrimitiveType, getPrimitiveType, getPrimitiveType, getPrimitiveType, getPrimitiveType, getSimpleArrayType, getSimpleArrayType, getSimpleArrayType, getSimpleArrayType, getSimpleArrayType, getSimpleArrayType, getSimpleType, getSimpleType, getSimpleType, getSimpleType, getSimpleType, getSimpleType, getWrapperArrayType, getWrapperArrayType, getWrapperArrayType, getWrapperArrayType, getWrapperArrayType, getWrapperArrayType, getWrapperType, getWrapperType, getWrapperType, getWrapperType, getWrapperType, getWrapperType, isArrayType, isArrayType, isArrayType, isArrayType, isArrayType, isArrayType, isCompositeArrayDir, isCompositeArrayDir, isCompositeArrayDir, isCompositeArrayDir, isCompositeArrayDir, isCompositeArrayDir, isCompositeDir, isCompositeDir, isCompositeDir, isCompositeDir, isCompositeDir, isCompositeDir, isPrimitiveArrayType, isPrimitiveArrayType, isPrimitiveArrayType, isPrimitiveArrayType, isPrimitiveArrayType, isPrimitiveArrayType, isPrimitiveType, isPrimitiveType, isPrimitiveType, isPrimitiveType, isPrimitiveType, isPrimitiveType, isSimpleArrayType, isSimpleArrayType, isSimpleArrayType, isSimpleArrayType, isSimpleArrayType, isSimpleArrayType, isSimpleType, isSimpleType, isSimpleType, isSimpleType, isSimpleType, isSimpleType, isWrapperArrayType, isWrapperArrayType, isWrapperArrayType, isWrapperArrayType, isWrapperArrayType, isWrapperArrayType, isWrapperType, isWrapperType, isWrapperType, isWrapperType, isWrapperType, isWrapperType, query, query, query, query, query, queryBetween, queryBetween, queryBetween, queryBetween, queryBetween, queryBetween, queryFrom, queryFrom, queryFrom, queryFrom, queryFrom, queryFrom, queryTo, queryTo, queryTo, queryTo, queryTo, queryTo, retrieveBetween, retrieveBetween, retrieveBetween, retrieveBetween, retrieveBetween, retrieveFrom, retrieveFrom, retrieveFrom, retrieveFrom, retrieveFrom, retrieveTo, retrieveTo, retrieveTo, retrieveTo, retrieveTo, toMap, toPropertiesMethods inherited from interface org.refcodes.struct.ImmutablePathTable
children, children, children, children, children, children, containsKey, containsKey, containsKey, dirs, dirs, dirs, dirs, dirs, dirs, findPaths, fromExternalPath, get, get, get, getArray, getArray, getArray, getArray, getArray, getArray, getArrayIndexes, getArrayIndexes, getArrayIndexes, getArrayIndexes, getArrayIndexes, getArrayOr, getArrayOr, getArrayOr, getArrayOr, getArrayOr, getArrayOr, getDirIndexes, getDirIndexes, getDirIndexes, getDirIndexes, getDirIndexes, getDirIndexes, getRootPath, getValueAt, getValueAt, getValueAt, getValueAt, getValueAt, getValueAt, hasChildren, hasChildren, hasChildren, hasChildren, hasChildren, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasParentPath, hasPath, hasPath, hasPath, hasPath, hasPath, hasSubDirs, hasSubDirs, hasSubDirs, hasSubDirs, hasValue, hasValue, hasValue, hasValue, hasValue, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, isArray, isArray, isArray, isArray, isArray, isArray, isChild, isChild, isChild, isChild, isDir, isDir, isDir, isDir, isDir, isEqualTo, isIndexDir, isIndexDir, isIndexDir, isIndexDir, isIndexDir, isLeaf, isLeaf, isLeaf, isLeaf, isLeaf, isRootPath, keySet, keySet, keySet, keySet, keySet, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastDirIndex, lastDirIndex, lastDirIndex, lastDirIndex, lastDirIndex, lastDirIndex, leaves, leaves, leaves, leaves, leaves, leaves, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextDirIndex, nextDirIndex, nextDirIndex, nextDirIndex, nextDirIndex, nextDirIndex, paths, paths, paths, paths, paths, paths, queryPaths, queryPaths, queryPaths, queryPaths, queryPaths, queryPaths, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, toDataStructure, toDataStructure, toExternalPath, toInstance, toInstance, toLeaf, toMap, toNormalizedPath, toParentPath, toPath, toPath, toPath, toPath, toPathElements, toPathList, toPathStack, toPrintable, toPropertyPath, toType, toType, toType, toType, toType, toType, toType, toTypeMethods inherited from interface org.refcodes.struct.ImmutablePathTable.MutablePathTable
add, add, add, add, add, add, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendValueTo, appendValueTo, appendValueTo, appendValueTo, appendValueTo, appendValueTo, delete, delete, delete, delete, delete, fromType, fromType, fromType, fromType, fromType, fromType, fromType, fromType, insert, insert, insertBetween, insertBetween, insertBetween, insertBetween, insertBetween, insertBetween, insertBetween, insertBetween, insertBetween, insertBetween, insertFrom, insertFrom, insertFrom, insertFrom, insertFrom, insertFrom, insertFrom, insertFrom, insertFrom, insertFrom, insertTo, insertTo, insertTo, insertTo, insertTo, insertTo, insertTo, insertTo, insertTo, insertTo, merge, merge, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeTo, mergeTo, mergeTo, mergeTo, mergeTo, mergeTo, mergeTo, mergeTo, mergeTo, mergeTo, put, putArray, putArray, putArray, putArray, putArray, putArray, putArray, putArray, putArray, putArray, putArray, putArray, putValueAt, putValueAt, putValueAt, putValueAt, putValueAt, putValueAt, remove, remove, remove, removeValueAt, removeValueAt, removeValueAt, removeValueAt, removeValueAt, toSourceCode, toSourceCodeMethods inherited from interface org.refcodes.struct.Keys
containsKey, get, getOr, keySet, use, valuesMethods inherited from interface org.refcodes.struct.Keys.MutableValues
putMethods inherited from interface java.util.Map
clear, compute, computeIfAbsent, computeIfPresent, containsKey, entrySet, equals, forEach, get, getOrDefault, hashCode, isEmpty, keySet, merge, put, putIfAbsent, remove, remove, replace, replace, replaceAll, size, valuesMethods inherited from interface org.refcodes.mixin.TypeAccessor
getTypeMethods inherited from interface org.refcodes.struct.TypeModeAccessor
getTypeMode
-
Method Details
-
containsValue
This method is defined for the sake ofMapconformity. Tests whether the provided value has a key assigned.- Specified by:
containsValuein interfaceImmutableClassStructTable- Specified by:
containsValuein interfaceKeys<String,Class<?>> - Specified by:
containsValuein interfaceMap<String,Class<?>> - Parameters:
value- The value to test if a key references this value.- Returns:
- True in case the given value is referenced by a key.
-
insert
Method to semantically emphasize that we support our own types. Actually delegates toImmutablePathTable.MutablePathTable.insert(Object).- Parameters:
aFrom- TheImmutableClassStructTablewhich is to be inspected with the therein contained values being added with their according determined paths.
-
insertBetween
Method to semantically emphasize that we support our own types. Actually delegates toImmutablePathTable.MutablePathTable.insertBetween(String, Object, String).- Parameters:
aToPath- The sub-path where to insert the object's introspected values to.aFrom- TheImmutableClassStructTablewhich is to be inspected with the therein contained values being added with their according determined paths.aFromPath- The path from where to start adding elements of the provided object.
-
insertFrom
Method to semantically emphasize that we support our own types. Actually delegates toImmutablePathTable.MutablePathTable.insertFrom(Object, String).- Parameters:
aFrom- TheImmutableClassStructTablewhich is to be inspected with the therein contained values being added with their according determined paths.aFromPath- The path from where to start adding elements of the provided object.
-
insertTo
Method to semantically emphasize that we support our own types. Actually delegates toImmutablePathTable.MutablePathTable.insertTo(String, Object).- Parameters:
aToPath- The sub-path where to insert the object's introspected values to.aFrom- TheImmutableClassStructTablewhich is to be inspected with the therein contained values being added with their according determined paths.
-
put
Adds the given element related to the given key. As the key passed is an enumeration, theEnum.toString()method is used on the enumeration to resolve the enumeration to a {link String} key.- Parameters:
aKey- The key for which to add the element.aValue- The value to be related with the given key.- Returns:
- The value being replaced by the provided value or null if none value has been replaced.
-
put
Puts the given value into the child's path, relative to the given parent's path.- Specified by:
putin interfaceImmutablePathTable.MutablePathTable<Class<?>>- Parameters:
aPathElements- The path elements of the path relative to which to put the value.aValue- The value to be added.- Returns:
- The replaced value in case a value has already been set for the resulting path, or null.
-
put
-
put
Adds the given element related to the given key.- Specified by:
putin interfaceImmutablePathTable.MutablePathTable<Class<?>>- Specified by:
putin interfaceImmutableTable.MutableTable<String,Class<?>> - Parameters:
aRelation- the relation- Returns:
- The value being replaced by the provided value or null if none value has been replaced.
-
put
Puts the given value into the child's path, relative to the given parent's path.- Specified by:
putin interfaceImmutablePathTable.MutablePathTable<Class<?>>- Parameters:
aPathElements- The path elements of the path relative to which to put the value.aValue- The value to be added.- Returns:
- The replaced value in case a value has already been set for the resulting path, or null.
-
putAll
This method inserts all elements (key/value-pairs) found in the providedImmutableClassStructTableinstances of interoperability reasons.- Parameters:
aProperties- AImmutableClassStructTablecontaining the key/value pairs to be inserted.
-
putAll
This method inserts all elements (key/value-pairs) found in the providedPropertiesinstances of interoperability reasons.- Parameters:
aProperties- APropertiescontaining the key/value-pairs to be inserted.
-
putAll
-
putDirAt
An indexed directory represents all elements which begin with a path which's last path element represents an index. There may by many sub-paths for the same indexed path which are all are included by the according directory. Puts the given values below the path at the given index.- Specified by:
putDirAtin interfaceImmutablePathTable.MutablePathTable<Class<?>>- Parameters:
aPathElements- The path elements of the path where to put the indexed element.aIndex- The index of the indexed element.aDir- The values to be put at the index.- Returns:
- The directory which has been replaced by the given directory.
-
putDirAt
default ClassStructTable putDirAt(Collection<?> aPathElements, int aIndex, ImmutablePathTable<Class<?>> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index. There may by many sub-paths for the same indexed path which are all are included by the according directory. Puts the given values below the path at the given index.- Specified by:
putDirAtin interfaceImmutablePathTable.MutablePathTable<Class<?>>- Parameters:
aPathElements- The path elements of the path where to put the indexed element.aIndex- The index of the indexed element.aDir- The values to be put at the index.- Returns:
- The directory which has been replaced by the given directory.
-
putDirAt
An indexed directory represents all elements which begin with a path which's last path element represents an index. There may by many sub-paths for the same indexed path which are all are included by the according directory. Puts the given values below the root path at the given index.- Specified by:
putDirAtin interfaceImmutablePathTable.MutablePathTable<Class<?>>- Parameters:
aIndex- The index of the indexed element.aDir- The values to be put at the index.- Returns:
- The directory which has been replaced by the given directory.
-
putDirAt
An indexed directory represents all elements which begin with a path which's last path element represents an index. There may by many sub-paths for the same indexed path which are all are included by the according directory. Puts the given values below the root path at the given index.- Specified by:
putDirAtin interfaceImmutablePathTable.MutablePathTable<Class<?>>- Parameters:
aIndex- The index of the indexed element.aDir- The values to be put at the index.- Returns:
- The directory which has been replaced by the given directory.
-
putDirAt
An indexed directory represents all elements which begin with a path which's last path element represents an index. There may by many sub-paths for the same indexed path which are all are included by the according directory. Puts the given values below the path at the given index.- Specified by:
putDirAtin interfaceImmutablePathTable.MutablePathTable<Class<?>>- Parameters:
aPath- The path where to put the indexed element.aIndex- The index of the indexed element.aDir- The values to be put at the index.- Returns:
- The directory which has been replaced by the given directory.
-
putDirAt
An indexed directory represents all elements which begin with a path which's last path element represents an index. There may by many sub-paths for the same indexed path which are all are included by the according directory. Puts the given values below the path at the given index.- Specified by:
putDirAtin interfaceImmutablePathTable.MutablePathTable<Class<?>>- Parameters:
aPath- The path where to put the indexed element.aIndex- The index of the indexed element.aDir- The values to be put at the index.- Returns:
- The directory which has been replaced by the given directory.
-
putDirAt
An indexed directory represents all elements which begin with a path which's last path element represents an index. There may by many sub-paths for the same indexed path which are all are included by the according directory. Puts the given values below the path at the given index.- Specified by:
putDirAtin interfaceImmutablePathTable.MutablePathTable<Class<?>>- Parameters:
aPathElements- The path elements of the path where to put the indexed element.aIndex- The index of the indexed element.aDir- The values to be put at the index.- Returns:
- The directory which has been replaced by the given directory.
-
putDirAt
default ClassStructTable putDirAt(Object[] aPathElements, int aIndex, ImmutablePathTable<Class<?>> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index. There may by many sub-paths for the same indexed path which are all are included by the according directory. Puts the given values below the path at the given index.- Specified by:
putDirAtin interfaceImmutablePathTable.MutablePathTable<Class<?>>- Parameters:
aPathElements- The path elements of the path where to put the indexed element.aIndex- The index of the indexed element.aDir- The values to be put at the index.- Returns:
- The directory which has been replaced by the given directory.
-
putDirAt
An indexed directory represents all elements which begin with a path which's last path element represents an index. There may by many sub-paths for the same indexed path which are all are included by the according directory. Puts the given values below the path at the given index.- Specified by:
putDirAtin interfaceImmutablePathTable.MutablePathTable<Class<?>>- Parameters:
aPath- The path where to put the indexed element.aIndex- The index of the indexed element.aDir- The values to be put at the index.- Returns:
- The directory which has been replaced by the given directory.
-
putDirAt
An indexed directory represents all elements which begin with a path which's last path element represents an index. There may by many sub-paths for the same indexed path which are all are included by the according directory. Puts the given values below the path at the given index.- Specified by:
putDirAtin interfaceImmutablePathTable.MutablePathTable<Class<?>>- Parameters:
aPath- The path where to put the indexed element.aIndex- The index of the indexed element.aDir- The values to be put at the index.- Returns:
- The directory which has been replaced by the given directory.
-
putDirAt
An indexed directory represents all elements which begin with a path which's last path element represents an index. There may by many sub-paths for the same indexed path which are all are included by the according directory. Puts the given values below the path at the given index.- Specified by:
putDirAtin interfaceImmutablePathTable.MutablePathTable<Class<?>>- Parameters:
aPathElements- The path elements of the path where to put the indexed element.aIndex- The index of the indexed element.aDir- The values to be put at the index.- Returns:
- The directory which has been replaced by the given directory.
-
putDirAt
default ClassStructTable putDirAt(String[] aPathElements, int aIndex, ImmutablePathTable<Class<?>> aDir) An indexed directory represents all elements which begin with a path which's last path element represents an index. There may by many sub-paths for the same indexed path which are all are included by the according directory. Puts the given values below the path at the given index.- Specified by:
putDirAtin interfaceImmutablePathTable.MutablePathTable<Class<?>>- Parameters:
aPathElements- The path elements of the path where to put the indexed element.aIndex- The index of the indexed element.aDir- The values to be put at the index.- Returns:
- The directory which has been replaced by the given directory.
-
removeAll
Removes all elements which's keys match the provided path query. Queries the keys of the instance using thePathMatcher' matching patterns, similar to the wildcards '*', '?' and '**' known when querying folders of a filesystem: ThePathMatcherapplies the following rules from the ANT path pattern to the query provided: A single asterisk ("*" as ofWildcard.FILE) matches zero or more characters within a path name. A double asterisk ("**" as ofWildcard.PATH) matches zero or more characters across directory levels. A question mark ("?" as ofWildcard.CHAR) matches exactly one character within a path name. The single asterisk ("*" as ofWildcard.FILE), the double asterisk ("**" as ofWildcard.PATH) and the question mark ("?" as ofWildcard.CHAR) we refer to as wildcards.- Specified by:
removeAllin interfaceImmutablePathTable.MutablePathTable<Class<?>>- Parameters:
aPathQueryElements- The elements representing your path query including your wildcards.- Returns:
- The removed properties.
-
removeAll
Removes all elements which's keys match the provided path query. Queries the keys of the instance using thePathMatcher' matching patterns, similar to the wildcards '*', '?' and '**' known when querying folders of a filesystem: ThePathMatcherapplies the following rules from the ANT path pattern to the query provided: A single asterisk ("*" as ofWildcard.FILE) matches zero or more characters within a path name. A double asterisk ("**" as ofWildcard.PATH) matches zero or more characters across directory levels. A question mark ("?" as ofWildcard.CHAR) matches exactly one character within a path name. The single asterisk ("*" as ofWildcard.FILE), the double asterisk ("**" as ofWildcard.PATH) and the question mark ("?" as ofWildcard.CHAR) we refer to as wildcards.- Specified by:
removeAllin interfaceImmutablePathTable.MutablePathTable<Class<?>>- Parameters:
aPathQueryElements- The elements representing your path query including your wildcards.- Returns:
- The removed properties.
-
removeAll
Removes all elements which's keys match the provided path query. Queries the keys of the instance using thePathMatcher' matching patterns, similar to the wildcards '*', '?' and '**' known when querying folders of a filesystem: ThePathMatcherapplies the following rules from the ANT path pattern to the query provided: A single asterisk ("*" as ofWildcard.FILE) matches zero or more characters within a path name. A double asterisk ("**" as ofWildcard.PATH) matches zero or more characters across directory levels. A question mark ("?" as ofWildcard.CHAR) matches exactly one character within a path name. The single asterisk ("*" as ofWildcard.FILE), the double asterisk ("**" as ofWildcard.PATH) and the question mark ("?" as ofWildcard.CHAR) we refer to as wildcards.- Specified by:
removeAllin interfaceImmutablePathTable.MutablePathTable<Class<?>>- Parameters:
aPathQuery- The path query including your wildcards.- Returns:
- The removed properties.
-
removeAll
Removes all elements which's keys match the provided regular expression: Queries the keys of the instance using the providedPattern.- Specified by:
removeAllin interfaceImmutablePathTable.MutablePathTable<Class<?>>- Parameters:
aRegExp- The regular expression to be used for the query.- Returns:
- The removed properties.
-
removeAll
Removes all elements which's keys match the provided path query. Queries the keys of the instance using thePathMatcher' matching patterns, similar to the wildcards '*', '?' and '**' known when querying folders of a filesystem: ThePathMatcherapplies the following rules from the ANT path pattern to the query provided: A single asterisk ("*" as ofWildcard.FILE) matches zero or more characters within a path name. A double asterisk ("**" as ofWildcard.PATH) matches zero or more characters across directory levels. A question mark ("?" as ofWildcard.CHAR) matches exactly one character within a path name. The single asterisk ("*" as ofWildcard.FILE), the double asterisk ("**" as ofWildcard.PATH) and the question mark ("?" as ofWildcard.CHAR) we refer to as wildcards.- Specified by:
removeAllin interfaceImmutablePathTable.MutablePathTable<Class<?>>- Parameters:
aPathQueryElements- The elements representing your path query including your wildcards.- Returns:
- The removed properties.
-
removeAll
Removes all elements which's keys match the provided path query. Queries the keys of the instance using thePathMatcher' matching patterns, similar to the wildcards '*', '?' and '**' known when querying folders of a filesystem: ThePathMatcherapplies the following rules from the ANT path pattern to the query provided: A single asterisk ("*" as ofWildcard.FILE) matches zero or more characters within a path name. A double asterisk ("**" as ofWildcard.PATH) matches zero or more characters across directory levels. A question mark ("?" as ofWildcard.CHAR) matches exactly one character within a path name. The single asterisk ("*" as ofWildcard.FILE), the double asterisk ("**" as ofWildcard.PATH) and the question mark ("?" as ofWildcard.CHAR) we refer to as wildcards.- Specified by:
removeAllin interfaceImmutablePathTable.MutablePathTable<Class<?>>- Parameters:
aPathQuery- The path query including your wildcards.- Returns:
- The removed properties.
-
removeDirAt
An indexed directory represents all elements which begin with a path which's last path element represents an index. There may by many sub-paths for the same indexed path which are all are included by the according directory. Removes the elements of the given index below the root path. Given the following paths and index = 1:/0/0aaa /0/0bbb /0/0bbb /1/1aaa /1/1bbb /1/1bbbYou will get a result containing all the elements which's keys begin with "/1/". The keys of the result will exclude the path "prefix" "/1".- Specified by:
removeDirAtin interfaceImmutablePathTable.MutablePathTable<Class<?>>- Parameters:
aIndex- The index which to use.- Returns:
- The indexed elements without the indexed path "prefixes".
-
removeDirAt
An indexed directory represents all elements which begin with a path which's last path element represents an index. There may by many sub-paths for the same indexed path which are all are included by the according directory. Removes the elements of the given index below the given path. Given the following paths and index = 1 with a queried path "/root/child":/root/child/0/0aaa /root/child/0/0bbb /root/child/0/0bbb /root/child/1/1aaa /root/child/1/1bbb /root/child/1/1bbbYou will get a result containing all the elements which's keys begin with "/root/child/1/". The keys of the result will exclude the path "prefix" "/root/child/1".- Specified by:
removeDirAtin interfaceImmutablePathTable.MutablePathTable<Class<?>>- Parameters:
aPath- The path from which to remove the indexed elements.aIndex- The index which to use.- Returns:
- The indexed elements without the indexed path "prefixes".
-
removeDirAt
An indexed directory represents all elements which begin with a path which's last path element represents an index. There may by many sub-paths for the same indexed path which are all are included by the according directory. Removes the elements of the given index below the given path. Given the following paths and index = 1 with a queried path "/root/child":/root/child/0/0aaa /root/child/0/0bbb /root/child/0/0bbb /root/child/1/1aaa /root/child/1/1bbb /root/child/1/1bbbYou will get a result containing all the elements which's keys begin with "/root/child/1/".The keys of the result will exclude the path "prefix" "/root/child/1".- Specified by:
removeDirAtin interfaceImmutablePathTable.MutablePathTable<Class<?>>- Parameters:
aPathElements- The elements of the path from which to remove the indexed elements.aIndex- The index which to use.- Returns:
- The indexed elements without the indexed path "prefixes".
-
removeDirAt
An indexed directory represents all elements which begin with a path which's last path element represents an index. There may by many sub-paths for the same indexed path which are all are included by the according directory. Removes the elements of the given index below the given path. Given the following paths and index = 1 with a queried path "/root/child":/root/child/0/0aaa /root/child/0/0bbb /root/child/0/0bbb /root/child/1/1aaa /root/child/1/1bbb /root/child/1/1bbbYou will get a result containing all the elements which's keys begin with "/root/child/1/".The keys of the result will exclude the path "prefix" "/root/child/1".- Specified by:
removeDirAtin interfaceImmutablePathTable.MutablePathTable<Class<?>>- Parameters:
aPath- The path from which to remove the indexed elements.aIndex- The index which to use.- Returns:
- The indexed elements without the indexed path "prefixes".
-
removeDirAt
An indexed directory represents all elements which begin with a path which's last path element represents an index. There may by many sub-paths for the same indexed path which are all are included by the according directory. Removes the elements of the given index below the given path. Given the following paths and index = 1 with a queried path "/root/child":/root/child/0/0aaa /root/child/0/0bbb /root/child/0/0bbb /root/child/1/1aaa /root/child/1/1bbb /root/child/1/1bbbYou will get a result containing all the elements which's keys begin with "/root/child/1/".The keys of the result will exclude the path "prefix" "/root/child/1".- Specified by:
removeDirAtin interfaceImmutablePathTable.MutablePathTable<Class<?>>- Parameters:
aPathElements- The elements of the path from which to remove the indexed elements.aIndex- The index which to use.- Returns:
- The indexed elements without the indexed path "prefixes".
-
removeFrom
Removes all properties below the provided path and returns thePathTablewith the removed elements, by which the paths exclude the parent's path.- Specified by:
removeFromin interfaceImmutablePathTable.MutablePathTable<Class<?>>- Parameters:
aPathElements- The path elements for the path from where to remove all properties.- Returns:
- The removed properties.
-
removeFrom
Removes all properties below the provided path and returns thePathTablewith the removed elements, by which the paths exclude the parent's path.- Specified by:
removeFromin interfaceImmutablePathTable.MutablePathTable<Class<?>>- Parameters:
aPathElements- The path elements for the path from where to remove all properties.- Returns:
- The removed properties.
-
removeFrom
Removes all properties below the provided path and returns thePathTablewith the removed elements, by which the paths exclude the parent's path.- Specified by:
removeFromin interfaceImmutablePathTable.MutablePathTable<Class<?>>- Parameters:
aPath- The path from where to remove all properties.- Returns:
- The removed properties.
-
removeFrom
Removes all properties below the provided path and returns thePathTablewith the removed elements, by which the paths exclude the parent's path.- Specified by:
removeFromin interfaceImmutablePathTable.MutablePathTable<Class<?>>- Parameters:
aPath- The path from where to remove all properties.- Returns:
- The removed properties.
-
removeFrom
Removes all properties below the provided path and returns thePathTablewith the removed elements, by which the paths exclude the parent's path.- Specified by:
removeFromin interfaceImmutablePathTable.MutablePathTable<Class<?>>- Parameters:
aPathElements- The path elements for the path from where to remove all properties.- Returns:
- The removed properties.
-
removePaths
Removes the paths contained in the provided collection.- Specified by:
removePathsin interfaceImmutablePathTable.MutablePathTable<Class<?>>- Parameters:
aPaths- The paths to be removed.- Returns:
- The removed properties.
-
removePaths
Removes the paths contained in the provided collection.- Specified by:
removePathsin interfaceImmutablePathTable.MutablePathTable<Class<?>>- Parameters:
aPaths- The paths to be removed.- Returns:
- The removed properties.
-