Interface ImmutableTable.MutableTable<K,V>

Type Parameters:
K - The type of the keys.
V - The type of a value relating to a key.
All Superinterfaces:
org.refcodes.mixin.Clearable, Containable, org.refcodes.mixin.EmptyAccessor, ImmutableTable<K,V>, Keys<K,V>, Keys.MutableKeys<K,V>, Keys.MutableValues<K,V>
All Known Subinterfaces:
CanonicalTable, ClassStructTable, ImmutableCanonicalTable.MutableCanonicalTable, ImmutableClassStructTable.MutableClassStructTable, ImmutableInterOperableTable.MutableInterOperableTable<T>, ImmutablePathTable.MutablePathTable<T>, ImmutableSimpleTypeTable.MutableSimpleTypeTable, InterOperableTable<T>, PathTable<T>, SimpleTypeTable, Table<K,V,B>
All Known Implementing Classes:
MapCanonicalTable, MapClassStructTable, MapPathTable, MapSimpleTypeTable
Enclosing interface:
ImmutableTable<K,V>

public static interface ImmutableTable.MutableTable<K,V> extends ImmutableTable<K,V>, Keys.MutableValues<K,V>
The ImmutableTable.MutableTable type extends the ImmutableTable type with mutable (writable) functionality and provides mutator methods such as Keys.MutableValues.put(Object, Object) and Keys.MutableKeys.delete(String) methods.
  • Nested Class Summary

    Nested classes/interfaces inherited from interface org.refcodes.mixin.EmptyAccessor

    org.refcodes.mixin.EmptyAccessor.EmptyBuilder<B extends org.refcodes.mixin.EmptyAccessor.EmptyBuilder<B>>, org.refcodes.mixin.EmptyAccessor.EmptyMutator, org.refcodes.mixin.EmptyAccessor.EmptyProperty

    Nested classes/interfaces inherited from interface org.refcodes.struct.ImmutableTable

    ImmutableTable.MutableTable<K,V>

    Nested classes/interfaces inherited from interface org.refcodes.struct.Keys

    Keys.MutableKeys<K,V>, Keys.MutableValues<K,V>
  • Method Summary

    Modifier and Type
    Method
    Description
    put(Relation<K,V> aRelation)
    Adds the given element related to the given key.

    Methods inherited from interface org.refcodes.mixin.Clearable

    clear

    Methods inherited from interface org.refcodes.struct.Containable

    size

    Methods inherited from interface org.refcodes.mixin.EmptyAccessor

    isEmpty

    Methods inherited from interface org.refcodes.struct.Keys

    containsKey, containsValue, get, getOr, keySet, use, values

    Methods inherited from interface org.refcodes.struct.Keys.MutableKeys

    delete

    Methods inherited from interface org.refcodes.struct.Keys.MutableValues

    put
  • Method Details

    • put

      V put(Relation<K,V> aRelation)
      Adds the given element related to the given key.
      Parameters:
      aRelation - the relation
      Returns:
      The value being replaced by the provided value or null if none value has been replaced.