Class MapClassStructTable
- All Implemented Interfaces:
Serializable,Map<String,,Class<?>> org.refcodes.mixin.AnnotatorAccessor,org.refcodes.mixin.Clearable,org.refcodes.mixin.DelimiterAccessor,org.refcodes.mixin.EmptyAccessor,org.refcodes.mixin.TypeAccessor<Class<?>>,ClassStructTable,Containable,ImmutableClassStructTable,ImmutableClassStructTable.MutableClassStructTable,ImmutablePathTable<Class<?>>,ImmutablePathTable.MutablePathTable<Class<?>>,ImmutableTable<String,,Class<?>> ImmutableTable.MutableTable<String,,Class<?>> Keys<String,,Class<?>> Keys.MutableKeys<String,,Class<?>> Keys.MutableValues<String,,Class<?>> PathTable<Class<?>>,Table<String,,Class<?>, PathTable<Class<?>>> TypeModeAccessor
- See Also:
-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.mixin.AnnotatorAccessor
org.refcodes.mixin.AnnotatorAccessor.AnnotatorBuilder<B extends org.refcodes.mixin.AnnotatorAccessor.AnnotatorBuilder<B>>, org.refcodes.mixin.AnnotatorAccessor.AnnotatorMutator, org.refcodes.mixin.AnnotatorAccessor.AnnotatorPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.DelimiterAccessor
org.refcodes.mixin.DelimiterAccessor.DelimiterBuilder<B extends org.refcodes.mixin.DelimiterAccessor.DelimiterBuilder<B>>, org.refcodes.mixin.DelimiterAccessor.DelimiterMutator, org.refcodes.mixin.DelimiterAccessor.DelimiterPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.EmptyAccessor
org.refcodes.mixin.EmptyAccessor.EmptyBuilder<B extends org.refcodes.mixin.EmptyAccessor.EmptyBuilder<B>>, org.refcodes.mixin.EmptyAccessor.EmptyMutator, org.refcodes.mixin.EmptyAccessor.EmptyPropertyNested classes/interfaces inherited from interface org.refcodes.struct.ImmutableClassStructTable
ImmutableClassStructTable.MutableClassStructTableNested classes/interfaces inherited from interface org.refcodes.struct.ImmutablePathTable
ImmutablePathTable.MutablePathTable<T>Nested classes/interfaces inherited from interface org.refcodes.struct.ImmutableTable
ImmutableTable.MutableTable<K,V> Nested classes/interfaces inherited from interface org.refcodes.struct.Keys
Keys.MutableKeys<K,V>, Keys.MutableValues<K, V> Nested classes/interfaces inherited from interface org.refcodes.mixin.TypeAccessor
org.refcodes.mixin.TypeAccessor.TypeBuilder<T,B extends org.refcodes.mixin.TypeAccessor.TypeBuilder<T, B>>, org.refcodes.mixin.TypeAccessor.TypeMutator<T>, org.refcodes.mixin.TypeAccessor.TypeProperty<T> Nested classes/interfaces inherited from interface org.refcodes.struct.TypeModeAccessor
TypeModeAccessor.TypeModeBuilder<B extends TypeModeAccessor.TypeModeBuilder<B>>, TypeModeAccessor.TypeModeMutator, TypeModeAccessor.TypeModeProperty -
Field Summary
Fields inherited from class org.refcodes.struct.MapPathTable
_backingMapFields inherited from interface org.refcodes.struct.ImmutableClassStructTable
ARRAY_SELECTORFields inherited from interface org.refcodes.struct.ImmutablePathTable
ANNOTATOR, DELIMITER -
Constructor Summary
ConstructorsConstructorDescriptionCreate an emptyClassStructTableinstance using the default path delimiter "/" (Delimiter.PATH) for the path declarations.MapClassStructTable(char aDelimiter) Create aClassStructTableinstance using the provided path delimiter for the path declarations.MapClassStructTable(char aDelimiter, Map<String, Class<?>> aBackingMap) Create aClassStructTableinstance using the provided path delimiter for the path declarations.MapClassStructTable(char aDelimiter, SimpleType aTypeMode) Create aClassStructTableinstance using the provided path delimiter for the path declarations.MapClassStructTable(char aDelimiter, SimpleType aTypeMode, Map<String, Class<?>> aBackingMap) Create aClassStructTableinstance using the provided path delimiter for the path declarations.MapClassStructTable(Object aObj) Create aClassStructTableinstance containing the elements as ofImmutablePathTable.MutablePathTable.insert(Object)using the default path delimiter "/" (Delimiter.PATH) for the path declarations.MapClassStructTable(Object aObj, char aDelimiter) Creates aClassStructTableinstance containing the elements as ofImmutablePathTable.MutablePathTable.insert(Object).MapClassStructTable(Object aObj, char aDelimiter, Map<String, Class<?>> aBackingMap) Creates aClassStructTableinstance containing the elements as ofImmutablePathTable.MutablePathTable.insert(Object).MapClassStructTable(Object aObj, char aDelimiter, SimpleType aTypeMode) Creates aClassStructTableinstance containing the elements as ofImmutablePathTable.MutablePathTable.insert(Object).MapClassStructTable(Object aObj, char aDelimiter, SimpleType aTypeMode, Map<String, Class<?>> aBackingMap) Creates aClassStructTableinstance containing the elements as ofImmutablePathTable.MutablePathTable.insert(Object).MapClassStructTable(Object aObj, String aFromPath) Creates aClassStructTableinstance containing the elements as ofImmutablePathTable.MutablePathTable.insert(Object)using the default path delimiter "/" (Delimiter.PATH) for the path declarations.MapClassStructTable(Object aObj, String aFromPath, char aDelimiter) Creates aClassStructTableinstance containing the elements as ofImmutablePathTable.MutablePathTable.insert(Object).MapClassStructTable(Object aObj, String aFromPath, char aDelimiter, Map<String, Class<?>> aBackingMap) Creates aClassStructTableinstance containing the elements as ofImmutablePathTable.MutablePathTable.insert(Object).MapClassStructTable(Object aObj, String aFromPath, char aDelimiter, SimpleType aTypeMode) Creates aClassStructTableinstance containing the elements as ofImmutablePathTable.MutablePathTable.insert(Object).MapClassStructTable(Object aObj, String aFromPath, char aDelimiter, SimpleType aTypeMode, Map<String, Class<?>> aBackingMap) Creates aClassStructTableinstance containing the elements as ofImmutablePathTable.MutablePathTable.insert(Object).Creates aClassStructTableinstance containing the elements as ofImmutablePathTable.MutablePathTable.insert(Object)using the default path delimiter "/" (Delimiter.PATH) for the path declarations.MapClassStructTable(Object aObj, String aFromPath, SimpleType aTypeMode) Creates aClassStructTableinstance containing the elements as ofImmutablePathTable.MutablePathTable.insert(Object)using the default path delimiter "/" (Delimiter.PATH) for the path declarations.MapClassStructTable(Object aObj, String aFromPath, SimpleType aTypeMode, Map<String, Class<?>> aBackingMap) Creates aClassStructTableinstance containing the elements as ofImmutablePathTable.MutablePathTable.insert(Object)using the default path delimiter "/" (Delimiter.PATH) for the path declarations.MapClassStructTable(Object aObj, Map<String, Class<?>> aBackingMap) Create aClassStructTableinstance containing the elements as ofImmutablePathTable.MutablePathTable.insert(Object)using the default path delimiter "/" (Delimiter.PATH) for the path declarations.MapClassStructTable(Object aObj, SimpleType aTypeMode) Create aClassStructTableinstance containing the elements as ofImmutablePathTable.MutablePathTable.insert(Object)using the default path delimiter "/" (Delimiter.PATH) for the path declarations.MapClassStructTable(Object aObj, SimpleType aTypeMode, Map<String, Class<?>> aBackingMap) Create aClassStructTableinstance containing the elements as ofImmutablePathTable.MutablePathTable.insert(Object)using the default path delimiter "/" (Delimiter.PATH) for the path declarations.MapClassStructTable(String aToPath, Object aObj) Create aClassStructTableinstance containing the elements as ofImmutablePathTable.MutablePathTable.insert(Object)using the default path delimiter "/" (Delimiter.PATH) for the path declarations.MapClassStructTable(String aToPath, Object aObj, char aDelimiter) Creates aClassStructTableinstance containing the elements as ofImmutablePathTable.MutablePathTable.insert(Object).Creates aClassStructTableinstance containing the elements as ofImmutablePathTable.MutablePathTable.insert(Object).MapClassStructTable(String aToPath, Object aObj, char aDelimiter, SimpleType aTypeMode) Creates aClassStructTableinstance containing the elements as ofImmutablePathTable.MutablePathTable.insert(Object).MapClassStructTable(String aToPath, Object aObj, char aDelimiter, SimpleType aTypeMode, Map<String, Class<?>> aBackingMap) Creates aClassStructTableinstance containing the elements as ofImmutablePathTable.MutablePathTable.insert(Object).MapClassStructTable(String aToPath, Object aObj, String aFromPath) Creates aClassStructTableinstance containing the elements as ofImmutablePathTable.MutablePathTable.insert(Object)using the default path delimiter "/" (Delimiter.PATHfor the path declarations.MapClassStructTable(String aToPath, Object aObj, String aFromPath, char aDelimiter) Create aClassStructTableinstance containing the elements as ofImmutablePathTable.MutablePathTable.insert(Object).MapClassStructTable(String aToPath, Object aObj, String aFromPath, char aDelimiter, Map<String, Class<?>> aBackingMap) Create aClassStructTableinstance containing the elements as ofImmutablePathTable.MutablePathTable.insert(Object).MapClassStructTable(String aToPath, Object aObj, String aFromPath, char aDelimiter, SimpleType aTypeMode) Create aClassStructTableinstance containing the elements as ofImmutablePathTable.MutablePathTable.insert(Object).MapClassStructTable(String aToPath, Object aObj, String aFromPath, char aDelimiter, SimpleType aTypeMode, Map<String, Class<?>> aBackingMap) Create aClassStructTableinstance containing the elements as ofImmutablePathTable.MutablePathTable.insert(Object).MapClassStructTable(String aToPath, Object aObj, String aFromPath, Map<String, Class<?>> aBackingMap) Creates aClassStructTableinstance containing the elements as ofImmutablePathTable.MutablePathTable.insert(Object)using the default path delimiter "/" (Delimiter.PATHfor the path declarations.MapClassStructTable(String aToPath, Object aObj, String aFromPath, SimpleType aTypeMode) Creates aClassStructTableinstance containing the elements as ofImmutablePathTable.MutablePathTable.insert(Object)using the default path delimiter "/" (Delimiter.PATHfor the path declarations.MapClassStructTable(String aToPath, Object aObj, String aFromPath, SimpleType aTypeMode, Map<String, Class<?>> aBackingMap) Creates aClassStructTableinstance containing the elements as ofImmutablePathTable.MutablePathTable.insert(Object)using the default path delimiter "/" (Delimiter.PATHfor the path declarations.Create aClassStructTableinstance containing the elements as ofImmutablePathTable.MutablePathTable.insert(Object)using the default path delimiter "/" (Delimiter.PATH) for the path declarations.MapClassStructTable(String aToPath, Object aObj, SimpleType aTypeMode) Create aClassStructTableinstance containing the elements as ofImmutablePathTable.MutablePathTable.insert(Object)using the default path delimiter "/" (Delimiter.PATH) for the path declarations.MapClassStructTable(String aToPath, Object aObj, SimpleType aTypeMode, Map<String, Class<?>> aBackingMap) Create aClassStructTableinstance containing the elements as ofImmutablePathTable.MutablePathTable.insert(Object)using the default path delimiter "/" (Delimiter.PATH) for the path declarations.MapClassStructTable(Map<String, Class<?>> aBackingMap) Create an emptyClassStructTableinstance using the default path delimiter "/" (Delimiter.PATH) for the path declarations.MapClassStructTable(SimpleType aTypeMode) Create an emptyClassStructTableinstance using the default path delimiter "/" (Delimiter.PATH) for the path declarations.MapClassStructTable(SimpleType aTypeMode, Map<String, Class<?>> aBackingMap) Create an emptyClassStructTableinstance using the default path delimiter "/" (Delimiter.PATH) for the path declarations. -
Method Summary
Modifier and TypeMethodDescriptionprotected Class<?> fromInstance(Object aValue) Hook method when introspecting an object to help conversion of that object to the target types.protected ImmutablePathTable<Class<?>> fromObject(Object aFrom) Hook method when internally creatingImmutablePathTablesub-types in the accordingImmutablePathTablesub-type implementations.protected voidHook method for intercepting or modifying the process of object introspection.Retrieves the type mode from the type mode property.retrieveFrom(String aFromPath) Extracts a newPathTablefrom the elements of this instance found below the "from-path".retrieveTo(String aToPath) Extracts a newPathTablefrom this instance's elements with the paths relocated to the provided "to-path".Builder method forKeys.MutableValues.put(Object, Object).Methods inherited from class org.refcodes.struct.MapPathTable
clear, compute, computeIfAbsent, computeIfPresent, containsKey, containsValue, createBackingMap, entrySet, equals, forEach, fromValue, get, getAnnotator, getDelimiter, getOrDefault, getType, hashCode, insert, insertBetween, insertFrom, insertTo, isEmpty, keySet, merge, merge, mergeBetween, mergeFrom, mergeTo, put, putAll, putIfAbsent, remove, remove, replace, replace, replaceAll, size, toDataStructure, toInstance, toString, toType, valuesMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface org.refcodes.mixin.AnnotatorAccessor
getAnnotatorMethods inherited from interface org.refcodes.struct.ClassStructTable
withInsert, withInsert, withInsertBetween, withInsertBetween, withInsertBetween, withInsertBetween, withInsertBetween, withInsertBetween, withInsertBetween, withInsertBetween, withInsertBetween, withInsertBetween, withInsertFrom, withInsertFrom, withInsertFrom, withInsertFrom, withInsertFrom, withInsertFrom, withInsertFrom, withInsertFrom, withInsertFrom, withInsertFrom, withInsertTo, withInsertTo, withInsertTo, withInsertTo, withInsertTo, withInsertTo, withInsertTo, withInsertTo, withInsertTo, withInsertTo, withMerge, withMerge, withMergeBetween, withMergeBetween, withMergeBetween, withMergeBetween, withMergeBetween, withMergeBetween, withMergeBetween, withMergeBetween, withMergeBetween, withMergeBetween, withMergeFrom, withMergeFrom, withMergeFrom, withMergeFrom, withMergeFrom, withMergeFrom, withMergeFrom, withMergeFrom, withMergeFrom, withMergeFrom, withMergeTo, withMergeTo, withMergeTo, withMergeTo, withMergeTo, withMergeTo, withMergeTo, withMergeTo, withMergeTo, withMergeTo, withPut, withPut, withPut, withPut, withPut, withPutDirAt, withPutDirAt, withPutDirAt, withPutDirAt, withPutDirAt, withPutDirAt, withPutDirAt, withPutDirAt, withPutDirAt, withPutDirAt, withPutDirAt, withPutDirAt, withRemoveFrom, withRemoveFrom, withRemoveFrom, withRemoveFrom, withRemoveFrom, withRemovePathsMethods inherited from interface org.refcodes.mixin.Clearable
clearMethods inherited from interface org.refcodes.struct.Containable
sizeMethods inherited from interface org.refcodes.mixin.DelimiterAccessor
getDelimiterMethods inherited from interface org.refcodes.mixin.EmptyAccessor
isEmptyMethods inherited from interface org.refcodes.struct.ImmutableClassStructTable
getArraySelector, getCompositeArrayDir, getCompositeArrayDir, getCompositeArrayDir, getCompositeArrayDir, getCompositeArrayDir, getCompositeArrayDir, getCompositeDir, getCompositeDir, getCompositeDir, getCompositeDir, getCompositeDir, getCompositeDir, getDir, getDir, getDir, getDir, getDir, getDirAt, getDirAt, getDirAt, getDirAt, getDirAt, getDirAt, getDirs, getDirs, getDirs, getDirs, getDirs, getPrimitiveArrayType, getPrimitiveArrayType, getPrimitiveArrayType, getPrimitiveArrayType, getPrimitiveArrayType, getPrimitiveArrayType, getPrimitiveType, getPrimitiveType, getPrimitiveType, getPrimitiveType, getPrimitiveType, getPrimitiveType, getSimpleArrayType, getSimpleArrayType, getSimpleArrayType, getSimpleArrayType, getSimpleArrayType, getSimpleArrayType, getSimpleType, getSimpleType, getSimpleType, getSimpleType, getSimpleType, getSimpleType, getWrapperArrayType, getWrapperArrayType, getWrapperArrayType, getWrapperArrayType, getWrapperArrayType, getWrapperArrayType, getWrapperType, getWrapperType, getWrapperType, getWrapperType, getWrapperType, getWrapperType, isArrayType, isArrayType, isArrayType, isArrayType, isArrayType, isArrayType, isCompositeArrayDir, isCompositeArrayDir, isCompositeArrayDir, isCompositeArrayDir, isCompositeArrayDir, isCompositeArrayDir, isCompositeDir, isCompositeDir, isCompositeDir, isCompositeDir, isCompositeDir, isCompositeDir, isPrimitiveArrayType, isPrimitiveArrayType, isPrimitiveArrayType, isPrimitiveArrayType, isPrimitiveArrayType, isPrimitiveArrayType, isPrimitiveType, isPrimitiveType, isPrimitiveType, isPrimitiveType, isPrimitiveType, isPrimitiveType, isSimpleArrayType, isSimpleArrayType, isSimpleArrayType, isSimpleArrayType, isSimpleArrayType, isSimpleArrayType, isSimpleType, isSimpleType, isSimpleType, isSimpleType, isSimpleType, isSimpleType, isWrapperArrayType, isWrapperArrayType, isWrapperArrayType, isWrapperArrayType, isWrapperArrayType, isWrapperArrayType, isWrapperType, isWrapperType, isWrapperType, isWrapperType, isWrapperType, isWrapperType, query, query, query, query, query, queryBetween, queryBetween, queryBetween, queryBetween, queryBetween, queryBetween, queryFrom, queryFrom, queryFrom, queryFrom, queryFrom, queryFrom, queryTo, queryTo, queryTo, queryTo, queryTo, queryTo, retrieveBetween, retrieveBetween, retrieveBetween, retrieveBetween, retrieveBetween, retrieveFrom, retrieveFrom, retrieveFrom, retrieveFrom, retrieveTo, retrieveTo, retrieveTo, retrieveTo, toMap, toPropertiesMethods inherited from interface org.refcodes.struct.ImmutableClassStructTable.MutableClassStructTable
containsValue, insert, insertBetween, insertFrom, insertTo, put, put, put, put, put, putAll, putAll, putAll, putDirAt, putDirAt, putDirAt, putDirAt, putDirAt, putDirAt, putDirAt, putDirAt, putDirAt, putDirAt, putDirAt, putDirAt, removeAll, removeAll, removeAll, removeAll, removeAll, removeAll, removeDirAt, removeDirAt, removeDirAt, removeDirAt, removeDirAt, removeFrom, removeFrom, removeFrom, removeFrom, removeFrom, removePaths, removePathsMethods inherited from interface org.refcodes.struct.ImmutablePathTable
children, children, children, children, children, children, containsKey, containsKey, containsKey, dirs, dirs, dirs, dirs, dirs, dirs, findPaths, fromExternalPath, get, get, get, getArray, getArray, getArray, getArray, getArray, getArray, getArrayIndexes, getArrayIndexes, getArrayIndexes, getArrayIndexes, getArrayIndexes, getArrayOr, getArrayOr, getArrayOr, getArrayOr, getArrayOr, getArrayOr, getDirIndexes, getDirIndexes, getDirIndexes, getDirIndexes, getDirIndexes, getDirIndexes, getRootPath, getValueAt, getValueAt, getValueAt, getValueAt, getValueAt, getValueAt, hasChildren, hasChildren, hasChildren, hasChildren, hasChildren, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasParentPath, hasPath, hasPath, hasPath, hasPath, hasPath, hasSubDirs, hasSubDirs, hasSubDirs, hasSubDirs, hasValue, hasValue, hasValue, hasValue, hasValue, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, isArray, isArray, isArray, isArray, isArray, isArray, isChild, isChild, isChild, isChild, isDir, isDir, isDir, isDir, isDir, isEqualTo, isIndexDir, isIndexDir, isIndexDir, isIndexDir, isIndexDir, isLeaf, isLeaf, isLeaf, isLeaf, isLeaf, isRootPath, keySet, keySet, keySet, keySet, keySet, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastDirIndex, lastDirIndex, lastDirIndex, lastDirIndex, lastDirIndex, lastDirIndex, leaves, leaves, leaves, leaves, leaves, leaves, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextDirIndex, nextDirIndex, nextDirIndex, nextDirIndex, nextDirIndex, nextDirIndex, paths, paths, paths, paths, paths, paths, queryPaths, queryPaths, queryPaths, queryPaths, queryPaths, queryPaths, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, toDataStructure, toDataStructure, toExternalPath, toInstance, toInstance, toLeaf, toMap, toNormalizedPath, toParentPath, toPath, toPath, toPath, toPath, toPathElements, toPathList, toPathStack, toPrintable, toPropertyPath, toType, toType, toType, toType, toType, toType, toType, toTypeMethods inherited from interface org.refcodes.struct.ImmutablePathTable.MutablePathTable
add, add, add, add, add, add, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendValueTo, appendValueTo, appendValueTo, appendValueTo, appendValueTo, appendValueTo, delete, delete, delete, delete, delete, fromType, fromType, fromType, fromType, fromType, fromType, fromType, fromType, insert, insert, insertBetween, insertBetween, insertBetween, insertBetween, insertBetween, insertBetween, insertBetween, insertBetween, insertBetween, insertBetween, insertFrom, insertFrom, insertFrom, insertFrom, insertFrom, insertFrom, insertFrom, insertFrom, insertFrom, insertFrom, insertTo, insertTo, insertTo, insertTo, insertTo, insertTo, insertTo, insertTo, insertTo, insertTo, merge, merge, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeTo, mergeTo, mergeTo, mergeTo, mergeTo, mergeTo, mergeTo, mergeTo, mergeTo, mergeTo, put, putArray, putArray, putArray, putArray, putArray, putArray, putArray, putArray, putArray, putArray, putArray, putArray, putValueAt, putValueAt, putValueAt, putValueAt, putValueAt, putValueAt, remove, remove, remove, removeValueAt, removeValueAt, removeValueAt, removeValueAt, removeValueAt, toSourceCode, toSourceCodeMethods inherited from interface org.refcodes.struct.Keys
containsKey, get, getOr, keySet, use, valuesMethods inherited from interface org.refcodes.struct.Keys.MutableValues
putMethods inherited from interface java.util.Map
clear, compute, computeIfAbsent, computeIfPresent, containsKey, containsValue, entrySet, equals, forEach, get, getOrDefault, hashCode, isEmpty, keySet, merge, put, putIfAbsent, remove, remove, replace, replace, replaceAll, size, valuesMethods inherited from interface org.refcodes.mixin.TypeAccessor
getType
-
Constructor Details
-
MapClassStructTable
public MapClassStructTable()Create an emptyClassStructTableinstance using the default path delimiter "/" (Delimiter.PATH) for the path declarations. -
MapClassStructTable
public MapClassStructTable(char aDelimiter) Create aClassStructTableinstance using the provided path delimiter for the path declarations.- Parameters:
aDelimiter- The path delimiter to be used for the path declarations.
-
MapClassStructTable
Create aClassStructTableinstance containing the elements as ofImmutablePathTable.MutablePathTable.insert(Object)using the default path delimiter "/" (Delimiter.PATH) for the path declarations.- Parameters:
aObj- The object from which the elements are to be added.
-
MapClassStructTable
Create aClassStructTableinstance containing the elements as ofImmutablePathTable.MutablePathTable.insert(Object)using the default path delimiter "/" (Delimiter.PATH) for the path declarations.- Parameters:
aToPath- The sub-path where to insert the object's introspected values to.aObj- The object from which the elements are to be added.
-
MapClassStructTable
Creates aClassStructTableinstance containing the elements as ofImmutablePathTable.MutablePathTable.insert(Object)using the default path delimiter "/" (Delimiter.PATH) for the path declarations.- Parameters:
aObj- The object from which the elements are to be added.aFromPath- The path from where to start adding elements of the provided object.
-
MapClassStructTable
Creates aClassStructTableinstance containing the elements as ofImmutablePathTable.MutablePathTable.insert(Object)using the default path delimiter "/" (Delimiter.PATHfor the path declarations.- Parameters:
aToPath- The sub-path where to insert the object's introspected values to.aObj- The object from which the elements are to be added.aFromPath- The path from where to start adding elements of the provided object.
-
MapClassStructTable
Creates aClassStructTableinstance containing the elements as ofImmutablePathTable.MutablePathTable.insert(Object).- Parameters:
aObj- The object from which the elements are to be added.aDelimiter- The path delimiter to be used for the path declarations.
-
MapClassStructTable
Creates aClassStructTableinstance containing the elements as ofImmutablePathTable.MutablePathTable.insert(Object).- Parameters:
aToPath- The sub-path where to insert the object's introspected values to.aObj- The object from which the elements are to be added.aDelimiter- The path delimiter to be used for the path declarations.
-
MapClassStructTable
Creates aClassStructTableinstance containing the elements as ofImmutablePathTable.MutablePathTable.insert(Object).- Parameters:
aObj- The object from which the elements are to be added.aFromPath- The path from where to start adding elements of the provided object.aDelimiter- The path delimiter to be used for the path declarations.
-
MapClassStructTable
Create aClassStructTableinstance containing the elements as ofImmutablePathTable.MutablePathTable.insert(Object).- Parameters:
aToPath- The sub-path where to insert the object's introspected values to.aObj- The object from which the elements are to be added.aFromPath- The path from where to start adding elements of the provided object.aDelimiter- The path delimiter to be used for the path declarations.
-
MapClassStructTable
Create an emptyClassStructTableinstance using the default path delimiter "/" (Delimiter.PATH) for the path declarations.- Parameters:
aTypeMode- TheSimpleTypeto use when processing primitive types, wrapper types or complex types.
-
MapClassStructTable
Create aClassStructTableinstance using the provided path delimiter for the path declarations.- Parameters:
aDelimiter- The path delimiter to be used for the path declarations.aTypeMode- TheSimpleTypeto use when processing primitive types, wrapper types or complex types.
-
MapClassStructTable
Create aClassStructTableinstance containing the elements as ofImmutablePathTable.MutablePathTable.insert(Object)using the default path delimiter "/" (Delimiter.PATH) for the path declarations.- Parameters:
aObj- The object from which the elements are to be added.aTypeMode- TheSimpleTypeto use when processing primitive types, wrapper types or complex types.
-
MapClassStructTable
Create aClassStructTableinstance containing the elements as ofImmutablePathTable.MutablePathTable.insert(Object)using the default path delimiter "/" (Delimiter.PATH) for the path declarations.- Parameters:
aToPath- The sub-path where to insert the object's introspected values to.aObj- The object from which the elements are to be added.aTypeMode- TheSimpleTypeto use when processing primitive types, wrapper types or complex types.
-
MapClassStructTable
Creates aClassStructTableinstance containing the elements as ofImmutablePathTable.MutablePathTable.insert(Object)using the default path delimiter "/" (Delimiter.PATH) for the path declarations.- Parameters:
aObj- The object from which the elements are to be added.aFromPath- The path from where to start adding elements of the provided object.aTypeMode- TheSimpleTypeto use when processing primitive types, wrapper types or complex types.
-
MapClassStructTable
Creates aClassStructTableinstance containing the elements as ofImmutablePathTable.MutablePathTable.insert(Object)using the default path delimiter "/" (Delimiter.PATHfor the path declarations.- Parameters:
aToPath- The sub-path where to insert the object's introspected values to.aObj- The object from which the elements are to be added.aFromPath- The path from where to start adding elements of the provided object.aTypeMode- TheSimpleTypeto use when processing primitive types, wrapper types or complex types.
-
MapClassStructTable
Creates aClassStructTableinstance containing the elements as ofImmutablePathTable.MutablePathTable.insert(Object).- Parameters:
aObj- The object from which the elements are to be added.aDelimiter- The path delimiter to be used for the path declarations.aTypeMode- TheSimpleTypeto use when processing primitive types, wrapper types or complex types.
-
MapClassStructTable
Creates aClassStructTableinstance containing the elements as ofImmutablePathTable.MutablePathTable.insert(Object).- Parameters:
aToPath- The sub-path where to insert the object's introspected values to.aObj- The object from which the elements are to be added.aDelimiter- The path delimiter to be used for the path declarations.aTypeMode- TheSimpleTypeto use when processing primitive types, wrapper types or complex types.
-
MapClassStructTable
Creates aClassStructTableinstance containing the elements as ofImmutablePathTable.MutablePathTable.insert(Object).- Parameters:
aObj- The object from which the elements are to be added.aFromPath- The path from where to start adding elements of the provided object.aDelimiter- The path delimiter to be used for the path declarations.aTypeMode- TheSimpleTypeto use when processing primitive types, wrapper types or complex types.
-
MapClassStructTable
public MapClassStructTable(String aToPath, Object aObj, String aFromPath, char aDelimiter, SimpleType aTypeMode) Create aClassStructTableinstance containing the elements as ofImmutablePathTable.MutablePathTable.insert(Object).- Parameters:
aToPath- The sub-path where to insert the object's introspected values to.aObj- The object from which the elements are to be added.aFromPath- The path from where to start adding elements of the provided object.aDelimiter- The path delimiter to be used for the path declarations.aTypeMode- TheSimpleTypeto use when processing primitive types, wrapper types or complex types.
-
MapClassStructTable
Create an emptyClassStructTableinstance using the default path delimiter "/" (Delimiter.PATH) for the path declarations.- Parameters:
aBackingMap- The backing map used as underlyingMapinstance.
-
MapClassStructTable
Create aClassStructTableinstance using the provided path delimiter for the path declarations.- Parameters:
aDelimiter- The path delimiter to be used for the path declarations.aBackingMap- The backing map used as underlyingMapinstance.
-
MapClassStructTable
Create aClassStructTableinstance containing the elements as ofImmutablePathTable.MutablePathTable.insert(Object)using the default path delimiter "/" (Delimiter.PATH) for the path declarations.- Parameters:
aObj- The object from which the elements are to be added.aBackingMap- The backing map used as underlyingMapinstance.
-
MapClassStructTable
Create aClassStructTableinstance containing the elements as ofImmutablePathTable.MutablePathTable.insert(Object)using the default path delimiter "/" (Delimiter.PATH) for the path declarations.- Parameters:
aToPath- The sub-path where to insert the object's introspected values to.aObj- The object from which the elements are to be added.aBackingMap- The backing map used as underlyingMapinstance.
-
MapClassStructTable
Creates aClassStructTableinstance containing the elements as ofImmutablePathTable.MutablePathTable.insert(Object)using the default path delimiter "/" (Delimiter.PATH) for the path declarations.- Parameters:
aObj- The object from which the elements are to be added.aFromPath- The path from where to start adding elements of the provided object.aBackingMap- The backing map used as underlyingMapinstance.
-
MapClassStructTable
public MapClassStructTable(String aToPath, Object aObj, String aFromPath, Map<String, Class<?>> aBackingMap) Creates aClassStructTableinstance containing the elements as ofImmutablePathTable.MutablePathTable.insert(Object)using the default path delimiter "/" (Delimiter.PATHfor the path declarations.- Parameters:
aToPath- The sub-path where to insert the object's introspected values to.aObj- The object from which the elements are to be added.aFromPath- The path from where to start adding elements of the provided object.aBackingMap- The backing map used as underlyingMapinstance.
-
MapClassStructTable
Creates aClassStructTableinstance containing the elements as ofImmutablePathTable.MutablePathTable.insert(Object).- Parameters:
aObj- The object from which the elements are to be added.aDelimiter- The path delimiter to be used for the path declarations.aBackingMap- The backing map used as underlyingMapinstance.
-
MapClassStructTable
public MapClassStructTable(String aToPath, Object aObj, char aDelimiter, Map<String, Class<?>> aBackingMap) Creates aClassStructTableinstance containing the elements as ofImmutablePathTable.MutablePathTable.insert(Object).- Parameters:
aToPath- The sub-path where to insert the object's introspected values to.aObj- The object from which the elements are to be added.aDelimiter- The path delimiter to be used for the path declarations.aBackingMap- The backing map used as underlyingMapinstance.
-
MapClassStructTable
public MapClassStructTable(Object aObj, String aFromPath, char aDelimiter, Map<String, Class<?>> aBackingMap) Creates aClassStructTableinstance containing the elements as ofImmutablePathTable.MutablePathTable.insert(Object).- Parameters:
aObj- The object from which the elements are to be added.aFromPath- The path from where to start adding elements of the provided object.aDelimiter- The path delimiter to be used for the path declarations.aBackingMap- The backing map used as underlyingMapinstance.
-
MapClassStructTable
public MapClassStructTable(String aToPath, Object aObj, String aFromPath, char aDelimiter, Map<String, Class<?>> aBackingMap) Create aClassStructTableinstance containing the elements as ofImmutablePathTable.MutablePathTable.insert(Object).- Parameters:
aToPath- The sub-path where to insert the object's introspected values to.aObj- The object from which the elements are to be added.aFromPath- The path from where to start adding elements of the provided object.aDelimiter- The path delimiter to be used for the path declarations.aBackingMap- The backing map used as underlyingMapinstance.
-
MapClassStructTable
Create an emptyClassStructTableinstance using the default path delimiter "/" (Delimiter.PATH) for the path declarations.- Parameters:
aTypeMode- TheSimpleTypeto use when processing primitive types, wrapper types or complex types.aBackingMap- The backing map used as underlyingMapinstance.
-
MapClassStructTable
Create aClassStructTableinstance using the provided path delimiter for the path declarations.- Parameters:
aDelimiter- The path delimiter to be used for the path declarations.aTypeMode- TheSimpleTypeto use when processing primitive types, wrapper types or complex types.aBackingMap- The backing map used as underlyingMapinstance.
-
MapClassStructTable
Create aClassStructTableinstance containing the elements as ofImmutablePathTable.MutablePathTable.insert(Object)using the default path delimiter "/" (Delimiter.PATH) for the path declarations.- Parameters:
aObj- The object from which the elements are to be added.aTypeMode- TheSimpleTypeto use when processing primitive types, wrapper types or complex types.aBackingMap- The backing map used as underlyingMapinstance.
-
MapClassStructTable
public MapClassStructTable(String aToPath, Object aObj, SimpleType aTypeMode, Map<String, Class<?>> aBackingMap) Create aClassStructTableinstance containing the elements as ofImmutablePathTable.MutablePathTable.insert(Object)using the default path delimiter "/" (Delimiter.PATH) for the path declarations.- Parameters:
aToPath- The sub-path where to insert the object's introspected values to.aObj- The object from which the elements are to be added.aTypeMode- TheSimpleTypeto use when processing primitive types, wrapper types or complex types.aBackingMap- The backing map used as underlyingMapinstance.
-
MapClassStructTable
public MapClassStructTable(Object aObj, String aFromPath, SimpleType aTypeMode, Map<String, Class<?>> aBackingMap) Creates aClassStructTableinstance containing the elements as ofImmutablePathTable.MutablePathTable.insert(Object)using the default path delimiter "/" (Delimiter.PATH) for the path declarations.- Parameters:
aObj- The object from which the elements are to be added.aFromPath- The path from where to start adding elements of the provided object.aTypeMode- TheSimpleTypeto use when processing primitive types, wrapper types or complex types.aBackingMap- The backing map used as underlyingMapinstance.
-
MapClassStructTable
public MapClassStructTable(String aToPath, Object aObj, String aFromPath, SimpleType aTypeMode, Map<String, Class<?>> aBackingMap) Creates aClassStructTableinstance containing the elements as ofImmutablePathTable.MutablePathTable.insert(Object)using the default path delimiter "/" (Delimiter.PATHfor the path declarations.- Parameters:
aToPath- The sub-path where to insert the object's introspected values to.aObj- The object from which the elements are to be added.aFromPath- The path from where to start adding elements of the provided object.aTypeMode- TheSimpleTypeto use when processing primitive types, wrapper types or complex types.aBackingMap- The backing map used as underlyingMapinstance.
-
MapClassStructTable
public MapClassStructTable(Object aObj, char aDelimiter, SimpleType aTypeMode, Map<String, Class<?>> aBackingMap) Creates aClassStructTableinstance containing the elements as ofImmutablePathTable.MutablePathTable.insert(Object).- Parameters:
aObj- The object from which the elements are to be added.aDelimiter- The path delimiter to be used for the path declarations.aTypeMode- TheSimpleTypeto use when processing primitive types, wrapper types or complex types.aBackingMap- The backing map used as underlyingMapinstance.
-
MapClassStructTable
public MapClassStructTable(String aToPath, Object aObj, char aDelimiter, SimpleType aTypeMode, Map<String, Class<?>> aBackingMap) Creates aClassStructTableinstance containing the elements as ofImmutablePathTable.MutablePathTable.insert(Object).- Parameters:
aToPath- The sub-path where to insert the object's introspected values to.aObj- The object from which the elements are to be added.aDelimiter- The path delimiter to be used for the path declarations.aTypeMode- TheSimpleTypeto use when processing primitive types, wrapper types or complex types.aBackingMap- The backing map used as underlyingMapinstance.
-
MapClassStructTable
public MapClassStructTable(Object aObj, String aFromPath, char aDelimiter, SimpleType aTypeMode, Map<String, Class<?>> aBackingMap) Creates aClassStructTableinstance containing the elements as ofImmutablePathTable.MutablePathTable.insert(Object).- Parameters:
aObj- The object from which the elements are to be added.aFromPath- The path from where to start adding elements of the provided object.aDelimiter- The path delimiter to be used for the path declarations.aTypeMode- TheSimpleTypeto use when processing primitive types, wrapper types or complex types.aBackingMap- The backing map used as underlyingMapinstance.
-
MapClassStructTable
public MapClassStructTable(String aToPath, Object aObj, String aFromPath, char aDelimiter, SimpleType aTypeMode, Map<String, Class<?>> aBackingMap) Create aClassStructTableinstance containing the elements as ofImmutablePathTable.MutablePathTable.insert(Object).- Parameters:
aToPath- The sub-path where to insert the object's introspected values to.aObj- The object from which the elements are to be added.aFromPath- The path from where to start adding elements of the provided object.aDelimiter- The path delimiter to be used for the path declarations.aTypeMode- TheSimpleTypeto use when processing primitive types, wrapper types or complex types.aBackingMap- The backing map used as underlyingMapinstance.
-
-
Method Details
-
getTypeMode
Retrieves the type mode from the type mode property.- Specified by:
getTypeModein interfaceTypeModeAccessor- Returns:
- The type mode stored by the type mode property.
-
retrieveFrom
Extracts a newPathTablefrom the elements of this instance found below the "from-path". The sub-paths will be the root paths for the newPathTable. Given we have a value for path "/dog/cat" in thePathTableand we callImmutablePathTable.retrieveFrom(String)with "/dog", then the resultingPathTablewill contain the path "/cat" for that value.- Specified by:
retrieveFromin interfaceImmutableClassStructTable- Specified by:
retrieveFromin interfaceImmutablePathTable<Class<?>>- Overrides:
retrieveFromin classMapPathTable<Class<?>>- Parameters:
aFromPath- The path from where to start extracting the paths.- Returns:
- The
PathTablewith the elements below the provided path which are root elements in the newPathTable.
-
retrieveTo
Extracts a newPathTablefrom this instance's elements with the paths relocated to the provided "to-path". Given we have a value for path "/dog/cat" in thePathTableand we callImmutablePathTable.retrieveTo(String)with "/animals", then the resultingPathTablewill contain the path "/animals/dog/cat" for that value.- Specified by:
retrieveToin interfaceImmutableClassStructTable- Specified by:
retrieveToin interfaceImmutablePathTable<Class<?>>- Overrides:
retrieveToin classMapPathTable<Class<?>>- Parameters:
aToPath- The path where to relocate the paths of thisPathTableto.- Returns:
- The
PathTablewith the elements from the providedPathTablewith accordingly relocated paths.
-
withPut
Builder method forKeys.MutableValues.put(Object, Object). -
fromValue
Hook method for intercepting or modifying the process of object introspection.- Overrides:
fromValuein classMapPathTable<Class<?>>- Parameters:
aToPath- The sub-path where to insert the object's introspected values to.aObj- The object from which the elements are to be added.
-
fromObject
Hook method when internally creatingImmutablePathTablesub-types in the accordingImmutablePathTablesub-type implementations.- Overrides:
fromObjectin classMapPathTable<Class<?>>- Parameters:
aFrom- TheObjectfrom which to create aImmutablePathTable(sub-type) instance.- Returns:
- The according
ImmutablePathTable(sub-type) instance.
-
fromInstance
Hook method when introspecting an object to help conversion of that object to the target types. By default this methods just tests for assignment conformity as ofClass.isAssignableFrom(Class)with the type retrieved byMapPathTable.getType().- Overrides:
fromInstancein classMapPathTable<Class<?>>- Parameters:
aValue- The value which is to be transformed to the expected type as ofMapPathTable.getType().- Returns:
- The converted type or null if conversion is not possible.
-