Class PropertyImpl.PropertyBuilderImpl
java.lang.Object
org.refcodes.struct.RelationImpl<String,String>
org.refcodes.struct.PropertyImpl
org.refcodes.struct.PropertyImpl.PropertyBuilderImpl
- All Implemented Interfaces:
KeyAccessor<String>, KeyAccessor.KeyBuilder<String, Relation.RelationBuilder<String,String>>, KeyAccessor.KeyMutator<String>, KeyAccessor.KeyProperty<String>, ValueAccessor<String>, ValueAccessor.ValueBuilder<String, Relation.RelationBuilder<String, String>>, ValueAccessor.ValueMutator<String>, ValueAccessor.ValueProperty<String>, Property, Property.PropertyBuilder, Relation<String, String>, Relation.RelationBuilder<String, String>
- Enclosing class:
PropertyImpl
public static class PropertyImpl.PropertyBuilderImpl
extends PropertyImpl
implements Property.PropertyBuilder
Implementation of the
Property.PropertyBuilder interface.-
Nested Class Summary
Nested classes/interfaces inherited from class PropertyImpl
PropertyImpl.PropertyBuilderImplNested classes/interfaces inherited from class RelationImpl
RelationImpl.RelationBuilderImpl<K,V> Nested classes/interfaces inherited from interface KeyAccessor
KeyAccessor.KeyBuilder<K,B>, KeyAccessor.KeyMutator<K>, KeyAccessor.KeyProperty<K> Nested classes/interfaces inherited from interface Property
Property.PropertyBuilderNested classes/interfaces inherited from interface Relation
Relation.RelationBuilder<K,V> Nested classes/interfaces inherited from interface ValueAccessor
ValueAccessor.ValueBuilder<V,B>, ValueAccessor.ValueMutator<V>, ValueAccessor.ValueProperty<V> -
Field Summary
Fields inherited from class RelationImpl
_key, _value -
Constructor Summary
ConstructorsConstructorDescriptionUse the builder methods or the bean attributes to set the key and the value.PropertyBuilderImpl(String aTupel) Initializes thePropertyImpl.PropertyBuilderImplwith the given values.PropertyBuilderImpl(String aTupel, char aTupelDelimeter) Initializes thePropertyImpl.PropertyBuilderImplwith the given values.PropertyBuilderImpl(String aKey, String aValue) Initializes thePropertyImpl.PropertyBuilderImplwith the given values. -
Method Summary
Methods inherited from class RelationImpl
getKey, getValueMethods inherited from class Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface KeyAccessor
getKeyMethods inherited from interface KeyAccessor.KeyProperty
letKeyMethods inherited from interface Property
toPropertyMethods inherited from interface Property.PropertyBuilder
withKey, withValueMethods inherited from interface ValueAccessor
getValue, getValueOr, hasValueMethods inherited from interface ValueAccessor.ValueProperty
letValue
-
Constructor Details
-
PropertyBuilderImpl
public PropertyBuilderImpl()Use the builder methods or the bean attributes to set the key and the value. -
PropertyBuilderImpl
Initializes thePropertyImpl.PropertyBuilderImplwith the given values.- Parameters:
aTupel- A tupel is a key and a value with the assignment operator "=" inbetween, e.g. "a=5" (the key would be a, the value would be 5).aTupelDelimeter- The delimiter to be used for dividing the key/value-pair.
-
PropertyBuilderImpl
Initializes thePropertyImpl.PropertyBuilderImplwith the given values.- Parameters:
aKey- The according key to set.aValue- The according value to set.
-
PropertyBuilderImpl
Initializes thePropertyImpl.PropertyBuilderImplwith the given values.- Parameters:
aTupel- A tupel is a key and a value with the assignment operator "=" inbetween, e.g. "a=5" (the key would be a, the value would be 5).
-
-
Method Details
-
toString
Description copied from class:RelationImpl- Overrides:
toStringin classRelationImpl<String,String>
-
setKey
Sets the key.- Specified by:
setKeyin interfaceKeyAccessor.KeyMutator<String>- Parameters:
aKey- the new key
-
setValue
Sets the value.- Specified by:
setValuein interfaceValueAccessor.ValueMutator<String>- Parameters:
aValue- the new value
-