- java.lang.Object
-
- org.refcodes.struct.RelationImpl<String,String>
-
- org.refcodes.struct.PropertyImpl
-
- org.refcodes.struct.PropertyImpl.PropertyBuilderImpl
-
- All Implemented Interfaces:
org.refcodes.mixin.KeyAccessor<String>,org.refcodes.mixin.KeyAccessor.KeyBuilder<String,Relation.RelationBuilder<String,String>>,org.refcodes.mixin.KeyAccessor.KeyMutator<String>,org.refcodes.mixin.KeyAccessor.KeyProperty<String>,org.refcodes.mixin.ValueAccessor<String>,org.refcodes.mixin.ValueAccessor.ValueBuilder<String,Relation.RelationBuilder<String,String>>,org.refcodes.mixin.ValueAccessor.ValueMutator<String>,org.refcodes.mixin.ValueAccessor.ValueProperty<String>,Property,Property.PropertyBuilder,Relation<String,String>,Relation.RelationBuilder<String,String>
- Enclosing class:
- PropertyImpl
public static class PropertyImpl.PropertyBuilderImpl extends PropertyImpl implements Property.PropertyBuilder
Implementation of theProperty.PropertyBuilderinterface.
-
-
Nested Class Summary
-
Nested classes/interfaces inherited from class org.refcodes.struct.PropertyImpl
PropertyImpl.PropertyBuilderImpl
-
Nested classes/interfaces inherited from class org.refcodes.struct.RelationImpl
RelationImpl.RelationBuilderImpl<K,V>
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.KeyAccessor
org.refcodes.mixin.KeyAccessor.KeyBuilder<K extends Object,B extends org.refcodes.mixin.KeyAccessor.KeyBuilder<K,B>>, org.refcodes.mixin.KeyAccessor.KeyMutator<K extends Object>, org.refcodes.mixin.KeyAccessor.KeyProperty<K extends Object>
-
Nested classes/interfaces inherited from interface org.refcodes.struct.Property
Property.PropertyBuilder
-
Nested classes/interfaces inherited from interface org.refcodes.struct.Relation
Relation.RelationBuilder<K,V>
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.ValueAccessor
org.refcodes.mixin.ValueAccessor.ValueBuilder<V extends Object,B extends org.refcodes.mixin.ValueAccessor.ValueBuilder<V,B>>, org.refcodes.mixin.ValueAccessor.ValueMutator<V extends Object>, org.refcodes.mixin.ValueAccessor.ValueProperty<V extends Object>
-
-
Field Summary
-
Fields inherited from class org.refcodes.struct.RelationImpl
_key, _value
-
-
Constructor Summary
Constructors Constructor Description PropertyBuilderImpl()Use the builder methods or the bean attributes to set the key and the value.PropertyBuilderImpl(String aTupel)Initializes thePropertyImpl.PropertyBuilderImplwith the given values.PropertyBuilderImpl(String aTupel, char aTupelDelimeter)Initializes thePropertyImpl.PropertyBuilderImplwith the given values.PropertyBuilderImpl(String aKey, String aValue)Initializes thePropertyImpl.PropertyBuilderImplwith the given values.
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description voidsetKey(String aKey)Sets the key.voidsetValue(String aValue)Sets the value.StringtoString()-
Methods inherited from class org.refcodes.struct.RelationImpl
getKey, getValue
-
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, wait
-
Methods inherited from interface org.refcodes.struct.Property
toProperty
-
Methods inherited from interface org.refcodes.struct.Property.PropertyBuilder
withKey, withValue
-
-
-
-
Constructor Detail
-
PropertyBuilderImpl
public PropertyBuilderImpl()
Use the builder methods or the bean attributes to set the key and the value.
-
PropertyBuilderImpl
public PropertyBuilderImpl(String aTupel, char aTupelDelimeter)
Initializes thePropertyImpl.PropertyBuilderImplwith the given values.- Parameters:
aTupel- A tupel is a key and a value with the assignment operator "=" inbetween, e.g. "a=5" (the key would be a, the value would be 5).aTupelDelimeter- The delimiter to be used for dividing the key/value-pair.
-
PropertyBuilderImpl
public PropertyBuilderImpl(String aKey, String aValue)
Initializes thePropertyImpl.PropertyBuilderImplwith the given values.- Parameters:
aKey- The according key to set.aValue- The according value to set.
-
PropertyBuilderImpl
public PropertyBuilderImpl(String aTupel)
Initializes thePropertyImpl.PropertyBuilderImplwith the given values.- Parameters:
aTupel- A tupel is a key and a value with the assignment operator "=" inbetween, e.g. "a=5" (the key would be a, the value would be 5).
-
-
Method Detail
-
toString
public String toString()
Description copied from class:RelationImpl- Overrides:
toStringin classRelationImpl<String,String>
-
setKey
public void setKey(String aKey)
Sets the key.- Specified by:
setKeyin interfaceorg.refcodes.mixin.KeyAccessor.KeyMutator<String>- Parameters:
aKey- the new key
-
-