Class Referencee<T>

java.lang.Object
org.refcodes.struct.Referencee<T>
Type Parameters:
T - The type of the referencee to be encapsulated by this Referencee.

public class Referencee<T> extends Object
A Referencee encapsulates a reference to an instance which might be null at the time of the referencee's creation. This way a reference to a non yet existing object can be provided.