Interface Table<K,V,B extends Table<K,V,B>>

Type Parameters:
K - the key type
V - The type of the value which relates to a key.
B - The builder to return in order to be able to apply multiple build operations.
All Superinterfaces:
org.refcodes.mixin.Clearable, Containable, org.refcodes.mixin.EmptyAccessor, ImmutableTable<K,V>, ImmutableTable.MutableTable<K,V>, Keys<K,V>, Keys.MutableKeys<K,V>, Keys.MutableValues<K,V>
All Known Subinterfaces:
CanonicalTable, ClassStructTable, InterOperableTable<T>, PathTable<T>, SimpleTypeTable
All Known Implementing Classes:
MapCanonicalTable, MapClassStructTable, MapPathTable, MapSimpleTypeTable

public interface Table<K,V,B extends Table<K,V,B>> extends ImmutableTable.MutableTable<K,V>
The Table type extends the ImmutableTable.MutableTable type and provides mutator as well as builder methods for manipulating the entries.
  • Method Details

    • withPut

      B withPut(K aKey, V aValue)
      Parameters:
      aKey - the key for the property to be put.
      aValue - the value for the property to be put.
      Returns:
      The implementing instance as of the builder pattern.
    • withPut

      B withPut(Relation<K,V> aRelation)
      Parameters:
      aRelation - the property to be put.
      Returns:
      The implementing instance as of the builder pattern.