Interface Table<K,V,B extends Table<K,V,B>>
- Type Parameters:
K- the key typeV- The type of the value which relates to a key.B- The builder to return in order to be able to apply multiple build operations.
- All Superinterfaces:
org.refcodes.mixin.Clearable,Containable,org.refcodes.mixin.EmptyAccessor,ImmutableTable<K,,V> ImmutableTable.MutableTable<K,,V> Keys<K,,V> Keys.MutableKeys<K,,V> Keys.MutableValues<K,V>
- All Known Subinterfaces:
CanonicalTable,ClassStructTable,InterOperableTable<T>,PathTable<T>,SimpleTypeTable
- All Known Implementing Classes:
MapCanonicalTable,MapClassStructTable,MapPathTable,MapSimpleTypeTable
The
Table type extends the ImmutableTable.MutableTable type and provides
mutator as well as builder methods for manipulating the entries.-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.mixin.EmptyAccessor
org.refcodes.mixin.EmptyAccessor.EmptyBuilder<B extends org.refcodes.mixin.EmptyAccessor.EmptyBuilder<B>>, org.refcodes.mixin.EmptyAccessor.EmptyMutator, org.refcodes.mixin.EmptyAccessor.EmptyPropertyNested classes/interfaces inherited from interface org.refcodes.struct.ImmutableTable
ImmutableTable.MutableTable<K,V> Nested classes/interfaces inherited from interface org.refcodes.struct.Keys
Keys.MutableKeys<K,V>, Keys.MutableValues<K, V> -
Method Summary
Methods inherited from interface org.refcodes.mixin.Clearable
clearMethods inherited from interface org.refcodes.struct.Containable
sizeMethods inherited from interface org.refcodes.mixin.EmptyAccessor
isEmptyMethods inherited from interface org.refcodes.struct.ImmutableTable.MutableTable
putMethods inherited from interface org.refcodes.struct.Keys
containsKey, containsValue, get, getOr, keySet, use, valuesMethods inherited from interface org.refcodes.struct.Keys.MutableKeys
deleteMethods inherited from interface org.refcodes.struct.Keys.MutableValues
put
-
Method Details
-
withPut
Builder method forKeys.MutableValues.put(Object, Object).- Parameters:
aKey- the key for the property to be put.aValue- the value for the property to be put.- Returns:
- The implementing instance as of the builder pattern.
-
withPut
Builder method forImmutableTable.MutableTable.put(Relation).- Parameters:
aRelation- the property to be put.- Returns:
- The implementing instance as of the builder pattern.
-