Uses of Interface
org.refcodes.struct.Dictionary
-
-
Uses of Dictionary in org.refcodes.struct
Subinterfaces of Dictionary in org.refcodes.struct Modifier and Type Interface Description interfaceCanonicalMapTheCanonicalMapis an "intermediate" type adding type and Data-Structure related functionality to any implementing class.static interfaceCanonicalMap.CanonicalMapBuilderThe Interface CanonicalMapBuilder.static interfaceCanonicalMap.MutableCanonicalMapThe Interface MutableCanonicalMap.interfaceClassStructMapTheClassStructMapdisects aClassinto its simple types (consideringStringandEnumtypes as well as primitive types).static interfaceClassStructMap.ClassStructMapBuilderThe Interface ClassStructMapBuilder.static interfaceClassStructMap.MutableClassStructMapThe Interface MutableClassStructMap.static interfaceDictionary.MutableDictionary<K,V>Extends theDictionarywith mutable (writable) functionality, especially by providingKeys.MutableValues.put(Object, Object)andKeys.MutableKeys.delete(String)methods.static interfaceDictionary.MutableDictionary.DictionaryBuilder<K,V,B extends Dictionary.MutableDictionary.DictionaryBuilder<K,V,B>>Provides a builder method for aRelationproperty returning the builder for applying multiple build operations.interfaceInterOperableMap<T>TheInterOperableMapprovides convenience accessor default methods for supporting primitive data types.static interfaceInterOperableMap.InterOperableMapBuilder<T>TheInterOperableMap.InterOperableMapBuilderprovides convenience accessor default methods for supporting primitive data types.static interfaceInterOperableMap.MutableInterOperableMap<T>TheInterOperableMap.InterOperableMapBuilderprovides convenience accessor default methods for supporting primitive data types.interfacePathMap<T>static interfacePathMap.MutablePathMap<T>ThePathMap.MutablePathMapadds mutable functionality to thePathMap.static interfacePathMap.PathMapBuilder<T>ThePathMap.PathMapBuilderadds builder functionality to thePathMap.MutablePathMap.interfaceSimpleTypeMapstatic interfaceSimpleTypeMap.MutableSimpleTypeMapTheSimpleTypeMap.MutableSimpleTypeMapadds functionality for manipulating the internal state to theSimpleTypeMap.static interfaceSimpleTypeMap.SimpleTypeMapBuilderASimpleTypeMap.SimpleTypeMapBuildersets builder functionality (as of the builder pattern) on top of theSimpleTypeMap.MutableSimpleTypeMap.Classes in org.refcodes.struct that implement Dictionary Modifier and Type Class Description classCanonicalMapBuilderImplThe Class CanonicalMapBuilderImpl.classCanonicalMapImplThe Class CanonicalMapImpl.classClassStructMapBuilderImplThe Class ClassStructBuilderImpl.classClassStructMapImplThe Class ClassStructMapImpl.classPathMapBuilderImpl<T>The Class PathMapBuilderImpl.classPathMapImpl<T>The Class PathMapImpl.classSimpleTypeMapBuilderImplAn implementation of theSimpleTypeMap.SimpleTypeMapBuilder.classSimpleTypeMapImplAn implementation of theSimpleTypeMap.
-