Uses of Interface
org.refcodes.struct.Dictionary.MutableDictionary.DictionaryBuilder
-
-
Uses of Dictionary.MutableDictionary.DictionaryBuilder in org.refcodes.struct
Classes in org.refcodes.struct with type parameters of type Dictionary.MutableDictionary.DictionaryBuilder Modifier and Type Interface Description static interfaceDictionary.MutableDictionary.DictionaryBuilder<K,V,B extends Dictionary.MutableDictionary.DictionaryBuilder<K,V,B>>Provides a builder method for aRelationproperty returning the builder for applying multiple build operations.Subinterfaces of Dictionary.MutableDictionary.DictionaryBuilder in org.refcodes.struct Modifier and Type Interface Description static interfaceCanonicalMap.CanonicalMapBuilderThe Interface CanonicalMapBuilder.static interfaceClassStructMap.ClassStructMapBuilderThe Interface ClassStructMapBuilder.static interfaceInterOperableMap.InterOperableMapBuilder<T>TheInterOperableMap.InterOperableMapBuilderprovides convenience accessor default methods for supporting primitive data types.static interfacePathMap.PathMapBuilder<T>ThePathMap.PathMapBuilderadds builder functionality to thePathMap.MutablePathMap.static interfaceSimpleTypeMap.SimpleTypeMapBuilderASimpleTypeMap.SimpleTypeMapBuildersets builder functionality (as of the builder pattern) on top of theSimpleTypeMap.MutableSimpleTypeMap.Classes in org.refcodes.struct that implement Dictionary.MutableDictionary.DictionaryBuilder Modifier and Type Class Description classCanonicalMapBuilderImplThe Class CanonicalMapBuilderImpl.classClassStructMapBuilderImplThe Class ClassStructBuilderImpl.classPathMapBuilderImpl<T>The Class PathMapBuilderImpl.classSimpleTypeMapBuilderImplAn implementation of theSimpleTypeMap.SimpleTypeMapBuilder.
-