Uses of Interface
org.refcodes.struct.Keys
-
Uses of Keys in org.refcodes.struct
Subinterfaces of Keys in org.refcodes.structModifier and TypeInterfaceDescriptioninterfaceTheCanonicalMapis an "intermediate" type adding type and Data-Structure related functionality to any implementing class.static interfaceThe Interface CanonicalMapBuilder.static interfaceThe Interface MutableCanonicalMap.interfaceTheClassStructMapdisects aClassinto its simple types (consideringStringandEnumtypes as well as primitive types).static interfaceThe Interface ClassStructMapBuilder.static interfaceThe Interface MutableClassStructMap.interfaceDictionary<K,V> Basic functionality being provided by anyDictionary(map) style class.static interfaceExtends theDictionarywith mutable (writable) functionality, ehttps://www.metacodes.proly by providingKeys.MutableValues.put(Object, Object)andKeys.MutableKeys.delete(String)methods.static interfaceDictionary.MutableDictionary.DictionaryBuilder<K,V, B extends Dictionary.MutableDictionary.DictionaryBuilder<K, V, B>> Provides a builder method for aRelationproperty returning the builder for applying multiple build operations.interfaceTheInterOperableMapprovides convenience accessor default methods for supporting primitive data types.static interfaceTheInterOperableMap.InterOperableMapBuilderprovides convenience accessor default methods for supporting primitive data types.static interfaceTheInterOperableMap.InterOperableMapBuilderprovides convenience accessor default methods for supporting primitive data types.static interfaceKeys.MutableKeys<K,V> Adds mutable functionality to theKeysinterface.static interfaceKeys.MutableValues<K,V> Mixin for mutable functionality accompanying theKeysinterface.interfacePathMap<T>static interfaceThePathMap.MutablePathMapadds mutable functionality to thePathMap.static interfaceThePathMap.PathMapBuilderadds builder functionality to thePathMap.MutablePathMap.interfacestatic interfaceTheSimpleTypeMap.MutableSimpleTypeMapadds functionality for manipulating the internal state to theSimpleTypeMap.static interfaceASimpleTypeMap.SimpleTypeMapBuildersets builder functionality (as of the builder pattern) on top of theSimpleTypeMap.MutableSimpleTypeMap.Classes in org.refcodes.struct that implement KeysModifier and TypeClassDescriptionclassThe Class CanonicalMapBuilderImpl.classThe Class CanonicalMapImpl.classThe Class ClassStructBuilderImpl.classThe Class ClassStructMapImpl.classThe Class PathMapBuilderImpl.classPathMapImpl<T>The Class PathMapImpl.classAn implementation of theSimpleTypeMap.SimpleTypeMapBuilder.classAn implementation of theSimpleTypeMap.