Uses of Interface
org.refcodes.struct.Keys.MutableValues
-
Uses of Keys.MutableValues in org.refcodes.struct
Subinterfaces of Keys.MutableValues in org.refcodes.structModifier and TypeInterfaceDescriptionstatic interfaceThe Interface CanonicalMapBuilder.static interfaceThe Interface MutableCanonicalMap.static interfaceThe Interface ClassStructMapBuilder.static interfaceThe Interface MutableClassStructMap.static interfaceTheInterOperableMap.InterOperableMapBuilderprovides convenience accessor default methods for supporting primitive data types.static interfaceTheInterOperableMap.InterOperableMapBuilderprovides convenience accessor default methods for supporting primitive data types.static interfaceThePathMap.MutablePathMapadds mutable functionality to thePathMap.static interfaceThePathMap.PathMapBuilderadds builder functionality to thePathMap.MutablePathMap.static interfaceTheSimpleTypeMap.MutableSimpleTypeMapadds functionality for manipulating the internal state to theSimpleTypeMap.static interfaceASimpleTypeMap.SimpleTypeMapBuildersets builder functionality (as of the builder pattern) on top of theSimpleTypeMap.MutableSimpleTypeMap.static interfaceExtends theTablewith mutable (writable) functionality, ehttps://www.metacodes.proly by providingput(Object, Object)andKeys.MutableKeys.delete(String)methods.static interfaceTable.TableDictionary.TableBuilder<K,V, B extends Table.TableDictionary.TableBuilder<K, V, B>> Provides a builder method for aRelationproperty returning the builder for applying multiple build operations.Classes in org.refcodes.struct that implement Keys.MutableValuesModifier and TypeClassDescriptionclassThe Class CanonicalMapBuilderImpl.classThe Class ClassStructBuilderImpl.classThePathMapBuilderImplclass implements thePathMap.PathMapBuilderinterface and provides a hookPathMapBuilderImpl.createBackingMap()method which may be overridden for providing anotherMaptype as backing map than the default one.classAn implementation of theSimpleTypeMap.SimpleTypeMapBuilder.