Uses of Interface
org.refcodes.struct.Relation
-
-
Uses of Relation in org.refcodes.struct
Subinterfaces of Relation in org.refcodes.struct Modifier and Type Interface Description interfaceAttributeInterface describing a bean's attribute with a key represented by aStringand the value being of any type.static interfaceAttribute.AttributeBuilderAdds builder functionality to anAttribute.interfacePropertystatic interfaceProperty.PropertyBuilderAdds builder functionality to aProperty.static interfaceRelation.RelationBuilder<K,V>Adds builder functionality to aRelation.Classes in org.refcodes.struct that implement Relation Modifier and Type Class Description classAttributeImplClass describing a beans's attribute.static classAttributeImpl.AttributeBuilderImplImplementation of theProperty.PropertyBuilderinterface.classPropertyImplImplementation of thePropertyinterface.static classPropertyImpl.PropertyBuilderImplImplementation of theProperty.PropertyBuilderinterface.classRelationImpl<K,V>Implementation of theRelationinterface.static classRelationImpl.RelationBuilderImpl<K,V>Implementation of theRelation.RelationBuilderinterface.Methods in org.refcodes.struct with parameters of type Relation Modifier and Type Method Description default StringCanonicalMap.MutableCanonicalMap. put(Relation<String,String> aRelation)Adds the given element related to the given key.default Class<?>ClassStructMap.MutableClassStructMap. put(Relation<String,Class<?>> aRelation)Adds the given element related to the given key.VDictionary.MutableDictionary. put(Relation<K,V> aRelation)Adds the given element related to the given key.default TPathMap.MutablePathMap. put(Relation<String,T> aRelation)Adds the given element related to the given key.default ObjectSimpleTypeMap.MutableSimpleTypeMap. put(Relation<String,Object> aRelation)Adds the given element related to the given key.default CanonicalMap.CanonicalMapBuilderCanonicalMap.CanonicalMapBuilder. withPut(Relation<String,String> aProperty)Builder method forDictionary.MutableDictionary.put(Relation).default ClassStructMap.ClassStructMapBuilderClassStructMap.ClassStructMapBuilder. withPut(Relation<String,Class<?>> aProperty)Builder method forDictionary.MutableDictionary.put(Relation).BDictionary.MutableDictionary.DictionaryBuilder. withPut(Relation<K,V> aRelation)Builder method forDictionary.MutableDictionary.put(Relation).default InterOperableMap.InterOperableMapBuilder<T>InterOperableMap.InterOperableMapBuilder. withPut(Relation<String,T> aProperty)Builder method forDictionary.MutableDictionary.put(Relation).default PathMap.PathMapBuilder<T>PathMap.PathMapBuilder. withPut(Relation<String,T> aRelation)Builder method forDictionary.MutableDictionary.put(Relation).default SimpleTypeMap.SimpleTypeMapBuilderSimpleTypeMap.SimpleTypeMapBuilder. withPut(Relation<String,Object> aProperty)Builder method forDictionary.MutableDictionary.put(Relation).
-