Module org.refcodes.struct
Package org.refcodes.struct
This artifact contains base definitions regarding collections being used
throughout the `REFCODES.ORG` artifacts; to unify management of various kinds
of collections.
Please note the PathMap, which's extension, the
HttpBodyMap (found in the refcodes-web artifact) is
used to represent dynamic data types produced e.g. by JavaScript
clients.
-
Interface Summary Interface Description Attribute Interface describing a bean's attribute with a key represented by aStringand the value being of any type.Attribute.AttributeBuilder Adds builder functionality to anAttribute.BooleanArrayAccessor Provides an accessor for a boolean array property.BooleanArrayAccessor.BooleanArrayBuilder<B extends BooleanArrayAccessor.BooleanArrayBuilder<B>> Provides a builder method for a boolean array property returning the builder for applying multiple build operations.BooleanArrayAccessor.BooleanArrayMutator Provides a mutator for a boolean array property.BooleanArrayAccessor.BooleanArrayProperty Provides a boolean array property.ByteArrayAccessor Provides an accessor for a byte array property.ByteArrayAccessor.ByteArrayBuilder<B extends ByteArrayAccessor.ByteArrayBuilder<B>> Provides a builder method for a byte array property returning the builder for applying multiple build operations.ByteArrayAccessor.ByteArrayMutator Provides a mutator for a byte array property.ByteArrayAccessor.ByteArrayProperty Provides a byte array property.CanonicalMap TheCanonicalMapis an "intermediate" type adding type and Data-Structure related functionality to any implementing class.CanonicalMap.CanonicalMapBuilder The Interface CanonicalMapBuilder.CanonicalMap.MutableCanonicalMap The Interface MutableCanonicalMap.ClassStructMap TheClassStructMapdisects aClassinto its simple types (consideringStringandEnumtypes as well as primitive types).ClassStructMap.ClassStructMapBuilder The Interface ClassStructMapBuilder.ClassStructMap.MutableClassStructMap The Interface MutableClassStructMap.Containable AContainableis the base functionality provided container (collection).Container<E> Basic functionality being provided by anyContainer(collection) style class.Container.ClearableContainer<E> Container.MutableContainer<E> Extends theContainerwith mutable (writable) functionality, especially by enabling theIterator.remove()method in theIteratorprovided viaElements.iterator().Dictionary<K,V> Basic functionality being provided by anyDictionary(map) style class.Dictionary.MutableDictionary<K,V> Extends theDictionarywith mutable (writable) functionality, especially by providingKeys.MutableValues.put(Object, Object)andKeys.MutableKeys.delete(String)methods.Dictionary.MutableDictionary.DictionaryBuilder<K,V,B extends Dictionary.MutableDictionary.DictionaryBuilder<K,V,B>> Provides a builder method for aRelationproperty returning the builder for applying multiple build operations.DoubleArrayAccessor Provides an accessor for a double array property.DoubleArrayAccessor.DoubleArrayBuilder<B extends DoubleArrayAccessor.DoubleArrayBuilder<B>> Provides a builder method for a double array property returning the builder for applying multiple build operations.DoubleArrayAccessor.DoubleArrayMutator Provides a mutator for a double array property.DoubleArrayAccessor.DoubleArrayProperty Provides a double array property.Elements<E> Basic functionality being provided by anyElements(collection) style class.Elements.ClearableElements<E> Elements.MutableElements<E> Extends theElementswith mutable (writable) functionality, especially by enabling theIterator.remove()method in theIteratorprovided viaElements.MutableElements.iterator()and by providing theElements.MutableElements.add(Object)and theElements.MutableElements.remove(Object)methods.FloatArrayAccessor Provides an accessor for a float array property.FloatArrayAccessor.FloatArrayBuilder<B extends FloatArrayAccessor.FloatArrayBuilder<B>> Provides a builder method for a float array property returning the builder for applying multiple build operations.FloatArrayAccessor.FloatArrayMutator Provides a mutator for a float array property.FloatArrayAccessor.FloatArrayProperty Provides a float array property.InterOperableMap<T> TheInterOperableMapprovides convenience accessor default methods for supporting primitive data types.InterOperableMap.InterOperableMapBuilder<T> TheInterOperableMap.InterOperableMapBuilderprovides convenience accessor default methods for supporting primitive data types.InterOperableMap.MutableInterOperableMap<T> TheInterOperableMap.InterOperableMapBuilderprovides convenience accessor default methods for supporting primitive data types.Keys<K,V> This interface provides functionality for working with keys.Keys.MutableKeys<K,V> Adds mutable functionality to theKeysinterface.Keys.MutableValues<K,V> Mixin for mutable functionality accompanying theKeysinterface.PathMap<T> PathMap.MutablePathMap<T> ThePathMap.MutablePathMapadds mutable functionality to thePathMap.PathMap.PathMapBuilder<T> ThePathMap.PathMapBuilderadds builder functionality to thePathMap.MutablePathMap.Property Property.PropertyBuilder Adds builder functionality to aProperty.Range<V extends Number & Comparable<V>> Interface describing a range with a minimum value and a maximum value.Range.RangeBuilder<V extends Number & Comparable<V>> Adds builder functionality to aRange.Relation<K,V> Provides an accessor for a key-to-value property useful in some occasions.Relation.RelationBuilder<K,V> Adds builder functionality to aRelation.ShortArrayAccessor Provides an accessor for a short array property.ShortArrayAccessor.ShortArrayBuilder<B extends ShortArrayAccessor.ShortArrayBuilder<B>> Provides a builder method for a short array property returning the builder for applying multiple build operations.ShortArrayAccessor.ShortArrayMutator Provides a mutator for a short array property.ShortArrayAccessor.ShortArrayProperty Provides a short array property.SimpleTypeMap SimpleTypeMap.MutableSimpleTypeMap TheSimpleTypeMap.MutableSimpleTypeMapadds functionality for manipulating the internal state to theSimpleTypeMap.SimpleTypeMap.SimpleTypeMapBuilder ASimpleTypeMap.SimpleTypeMapBuildersets builder functionality (as of the builder pattern) on top of theSimpleTypeMap.MutableSimpleTypeMap.StringArrayAccessor Provides an accessor for a String array property.StringArrayAccessor.StringArrayBuilder<B extends StringArrayAccessor.StringArrayBuilder<B>> Provides a builder method for a String array property returning the builder for applying multiple build operations.StringArrayAccessor.StringArrayMutator Provides a mutator for a String array property.StringArrayAccessor.StringArrayProperty Provides a String array property.TypeModeAccessor Provides an accessor for a type mode property.TypeModeAccessor.TypeModeBuilder<B extends TypeModeAccessor.TypeModeBuilder<B>> Provides a builder method for a type mode property returning the builder for applying multiple build operations.TypeModeAccessor.TypeModeMutator Provides a mutator for a type mode property.TypeModeAccessor.TypeModeProperty Provides a type mode property. -
Class Summary Class Description AttributeImpl Class describing a beans's attribute.AttributeImpl.AttributeBuilderImpl Implementation of theProperty.PropertyBuilderinterface.BoundedIterator<T> TheBoundedIteratordecorates anIteratorto limit its element to a maximum number.CanonicalMapBuilderImpl The Class CanonicalMapBuilderImpl.CanonicalMapImpl The Class CanonicalMapImpl.ClassStructMapBuilderImpl The Class ClassStructBuilderImpl.ClassStructMapImpl The Class ClassStructMapImpl.PathComparator Comparator for path elements, it takes care to sort index values correctly, e.g. "1000" must come after "9": The paths "/foo/bar/1000/wow" and "/foo/bar/9/wow" should be sorted as follows:"/foo/bar/9/wow" "/foo/bar/1000/wow"PathMapBuilderImpl<T> The Class PathMapBuilderImpl.PathMapImpl<T> The Class PathMapImpl.PropertyImpl Implementation of thePropertyinterface.PropertyImpl.PropertyBuilderImpl Implementation of theProperty.PropertyBuilderinterface.RangeImpl<V extends Number & Comparable<V>> Implementation of theRangeinterface.RangeImpl.RangeBuilderImpl<V extends Number & Comparable<V>> Implementation of theRange.RangeBuilderinterface.Referencee<T> AReferenceeencapsulates a reference to an instance which might be null at the time of the referencee's creation.RelationImpl<K,V> Implementation of theRelationinterface.RelationImpl.RelationBuilderImpl<K,V> Implementation of theRelation.RelationBuilderinterface.SimpleTypeMapBuilderImpl An implementation of theSimpleTypeMap.SimpleTypeMapBuilder.SimpleTypeMapImpl An implementation of theSimpleTypeMap.StructureUtility Utility class to avoid redundant code regarding variousPathMapimplementations.TypeUtility The Class TypeUtility. -
Enum Summary Enum Description PathSortStrategy ThePathSortStrategydefines strategies to use when sorting e.g. when using aPathComparatoror the methodPathMap.sortedKeys(PathSortStrategy)PrimitiveArrayType ThePrimitiveArrayTypeenumeration contains theClassrepresentation of the primitive array types.SimpleType -
Exception Summary Exception Description AmbigousKeyRuntimeException Thrown in case this instance does not contain the requested element (no such key found in the collection).KeyNotFoundException Thrown in case this instance does not contain the requested element (no such key found in the collection).KeyNotFoundRuntimeException Thrown in case this instance does not contain the requested element (no such key found in the collection).StructureException TheStructureExceptionis the base checked exception for this package.StructureRuntimeException TheStructureRuntimeExceptionis the base runtime exception for this package.