| Attribute |
Interface describing a bean's attribute with a key represented by a
String and the value being of any type.
|
| Attribute.AttributeBuilder |
|
| AttributeImpl |
Class describing a beans's attribute.
|
| BooleanArrayAccessor |
Provides an accessor for a boolean array property.
|
| BooleanArrayAccessor.BooleanArrayBuilder |
Provides a builder method for a boolean array property returning the
builder for applying multiple build operations.
|
| BooleanArrayAccessor.BooleanArrayMutator |
Provides a mutator for a boolean array property.
|
| ByteArrayAccessor |
Provides an accessor for a byte array property.
|
| ByteArrayAccessor.ByteArrayBuilder |
Provides a builder method for a byte array property returning the builder
for applying multiple build operations.
|
| ByteArrayAccessor.ByteArrayMutator |
Provides a mutator for a byte array property.
|
| CanonicalMap |
The CanonicalMap is an "intermediate" type adding type and
Data-Structure related functionality to any implementing class.
|
| CanonicalMap.CanonicalMapBuilder |
The Interface CanonicalMapBuilder.
|
| CanonicalMap.MutableCanonicalMap |
The Interface MutableCanonicalMap.
|
| ClassStructMap |
|
| ClassStructMap.ClassStructMapBuilder |
The Interface ClassStructMapBuilder.
|
| ClassStructMap.MutableClassStructMap |
The Interface MutableClassStructMap.
|
| Containable |
A Containable is the base functionality provided container
(collection).
|
| Container |
Basic functionality being provided by any Container (collection)
style class.
|
| Container.ClearableContainer |
Extends the Container interface with Clearable
functionality (as of Clearable.clear()).
|
| Dictionary |
Basic functionality being provided by any Dictionary (map) style
class.
|
| Dictionary.MutableDictionary |
|
| Dictionary.MutableDictionary.DictionaryBuilder |
Provides a builder method for a Relation property returning
the builder for applying multiple build operations.
|
| DoubleArrayAccessor |
Provides an accessor for a double array property.
|
| DoubleArrayAccessor.DoubleArrayBuilder |
Provides a builder method for a double array property returning the
builder for applying multiple build operations.
|
| DoubleArrayAccessor.DoubleArrayMutator |
Provides a mutator for a double array property.
|
| Elements |
Basic functionality being provided by any Elements (collection) style
class.
|
| Elements.ClearableElements |
Extends the Elements interface with Clearable
functionality (as of Clearable.clear()).
|
| Elements.MutableElements |
|
| FloatArrayAccessor |
Provides an accessor for a float array property.
|
| FloatArrayAccessor.FloatArrayBuilder |
Provides a builder method for a float array property returning the
builder for applying multiple build operations.
|
| FloatArrayAccessor.FloatArrayMutator |
Provides a mutator for a float array property.
|
| InterOperableMap |
The InterOperableMap provides convenience accessor default methods
for supporting primitive data types.
|
| InterOperableMap.InterOperableMapBuilder |
|
| InterOperableMap.MutableInterOperableMap |
|
| KeyNotFoundException |
Thrown in case this instance does not contain the requested element (no such
key found in the collection).
|
| Keys |
This interface provides functionality for working with keys.
|
| Keys.MutableKeys |
Adds mutable functionality to the Keys interface.
|
| Keys.MutableValues |
Mixin for mutable functionality accompanying the Keys interface.
|
| PathMap |
A PathMap is a flat map by which each element is addressed by a path;
represented by the PathMap's keys.
|
| PathMap.MutablePathMap |
|
| PathMap.PathMapBuilder |
|
| PathMapBuilderImpl |
The Class PathMapBuilderImpl.
|
| PathSortStrategy |
|
| PrimitiveArrayType |
|
| Property |
A Property is defined as being String representing a
property's key and a String representing the proprty's value.
|
| Property.PropertyBuilder |
Adds builder functionality to a Property.
|
| PropertyImpl |
Implementation of the Property interface.
|
| Range |
Interface describing a range with a minimum value and a maximum value.
|
| Range.RangeBuilder |
Adds builder functionality to a Range.
|
| RangeImpl |
Implementation of the Range interface.
|
| Relation |
Provides an accessor for a key-to-value property useful in some occasions.
|
| Relation.RelationBuilder |
Adds builder functionality to a Relation.
|
| RelationImpl |
Implementation of the Relation interface.
|
| ShortArrayAccessor |
Provides an accessor for a short array property.
|
| ShortArrayAccessor.ShortArrayBuilder |
Provides a builder method for a short array property returning the
builder for applying multiple build operations.
|
| ShortArrayAccessor.ShortArrayMutator |
Provides a mutator for a short array property.
|
| SimpleType |
The SimpleType enumeration provides functionality useful when working
wit Java's primitive types, their wrapper counterparts as well as with some
other crucial types such as String, Date, Enum,
Class or Locale types.
|
| SimpleTypeMap |
|
| SimpleTypeMap.MutableSimpleTypeMap |
|
| SimpleTypeMap.SimpleTypeMapBuilder |
|
| SimpleTypeMapBuilderImpl |
|
| StringArrayAccessor |
Provides an accessor for a String array property.
|
| StringArrayAccessor.StringArrayBuilder |
Provides a builder method for a String array property returning the
builder for applying multiple build operations.
|
| StringArrayAccessor.StringArrayMutator |
Provides a mutator for a String array property.
|
| StructureException |
|
| StructureRuntimeException |
|
| TypeModeAccessor |
Provides an accessor for a type mode property.
|
| TypeModeAccessor.TypeModeBuilder |
Provides a builder method for a type mode property returning the builder
for applying multiple build operations.
|
| TypeModeAccessor.TypeModeMutator |
Provides a mutator for a type mode property.
|