Interface describing a bean's attribute with a key represented by a
String and the value being of any type.
Class describing a beans's attribute.
Provides an accessor for a boolean array property.
Provides a builder method for a boolean array property returning the
builder for applying multiple build operations.
Provides a mutator for a boolean array property.
Provides an accessor for a byte array property.
Provides a builder method for a byte array property returning the builder
for applying multiple build operations.
Provides a mutator for a byte array property.
The
CanonicalMap is an "intermediate" type adding type and
Data-Structure related functionality to any implementing class.
The Interface CanonicalMapBuilder.
The Interface MutableCanonicalMap.
The Interface ClassStructMapBuilder.
The Interface MutableClassStructMap.
A
Containable is the base functionality provided container
(collection).
Basic functionality being provided by any
Container (collection)
style class.
Extends the
Container interface with
Clearable
functionality (as of
Clearable.clear()).
Basic functionality being provided by any
Dictionary (map) style
class.
Provides a builder method for a
Relation property returning
the builder for applying multiple build operations.
Provides an accessor for a double array property.
Provides a builder method for a double array property returning the
builder for applying multiple build operations.
Provides a mutator for a double array property.
Basic functionality being provided by any
Elements (collection) style
class.
Extends the
Elements interface with
Clearable
functionality (as of
Clearable.clear()).
Provides an accessor for a float array property.
Provides a builder method for a float array property returning the
builder for applying multiple build operations.
Provides a mutator for a float array property.
The
InterOperableMap provides convenience accessor default methods
for supporting primitive data types.
Thrown in case this instance does not contain the requested element (no such
key found in the collection).
This interface provides functionality for working with keys.
Adds mutable functionality to the
Keys interface.
Mixin for mutable functionality accompanying the
Keys interface.
A
PathMap is a flat map by which each element is addressed by a path;
represented by the
PathMap's keys.
The Class PathMapBuilderImpl.
A
Property is defined as being
String representing a
property's key and a
String representing the proprty's value.
Adds builder functionality to a
Property.
Implementation of the
Property interface.
Interface describing a range with a minimum value and a maximum value.
Adds builder functionality to a
Range.
Implementation of the
Range interface.
Provides an accessor for a key-to-value property useful in some occasions.
Adds builder functionality to a
Relation.
Implementation of the
Relation interface.
Provides an accessor for a short array property.
Provides a builder method for a short array property returning the
builder for applying multiple build operations.
Provides a mutator for a short array property.
The
SimpleType enumeration provides functionality useful when working
wit Java's primitive types, their wrapper counterparts as well as with some
other crucial types such as
String,
Date,
Enum,
Class or
Locale types.
Provides an accessor for a String array property.
Provides a builder method for a String array property returning the
builder for applying multiple build operations.
Provides a mutator for a String array property.
Provides an accessor for a type mode property.
Provides a builder method for a type mode property returning the builder
for applying multiple build operations.
Provides a mutator for a type mode property.